@@ -30,6 +30,7 @@ sys.meta_path.insert(
 # ##### NOTES ON IMPORT FORMAT
 # ########################
 #
+# ok
 # This file defines dagster's public API. Imports need to be structured/formatted so as to to ensure
 # that the broadest possible set of static analyzers understand Dagster's
 # public API as intended. The below guidelines ensure this is the case.
@@ -86,6 +87,7 @@ from dagster._config.config_type import (
 )
 from dagster._config.field import Field as Field
 from dagster._config.field_utils import (
+    EnvVar as EnvVar,
     Map as Map,
     Permissive as Permissive,
     Selector as Selector,
@@ -96,6 +98,16 @@ from dagster._config.source import (
     IntSource as IntSource,
     StringSource as StringSource,
 )
+from dagster._config.structured_config import (
+    Config as Config,
+    ConfigurableIOManager as ConfigurableIOManager,
+    ConfigurableIOManagerFactory as ConfigurableIOManagerFactory,
+    ConfigurableLegacyIOManagerAdapter as ConfigurableLegacyIOManagerAdapter,
+    ConfigurableLegacyResourceAdapter as ConfigurableLegacyResourceAdapter,
+    ConfigurableResource as ConfigurableResource,
+    PermissiveConfig as PermissiveConfig,
+    ResourceDependency as ResourceDependency,
+)
 from dagster._core.definitions.asset_in import AssetIn as AssetIn
 from dagster._core.definitions.asset_out import AssetOut as AssetOut
 from dagster._core.definitions.asset_reconciliation_sensor import (
@@ -109,8 +121,14 @@ from dagster._core.definitions.assets import AssetsDefinition as AssetsDefinitio
 from dagster._core.definitions.composition import PendingNodeInvocation as PendingNodeInvocation
 from dagster._core.definitions.config import ConfigMapping as ConfigMapping
 from dagster._core.definitions.configurable import configured as configured
+from dagster._core.definitions.data_version import (
+    DataProvenance as DataProvenance,
+    DataVersion as DataVersion,
+)
 from dagster._core.definitions.decorators.asset_decorator import (
     asset as asset,
+    graph_asset as graph_asset,
+    graph_multi_asset as graph_multi_asset,
     multi_asset as multi_asset,
 )
 from dagster._core.definitions.decorators.config_mapping_decorator import (
@@ -188,7 +206,6 @@ from dagster._core.definitions.logger_definition import (
     build_init_logger_context as build_init_logger_context,
     logger as logger,
 )
-from dagster._core.definitions.logical_version import LogicalVersion as LogicalVersion
 from dagster._core.definitions.materialize import (
     materialize as materialize,
     materialize_to_memory as materialize_to_memory,
@@ -239,7 +256,6 @@ from dagster._core.definitions.partition import (
     DynamicPartitionsDefinition as DynamicPartitionsDefinition,
     Partition as Partition,
     PartitionedConfig as PartitionedConfig,
-    PartitionScheduleDefinition as PartitionScheduleDefinition,
     PartitionsDefinition as PartitionsDefinition,
     StaticPartitionsDefinition as StaticPartitionsDefinition,
     dynamic_partitioned_config as dynamic_partitioned_config,
@@ -250,6 +266,7 @@ from dagster._core.definitions.partition_mapping import (
     AllPartitionMapping as AllPartitionMapping,
     IdentityPartitionMapping as IdentityPartitionMapping,
     LastPartitionMapping as LastPartitionMapping,
+    MultiToSingleDimensionPartitionMapping as MultiToSingleDimensionPartitionMapping,
     PartitionMapping as PartitionMapping,
     StaticPartitionMapping as StaticPartitionMapping,
 )
@@ -269,11 +286,15 @@ from dagster._core.definitions.repository_definition import (
     RepositoryData as RepositoryData,
     RepositoryDefinition as RepositoryDefinition,
 )
+from dagster._core.definitions.resource_annotation import (
+    Resource as Resource,
+)
 from dagster._core.definitions.resource_definition import (
     ResourceDefinition as ResourceDefinition,
     make_values_resource as make_values_resource,
     resource as resource,
 )
+from dagster._core.definitions.run_config import RunConfig as RunConfig
 from dagster._core.definitions.run_request import (
     RunRequest as RunRequest,
     SkipReason as SkipReason,
@@ -292,6 +313,11 @@ from dagster._core.definitions.schedule_definition import (
     ScheduleEvaluationContext as ScheduleEvaluationContext,
     build_schedule_context as build_schedule_context,
 )
+from dagster._core.definitions.selector import (
+    CodeLocationSelector as CodeLocationSelector,
+    JobSelector as JobSelector,
+    RepositorySelector as RepositorySelector,
+)
 from dagster._core.definitions.sensor_definition import (
     DefaultSensorStatus as DefaultSensorStatus,
     SensorDefinition as SensorDefinition,
@@ -410,12 +436,8 @@ from dagster._core.execution.validate_run_config import validate_run_config as v
 from dagster._core.execution.with_resources import with_resources as with_resources
 from dagster._core.executor.base import Executor as Executor
 from dagster._core.executor.init import InitExecutorContext as InitExecutorContext
-from dagster._core.host_representation.selector import (
-    CodeLocationSelector as CodeLocationSelector,
-    JobSelector as JobSelector,
-    RepositorySelector as RepositorySelector,
-)
 from dagster._core.instance import DagsterInstance as DagsterInstance
+from dagster._core.instance_for_test import instance_for_test as instance_for_test
 from dagster._core.launcher.default_run_launcher import DefaultRunLauncher as DefaultRunLauncher
 from dagster._core.log_manager import DagsterLogManager as DagsterLogManager
 from dagster._core.storage.asset_value_loader import AssetValueLoader as AssetValueLoader
@@ -455,7 +477,6 @@ from dagster._core.storage.root_input_manager import (
 )
 from dagster._core.storage.tags import MEMOIZED_RUN_TAG as MEMOIZED_RUN_TAG
 from dagster._core.storage.upath_io_manager import UPathIOManager as UPathIOManager
-from dagster._core.test_utils import instance_for_test as instance_for_test
 from dagster._core.types.config_schema import (
     DagsterTypeLoader as DagsterTypeLoader,
     dagster_type_loader as dagster_type_loader,
@@ -515,37 +536,26 @@ from dagster._utils.backcompat import deprecation_warning, rename_warning
 # in `_DEPRECATED` is required  for us to generate the deprecation warning.
 
 if TYPE_CHECKING:
-    from dagster._core.execution.context.system import (
-        DagsterTypeMaterializerContext as DagsterTypeMaterializerContext,
-    )
-    from dagster._core.types.config_schema import (
-        DagsterTypeMaterializer as DagsterTypeMaterializer,
-        dagster_type_materializer as dagster_type_materializer,
-    )
+    ##### EXAMPLE
+    # from dagster.some.module import (
+    #     Foo as Foo,
+    # )
+    pass
 
 
 _DEPRECATED: Final[Mapping[str, TypingTuple[str, str, str]]] = {
-    "dagster_type_materializer": (
-        "dagster._core.types.config_schema",
-        "1.1.0",
-        "Instead, use an IOManager.",
-    ),
-    "DagsterTypeMaterializer": (
-        "dagster._core.types.config_schema",
-        "1.1.0",
-        "Instead, use an IOManager.",
-    ),
-    "DagsterTypeMaterializerContext": (
-        "dagster._core.execution.context.system",
-        "1.1.0",
-        "Instead, use an IOManager.",
-    ),
+    ##### EXAMPLE
+    # "Foo": (
+    #     "dagster.some.module",
+    #     "1.1.0",  # breaking version
+    #     "Use Bar instead.",
+    # ),
 }
 
-# Example Deprecated Renamed Entry:
-#
-# "EventMetadataEntry": (MetadataEntry, "1.0.0"),
-_DEPRECATED_RENAMED: Final[Mapping[str, TypingTuple[Callable, str]]] = {}
+_DEPRECATED_RENAMED: Final[Mapping[str, TypingTuple[Callable, str]]] = {
+    ##### EXAMPLE
+    # "Foo": (Bar, "1.1.0"),
+}
 
 
 def __getattr__(name: str) -> TypingAny:
