@@ -68,7 +68,7 @@ def resolve_to_config_type(obj: object) -> Union[ConfigType, bool]:
                         )
                     )
 
-                if not key_type.kind == ConfigTypeKind.SCALAR:
+                if not key_type.kind == ConfigTypeKind.SCALAR:  # type: ignore
                     raise DagsterInvalidDefinitionError(
                         "Non-scalar key in map specification: {key} in map {collection}".format(
                             key=repr(key), collection=obj
@@ -123,9 +123,12 @@ def resolve_to_config_type(obj: object) -> Union[ConfigType, bool]:
         check.param_invariant(
             False,
             "dagster_type",
-            f"Cannot pass config type class {obj} to resolve_to_config_type. "
-            "This error usually occurs when you pass a dagster config type class instead of a class instance into "
-            'another dagster config type. E.g. "Noneable(Permissive)" should instead be "Noneable(Permissive())".',
+            (
+                f"Cannot pass config type class {obj} to resolve_to_config_type. This error usually"
+                " occurs when you pass a dagster config type class instead of a class instance into"
+                ' another dagster config type. E.g. "Noneable(Permissive)" should instead be'
+                ' "Noneable(Permissive())".'
+            ),
         )
 
     if isinstance(obj, type) and is_subclass(obj, DagsterType):
@@ -204,8 +207,8 @@ class Field:
 
     Config fields are parsed according to their schemas in order to yield values available at
     job execution time through the config system. Config fields can be set on ops, on
-    loaders and materializers for custom, and on other pluggable components of the system, such as
-    resources, loggers, and executors.
+    loaders for custom, and on other pluggable components of the system, such as resources, loggers,
+    and executors.
 
 
     Args:
@@ -255,17 +258,16 @@ class Field:
             A human-readable description of this config field.
 
     Examples:
+        .. code-block:: python
 
-    .. code-block:: python
-
-        @op(
-            config_schema={
-                'word': Field(str, description='I am a word.'),
-                'repeats': Field(Int, default_value=1, is_required=False),
-            }
-        )
-        def repeat_word(context):
-            return context.op_config['word'] * context.op_config['repeats']
+            @op(
+                config_schema={
+                    'word': Field(str, description='I am a word.'),
+                    'repeats': Field(Int, default_value=1, is_required=False),
+                }
+            )
+            def repeat_word(context):
+                return context.op_config['word'] * context.op_config['repeats']
     """
 
     def _resolve_config_arg(self, config):
@@ -321,7 +323,7 @@ class Field:
                         "into of a config enum type {name}. You must pass in the underlying "
                         "string represention as the default value. One of {value_set}."
                     ).format(
-                        value_set=[ev.config_value for ev in self.config_type.enum_values],  # type: ignore
+                        value_set=[ev.config_value for ev in self.config_type.enum_values],
                         name=self.config_type.given_name,
                     )
                 )
@@ -351,28 +353,28 @@ class Field:
                 self._default_value = evr.value
         self._is_required = is_required
 
-    @public  # type: ignore
+    @public
     @property
     def is_required(self) -> bool:
         return self._is_required
 
-    @public  # type: ignore
+    @public
     @property
     def default_provided(self) -> bool:
-        """Was a default value provided
+        """Was a default value provided.
 
         Returns:
             bool: Yes or no
         """
         return self._default_value != FIELD_NO_DEFAULT_PROVIDED
 
-    @public  # type: ignore
+    @public
     @property
     def default_value(self) -> Any:
         check.invariant(self.default_provided, "Asking for default value when none was provided")
         return self._default_value
 
-    @public  # type: ignore
+    @public
     @property
     def description(self) -> Optional[str]:
         return self._description
