@@ -66,7 +66,7 @@ def rebase_file(relative_path_in_file: str, file_path_resides_in: str) -> str:
 
 def load_python_file(python_file: str, working_directory: Optional[str]) -> ModuleType:
     """
-    Takes a path to a python file and returns a loaded module
+    Takes a path to a python file and returns a loaded module.
     """
     check.str_param(python_file, "python_file")
     check.opt_str_param(working_directory, "working_directory")
@@ -142,7 +142,7 @@ def load_python_module(
                 abs_working_directory = os.path.abspath(os.path.expanduser(working_directory))
                 raise DagsterImportError(
                     f"Encountered ImportError: `{msg}` while importing module {module_name}. "
-                    f"Local modules were resolved using the working "
+                    "Local modules were resolved using the working "
                     f"directory `{abs_working_directory}`. If another working directory should be "
                     "used, please explicitly specify the appropriate path using the `-d` or "
                     "`--working-directory` for CLI based targets or the `working_directory` "
@@ -151,7 +151,7 @@ def load_python_module(
             else:
                 raise DagsterImportError(
                     f"Encountered ImportError: `{msg}` while importing module {module_name}. "
-                    f"If relying on the working directory to resolve modules, please "
+                    "If relying on the working directory to resolve modules, please "
                     "explicitly specify the appropriate path using the `-d` or "
                     "`--working-directory` for CLI based targets or the `working_directory` "
                     "configuration option for workspace targets. "
