@@ -2,11 +2,13 @@ import functools
 from collections import deque
 from heapq import heapify, heappop, heappush
 from typing import (
+    TYPE_CHECKING,
     AbstractSet,
     Callable,
     Dict,
     Iterable,
     Iterator,
+    List,
     Mapping,
     NamedTuple,
     Optional,
@@ -20,27 +22,33 @@ import toposort
 
 import dagster._check as check
 from dagster._core.errors import DagsterInvalidInvocationError, DagsterInvariantViolationError
+from dagster._core.instance import DynamicPartitionsStore
 from dagster._core.selector.subset_selector import DependencyGraph, generate_asset_dep_graph
+from dagster._utils.cached_method import cached_method
 
 from .assets import AssetsDefinition
 from .events import AssetKey, AssetKeyPartitionKey
 from .freshness_policy import FreshnessPolicy
-from .partition import PartitionsDefinition
+from .partition import PartitionsDefinition, PartitionsSubset
 from .partition_mapping import PartitionMapping, infer_partition_mapping
 from .source_asset import SourceAsset
 from .time_window_partitions import TimeWindowPartitionsDefinition
 
+if TYPE_CHECKING:
+    from dagster._core.definitions.asset_graph_subset import AssetGraphSubset
+
 
 class AssetGraph:
     def __init__(
         self,
-        asset_dep_graph: DependencyGraph,
+        asset_dep_graph: DependencyGraph[AssetKey],
         source_asset_keys: AbstractSet[AssetKey],
         partitions_defs_by_key: Mapping[AssetKey, Optional[PartitionsDefinition]],
         partition_mappings_by_key: Mapping[AssetKey, Optional[Mapping[AssetKey, PartitionMapping]]],
         group_names_by_key: Mapping[AssetKey, Optional[str]],
         freshness_policies_by_key: Mapping[AssetKey, Optional[FreshnessPolicy]],
         required_multi_asset_sets_by_key: Optional[Mapping[AssetKey, AbstractSet[AssetKey]]],
+        code_versions_by_key: Mapping[AssetKey, Optional[str]],
     ):
         self._asset_dep_graph = asset_dep_graph
         self._source_asset_keys = source_asset_keys
@@ -49,17 +57,18 @@ class AssetGraph:
         self._group_names_by_key = group_names_by_key
         self._freshness_policies_by_key = freshness_policies_by_key
         self._required_multi_asset_sets_by_key = required_multi_asset_sets_by_key
+        self._code_versions_by_key = code_versions_by_key
 
     @property
-    def asset_dep_graph(self):
+    def asset_dep_graph(self) -> DependencyGraph[AssetKey]:
         return self._asset_dep_graph
 
     @property
-    def group_names_by_key(self):
+    def group_names_by_key(self) -> Mapping[AssetKey, Optional[str]]:
         return self._group_names_by_key
 
     @property
-    def source_asset_keys(self):
+    def source_asset_keys(self) -> AbstractSet[AssetKey]:
         return self._source_asset_keys
 
     @property
@@ -70,13 +79,15 @@ class AssetGraph:
         return AssetSelection.keys(*self.all_asset_keys).sources().resolve(self)
 
     @property
-    def freshness_policies_by_key(self):
+    def freshness_policies_by_key(self) -> Mapping[AssetKey, Optional[FreshnessPolicy]]:
         return self._freshness_policies_by_key
 
     @staticmethod
-    def from_assets(all_assets: Sequence[Union[AssetsDefinition, SourceAsset]]) -> "AssetGraph":
-        assets_defs = []
-        source_assets = []
+    def from_assets(
+        all_assets: Sequence[Union[AssetsDefinition, SourceAsset]]
+    ) -> "InternalAssetGraph":
+        assets_defs: List[AssetsDefinition] = []
+        source_assets: List[SourceAsset] = []
         partitions_defs_by_key: Dict[AssetKey, Optional[PartitionsDefinition]] = {}
         partition_mappings_by_key: Dict[
             AssetKey, Optional[Mapping[AssetKey, PartitionMapping]]
@@ -84,17 +95,17 @@ class AssetGraph:
         group_names_by_key: Dict[AssetKey, Optional[str]] = {}
         freshness_policies_by_key: Dict[AssetKey, Optional[FreshnessPolicy]] = {}
         required_multi_asset_sets_by_key: Dict[AssetKey, AbstractSet[AssetKey]] = {}
+        code_versions_by_key: Dict[AssetKey, Optional[str]] = {}
 
         for asset in all_assets:
             if isinstance(asset, SourceAsset):
                 source_assets.append(asset)
-            elif isinstance(asset, AssetsDefinition):
+                partitions_defs_by_key[asset.key] = asset.partitions_def
+                group_names_by_key[asset.key] = asset.group_name
+            else:  # AssetsDefinition
                 assets_defs.append(asset)
                 partition_mappings_by_key.update(
-                    {
-                        key: asset._partition_mappings  # pylint: disable=protected-access
-                        for key in asset.keys
-                    }
+                    {key: asset.partition_mappings for key in asset.keys}
                 )
                 partitions_defs_by_key.update({key: asset.partitions_def for key in asset.keys})
                 group_names_by_key.update(asset.group_names_by_key)
@@ -102,10 +113,9 @@ class AssetGraph:
                 if len(asset.keys) > 1 and not asset.can_subset:
                     for key in asset.keys:
                         required_multi_asset_sets_by_key[key] = asset.keys
+                code_versions_by_key.update(asset.code_versions_by_key)
 
-            else:
-                check.failed(f"Expected SourceAsset or AssetsDefinition, got {type(asset)}")
-        return AssetGraph(
+        return InternalAssetGraph(
             asset_dep_graph=generate_asset_dep_graph(assets_defs, source_assets),
             source_asset_keys={source_asset.key for source_asset in source_assets},
             partitions_defs_by_key=partitions_defs_by_key,
@@ -113,6 +123,9 @@ class AssetGraph:
             group_names_by_key=group_names_by_key,
             freshness_policies_by_key=freshness_policies_by_key,
             required_multi_asset_sets_by_key=required_multi_asset_sets_by_key,
+            assets=assets_defs,
+            source_assets=source_assets,
+            code_versions_by_key=code_versions_by_key,
         )
 
     @property
@@ -125,9 +138,12 @@ class AssetGraph:
     def get_partition_mapping(
         self, asset_key: AssetKey, in_asset_key: AssetKey
     ) -> PartitionMapping:
-        partitions_def = self.get_partitions_def(asset_key)
         partition_mappings = self._partition_mappings_by_key.get(asset_key) or {}
-        return infer_partition_mapping(partition_mappings.get(in_asset_key), partitions_def)
+        return infer_partition_mapping(
+            partition_mappings.get(in_asset_key),
+            self.get_partitions_def(asset_key),
+            self.get_partitions_def(in_asset_key),
+        )
 
     def is_partitioned(self, asset_key: AssetKey) -> bool:
         return self.get_partitions_def(asset_key) is not None
@@ -136,6 +152,17 @@ class AssetGraph:
         """Returns whether the given assets have the same partitions definition."""
         return self.get_partitions_def(asset_key1) == self.get_partitions_def(asset_key2)
 
+    def have_same_or_no_partitioning(self, asset_keys: Iterable[AssetKey]) -> bool:
+        partitions_defs = []
+        for asset_key in asset_keys:
+            partitions_def = self.get_partitions_def(asset_key)
+            if partitions_def:
+                partitions_defs.append(partitions_def)
+
+        return len(partitions_defs) <= 1 or all(
+            partitions_defs[i] == partitions_defs[0] for i in range(1, len(partitions_defs))
+        )
+
     def get_children(self, asset_key: AssetKey) -> AbstractSet[AssetKey]:
         """Returns all assets that depend on the given asset."""
         return self._asset_dep_graph["downstream"][asset_key]
@@ -145,17 +172,20 @@ class AssetGraph:
         return self._asset_dep_graph["upstream"][asset_key]
 
     def get_children_partitions(
-        self, asset_key: AssetKey, partition_key: Optional[str] = None
+        self,
+        dynamic_partitions_store: DynamicPartitionsStore,
+        asset_key: AssetKey,
+        partition_key: Optional[str] = None,
     ) -> AbstractSet[AssetKeyPartitionKey]:
         """
         Returns every partition in every of the given asset's children that depends on the given
         partition of that asset.
         """
-        result = set()
+        result: Set[AssetKeyPartitionKey] = set()
         for child_asset_key in self.get_children(asset_key):
             if self.is_partitioned(child_asset_key):
                 for child_partition_key in self.get_child_partition_keys_of_parent(
-                    partition_key, asset_key, child_asset_key
+                    dynamic_partitions_store, partition_key, asset_key, child_asset_key
                 ):
                     result.add(AssetKeyPartitionKey(child_asset_key, child_partition_key))
             else:
@@ -164,6 +194,7 @@ class AssetGraph:
 
     def get_child_partition_keys_of_parent(
         self,
+        dynamic_partitions_store: DynamicPartitionsStore,
         parent_partition_key: Optional[str],
         parent_asset_key: AssetKey,
         child_asset_key: AssetKey,
@@ -190,7 +221,9 @@ class AssetGraph:
                 f"Asset key {child_asset_key} is not partitioned. Cannot get partition keys."
             )
         if parent_partition_key is None:
-            return child_partitions_def.get_partition_keys()
+            return child_partitions_def.get_partition_keys(
+                dynamic_partitions_store=dynamic_partitions_store
+            )
 
         if parent_partitions_def is None:
             raise DagsterInvalidInvocationError(
@@ -201,22 +234,29 @@ class AssetGraph:
         child_partitions_subset = partition_mapping.get_downstream_partitions_for_partitions(
             parent_partitions_def.empty_subset().with_partition_keys([parent_partition_key]),
             downstream_partitions_def=child_partitions_def,
+            dynamic_partitions_store=dynamic_partitions_store,
         )
 
         return list(child_partitions_subset.get_partition_keys())
 
     def get_parents_partitions(
-        self, asset_key: AssetKey, partition_key: Optional[str] = None
+        self,
+        dynamic_partitions_store: DynamicPartitionsStore,
+        asset_key: AssetKey,
+        partition_key: Optional[str] = None,
     ) -> AbstractSet[AssetKeyPartitionKey]:
         """
         Returns every partition in every of the given asset's parents that the given partition of
         that asset depends on.
         """
-        result = set()
+        result: Set[AssetKeyPartitionKey] = set()
         for parent_asset_key in self.get_parents(asset_key):
             if self.is_partitioned(parent_asset_key):
                 for parent_partition_key in self.get_parent_partition_keys_for_child(
-                    partition_key, parent_asset_key, asset_key
+                    partition_key,
+                    parent_asset_key,
+                    asset_key,
+                    dynamic_partitions_store=dynamic_partitions_store,
                 ):
                     result.add(AssetKeyPartitionKey(parent_asset_key, parent_partition_key))
             else:
@@ -224,7 +264,11 @@ class AssetGraph:
         return result
 
     def get_parent_partition_keys_for_child(
-        self, partition_key: Optional[str], parent_asset_key: AssetKey, child_asset_key: AssetKey
+        self,
+        partition_key: Optional[str],
+        parent_asset_key: AssetKey,
+        child_asset_key: AssetKey,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Sequence[str]:
         """
         Converts a partition key from one asset to the corresponding partition keys in one of its
@@ -259,6 +303,7 @@ class AssetGraph:
             if partition_key
             else None,
             upstream_partitions_def=parent_partitions_def,
+            dynamic_partitions_store=dynamic_partitions_store,
         )
         return list(parent_partition_key_subset.get_partition_keys())
 
@@ -311,6 +356,10 @@ class AssetGraph:
             return self._required_multi_asset_sets_by_key[asset_key]
         return set()
 
+    def get_code_version(self, asset_key: AssetKey) -> Optional[str]:
+        return self._code_versions_by_key[asset_key]
+
+    @cached_method
     def toposort_asset_keys(self) -> Sequence[AbstractSet[AssetKey]]:
         return [
             {key for key in level} for level in toposort.toposort(self._asset_dep_graph["upstream"])
@@ -319,8 +368,85 @@ class AssetGraph:
     def has_self_dependency(self, asset_key: AssetKey) -> bool:
         return asset_key in self.get_parents(asset_key)
 
+    def bfs_filter_subsets(
+        self,
+        dynamic_partitions_store: DynamicPartitionsStore,
+        condition_fn: Callable[[AssetKey, Optional[PartitionsSubset]], bool],
+        initial_subset: "AssetGraphSubset",
+    ) -> "AssetGraphSubset":
+        """
+        Returns asset partitions within the graph that
+        - Are >= initial_asset_partitions
+        - Asset matches the condition_fn
+        - Any of their ancestors >= initial_asset_partitions match the condition_fn
+
+        Visits parents before children.
+        """
+        from .asset_graph_subset import AssetGraphSubset
+
+        all_assets = set(initial_subset.asset_keys)
+        check.invariant(
+            len(initial_subset.asset_keys) == 1, "Multiple initial assets not yet supported"
+        )
+        initial_asset_key = next(iter(initial_subset.asset_keys))
+        queue = deque([initial_asset_key])
+
+        queued_subsets_by_asset_key: Dict[AssetKey, Optional[PartitionsSubset]] = {
+            initial_asset_key: initial_subset.get_partitions_subset(initial_asset_key)
+            if self.get_partitions_def(initial_asset_key)
+            else None,
+        }
+        result = AssetGraphSubset(self)
+
+        while len(queue) > 0:
+            asset_key = queue.popleft()
+            partitions_subset = queued_subsets_by_asset_key.get(asset_key)
+
+            if condition_fn(asset_key, partitions_subset):
+                result |= AssetGraphSubset(
+                    self,
+                    non_partitioned_asset_keys={asset_key} if partitions_subset is None else set(),
+                    partitions_subsets_by_asset_key={asset_key: partitions_subset}
+                    if partitions_subset is not None
+                    else {},
+                )
+
+                for child in self.get_children(asset_key):
+                    partition_mapping = self.get_partition_mapping(child, asset_key)
+                    child_partitions_def = self.get_partitions_def(child)
+
+                    if child_partitions_def:
+                        if partitions_subset is None:
+                            child_partitions_subset = (
+                                child_partitions_def.subset_with_all_partitions()
+                            )
+                            queued_subsets_by_asset_key[child] = child_partitions_subset
+                        else:
+                            child_partitions_subset = (
+                                partition_mapping.get_downstream_partitions_for_partitions(
+                                    partitions_subset,
+                                    downstream_partitions_def=child_partitions_def,
+                                    dynamic_partitions_store=dynamic_partitions_store,
+                                )
+                            )
+                            prior_child_partitions_subset = queued_subsets_by_asset_key.get(child)
+                            queued_subsets_by_asset_key[child] = (
+                                child_partitions_subset
+                                if not prior_child_partitions_subset
+                                else child_partitions_subset | prior_child_partitions_subset
+                            )
+                    else:
+                        child_partitions_subset = None
+
+                    if child not in all_assets:
+                        queue.append(child)
+                        all_assets.add(child)
+
+        return result
+
     def bfs_filter_asset_partitions(
         self,
+        dynamic_partitions_store: DynamicPartitionsStore,
         condition_fn: Callable[
             [Iterable[AssetKeyPartitionKey], AbstractSet[AssetKeyPartitionKey]], bool
         ],
@@ -330,7 +456,8 @@ class AssetGraph:
         Returns asset partitions within the graph that
         - Are >= initial_asset_partitions
         - Match the condition_fn
-        - All of their ancestors >= initial_asset_partitions match the condition_fn
+        - Any of their ancestors >= initial_asset_partitions match the condition_fn
+
         Visits parents before children.
 
         When asset partitions are part of the same non-subsettable multi-asset, they're provided all
@@ -351,7 +478,7 @@ class AssetGraph:
 
                 for candidate in candidates_unit:
                     for child in self.get_children_partitions(
-                        candidate.asset_key, candidate.partition_key
+                        dynamic_partitions_store, candidate.asset_key, candidate.partition_key
                     ):
                         if child not in all_nodes:
                             queue.enqueue(child)
@@ -359,13 +486,49 @@ class AssetGraph:
 
         return result
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return id(self)
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         return self is other
 
 
+class InternalAssetGraph(AssetGraph):
+    def __init__(
+        self,
+        asset_dep_graph: DependencyGraph[AssetKey],
+        source_asset_keys: AbstractSet[AssetKey],
+        partitions_defs_by_key: Mapping[AssetKey, Optional[PartitionsDefinition]],
+        partition_mappings_by_key: Mapping[AssetKey, Optional[Mapping[AssetKey, PartitionMapping]]],
+        group_names_by_key: Mapping[AssetKey, Optional[str]],
+        freshness_policies_by_key: Mapping[AssetKey, Optional[FreshnessPolicy]],
+        required_multi_asset_sets_by_key: Optional[Mapping[AssetKey, AbstractSet[AssetKey]]],
+        assets: Sequence[AssetsDefinition],
+        source_assets: Sequence[SourceAsset],
+        code_versions_by_key: Mapping[AssetKey, Optional[str]],
+    ):
+        super().__init__(
+            asset_dep_graph=asset_dep_graph,
+            source_asset_keys=source_asset_keys,
+            partitions_defs_by_key=partitions_defs_by_key,
+            partition_mappings_by_key=partition_mappings_by_key,
+            group_names_by_key=group_names_by_key,
+            freshness_policies_by_key=freshness_policies_by_key,
+            required_multi_asset_sets_by_key=required_multi_asset_sets_by_key,
+            code_versions_by_key=code_versions_by_key,
+        )
+        self._assets = assets
+        self._source_assets = source_assets
+
+    @property
+    def assets(self) -> Sequence[AssetsDefinition]:
+        return self._assets
+
+    @property
+    def source_assets(self) -> Sequence[SourceAsset]:
+        return self._source_assets
+
+
 class ToposortedPriorityQueue:
     """Queue that returns parents before their children"""
 
@@ -375,15 +538,23 @@ class ToposortedPriorityQueue:
         partition_sort_key: Optional[float]
         multi_asset_partition: Iterable[AssetKeyPartitionKey]
 
-        def __eq__(self, other):
-            return self.level == other.level and self.partition_sort_key == other.partition_sort_key
+        def __eq__(self, other: object) -> bool:
+            if isinstance(other, ToposortedPriorityQueue.QueueItem):
+                return (
+                    self.level == other.level
+                    and self.partition_sort_key == other.partition_sort_key
+                )
+            return False
 
-        def __lt__(self, other):
-            return self.level < other.level or (
-                self.level == other.level
-                and self.partition_sort_key is not None
-                and self.partition_sort_key < other.partition_sort_key
-            )
+        def __lt__(self, other: object) -> bool:
+            if isinstance(other, ToposortedPriorityQueue.QueueItem):
+                return self.level < other.level or (
+                    self.level == other.level
+                    and self.partition_sort_key is not None
+                    and other.partition_sort_key is not None
+                    and self.partition_sort_key < other.partition_sort_key
+                )
+            raise TypeError()
 
     def __init__(self, asset_graph: AssetGraph, items: Iterable[AssetKeyPartitionKey]):
         self._asset_graph = asset_graph
@@ -402,7 +573,9 @@ class ToposortedPriorityQueue:
     def dequeue(self) -> Iterable[AssetKeyPartitionKey]:
         return heappop(self._heap).multi_asset_partition
 
-    def _queue_item(self, asset_partition: AssetKeyPartitionKey):
+    def _queue_item(
+        self, asset_partition: AssetKeyPartitionKey
+    ) -> "ToposortedPriorityQueue.QueueItem":
         asset_key = asset_partition.asset_key
 
         required_multi_asset_keys = self._asset_graph.get_required_multi_asset_keys(asset_key) | {
@@ -417,11 +590,9 @@ class ToposortedPriorityQueue:
             if partitions_def is not None and isinstance(
                 partitions_def, TimeWindowPartitionsDefinition
             ):
-                partition_sort_key = (
-                    cast(TimeWindowPartitionsDefinition, partitions_def)
-                    .time_window_for_partition_key(cast(str, asset_partition.partition_key))
-                    .start.timestamp()
-                )
+                partition_sort_key = partitions_def.time_window_for_partition_key(
+                    cast(str, asset_partition.partition_key)
+                ).start.timestamp()
             else:
                 check.failed("Assets with self-dependencies must have time-window partitions")
         else:
