@@ -24,7 +24,7 @@ from dagster._core.errors import (
     DagsterUnmetExecutorRequirementsError,
 )
 from dagster._core.selector.subset_selector import AssetSelectionData
-from dagster._utils import merge_dicts
+from dagster._utils.merger import merge_dicts
 
 from .asset_layer import build_asset_selection_job
 from .assets import AssetsDefinition
@@ -65,7 +65,6 @@ class AssetGroup:
             use when re-materializing assets in this group.
 
     Examples:
-
         .. code-block:: python
 
             from dagster import AssetGroup, asset, AssetIn, AssetKey, SourceAsset, resource
@@ -140,7 +139,7 @@ class AssetGroup:
     def build_job(
         self,
         name: str,
-        selection: Optional[Union[str, Sequence[str]]] = None,
+        selection: Optional[Union[str, Sequence[str]]] = "*",
         executor_def: Optional[ExecutorDefinition] = None,
         tags: Optional[Mapping[str, Any]] = None,
         description: Optional[str] = None,
@@ -169,7 +168,6 @@ class AssetGroup:
             description (Optional[str]): A description of the job.
 
         Examples:
-
             .. code-block:: python
 
                 from dagster import AssetGroup
@@ -182,7 +180,6 @@ class AssetGroup:
 
                 job_with_multiple_selections = the_asset_group.build_job(selection=["*some_asset", "other_asset++"])
         """
-
         from dagster._core.selector.subset_selector import parse_asset_selection
 
         check.str_param(name, "name")
@@ -354,7 +351,7 @@ class AssetGroup:
 
     def materialize(
         self,
-        selection: Optional[Union[str, Sequence[str]]] = None,
+        selection: Optional[Union[str, Sequence[str]]] = "*",
         run_config: Optional[Any] = None,
     ) -> "ExecuteInProcessResult":
         """
@@ -489,13 +486,13 @@ def _validate_resource_reqs_for_asset_group(
         present_resource_keys = present_resource_keys.union(provided_resource_keys)
 
         required_resource_keys: Set[str] = set()
-        for op_def in asset_def.node_def.iterate_solid_defs():
+        for op_def in asset_def.node_def.iterate_op_defs():
             required_resource_keys.update(set(op_def.required_resource_keys or {}))
         missing_resource_keys = list(set(required_resource_keys) - present_resource_keys)
         if missing_resource_keys:
             raise DagsterInvalidDefinitionError(
-                f"AssetGroup is missing required resource keys for asset '{asset_def.node_def.name}'. "
-                f"Missing resource keys: {missing_resource_keys}"
+                "AssetGroup is missing required resource keys for asset"
+                f" '{asset_def.node_def.name}'. Missing resource keys: {missing_resource_keys}"
             )
 
         for output_name, asset_key in asset_def.keys_by_output_name.items():
@@ -504,9 +501,9 @@ def _validate_resource_reqs_for_asset_group(
             )
             if output_def.io_manager_key and output_def.io_manager_key not in present_resource_keys:
                 raise DagsterInvalidDefinitionError(
-                    f"Output '{output_def.name}' with AssetKey '{asset_key}' "
-                    f"requires io manager '{output_def.io_manager_key}' but was "
-                    f"not provided on asset group. Provided resources: {sorted(list(present_resource_keys))}"
+                    f"Output '{output_def.name}' with AssetKey '{asset_key}' requires io manager"
+                    f" '{output_def.io_manager_key}' but was not provided on asset group. Provided"
+                    f" resources: {sorted(list(present_resource_keys))}"
                 )
 
     for source_asset in source_assets:
