@@ -7,6 +7,7 @@ from typing import (
     Dict,
     Iterable,
     Iterator,
+    List,
     Mapping,
     Optional,
     Sequence,
@@ -19,22 +20,21 @@ import dagster._check as check
 from dagster._annotations import public
 from dagster._core.decorator_utils import get_function_params
 from dagster._core.definitions.asset_layer import get_dep_node_handles_of_graph_backed_asset
-from dagster._core.definitions.events import AssetKey
 from dagster._core.definitions.freshness_policy import FreshnessPolicy
 from dagster._core.definitions.metadata import MetadataUserInput
-from dagster._core.definitions.partition import PartitionsDefinition
 from dagster._core.definitions.time_window_partition_mapping import TimeWindowPartitionMapping
-from dagster._core.definitions.utils import DEFAULT_GROUP_NAME, validate_group_name
+from dagster._core.definitions.time_window_partitions import TimeWindowPartitionsDefinition
 from dagster._core.errors import DagsterInvalidDefinitionError, DagsterInvalidInvocationError
-from dagster._utils import merge_dicts
+from dagster._core.selector.subset_selector import SelectionTree
 from dagster._utils.backcompat import (
     ExperimentalWarning,
     deprecation_warning,
     experimental_arg_warning,
 )
+from dagster._utils.merger import merge_dicts
 
 from .dependency import NodeHandle
-from .events import AssetKey, CoercibleToAssetKeyPrefix
+from .events import AssetKey, CoercibleToAssetKey, CoercibleToAssetKeyPrefix
 from .node_definition import NodeDefinition
 from .op_definition import OpDefinition
 from .partition import PartitionsDefinition
@@ -86,6 +86,7 @@ class AssetsDefinition(ResourceAddable):
     _metadata_by_key: Mapping[AssetKey, MetadataUserInput]
     _freshness_policies_by_key: Mapping[AssetKey, FreshnessPolicy]
     _code_versions_by_key: Mapping[AssetKey, Optional[str]]
+    _descriptions_by_key: Mapping[AssetKey, str]
 
     def __init__(
         self,
@@ -102,6 +103,7 @@ class AssetsDefinition(ResourceAddable):
         group_names_by_key: Optional[Mapping[AssetKey, str]] = None,
         metadata_by_key: Optional[Mapping[AssetKey, MetadataUserInput]] = None,
         freshness_policies_by_key: Optional[Mapping[AssetKey, FreshnessPolicy]] = None,
+        descriptions_by_key: Optional[Mapping[AssetKey, str]] = None,
         # if adding new fields, make sure to handle them in the with_prefix_or_group
         # and from_graph methods
     ):
@@ -148,10 +150,12 @@ class AssetsDefinition(ResourceAddable):
         }
         check.invariant(
             set(self._asset_deps.keys()) == all_asset_keys,
-            "The set of asset keys with dependencies specified in the asset_deps argument must "
-            "equal the set of asset keys produced by this AssetsDefinition. \n"
-            f"asset_deps keys: {set(self._asset_deps.keys())} \n"
-            f"expected keys: {all_asset_keys}",
+            (
+                "The set of asset keys with dependencies specified in the asset_deps argument must "
+                "equal the set of asset keys produced by this AssetsDefinition. \n"
+                f"asset_deps keys: {set(self._asset_deps.keys())} \n"
+                f"expected keys: {all_asset_keys}"
+            ),
         )
         self._resource_defs = check.opt_mapping_param(resource_defs, "resource_defs")
 
@@ -178,19 +182,37 @@ class AssetsDefinition(ResourceAddable):
                 metadata_by_key, "metadata_by_key", key_type=AssetKey, value_type=dict
             )
         )
+        self._descriptions_by_key = dict(
+            check.opt_mapping_param(
+                descriptions_by_key, "descriptions_by_key", key_type=AssetKey, value_type=str
+            )
+        )
         for output_name, asset_key in keys_by_output_name.items():
             output_def, _ = node_def.resolve_output_to_origin(output_name, None)
             self._metadata_by_key[asset_key] = merge_dicts(
                 output_def.metadata,
                 self._metadata_by_key.get(asset_key, {}),
             )
+            description = (
+                self._descriptions_by_key.get(asset_key, output_def.description)
+                or node_def.description
+            )
+            if description:
+                self._descriptions_by_key[asset_key] = description
             self._code_versions_by_key[asset_key] = output_def.code_version
 
         for key, freshness_policy in (freshness_policies_by_key or {}).items():
             check.param_invariant(
-                not (freshness_policy and self._partitions_def),
+                not (
+                    freshness_policy
+                    and self._partitions_def is not None
+                    and not isinstance(self._partitions_def, TimeWindowPartitionsDefinition)
+                ),
                 "freshness_policies_by_key",
-                "FreshnessPolicies are currently unsupported for partitioned assets.",
+                (
+                    "FreshnessPolicies are currently unsupported for assets with partitions of type"
+                    f" {type(self._partitions_def)}."
+                ),
             )
 
         self._freshness_policies_by_key = check.opt_mapping_param(
@@ -207,7 +229,7 @@ class AssetsDefinition(ResourceAddable):
         )
 
     def __call__(self, *args: object, **kwargs: object) -> object:
-        from dagster._core.definitions.decorators.solid_decorator import DecoratedOpFunction
+        from dagster._core.definitions.decorators.op_decorator import DecoratedOpFunction
         from dagster._core.execution.context.compute import OpExecutionContext
 
         from .graph_definition import GraphDefinition
@@ -249,7 +271,9 @@ class AssetsDefinition(ResourceAddable):
         resource_defs: Optional[Mapping[str, ResourceDefinition]] = None,
         partition_mappings: Optional[Mapping[str, PartitionMapping]] = None,
         metadata_by_output_name: Optional[Mapping[str, MetadataUserInput]] = None,
+        freshness_policies_by_output_name: Optional[Mapping[str, FreshnessPolicy]] = None,
         can_subset: bool = False,
+        descriptions_by_output_name: Optional[Mapping[str, str]] = None,
     ) -> "AssetsDefinition":
         """
         Constructs an AssetsDefinition from a GraphDefinition.
@@ -289,6 +313,12 @@ class AssetsDefinition(ResourceAddable):
                 be associated with each of the output assets for this node. Keys are names of the
                 outputs, and values are dictionaries of metadata to be associated with the related
                 asset.
+            freshness_policies_by_output_name_ouptut_name (Optional[Mapping[str, FreshnessPolicy]]): Defines a
+                FreshnessPolicy to be associated with some or all of the output assets for this node.
+                Keys are the names of the outputs, and values are the FreshnessPolicies to be attached
+                to the associated asset.
+            descriptions_by_output_name (Optional[Mapping[str, str]]): Defines a description to be
+                associated with each of the output asstes for this graph.
         """
         if resource_defs is not None:
             experimental_arg_warning("resource_defs", "AssetsDefinition.from_graph")
@@ -302,8 +332,10 @@ class AssetsDefinition(ResourceAddable):
             resource_defs=resource_defs,
             partition_mappings=partition_mappings,
             metadata_by_output_name=metadata_by_output_name,
+            freshness_policies_by_output_name=freshness_policies_by_output_name,
             key_prefix=key_prefix,
             can_subset=can_subset,
+            descriptions_by_output_name=descriptions_by_output_name,
         )
 
     @public
@@ -319,6 +351,7 @@ class AssetsDefinition(ResourceAddable):
         group_name: Optional[str] = None,
         partition_mappings: Optional[Mapping[str, PartitionMapping]] = None,
         metadata_by_output_name: Optional[Mapping[str, MetadataUserInput]] = None,
+        freshness_policies_by_output_name: Optional[Mapping[str, FreshnessPolicy]] = None,
     ) -> "AssetsDefinition":
         """
         Constructs an AssetsDefinition from an OpDefinition.
@@ -354,6 +387,10 @@ class AssetsDefinition(ResourceAddable):
                 be associated with each of the output assets for this node. Keys are names of the
                 outputs, and values are dictionaries of metadata to be associated with the related
                 asset.
+            freshness_policies_by_output_name_ouptut_name (Optional[Mapping[str, FreshnessPolicy]]): Defines a
+                FreshnessPolicy to be associated with some or all of the output assets for this node.
+                Keys are the names of the outputs, and values are the FreshnessPolicies to be attached
+                to the associated asset.
         """
         return AssetsDefinition._from_node(
             node_def=op_def,
@@ -364,6 +401,7 @@ class AssetsDefinition(ResourceAddable):
             group_name=group_name,
             partition_mappings=partition_mappings,
             metadata_by_output_name=metadata_by_output_name,
+            freshness_policies_by_output_name=freshness_policies_by_output_name,
             key_prefix=key_prefix,
         )
 
@@ -379,8 +417,10 @@ class AssetsDefinition(ResourceAddable):
         resource_defs: Optional[Mapping[str, ResourceDefinition]] = None,
         partition_mappings: Optional[Mapping[str, PartitionMapping]] = None,
         metadata_by_output_name: Optional[Mapping[str, MetadataUserInput]] = None,
+        freshness_policies_by_output_name: Optional[Mapping[str, FreshnessPolicy]] = None,
         key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
         can_subset: bool = False,
+        descriptions_by_output_name: Optional[Mapping[str, str]] = None,
     ) -> "AssetsDefinition":
         node_def = check.inst_param(node_def, "node_def", NodeDefinition)
         keys_by_input_name = _infer_keys_by_input_names(
@@ -402,12 +442,15 @@ class AssetsDefinition(ResourceAddable):
             resource_defs, "resource_defs", key_type=str, value_type=ResourceDefinition
         )
 
-        transformed_internal_asset_deps = {}
+        transformed_internal_asset_deps: Dict[AssetKey, AbstractSet[AssetKey]] = {}
         if internal_asset_deps:
             for output_name, asset_keys in internal_asset_deps.items():
                 check.invariant(
                     output_name in keys_by_output_name,
-                    f"output_name {output_name} specified in internal_asset_deps does not exist in the decorated function",
+                    (
+                        f"output_name {output_name} specified in internal_asset_deps does not exist"
+                        " in the decorated function"
+                    ),
                 )
                 transformed_internal_asset_deps[keys_by_output_name[output_name]] = asset_keys
 
@@ -454,20 +497,37 @@ class AssetsDefinition(ResourceAddable):
             }
             if metadata_by_output_name
             else None,
+            freshness_policies_by_key={
+                keys_by_output_name[output_name]: freshness_policy
+                for output_name, freshness_policy in freshness_policies_by_output_name.items()
+            }
+            if freshness_policies_by_output_name
+            else None,
             can_subset=can_subset,
+            descriptions_by_key={
+                keys_by_output_name[output_name]: description
+                for output_name, description in descriptions_by_output_name.items()
+            }
+            if descriptions_by_output_name
+            else None,
         )
 
-    @public  # type: ignore
+    @public
     @property
     def can_subset(self) -> bool:
         return self._can_subset
 
-    @public  # type: ignore
+    @public
     @property
     def group_names_by_key(self) -> Mapping[AssetKey, str]:
         return self._group_names_by_key
 
-    @public  # type: ignore
+    @public
+    @property
+    def descriptions_by_key(self) -> Mapping[AssetKey, str]:
+        return self._descriptions_by_key
+
+    @public
     @property
     def op(self) -> OpDefinition:
         check.invariant(
@@ -476,12 +536,12 @@ class AssetsDefinition(ResourceAddable):
         )
         return cast(OpDefinition, self._node_def)
 
-    @public  # type: ignore
+    @public
     @property
     def node_def(self) -> NodeDefinition:
         return self._node_def
 
-    @public  # type: ignore
+    @public
     @property
     def asset_deps(self) -> Mapping[AssetKey, AbstractSet[AssetKey]]:
         return self._asset_deps
@@ -490,7 +550,7 @@ class AssetsDefinition(ResourceAddable):
     def input_names(self) -> Iterable[str]:
         return self.keys_by_input_name.keys()
 
-    @public  # type: ignore
+    @public
     @property
     def key(self) -> AssetKey:
         check.invariant(
@@ -508,12 +568,12 @@ class AssetsDefinition(ResourceAddable):
         )
         return self.key
 
-    @public  # type: ignore
+    @public
     @property
     def resource_defs(self) -> Mapping[str, ResourceDefinition]:
         return dict(self._resource_defs)
 
-    @public  # type: ignore
+    @public
     @property
     def keys(self) -> AbstractSet[AssetKey]:
         return self._selected_asset_keys
@@ -525,22 +585,22 @@ class AssetsDefinition(ResourceAddable):
         )
         return self.keys
 
-    @public  # type: ignore
+    @public
     @property
     def dependency_keys(self) -> Iterable[AssetKey]:
         # the input asset keys that are directly upstream of a selected asset key
-        upstream_keys = set().union(*(self.asset_deps[key] for key in self.keys))
+        upstream_keys = {dep_key for key in self.keys for dep_key in self.asset_deps[key]}
         input_keys = set(self._keys_by_input_name.values())
         return upstream_keys.intersection(input_keys)
 
     @property
     def node_keys_by_output_name(self) -> Mapping[str, AssetKey]:
-        """AssetKey for each output on the underlying NodeDefinition"""
+        """AssetKey for each output on the underlying NodeDefinition."""
         return self._keys_by_output_name
 
     @property
     def node_keys_by_input_name(self) -> Mapping[str, AssetKey]:
-        """AssetKey for each input on the underlying NodeDefinition"""
+        """AssetKey for each input on the underlying NodeDefinition."""
         return self._keys_by_input_name
 
     @property
@@ -551,7 +611,7 @@ class AssetsDefinition(ResourceAddable):
 
     @property
     def keys_by_input_name(self) -> Mapping[str, AssetKey]:
-        upstream_keys = set().union(*(self.asset_deps[key] for key in self.keys))
+        upstream_keys = {dep_key for key in self.keys for dep_key in self.asset_deps[key]}
         return {
             name: key for name, key in self.node_keys_by_input_name.items() if key in upstream_keys
         }
@@ -560,29 +620,40 @@ class AssetsDefinition(ResourceAddable):
     def freshness_policies_by_key(self) -> Mapping[AssetKey, FreshnessPolicy]:
         return self._freshness_policies_by_key
 
-    @public  # type: ignore
+    @public
     @property
     def partitions_def(self) -> Optional[PartitionsDefinition]:
         return self._partitions_def
 
     @property
-    def metadata_by_key(self):
+    def metadata_by_key(self) -> Mapping[AssetKey, MetadataUserInput]:
         return self._metadata_by_key
 
     @property
-    def code_versions_by_key(self):
+    def code_versions_by_key(self) -> Mapping[AssetKey, Optional[str]]:
         return self._code_versions_by_key
 
+    @property
+    def partition_mappings(self) -> Mapping[AssetKey, PartitionMapping]:
+        return self._partition_mappings
+
     @public
     def get_partition_mapping(self, in_asset_key: AssetKey) -> Optional[PartitionMapping]:
         return self._partition_mappings.get(in_asset_key)
 
-    def infer_partition_mapping(self, in_asset_key: AssetKey) -> PartitionMapping:
+    def get_partition_mapping_for_input(self, input_name: str) -> Optional[PartitionMapping]:
+        return self._partition_mappings.get(self._keys_by_input_name[input_name])
+
+    def infer_partition_mapping(
+        self, upstream_asset_key: AssetKey, upstream_partitions_def: Optional[PartitionsDefinition]
+    ) -> PartitionMapping:
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=ExperimentalWarning)
 
-            partition_mapping = self._partition_mappings.get(in_asset_key)
-            return infer_partition_mapping(partition_mapping, self._partitions_def)
+            partition_mapping = self._partition_mappings.get(upstream_asset_key)
+            return infer_partition_mapping(
+                partition_mapping, self._partitions_def, upstream_partitions_def
+            )
 
     def get_output_name_for_asset_key(self, key: AssetKey) -> str:
         for output_name, asset_key in self.keys_by_output_name.items():
@@ -597,7 +668,7 @@ class AssetsDefinition(ResourceAddable):
         returns the op def within the graph that produces the given asset key.
         """
         output_name = self.get_output_name_for_asset_key(key)
-        return cast(OpDefinition, self.node_def.resolve_output_to_origin_op_def(output_name))
+        return self.node_def.resolve_output_to_origin_op_def(output_name)
 
     def with_prefix_or_group(
         self,
@@ -642,6 +713,11 @@ class AssetsDefinition(ResourceAddable):
             for key, policy in self._freshness_policies_by_key.items()
         }
 
+        replaced_descriptions_by_key = {
+            output_asset_key_replacements.get(key, key): description
+            for key, description in self._descriptions_by_key.items()
+        }
+
         return self.__class__(
             keys_by_input_name={
                 input_name: input_asset_key_replacements.get(key, key)
@@ -682,6 +758,7 @@ class AssetsDefinition(ResourceAddable):
                 for key, value in self.metadata_by_key.items()
             },
             freshness_policies_by_key=replaced_freshness_policies_by_key,
+            descriptions_by_key=replaced_descriptions_by_key,
         )
 
     def _subset_graph_backed_asset(
@@ -689,7 +766,9 @@ class AssetsDefinition(ResourceAddable):
         selected_asset_keys: AbstractSet[AssetKey],
     ):
         from dagster._core.definitions.graph_definition import GraphDefinition
-        from dagster._core.selector.subset_selector import convert_dot_seperated_string_to_dict
+        from dagster._core.selector.subset_selector import (
+            convert_dot_separated_string_to_selection_tree,
+        )
 
         from .job_definition import get_subselected_graph_definition
 
@@ -702,7 +781,7 @@ class AssetsDefinition(ResourceAddable):
         dep_node_handles_by_asset_key = get_dep_node_handles_of_graph_backed_asset(
             self.node_def, self
         )
-        op_selection = []
+        op_selection: List[str] = []
         for asset_key in selected_asset_keys:
             dep_node_handles = dep_node_handles_by_asset_key[asset_key]
             for dep_node_handle in dep_node_handles:
@@ -713,11 +792,13 @@ class AssetsDefinition(ResourceAddable):
         # generate the selected assets. The ops should all be nested within a top-level graph
         # node in the original job.
 
-        resolved_op_selection_dict: Dict = {}
+        op_selection_tree: SelectionTree = {}
         for item in op_selection:
-            convert_dot_seperated_string_to_dict(resolved_op_selection_dict, splits=item.split("."))
+            convert_dot_separated_string_to_selection_tree(
+                op_selection_tree, splits=item.split(".")
+            )
 
-        return get_subselected_graph_definition(self.node_def, resolved_op_selection_dict)
+        return get_subselected_graph_definition(self.node_def, op_selection_tree)
 
     def subset_for(
         self,
@@ -810,28 +891,67 @@ class AssetsDefinition(ResourceAddable):
             )
 
     def to_source_assets(self) -> Sequence[SourceAsset]:
-        result = []
+        return [
+            self._output_to_source_asset(output_name)
+            for output_name in self.keys_by_output_name.keys()
+        ]
+
+    @public
+    def to_source_asset(self, key: Optional[CoercibleToAssetKey] = None) -> SourceAsset:
+        """
+        Returns a representation of this asset as a :py:class:`SourceAsset`.
+
+        If this is a multi-asset, the "key" argument allows selecting which asset to return a
+        SourceAsset representation of.
+
+        Args:
+            key (Optional[Union[str, Sequence[str], AssetKey]]]): If this is a multi-asset, select
+                which asset to return a SourceAsset representation of. If not a multi-asset, this
+                can be left as None.
+
+        Returns:
+            SourceAsset
+        """
+        if len(self.keys) > 1:
+            check.invariant(
+                key is not None,
+                "The 'key' argument is required when there are multiple assets to choose from",
+            )
+
+        if key is not None:
+            resolved_key = AssetKey.from_coerceable(key)
+            check.invariant(
+                resolved_key in self.keys, f"Key {resolved_key} not found in AssetsDefinition"
+            )
+        else:
+            resolved_key = self.key
+
+        output_names = [
+            output_name
+            for output_name, ak in self.keys_by_output_name.items()
+            if ak == resolved_key
+        ]
+        check.invariant(len(output_names) == 1)
+        return self._output_to_source_asset(output_names[0])
+
+    def _output_to_source_asset(self, output_name: str) -> SourceAsset:
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=ExperimentalWarning)
 
-            for output_name, asset_key in self.keys_by_output_name.items():
-                # This could maybe be sped up by batching
-                output_def = self.node_def.resolve_output_to_origin(
-                    output_name, NodeHandle(self.node_def.name, parent=None)
-                )[0]
-                result.append(
-                    SourceAsset(
-                        key=asset_key,
-                        metadata=output_def.metadata,
-                        io_manager_key=output_def.io_manager_key,
-                        description=output_def.description,
-                        resource_defs=self.resource_defs,
-                        partitions_def=self.partitions_def,
-                        group_name=self.group_names_by_key[asset_key],
-                    )
-                )
+            output_def = self.node_def.resolve_output_to_origin(
+                output_name, NodeHandle(self.node_def.name, parent=None)
+            )[0]
+            key = self._keys_by_output_name[output_name]
 
-            return result
+            return SourceAsset(
+                key=key,
+                metadata=output_def.metadata,
+                io_manager_key=output_def.io_manager_key,
+                description=output_def.description,
+                resource_defs=self.resource_defs,
+                partitions_def=self.partitions_def,
+                group_name=self.group_names_by_key[key],
+            )
 
     def get_io_manager_key_for_asset_key(self, key: AssetKey) -> str:
         output_name = self.get_output_name_for_asset_key(key)
@@ -844,7 +964,7 @@ class AssetsDefinition(ResourceAddable):
         for source_key, resource_def in self.resource_defs.items():
             yield from resource_def.get_resource_requirements(outer_context=source_key)
 
-    @public  # type: ignore
+    @public
     @property
     def required_resource_keys(self) -> Set[str]:
         return {requirement.key for requirement in self.get_resource_requirements()}
@@ -854,7 +974,7 @@ class AssetsDefinition(ResourceAddable):
             return f"AssetsDefinition with key {self.asset_key.to_string()}"
         else:
             asset_keys = ", ".join(
-                sorted(list([asset_key.to_string() for asset_key in self.asset_keys]))
+                sorted(([asset_key.to_string() for asset_key in self.asset_keys]))
             )
             return f"AssetsDefinition with keys {asset_keys}"
 
@@ -917,10 +1037,12 @@ def _infer_keys_by_input_names(
     if keys_by_input_name:
         check.invariant(
             set(keys_by_input_name.keys()) == set(all_input_names),
-            "The set of input names keys specified in the keys_by_input_name argument must "
-            f"equal the set of asset keys inputted by '{node_def.name}'. \n"
-            f"keys_by_input_name keys: {set(keys_by_input_name.keys())} \n"
-            f"expected keys: {all_input_names}",
+            (
+                "The set of input names keys specified in the keys_by_input_name argument must "
+                f"equal the set of asset keys inputted by '{node_def.name}'. \n"
+                f"keys_by_input_name keys: {set(keys_by_input_name.keys())} \n"
+                f"expected keys: {all_input_names}"
+            ),
         )
 
     # If asset key is not supplied in keys_by_input_name, create asset key
@@ -940,10 +1062,12 @@ def _infer_keys_by_output_names(
     if keys_by_output_name:
         check.invariant(
             set(keys_by_output_name.keys()) == set(output_names),
-            "The set of output names keys specified in the keys_by_output_name argument must "
-            f"equal the set of asset keys outputted by {node_def.name}. \n"
-            f"keys_by_input_name keys: {set(keys_by_output_name.keys())} \n"
-            f"expected keys: {set(output_names)}",
+            (
+                "The set of output names keys specified in the keys_by_output_name argument must "
+                f"equal the set of asset keys outputted by {node_def.name}. \n"
+                f"keys_by_input_name keys: {set(keys_by_output_name.keys())} \n"
+                f"expected keys: {set(output_names)}"
+            ),
         )
 
     inferred_keys_by_output_names: Dict[str, AssetKey] = {
@@ -989,7 +1113,7 @@ def _build_invocation_context_with_included_resources(
         # pylint: disable=protected-access
         return build_op_context(
             resources=all_resources,
-            config=context.solid_config,
+            config=context.op_config,
             resources_config=context._resources_config,
             instance=context._instance,
             partition_key=context._partition_key,
@@ -1003,7 +1127,7 @@ def _build_invocation_context_with_included_resources(
 
 def _validate_graph_def(graph_def: "GraphDefinition", prefix: Optional[Sequence[str]] = None):
     """Ensure that all leaf nodes are mapped to graph outputs."""
-    from dagster._core.definitions.graph_definition import GraphDefinition, _create_adjacency_lists
+    from dagster._core.definitions.graph_definition import GraphDefinition, create_adjacency_lists
 
     prefix = check.opt_sequence_param(prefix, "prefix")
 
@@ -1013,14 +1137,14 @@ def _validate_graph_def(graph_def: "GraphDefinition", prefix: Optional[Sequence[
             _validate_graph_def(inner_node_def, prefix=[*prefix, graph_def.name])
 
     # leaf nodes have no downstream nodes
-    forward_edges, _ = _create_adjacency_lists(graph_def.solids, graph_def.dependency_structure)
+    forward_edges, _ = create_adjacency_lists(graph_def.nodes, graph_def.dependency_structure)
     leaf_nodes = {
         node_name for node_name, downstream_nodes in forward_edges.items() if not downstream_nodes
     }
 
     # set of nodes that have outputs mapped to a graph output
     mapped_output_nodes = {
-        output_mapping.maps_from.solid_name for output_mapping in graph_def.output_mappings
+        output_mapping.maps_from.node_name for output_mapping in graph_def.output_mappings
     }
 
     # leaf nodes which do not have an associated mapped output
@@ -1028,10 +1152,13 @@ def _validate_graph_def(graph_def: "GraphDefinition", prefix: Optional[Sequence[
 
     check.invariant(
         not unmapped_leaf_nodes,
-        f"All leaf nodes within graph '{graph_def.name}' must generate outputs which are mapped to "
-        "outputs of the graph, and produce assets. The following leaf node(s) are non-asset producing "
-        f"ops: {unmapped_leaf_nodes}. This behavior is not currently supported because these ops "
-        "are not required for the creation of the associated asset(s).",
+        (
+            f"All leaf nodes within graph '{graph_def.name}' must generate outputs which are mapped"
+            " to outputs of the graph, and produce assets. The following leaf node(s) are"
+            f" non-asset producing ops: {unmapped_leaf_nodes}. This behavior is not currently"
+            " supported because these ops are not required for the creation of the associated"
+            " asset(s)."
+        ),
     )
 
 
@@ -1053,5 +1180,6 @@ def _validate_self_deps(
                     continue
 
             raise DagsterInvalidDefinitionError(
-                "Assets can only depend on themselves if they are time-partitioned and each partition depends on earlier partitions"
+                "Assets can only depend on themselves if they are time-partitioned and each"
+                " partition depends on earlier partitions"
             )
