@@ -1,15 +1,23 @@
-import warnings
 from collections import defaultdict
-from typing import Any, Dict, Iterable, List, Mapping, Optional, Sequence, Set, Tuple, Union
+from typing import (
+    Any,
+    Dict,
+    Iterable,
+    List,
+    Mapping,
+    Optional,
+    Sequence,
+    Set,
+    Tuple,
+    Union,
+)
 
 from toposort import CircularDependencyError, toposort
 
 import dagster._check as check
-from dagster._annotations import experimental
 from dagster._core.errors import DagsterInvalidDefinitionError
 from dagster._core.selector.subset_selector import AssetSelectionData
-from dagster._utils import merge_dicts
-from dagster._utils.backcompat import ExperimentalWarning
+from dagster._utils.merger import merge_dicts
 
 from .asset_layer import AssetLayer
 from .assets import AssetsDefinition
@@ -40,50 +48,46 @@ def get_base_asset_jobs(
     resource_defs: Optional[Mapping[str, ResourceDefinition]],
     executor_def: Optional[ExecutorDefinition],
 ) -> Sequence[JobDefinition]:
-    with warnings.catch_warnings():
-        warnings.simplefilter("ignore", category=ExperimentalWarning)
+    assets_by_partitions_def: Dict[
+        Optional[PartitionsDefinition], List[AssetsDefinition]
+    ] = defaultdict(list)
+    for assets_def in assets:
+        assets_by_partitions_def[assets_def.partitions_def].append(assets_def)
 
-        assets_by_partitions_def: Dict[
-            Optional[PartitionsDefinition], List[AssetsDefinition]
-        ] = defaultdict(list)
-        for assets_def in assets:
-            assets_by_partitions_def[assets_def.partitions_def].append(assets_def)
+    if len(assets_by_partitions_def.keys()) == 0 or assets_by_partitions_def.keys() == {None}:
+        return [
+            build_assets_job(
+                name=ASSET_BASE_JOB_PREFIX,
+                assets=assets,
+                source_assets=source_assets,
+                executor_def=executor_def,
+                resource_defs=resource_defs,
+            )
+        ]
+    else:
+        unpartitioned_assets = assets_by_partitions_def.get(None, [])
+        partitioned_assets_by_partitions_def = {
+            k: v for k, v in assets_by_partitions_def.items() if k is not None
+        }
+        jobs = []
 
-        if len(assets_by_partitions_def.keys()) == 0 or assets_by_partitions_def.keys() == {None}:
-            return [
+        # sort to ensure some stability in the ordering
+        for i, (_, assets_with_partitions) in enumerate(
+            sorted(partitioned_assets_by_partitions_def.items(), key=lambda item: repr(item[0]))
+        ):
+            jobs.append(
                 build_assets_job(
-                    name=ASSET_BASE_JOB_PREFIX,
-                    assets=assets,
-                    source_assets=source_assets,
-                    executor_def=executor_def,
+                    f"{ASSET_BASE_JOB_PREFIX}_{i}",
+                    assets=assets_with_partitions + unpartitioned_assets,
+                    source_assets=[*source_assets, *assets],
                     resource_defs=resource_defs,
+                    executor_def=executor_def,
                 )
-            ]
-        else:
-            unpartitioned_assets = assets_by_partitions_def.get(None, [])
-            partitioned_assets_by_partitions_def = {
-                k: v for k, v in assets_by_partitions_def.items() if k is not None
-            }
-            jobs = []
+            )
 
-            # sort to ensure some stability in the ordering
-            for i, (_, assets_with_partitions) in enumerate(
-                sorted(partitioned_assets_by_partitions_def.items(), key=lambda item: repr(item[0]))
-            ):
-                jobs.append(
-                    build_assets_job(
-                        f"{ASSET_BASE_JOB_PREFIX}_{i}",
-                        assets=assets_with_partitions + unpartitioned_assets,
-                        source_assets=[*source_assets, *assets],
-                        resource_defs=resource_defs,
-                        executor_def=executor_def,
-                    )
-                )
-
-            return jobs
+        return jobs
 
 
-@experimental
 def build_assets_job(
     name: str,
     assets: Sequence[AssetsDefinition],
@@ -113,7 +117,6 @@ def build_assets_job(
         description (Optional[str]): A description of the job.
 
     Examples:
-
         .. code-block:: python
 
             @asset
@@ -210,7 +213,6 @@ def build_assets_job(
     )
 
 
-@experimental
 def build_source_asset_observation_job(
     name: str,
     source_assets: Sequence[SourceAsset],
@@ -234,7 +236,6 @@ def build_source_asset_observation_job(
         description (Optional[str]): A description of the job.
 
     Examples:
-
         .. code-block:: python
 
             @asset
@@ -515,7 +516,8 @@ def _ensure_resources_dont_conflict(
     source_assets: Sequence[SourceAsset],
     resource_defs: Mapping[str, ResourceDefinition],
 ) -> None:
-    """Ensures that resources between assets, source assets, and provided resource dictionary do not conflict."""
+    """Ensures that resources between assets, source assets, and provided resource dictionary do not conflict.
+    """
     resource_defs_from_assets = {}
     all_assets: Sequence[Union[AssetsDefinition, SourceAsset]] = [*assets, *source_assets]
     for asset in all_assets:
@@ -552,7 +554,6 @@ def check_resources_satisfy_requirements(
 
     Note that resources provided on assets cannot satisfy resource requirements provided on other assets.
     """
-
     _ensure_resources_dont_conflict(assets, source_assets, resource_defs)
 
     all_assets: Sequence[Union[AssetsDefinition, SourceAsset]] = [*assets, *source_assets]
@@ -567,7 +568,6 @@ def get_all_resource_defs(
     source_assets: Sequence[SourceAsset],
     resource_defs: Mapping[str, ResourceDefinition],
 ) -> Mapping[str, ResourceDefinition]:
-
     # Ensures that no resource keys conflict, and each asset has its resource requirements satisfied.
     check_resources_satisfy_requirements(assets, source_assets, resource_defs)
 
