@@ -1,5 +1,5 @@
 import warnings
-from collections import namedtuple
+from collections import defaultdict, namedtuple
 from typing import (
     TYPE_CHECKING,
     AbstractSet,
@@ -55,6 +55,7 @@ if TYPE_CHECKING:
     from .executor_definition import ExecutorDefinition
     from .job_definition import JobDefinition
     from .partition import PartitionedConfig, PartitionsDefinition
+    from .source_asset import SourceAsset
 
 
 _composition_stack: List["InProgressCompositionContext"] = []
@@ -64,6 +65,92 @@ class MappedInputPlaceholder:
     """Marker for holding places in fan-in lists where input mappings will feed."""
 
 
+class InvokedNodeOutputHandle:
+    """The return value for an output when invoking a node in a composition function."""
+
+    solid_name: str
+    output_name: str
+    node_type: str
+
+    def __init__(self, solid_name: str, output_name: str, node_type: str):
+        self.solid_name = check.str_param(solid_name, "solid_name")
+        self.output_name = check.str_param(output_name, "output_name")
+        self.node_type = check.str_param(node_type, "node_type")
+
+    def __iter__(self) -> NoReturn:
+        raise DagsterInvariantViolationError(
+            'Attempted to iterate over an {cls}. This object represents the output "{out}" '
+            'from the op/graph "{solid}". Consider defining multiple Outs if you seek to pass '
+            "different parts of this output to different op/graph.".format(
+                cls=self.__class__.__name__, out=self.output_name, solid=self.solid_name
+            )
+        )
+
+    def __getitem__(self, idx: object) -> NoReturn:
+        raise DagsterInvariantViolationError(
+            'Attempted to index in to an {cls}. This object represents the output "{out}" '
+            "from the {described_node}. Consider defining multiple Outs if you seek to pass "
+            "different parts of this output to different {node_type}s.".format(
+                cls=self.__class__.__name__,
+                out=self.output_name,
+                described_node=self.describe_node(),
+                node_type=self.node_type,
+            )
+        )
+
+    def describe_node(self) -> str:
+        return f"{self.node_type} '{self.solid_name}'"
+
+    def alias(self, _) -> NoReturn:
+        raise DagsterInvariantViolationError(
+            "In {source} {name}, attempted to call alias method for {cls}. This object "
+            'represents the output "{out}" from the already invoked {described_node}. Consider '
+            "checking the location of parentheses.".format(
+                source=current_context().source,
+                name=current_context().name,
+                cls=self.__class__.__name__,
+                out=self.output_name,
+                described_node=self.describe_node(),
+            )
+        )
+
+    def with_hooks(self, _) -> NoReturn:
+        raise DagsterInvariantViolationError(
+            "In {source} {name}, attempted to call hook method for {cls}. This object "
+            'represents the output "{out}" from the already invoked {described_node}. Consider '
+            "checking the location of parentheses.".format(
+                source=current_context().source,
+                name=current_context().name,
+                cls=self.__class__.__name__,
+                out=self.output_name,
+                described_node=self.describe_node(),
+            )
+        )
+
+
+class InputMappingNode(NamedTuple):
+    input_def: InputDefinition
+
+
+class DynamicFanIn(NamedTuple):
+    """
+    Type to signify collecting over a dynamic output, output by collect() on a
+    InvokedNodeDynamicOutputWrapper.
+    """
+
+    solid_name: str
+    output_name: str
+
+
+InputSource = Union[
+    InvokedNodeOutputHandle,
+    InputMappingNode,
+    DynamicFanIn,
+    "SourceAsset",
+    List[Union[InvokedNodeOutputHandle, InputMappingNode]],
+]
+
+
 def _not_invoked_warning(
     solid: "PendingNodeInvocation",
     context_source: str,
@@ -113,15 +200,9 @@ def is_in_composition() -> bool:
 def assert_in_composition(name: str, node_def: NodeDefinition) -> None:
     if len(_composition_stack) < 1:
         node_label = node_def.node_type_str
-        if node_def.is_graph_job_op_node:
-            correction = (
-                f"Invoking {node_label}s is only valid in a function decorated with @job or @graph."
-            )
-        else:
-            correction = (
-                f"Invoking {node_label}s is only valid in a function decorated with "
-                "@pipeline or @composite_solid."
-            )
+        correction = (
+            f"Invoking {node_label}s is only valid in a function decorated with @job or @graph."
+        )
         raise DagsterInvariantViolationError(
             f"Attempted to call {node_label} '{name}' outside of a composition function."
             f" {correction}"
@@ -130,7 +211,7 @@ def assert_in_composition(name: str, node_def: NodeDefinition) -> None:
 
 class InProgressCompositionContext:
     """This context captures invocations of solids within a
-    composition function such as @composite_solid or @pipeline.
+    composition function such as @job or @graph.
     """
 
     name: str
@@ -150,7 +231,7 @@ class InProgressCompositionContext:
         self,
         given_alias: Optional[str],
         node_def: NodeDefinition,
-        input_bindings: Mapping[str, Any],
+        input_bindings: Mapping[str, InputSource],
         tags: Optional[frozentags],
         hook_defs: Optional[AbstractSet[HookDefinition]],
         retry_policy: Optional[RetryPolicy],
@@ -204,6 +285,7 @@ class CompleteCompositionContext(NamedTuple):
     dependencies: Mapping[Union[str, NodeInvocation], Dict[str, IDependencyDefinition]]
     input_mappings: Sequence[InputMapping]
     output_mapping_dict: Mapping[str, OutputMapping]
+    node_input_source_assets: Mapping[str, Mapping[str, "SourceAsset"]]
 
     @staticmethod
     def create(
@@ -213,9 +295,12 @@ class CompleteCompositionContext(NamedTuple):
         output_mapping_dict: Mapping[str, OutputMapping],
         pending_invocations: Mapping[str, "PendingNodeInvocation"],
     ):
+        from .source_asset import SourceAsset
+
         dep_dict: Dict[Union[str, NodeInvocation], Dict[str, IDependencyDefinition]] = {}
         node_def_dict: Dict[str, NodeDefinition] = {}
         input_mappings = []
+        node_input_source_assets: Dict[str, Dict[str, "SourceAsset"]] = defaultdict(dict)
 
         for solid in pending_invocations.values():
             _not_invoked_warning(solid, source, name)
@@ -238,6 +323,8 @@ class CompleteCompositionContext(NamedTuple):
                     input_mappings.append(
                         node.input_def.mapping_to(invocation.node_name, input_name)
                     )
+                elif isinstance(node, SourceAsset):
+                    node_input_source_assets[invocation.node_name][input_name] = node
                 elif isinstance(node, list):
                     entries: List[Union[DependencyDefinition, Type[MappedInputPlaceholder]]] = []
                     for idx, fanned_in_node in enumerate(node):
@@ -281,6 +368,7 @@ class CompleteCompositionContext(NamedTuple):
             dep_dict,
             input_mappings,
             output_mapping_dict,
+            node_input_source_assets=node_input_source_assets,
         )
 
 
@@ -335,7 +423,7 @@ class PendingNodeInvocation:
 
     def __call__(self, *args, **kwargs) -> Any:
         from ..execution.context.invocation import UnboundOpExecutionContext
-        from .decorators.solid_decorator import DecoratedOpFunction
+        from .decorators.op_decorator import DecoratedOpFunction
         from .solid_invocation import op_invocation_result
 
         node_name = self.given_alias if self.given_alias else self.node_def.name
@@ -374,15 +462,7 @@ class PendingNodeInvocation:
                 return op_invocation_result(self, None, *args, **kwargs)
 
         assert_in_composition(node_name, self.node_def)
-        input_bindings: Dict[
-            str,
-            Union[
-                InvokedNodeOutputHandle,
-                InputMappingNode,
-                DynamicFanIn,
-                List[Union[InvokedNodeOutputHandle, InputMappingNode]],
-            ],
-        ] = {}
+        input_bindings: Dict[str, InputSource] = {}
 
         # handle *args
         for idx, output_node in enumerate(args):
@@ -479,7 +559,11 @@ class PendingNodeInvocation:
         return f"{self.node_def.node_type_str} '{node_name}'"
 
     def _process_argument_node(self, node_name, output_node, input_name, input_bindings, arg_desc):
-        if isinstance(output_node, (InvokedNodeOutputHandle, InputMappingNode, DynamicFanIn)):
+        from .source_asset import SourceAsset
+
+        if isinstance(
+            output_node, (InvokedNodeOutputHandle, InputMappingNode, DynamicFanIn, SourceAsset)
+        ):
             input_bindings[input_name] = output_node
 
         elif isinstance(output_node, list):
@@ -692,85 +776,12 @@ class InvokedNode(NamedTuple):
 
     node_name: str
     node_def: NodeDefinition
-    input_bindings: Mapping[str, Any]
+    input_bindings: Mapping[str, InputSource]
     tags: Optional[frozentags]
     hook_defs: Optional[AbstractSet[HookDefinition]]
     retry_policy: Optional[RetryPolicy]
 
 
-class InvokedNodeOutputHandle:
-    """The return value for an output when invoking a node in a composition function."""
-
-    solid_name: str
-    output_name: str
-    node_type: str
-
-    def __init__(self, solid_name: str, output_name: str, node_type: str):
-        self.solid_name = check.str_param(solid_name, "solid_name")
-        self.output_name = check.str_param(output_name, "output_name")
-        self.node_type = check.str_param(node_type, "node_type")
-
-    def __iter__(self) -> NoReturn:
-        raise DagsterInvariantViolationError(
-            'Attempted to iterate over an {cls}. This object represents the output "{out}" '
-            'from the solid "{solid}". Consider defining multiple Outs if you seek to pass '
-            "different parts of this output to different solids.".format(
-                cls=self.__class__.__name__, out=self.output_name, solid=self.solid_name
-            )
-        )
-
-    def __getitem__(self, idx: object) -> NoReturn:
-        raise DagsterInvariantViolationError(
-            'Attempted to index in to an {cls}. This object represents the output "{out}" '
-            "from the {described_node}. Consider defining multiple Outs if you seek to pass "
-            "different parts of this output to different {node_type}s.".format(
-                cls=self.__class__.__name__,
-                out=self.output_name,
-                described_node=self.describe_node(),
-                node_type=self.node_type,
-            )
-        )
-
-    def describe_node(self) -> str:
-        return f"{self.node_type} '{self.solid_name}'"
-
-    def alias(self, _) -> NoReturn:
-        raise DagsterInvariantViolationError(
-            "In {source} {name}, attempted to call alias method for {cls}. This object "
-            'represents the output "{out}" from the already invoked {described_node}. Consider '
-            "checking the location of parentheses.".format(
-                source=current_context().source,
-                name=current_context().name,
-                cls=self.__class__.__name__,
-                out=self.output_name,
-                described_node=self.describe_node(),
-            )
-        )
-
-    def with_hooks(self, _) -> NoReturn:
-        raise DagsterInvariantViolationError(
-            "In {source} {name}, attempted to call hook method for {cls}. This object "
-            'represents the output "{out}" from the already invoked {described_node}. Consider '
-            "checking the location of parentheses.".format(
-                source=current_context().source,
-                name=current_context().name,
-                cls=self.__class__.__name__,
-                out=self.output_name,
-                described_node=self.describe_node(),
-            )
-        )
-
-
-class DynamicFanIn(NamedTuple):
-    """
-    Type to signify collecting over a dynamic output, output by collect() on a
-    InvokedNodeDynamicOutputWrapper.
-    """
-
-    solid_name: str
-    output_name: str
-
-
 class InvokedNodeDynamicOutputWrapper:
     """
     The return value for a dynamic output when invoking a solid in a composition function.
@@ -871,10 +882,6 @@ class InvokedNodeDynamicOutputWrapper:
         )
 
 
-class InputMappingNode(NamedTuple):
-    input_def: InputDefinition
-
-
 def composite_mapping_from_output(
     output: Any,
     output_defs: Sequence[OutputDefinition],
@@ -1019,14 +1026,14 @@ def do_composition(
     Sequence[NodeDefinition],
     Optional[ConfigMapping],
     Sequence[str],
+    Mapping[str, Mapping[str, "SourceAsset"]],
 ]:
     """
-    This a function used by both @pipeline and @composite_solid to implement their composition
+    This a function used by both @job and @graph to implement their composition
     function which is our DSL for constructing a dependency graph.
 
     Args:
-        decorator_name (str): Name of the calling decorator. e.g. "@pipeline",
-            "@composite_solid", "@graph"
+        decorator_name (str): Name of the calling decorator. e.g. "@graph" or "@job"
         graph_name (str): User-defined name of the definition being constructed
         fn (Callable): The composition function to be called.
         provided_input_defs(List[InputDefinition]): List of input definitions
@@ -1041,7 +1048,7 @@ def do_composition(
             the user has not explicitly provided the output definitions.
             This should be removed in 0.11.0.
     """
-    from .decorators.solid_decorator import (
+    from .decorators.op_decorator import (
         NoContextDecoratedOpFunction,
         resolve_checked_solid_fn_inputs,
     )
@@ -1109,17 +1116,12 @@ def do_composition(
         ]
 
         if len(mappings) == 0:
-            if decorator_name in {"@op", "@graph"}:
-                invocation_name = "op/graph"
-            else:
-                invocation_name = "solid"
             raise DagsterInvalidDefinitionError(
                 "{decorator_name} '{graph_name}' has unmapped input '{input_name}'. "
-                "Remove it or pass it to the appropriate {invocation_name} invocation.".format(
+                "Remove it or pass it to the appropriate op/graph invocation.".format(
                     decorator_name=decorator_name,
                     graph_name=graph_name,
                     input_name=defn.name,
-                    invocation_name=invocation_name,
                 )
             )
 
@@ -1139,7 +1141,7 @@ def do_composition(
 
             raise DagsterInvalidDefinitionError(
                 "{decorator_name} '{graph_name}' has unmapped output '{output_name}'. "
-                "Remove it or return a value from the appropriate solid invocation.".format(
+                "Remove it or return a value from the appropriate op/graph invocation.".format(
                     decorator_name=decorator_name, graph_name=graph_name, output_name=defn.name
                 )
             )
@@ -1152,6 +1154,7 @@ def do_composition(
         context.solid_defs,
         config_mapping,
         compute_fn.positional_inputs(),
+        context.node_input_source_assets,
     )
 
 
