@@ -1,4 +1,5 @@
 import warnings
+from inspect import Parameter
 from typing import (
     AbstractSet,
     Any,
@@ -18,11 +19,11 @@ from dagster._builtins import Nothing
 from dagster._config import UserConfigSchema
 from dagster._core.decorator_utils import get_function_params, get_valid_name_permutations
 from dagster._core.definitions.freshness_policy import FreshnessPolicy
-from dagster._core.definitions.resource_output import get_resource_args
+from dagster._core.definitions.metadata import MetadataUserInput
+from dagster._core.definitions.resource_annotation import get_resource_args
 from dagster._core.errors import DagsterInvalidDefinitionError
 from dagster._core.storage.io_manager import IOManagerDefinition
 from dagster._core.types.dagster_type import DagsterType
-from dagster._seven import funcsigs
 from dagster._utils.backcompat import (
     ExperimentalWarning,
     deprecation_warning,
@@ -32,10 +33,11 @@ from dagster._utils.backcompat import (
 from ..asset_in import AssetIn
 from ..asset_out import AssetOut
 from ..assets import AssetsDefinition
+from ..decorators.graph_decorator import graph
 from ..decorators.op_decorator import _Op
 from ..events import AssetKey, CoercibleToAssetKeyPrefix
 from ..input import In
-from ..output import Out
+from ..output import GraphOut, Out
 from ..partition import PartitionsDefinition
 from ..policy import RetryPolicy
 from ..resource_definition import ResourceDefinition
@@ -170,23 +172,8 @@ def asset(
             def my_asset(my_upstream_asset: int) -> int:
                 return my_upstream_asset + 1
     """
-    if compute_fn is not None:
-        return _Asset()(compute_fn)
-
-    def inner(fn: Callable[..., Any]) -> AssetsDefinition:
-        check.invariant(
-            not (io_manager_key and io_manager_def),
-            (
-                "Both io_manager_key and io_manager_def were provided to `@asset` decorator. Please"
-                " provide one or the other. "
-            ),
-        )
-        if resource_defs is not None:
-            experimental_arg_warning("resource_defs", "asset")
-
-        if io_manager_def is not None:
-            experimental_arg_warning("io_manager_def", "asset")
 
+    def create_asset():
         return _Asset(
             name=cast(Optional[str], name),  # (mypy bug that it can't infer name is Optional[str])
             key_prefix=key_prefix,
@@ -207,7 +194,26 @@ def asset(
             freshness_policy=freshness_policy,
             retry_policy=retry_policy,
             code_version=code_version,
-        )(fn)
+        )
+
+    if compute_fn is not None:
+        return create_asset()(compute_fn)
+
+    def inner(fn: Callable[..., Any]) -> AssetsDefinition:
+        check.invariant(
+            not (io_manager_key and io_manager_def),
+            (
+                "Both io_manager_key and io_manager_def were provided to `@asset` decorator. Please"
+                " provide one or the other. "
+            ),
+        )
+        if resource_defs is not None:
+            experimental_arg_warning("resource_defs", "asset")
+
+        if io_manager_def is not None:
+            experimental_arg_warning("io_manager_def", "asset")
+
+        return create_asset()(fn)
 
     return inner
 
@@ -270,11 +276,13 @@ class _Asset:
             warnings.simplefilter("ignore", category=ExperimentalWarning)
 
             arg_resource_keys = {arg.name for arg in get_resource_args(fn)}
-            decorator_resource_keys = set(self.required_resource_keys).union(
-                set(self.resource_defs.keys())
-            )
+
+            bare_required_resource_keys = set(self.required_resource_keys)
+            resource_defs_keys = set(self.resource_defs.keys())
+            decorator_resource_keys = bare_required_resource_keys | resource_defs_keys
+
             check.param_invariant(
-                len(decorator_resource_keys) == 0 or len(arg_resource_keys) == 0,
+                len(bare_required_resource_keys) == 0 or len(arg_resource_keys) == 0,
                 (
                     "Cannot specify resource requirements in both @asset decorator and as arguments"
                     " to the decorated function"
@@ -301,6 +309,8 @@ class _Asset:
                 code_version=self.code_version,
             )
 
+            op_required_resource_keys = decorator_resource_keys - arg_resource_keys
+
             op = _Op(
                 name=out_asset_key.to_python_identifier(),
                 description=self.description,
@@ -308,7 +318,7 @@ class _Asset:
                 out=out,
                 # Any resource requirements specified as arguments will be identified as
                 # part of the Op definition instantiation
-                required_resource_keys=decorator_resource_keys,
+                required_resource_keys=op_required_resource_keys,
                 tags={
                     **({"kind": self.compute_kind} if self.compute_kind else {}),
                     **(self.op_tags or {}),
@@ -415,12 +425,14 @@ def multi_asset(
         resource_defs, "resource_defs", key_type=str, value_type=ResourceDefinition
     )
     _config_schema = check.opt_mapping_param(
-        config_schema,  # type: ignore
+        config_schema,
         "config_schema",
         additional_message="Only dicts are supported for asset config_schema.",
     )
 
-    required_resource_keys = set(required_resource_keys).union(set(resource_defs.keys()))
+    bare_required_resource_keys = set(required_resource_keys)
+    resource_defs_keys = set(resource_defs.keys())
+    required_resource_keys = bare_required_resource_keys | resource_defs_keys
 
     for out in outs.values():
         if isinstance(out, Out) and not isinstance(out, AssetOut):
@@ -439,7 +451,7 @@ def multi_asset(
 
         arg_resource_keys = {arg.name for arg in get_resource_args(fn)}
         check.param_invariant(
-            len(required_resource_keys or []) == 0 or len(arg_resource_keys) == 0,
+            len(bare_required_resource_keys or []) == 0 or len(arg_resource_keys) == 0,
             (
                 "Cannot specify resource requirements in both @multi_asset decorator and as"
                 " arguments to the decorated function"
@@ -471,12 +483,14 @@ def multi_asset(
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=ExperimentalWarning)
 
+            op_required_resource_keys = required_resource_keys - arg_resource_keys
+
             op = _Op(
                 name=op_name,
                 description=description,
                 ins=dict(asset_ins.values()),
                 out=dict(asset_outs.values()),
-                required_resource_keys=required_resource_keys,
+                required_resource_keys=op_required_resource_keys,
                 tags={
                     **({"kind": compute_kind} if compute_kind else {}),
                     **(op_tags or {}),
@@ -565,11 +579,9 @@ def build_asset_ins(
     input_params = new_input_args
 
     non_var_input_param_names = [
-        param.name
-        for param in new_input_args
-        if param.kind == funcsigs.Parameter.POSITIONAL_OR_KEYWORD
+        param.name for param in new_input_args if param.kind == Parameter.POSITIONAL_OR_KEYWORD
     ]
-    has_kwargs = any(param.kind == funcsigs.Parameter.VAR_KEYWORD for param in new_input_args)
+    has_kwargs = any(param.kind == Parameter.VAR_KEYWORD for param in new_input_args)
 
     all_input_names = set(non_var_input_param_names) | asset_ins.keys()
 
@@ -615,29 +627,246 @@ def build_asset_ins(
     return ins_by_asset_key
 
 
-def build_asset_outs(
-    asset_outs: Mapping[str, Union[Out, AssetOut]]
-) -> Mapping[AssetKey, Tuple[str, Out]]:
+@overload
+def graph_asset(compose_fn: Callable) -> AssetsDefinition:
+    ...
+
+
+@overload
+def graph_asset(
+    *,
+    name: Optional[str] = None,
+    key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
+    ins: Optional[Mapping[str, AssetIn]] = None,
+    description: Optional[str] = None,
+    partitions_def: Optional[PartitionsDefinition] = None,
+    group_name: Optional[str] = None,
+    metadata: Optional[MetadataUserInput] = ...,
+    freshness_policy: Optional[FreshnessPolicy] = ...,
+) -> Callable[[Callable[..., Any]], AssetsDefinition]:
+    ...
+
+
+def graph_asset(
+    compose_fn: Optional[Callable] = None,
+    *,
+    name: Optional[str] = None,
+    key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
+    ins: Optional[Mapping[str, AssetIn]] = None,
+    description: Optional[str] = None,
+    partitions_def: Optional[PartitionsDefinition] = None,
+    group_name: Optional[str] = None,
+    metadata: Optional[MetadataUserInput] = None,
+    freshness_policy: Optional[FreshnessPolicy] = None,
+) -> Union[AssetsDefinition, Callable[[Callable[..., Any]], AssetsDefinition]]:
+    """
+    Creates a software-defined asset that's computed using a graph of ops.
+
+    This decorator is meant to decorate a function that composes a set of ops or graphs to define
+    the dependencies between them.
+
+    Args:
+        name (Optional[str]): The name of the asset.  If not provided, defaults to the name of the
+            decorated function. The asset's name must be a valid name in dagster (ie only contains
+            letters, numbers, and _) and may not contain python reserved keywords.
+        key_prefix (Optional[Union[str, Sequence[str]]]): If provided, the asset's key is the
+            concatenation of the key_prefix and the asset's name, which defaults to the name of
+            the decorated function. Each item in key_prefix must be a valid name in dagster (ie only
+            contains letters, numbers, and _) and may not contain python reserved keywords.
+        ins (Optional[Mapping[str, AssetIn]]): A dictionary that maps input names to information
+            about the input.
+        partitions_def (Optional[PartitionsDefinition]): Defines the set of partition keys that
+            compose the asset.
+        group_name (Optional[str]): A string name used to organize multiple assets into groups. If
+            not provided, the name "default" is used.
+        metadata (Optional[MetadataUserInput]): Dictionary of metadata to be associated with
+            the asset.
+        freshness_policy (FreshnessPolicy): A constraint telling Dagster how often this asset is
+            intended to be updated with respect to its root data.
+
+    Examples:
+        .. code-block:: python
+
+            @op
+            def fetch_files_from_slack(context) -> pd.DataFrame:
+                ...
+
+            @op
+            def store_files_in_table(files) -> None:
+                files.to_sql(name="slack_files", con=create_db_connection())
+
+            @graph_asset
+            def slack_files_table():
+                return store_files(fetch_files_from_slack())
+    """
+    if compose_fn is not None:
+        return _GraphBackedAsset()(compose_fn)
+
+    def inner(fn: Callable[..., Any]) -> AssetsDefinition:
+        return _GraphBackedAsset(
+            name=cast(Optional[str], name),  # (mypy bug that it can't infer name is Optional[str])
+            key_prefix=key_prefix,
+            ins=ins,
+            description=description,
+            partitions_def=partitions_def,
+            group_name=group_name,
+            metadata=metadata,
+            freshness_policy=freshness_policy,
+        )(fn)
+
+    return inner
+
+
+class _GraphBackedAsset:
+    def __init__(
+        self,
+        name: Optional[str] = None,
+        key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
+        ins: Optional[Mapping[str, AssetIn]] = None,
+        description: Optional[str] = None,
+        partitions_def: Optional[PartitionsDefinition] = None,
+        group_name: Optional[str] = None,
+        metadata: Optional[MetadataUserInput] = None,
+        freshness_policy: Optional[FreshnessPolicy] = None,
+    ):
+        self.name = name
+
+        if isinstance(key_prefix, str):
+            key_prefix = [key_prefix]
+        self.key_prefix = key_prefix
+        self.ins = ins or {}
+        self.description = description
+        self.partitions_def = partitions_def
+        self.group_name = group_name
+        self.metadata = metadata
+        self.freshness_policy = freshness_policy
+
+    def __call__(self, fn: Callable) -> AssetsDefinition:
+        asset_name = self.name or fn.__name__
+        asset_ins = build_asset_ins(fn, self.ins or {}, set())
+        out_asset_key = AssetKey(list(filter(None, [*(self.key_prefix or []), asset_name])))
+
+        keys_by_input_name = {
+            input_name: asset_key for asset_key, (input_name, _) in asset_ins.items()
+        }
+        partition_mappings = {
+            input_name: asset_in.partition_mapping
+            for input_name, asset_in in self.ins.items()
+            if asset_in.partition_mapping
+        }
+
+        op_graph = graph(name=out_asset_key.to_python_identifier(), description=self.description)(
+            fn
+        )
+        return AssetsDefinition.from_graph(
+            op_graph,
+            keys_by_input_name=keys_by_input_name,
+            keys_by_output_name={"result": out_asset_key},
+            partitions_def=self.partitions_def,
+            partition_mappings=partition_mappings if partition_mappings else None,
+            group_name=self.group_name,
+            metadata_by_output_name={"result": self.metadata} if self.metadata else None,
+            freshness_policies_by_output_name={"result": self.freshness_policy}
+            if self.freshness_policy
+            else None,
+            descriptions_by_output_name={"result": self.description} if self.description else None,
+        )
+
+
+def graph_multi_asset(
+    *,
+    outs: Mapping[str, AssetOut],
+    name: Optional[str] = None,
+    ins: Optional[Mapping[str, AssetIn]] = None,
+    partitions_def: Optional[PartitionsDefinition[object]] = None,
+    group_name: Optional[str] = None,
+    can_subset: bool = False,
+) -> Callable[[Callable[..., Any]], AssetsDefinition]:
+    """Create a combined definition of multiple assets that are computed using the same graph of
+    ops, and the same upstream assets.
+
+    Each argument to the decorated function references an upstream asset that this asset depends on.
+    The name of the argument designates the name of the upstream asset.
+
+    Args:
+        name (Optional[str]): The name of the graph.
+        outs: (Optional[Dict[str, AssetOut]]): The AssetOuts representing the produced assets.
+        ins (Optional[Mapping[str, AssetIn]]): A dictionary that maps input names to information
+            about the input.
+        partitions_def (Optional[PartitionsDefinition]): Defines the set of partition keys that
+            compose the assets.
+        group_name (Optional[str]): A string name used to organize multiple assets into groups. This
+            group name will be applied to all assets produced by this multi_asset.
+        can_subset (bool): Whether this asset's computation can emit a subset of the asset
+            keys based on the context.selected_assets argument. Defaults to False.
+    """
+
+    def inner(fn: Callable) -> AssetsDefinition:
+        partition_mappings = {
+            input_name: asset_in.partition_mapping
+            for input_name, asset_in in (ins or {}).items()
+            if asset_in.partition_mapping
+        }
+
+        asset_ins = build_asset_ins(fn, ins or {}, set())
+        keys_by_input_name = {
+            input_name: asset_key for asset_key, (input_name, _) in asset_ins.items()
+        }
+        asset_outs = build_asset_outs(outs)
+        op_graph = graph(
+            name=name or fn.__name__,
+            out={out_name: GraphOut() for out_name, _ in asset_outs.values()},
+        )(fn)
+
+        # source metadata from the AssetOuts (if any)
+        metadata_by_output_name = {
+            output_name: out.metadata
+            for output_name, out in outs.items()
+            if isinstance(out, AssetOut) and out.metadata is not None
+        }
+
+        # source freshness policies from the AssetOuts (if any)
+        freshness_policies_by_output_name = {
+            output_name: out.freshness_policy
+            for output_name, out in outs.items()
+            if isinstance(out, AssetOut) and out.freshness_policy is not None
+        }
+
+        # source descriptions from the AssetOuts (if any)
+        descriptions_by_output_name = {
+            output_name: out.description
+            for output_name, out in outs.items()
+            if isinstance(out, AssetOut) and out.description is not None
+        }
+
+        return AssetsDefinition.from_graph(
+            op_graph,
+            keys_by_input_name=keys_by_input_name,
+            keys_by_output_name={
+                output_name: asset_key for asset_key, (output_name, _) in asset_outs.items()
+            },
+            partitions_def=partitions_def,
+            partition_mappings=partition_mappings if partition_mappings else None,
+            group_name=group_name,
+            can_subset=can_subset,
+            metadata_by_output_name=metadata_by_output_name,
+            freshness_policies_by_output_name=freshness_policies_by_output_name,
+            descriptions_by_output_name=descriptions_by_output_name,
+        )
+
+    return inner
+
+
+def build_asset_outs(asset_outs: Mapping[str, AssetOut]) -> Mapping[AssetKey, Tuple[str, Out]]:
     """
     Creates a mapping from AssetKey to (name of output, Out object).
     """
     outs_by_asset_key: Dict[AssetKey, Tuple[str, Out]] = {}
     for output_name, asset_out in asset_outs.items():
-        if isinstance(asset_out, AssetOut):
-            out = asset_out.to_out()
-            asset_key = asset_out.key or AssetKey(
-                list(filter(None, [*(asset_out.key_prefix or []), output_name]))
-            )
-        elif isinstance(asset_out, Out):
-            out = asset_out
-            if isinstance(asset_out.asset_key, AssetKey):
-                asset_key = asset_out.asset_key
-            elif asset_out.asset_key is None:
-                asset_key = AssetKey(output_name)
-            else:
-                check.failed("Expected AssetKey or None")
-        else:
-            check.failed("Expected Out or AssetOut")
+        out = asset_out.to_out()
+        asset_key = asset_out.key or AssetKey(
+            list(filter(None, [*(asset_out.key_prefix or []), output_name]))
+        )
 
         outs_by_asset_key[asset_key] = (output_name.replace("-", "_"), out)
 
