@@ -76,6 +76,7 @@ class _Pipeline:
             solid_defs,
             config_mapping,
             positional_inputs,
+            node_input_source_assets,
         ) = do_composition(
             "@pipeline",
             self.name,
@@ -98,6 +99,7 @@ class _Pipeline:
                 output_mappings=output_mappings,
                 config=config_mapping,
                 positional_inputs=positional_inputs,
+                node_input_source_assets=node_input_source_assets,
             ),
             tags=self.tags,
             description=self.description or format_docstring_for_description(fn),
@@ -180,7 +182,6 @@ def pipeline(
             pipeline. Providing a VersionStrategy will enable memoization on the pipeline.
 
     Example:
-
         .. code-block:: python
 
             @solid(output_defs=[OutputDefinition(int, "two"), OutputDefinition(int, "four")])
@@ -189,23 +190,12 @@ def pipeline(
                 yield Output(4, "four")
 
 
-            @lambda_solid
-            def add_one(num: int) -> int:
-                return num + 1
-
-
-            @lambda_solid
-            def mult_two(num: int) -> int:
-                return num * 2
-
-
             @pipeline
             def math_pipeline():
                 two, four = emit_two_four()
                 add_one(two)
                 mult_two(four)
     """
-
     if input_defs is not None:
         experimental_arg_warning("input_defs", "pipeline")
 
