@@ -15,12 +15,14 @@ from typing import (
 
 import dagster._check as check
 from dagster._core.decorator_utils import get_function_params
+from dagster._core.definitions.resource_definition import ResourceDefinition
 from dagster._core.errors import DagsterInvalidDefinitionError
 
 from ..executor_definition import ExecutorDefinition
 from ..graph_definition import GraphDefinition
 from ..logger_definition import LoggerDefinition
 from ..partition import PartitionSetDefinition
+from ..partitioned_schedule import UnresolvedPartitionedAssetScheduleDefinition
 from ..pipeline_definition import PipelineDefinition
 from ..repository_definition import (
     VALID_REPOSITORY_DATA_DICT_KEYS,
@@ -52,6 +54,7 @@ class _Repository:
         description: Optional[str] = None,
         default_executor_def: Optional[ExecutorDefinition] = None,
         default_logger_defs: Optional[Mapping[str, LoggerDefinition]] = None,
+        top_level_resources: Optional[Mapping[str, ResourceDefinition]] = None,
     ):
         self.name = check.opt_str_param(name, "name")
         self.description = check.opt_str_param(description, "description")
@@ -61,6 +64,9 @@ class _Repository:
         self.default_logger_defs = check.opt_mapping_param(
             default_logger_defs, "default_logger_defs", key_type=str, value_type=LoggerDefinition
         )
+        self.top_level_resources = check.opt_mapping_param(
+            top_level_resources, "top_level_resources", key_type=str, value_type=ResourceDefinition
+        )
 
     def __call__(
         self, fn: Callable[[], Sequence[Any]]
@@ -89,6 +95,7 @@ class _Repository:
                         PipelineDefinition,
                         PartitionSetDefinition,
                         ScheduleDefinition,
+                        UnresolvedPartitionedAssetScheduleDefinition,
                         SensorDefinition,
                         GraphDefinition,
                         AssetGroup,
@@ -123,6 +130,7 @@ class _Repository:
                     repository_defns,
                     default_executor_def=self.default_executor_def,
                     default_logger_defs=self.default_logger_defs,
+                    top_level_resources=self.top_level_resources,
                 )
             )
 
@@ -158,6 +166,7 @@ class _Repository:
                 description=self.description,
                 default_executor_def=self.default_executor_def,
                 default_logger_defs=self.default_logger_defs,
+                _top_level_resources=self.top_level_resources,
             )
         else:
             repository_def = RepositoryDefinition(
@@ -182,6 +191,7 @@ def repository(
     description: Optional[str] = ...,
     default_executor_def: Optional[ExecutorDefinition] = ...,
     default_logger_defs: Optional[Mapping[str, LoggerDefinition]] = ...,
+    _top_level_resources: Optional[Mapping[str, ResourceDefinition]] = ...,
 ) -> _Repository:
     ...
 
@@ -193,6 +203,7 @@ def repository(
     description: Optional[str] = None,
     default_executor_def: Optional[ExecutorDefinition] = None,
     default_logger_defs: Optional[Mapping[str, LoggerDefinition]] = None,
+    _top_level_resources: Optional[Mapping[str, ResourceDefinition]] = None,
 ) -> Union[RepositoryDefinition, PendingRepositoryDefinition, _Repository]:
     """Create a repository from the decorated function.
 
@@ -224,6 +235,8 @@ def repository(
         name (Optional[str]): The name of the repository. Defaults to the name of the decorated
             function.
         description (Optional[str]): A string description of the repository.
+        top_level_resources (Optional[Mapping[str, ResourceDefinition]]): A dict of top-level
+            resource keys to defintions, for resources which should be displayed in the UI.
 
     Example:
         .. code-block:: python
@@ -327,4 +340,5 @@ def repository(
         description=description,
         default_executor_def=default_executor_def,
         default_logger_defs=default_logger_defs,
+        top_level_resources=_top_level_resources,
     )
