@@ -21,6 +21,8 @@ from typing import (
     cast,
 )
 
+from typing_extensions import TypeAlias
+
 import dagster._check as check
 from dagster._annotations import PublicAttr, public
 from dagster._core.definitions.policy import RetryPolicy
@@ -72,7 +74,6 @@ class NodeInvocation(
             node instance.
 
     Examples:
-
     In general, users should prefer not to construct this class directly or use the
     :py:class:`JobDefinition` API that requires instances of this class. Instead, use the
     :py:func:`@job <job>` API:
@@ -252,7 +253,6 @@ class Node(ABC):
 
 
 class GraphNode(Node):
-
     definition: "GraphDefinition"
 
     def __init__(
@@ -275,7 +275,6 @@ class GraphNode(Node):
         parent_handle: Optional["NodeHandle"] = None,
         asset_layer: Optional["AssetLayer"] = None,
     ) -> Iterator["ResourceRequirement"]:
-
         cur_node_handle = NodeHandle(self.name, parent_handle)
 
         for node in self.definition.node_dict.values():
@@ -290,7 +289,6 @@ class GraphNode(Node):
 
 
 class OpNode(Node):
-
     definition: "OpDefinition"
 
     def __init__(
@@ -356,11 +354,7 @@ class NodeHandleSerializer(DefaultNamedTupleSerializer):
 
 
 @whitelist_for_serdes(serializer=NodeHandleSerializer)
-class NodeHandle(
-    # mypy does not yet support recursive types
-    # NamedTuple("_NodeHandle", [("name", str), ("parent", Optional["NodeHandle"])])
-    NamedTuple("_NodeHandle", [("name", str), ("parent", Any)])
-):
+class NodeHandle(NamedTuple("_NodeHandle", [("name", str), ("parent", Optional["NodeHandle"])])):
     """
     A structured object to identify nodes in the potentially recursive graph structure.
     """
@@ -375,6 +369,13 @@ class NodeHandle(
     def __str__(self):
         return self.to_string()
 
+    @property
+    def root(self):
+        if self.parent:
+            return self.parent.root
+        else:
+            return self
+
     @property
     def path(self) -> Sequence[str]:
         """Return a list representation of the handle.
@@ -384,7 +385,7 @@ class NodeHandle(
         Returns:
             List[str]:
         """
-        path = []
+        path: List[str] = []
         cur = self
         while cur:
             path.append(cur.name)
@@ -434,7 +435,6 @@ class NodeHandle(
             ancestor = NodeHandle('bar', NodeHandle('foo', None))
             assert handle.pop(ancestor) == NodeHandle('baz', None)
         """
-
         check.inst_param(ancestor, "ancestor", NodeHandle)
         check.invariant(
             self.is_or_descends_from(ancestor),
@@ -490,10 +490,10 @@ class NodeHandle(
         return NodeHandle.from_path(path)
 
     @classmethod
-    def from_dict(cls, dict_repr: Dict[str, Any]) -> Optional["NodeHandle"]:
+    def from_dict(cls, dict_repr: Mapping[str, Any]) -> "NodeHandle":
         """This method makes it possible to load a potentially nested NodeHandle after a
-        roundtrip through json.loads(json.dumps(NodeHandle._asdict()))"""
-
+        roundtrip through json.loads(json.dumps(NodeHandle._asdict())).
+        """
         check.dict_param(dict_repr, "dict_repr", key_type=str)
         check.invariant(
             "name" in dict_repr, "Dict representation of NodeHandle must have a 'name' key"
@@ -503,14 +503,16 @@ class NodeHandle(
         )
 
         if isinstance(dict_repr["parent"], (list, tuple)):
-            dict_repr["parent"] = NodeHandle.from_dict(
+            parent = NodeHandle.from_dict(
                 {
                     "name": dict_repr["parent"][0],
                     "parent": dict_repr["parent"][1],
                 }
             )
+        else:
+            parent = dict_repr["parent"]
 
-        return NodeHandle(**{k: dict_repr[k] for k in ["name", "parent"]})
+        return NodeHandle(name=dict_repr["name"], parent=parent)
 
 
 class NodeInputHandle(
@@ -568,10 +570,6 @@ class NodeInput(NamedTuple("_NodeInput", [("node", Node), ("input_def", InputDef
     def node_name(self) -> str:
         return self.node.name
 
-    @property
-    def solid_name(self) -> str:
-        return self.node.name
-
     @property
     def input_name(self) -> str:
         return self.input_def.name
@@ -598,10 +596,10 @@ class NodeOutput(NamedTuple("_NodeOutput", [("node", Node), ("output_def", Outpu
     def __repr__(self):
         return self._inner_str()
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash((self.node.name, self.output_def.name))
 
-    def __eq__(self, other: Any):
+    def __eq__(self, other: Any) -> bool:
         return self.node.name == other.node.name and self.output_def.name == other.output_def.name
 
     def describe(self) -> str:
@@ -629,7 +627,8 @@ class IDependencyDefinition(ABC):  # pylint: disable=no-init
 
     @abstractmethod
     def is_fan_in(self) -> bool:
-        """The result passed to the corresponding input will be a List made from different node outputs"""
+        """The result passed to the corresponding input will be a List made from different node outputs.
+        """
 
 
 class DependencyDefinition(
@@ -670,32 +669,18 @@ class DependencyDefinition(
 
 
     Args:
-        solid (str): (legacy) The name of the solid that is depended on, that is, from which the value
+        node (str): The name of the node (op or graph) that is depended on, that is, from which the value
             passed between the two nodes originates.
         output (Optional[str]): The name of the output that is depended on. (default: "result")
         description (Optional[str]): Human-readable description of this dependency.
-        node (str): The name of the node (op or graph) that is depended on, that is, from which the value
-            passed between the two nodes originates.
     """
 
     def __new__(
         cls,
-        solid: Optional[str] = None,
+        node: str,
         output: str = DEFAULT_OUTPUT,
         description: Optional[str] = None,
-        node: Optional[str] = None,
     ):
-        if solid and node:
-            raise DagsterInvalidDefinitionError(
-                "Both ``node`` and legacy ``solid`` arguments provided to DependencyDefinition. Please use one or the other."
-            )
-
-        if not solid and not node:
-            raise DagsterInvalidDefinitionError(
-                "Expected node parameter to be str for DependencyDefinition"
-            )
-
-        node = node or solid
         return super(DependencyDefinition, cls).__new__(
             cls,
             check.str_param(node, "node"),
@@ -805,43 +790,43 @@ class MultiDependencyDefinition(
 
 
 class DynamicCollectDependencyDefinition(
-    NamedTuple("_DynamicCollectDependencyDefinition", [("solid_name", str), ("output_name", str)]),
+    NamedTuple("_DynamicCollectDependencyDefinition", [("node_name", str), ("output_name", str)]),
     IDependencyDefinition,
 ):
     def get_node_dependencies(self) -> Sequence[DependencyDefinition]:
-        return [DependencyDefinition(self.solid_name, self.output_name)]
+        return [DependencyDefinition(self.node_name, self.output_name)]
 
     def is_fan_in(self) -> bool:
         return True
 
 
-DepTypeAndOutputs = Tuple[
+DepTypeAndOutputs: TypeAlias = Tuple[
     DependencyType,
     Union[NodeOutput, List[Union[NodeOutput, Type["MappedInputPlaceholder"]]]],
 ]
 
-InputToOutputMap = Dict[NodeInput, DepTypeAndOutputs]
+InputToOutputMap: TypeAlias = Dict[NodeInput, DepTypeAndOutputs]
 
 
 def _create_handle_dict(
-    solid_dict: Mapping[str, Node],
+    node_dict: Mapping[str, Node],
     dep_dict: Mapping[str, Mapping[str, IDependencyDefinition]],
 ) -> InputToOutputMap:
     from .composition import MappedInputPlaceholder
 
-    check.mapping_param(solid_dict, "solid_dict", key_type=str, value_type=Node)
+    check.mapping_param(node_dict, "node_dict", key_type=str, value_type=Node)
     check.two_dim_mapping_param(dep_dict, "dep_dict", value_type=IDependencyDefinition)
 
     handle_dict: InputToOutputMap = {}
 
-    for solid_name, input_dict in dep_dict.items():
-        from_solid = solid_dict[solid_name]
+    for node_name, input_dict in dep_dict.items():
+        from_node = node_dict[node_name]
         for input_name, dep_def in input_dict.items():
             if isinstance(dep_def, MultiDependencyDefinition):
                 handles: List[Union[NodeOutput, Type[MappedInputPlaceholder]]] = []
                 for inner_dep in dep_def.get_dependencies_and_mappings():
                     if isinstance(inner_dep, DependencyDefinition):
-                        handles.append(solid_dict[inner_dep.node].get_output(inner_dep.output))
+                        handles.append(node_dict[inner_dep.node].get_output(inner_dep.output))
                     elif inner_dep is MappedInputPlaceholder:
                         handles.append(inner_dep)
                     else:
@@ -851,17 +836,17 @@ def _create_handle_dict(
                             )
                         )
 
-                handle_dict[from_solid.get_input(input_name)] = (DependencyType.FAN_IN, handles)
+                handle_dict[from_node.get_input(input_name)] = (DependencyType.FAN_IN, handles)
 
             elif isinstance(dep_def, DependencyDefinition):
-                handle_dict[from_solid.get_input(input_name)] = (
+                handle_dict[from_node.get_input(input_name)] = (
                     DependencyType.DIRECT,
-                    solid_dict[dep_def.node].get_output(dep_def.output),
+                    node_dict[dep_def.node].get_output(dep_def.output),
                 )
             elif isinstance(dep_def, DynamicCollectDependencyDefinition):
-                handle_dict[from_solid.get_input(input_name)] = (
+                handle_dict[from_node.get_input(input_name)] = (
                     DependencyType.DYNAMIC_COLLECT,
-                    solid_dict[dep_def.solid_name].get_output(dep_def.output_name),
+                    node_dict[dep_def.node_name].get_output(dep_def.output_name),
                 )
 
             else:
@@ -872,8 +857,8 @@ def _create_handle_dict(
 
 class DependencyStructure:
     @staticmethod
-    def from_definitions(solids: Mapping[str, Node], dep_dict: Mapping[str, Any]):
-        return DependencyStructure(list(dep_dict.keys()), _create_handle_dict(solids, dep_dict))
+    def from_definitions(nodes: Mapping[str, Node], dep_dict: Mapping[str, Any]):
+        return DependencyStructure(list(dep_dict.keys()), _create_handle_dict(nodes, dep_dict))
 
     _node_input_index: DefaultDict[str, Dict[NodeInput, List[NodeOutput]]]
     _node_output_index: Dict[str, DefaultDict[NodeOutput, List[NodeInput]]]
@@ -885,38 +870,40 @@ class DependencyStructure:
         self._input_to_output_map = input_to_output_map
 
         # Building up a couple indexes here so that one can look up all the upstream output handles
-        # or downstream input handles in O(1). Without this, this can become O(N^2) where N is solid
+        # or downstream input handles in O(1). Without this, this can become O(N^2) where N is node
         # count during the GraphQL query in particular
 
-        # solid_name => input_handle => list[output_handle]
+        # node_name => input_handle => list[output_handle]
         self._node_input_index = defaultdict(dict)
 
-        # solid_name => output_handle => list[input_handle]
+        # node_name => output_handle => list[input_handle]
         self._node_output_index = defaultdict(lambda: defaultdict(list))
 
-        # solid_name => dynamic output_handle that this solid will dupe for
+        # node_name => dynamic output_handle that this node will dupe for
         self._dynamic_fan_out_index = {}
 
-        # solid_name => set of dynamic output_handle this collects over
+        # node_name => set of dynamic output_handle this collects over
         self._collect_index = defaultdict(set)
 
         for node_input, (dep_type, node_output_or_list) in self._input_to_output_map.items():
             if dep_type == DependencyType.FAN_IN:
-                node_output_list = []
+                node_output_list: List[NodeOutput] = []
                 for node_output in node_output_or_list:
                     if not isinstance(node_output, NodeOutput):
                         continue
 
                     if node_output.is_dynamic:
                         raise DagsterInvalidDefinitionError(
-                            "Currently, items in a fan-in dependency cannot be downstream of dynamic outputs. "
-                            f'Problematic dependency on dynamic output "{node_output.describe()}".'
+                            "Currently, items in a fan-in dependency cannot be downstream of"
+                            " dynamic outputs. Problematic dependency on dynamic output"
+                            f' "{node_output.describe()}".'
                         )
                     if self._dynamic_fan_out_index.get(node_output.node_name):
                         raise DagsterInvalidDefinitionError(
-                            "Currently, items in a fan-in dependency cannot be downstream of dynamic outputs. "
-                            f'Problematic dependency on output "{node_output.describe()}", downstream of '
-                            f'"{self._dynamic_fan_out_index[node_output.node_name].describe()}".'
+                            "Currently, items in a fan-in dependency cannot be downstream of"
+                            " dynamic outputs. Problematic dependency on output"
+                            f' "{node_output.describe()}", downstream of'
+                            f' "{self._dynamic_fan_out_index[node_output.node_name].describe()}".'
                         )
 
                     node_output_list.append(node_output)
@@ -957,14 +944,13 @@ class DependencyStructure:
                 self._node_output_index[node_output.node.name][node_output].append(node_input)
 
     def _validate_and_set_fan_out(self, node_input: NodeInput, node_output: NodeOutput) -> None:
-        """Helper function for populating _dynamic_fan_out_index"""
-
+        """Helper function for populating _dynamic_fan_out_index."""
         if not node_input.node.definition.input_supports_dynamic_output_dep(node_input.input_name):
             raise DagsterInvalidDefinitionError(
-                f"{node_input.node.describe_node()} cannot be downstream of dynamic output "
-                f'"{node_output.describe()}" since input "{node_input.input_name}" maps to a node '
-                "that is already downstream of another dynamic output. Nodes cannot be downstream of more "
-                "than one dynamic output"
+                f"{node_input.node.describe_node()} cannot be downstream of dynamic output"
+                f' "{node_output.describe()}" since input "{node_input.input_name}" maps to a'
+                " node that is already downstream of another dynamic output. Nodes cannot be"
+                " downstream of more than one dynamic output"
             )
 
         if self._collect_index.get(node_input.node_name):
@@ -980,9 +966,9 @@ class DependencyStructure:
 
         if self._dynamic_fan_out_index[node_input.node_name] != node_output:
             raise DagsterInvalidDefinitionError(
-                f"{node_input.node.describe_node()} cannot be downstream of more than one dynamic output. "
-                f'It is downstream of both "{node_output.describe()}" and '
-                f'"{self._dynamic_fan_out_index[node_input.node_name].describe()}"'
+                f"{node_input.node.describe_node()} cannot be downstream of more than one dynamic"
+                f' output. It is downstream of both "{node_output.describe()}" and'
+                f' "{self._dynamic_fan_out_index[node_input.node_name].describe()}"'
             )
 
     def _validate_and_set_collect(
@@ -1002,15 +988,15 @@ class DependencyStructure:
         # if the output is already fanned out
         if self._dynamic_fan_out_index.get(node_output.node_name):
             raise DagsterInvalidDefinitionError(
-                f"{node_input.node.describe_node()} cannot be downstream of more than one dynamic output. "
-                f'It is downstream of both "{node_output.describe()}" and '
-                f'"{self._dynamic_fan_out_index[node_output.node_name].describe()}"'
+                f"{node_input.node.describe_node()} cannot be downstream of more than one dynamic"
+                f' output. It is downstream of both "{node_output.describe()}" and'
+                f' "{self._dynamic_fan_out_index[node_output.node_name].describe()}"'
             )
 
     def all_upstream_outputs_from_node(self, node_name: str) -> Sequence[NodeOutput]:
         check.str_param(node_name, "node_name")
 
-        # flatten out all outputs that feed into the inputs of this solid
+        # flatten out all outputs that feed into the inputs of this node
         return [
             output_handle
             for output_handle_list in self._node_input_index[node_name].values()
@@ -1035,7 +1021,7 @@ class DependencyStructure:
         """
         Returns a Dict[NodeOutput, List[NodeInput]] that
         represents all the downstream inputs for each output in the
-        dictionary
+        dictionary.
         """
         check.str_param(node_name, "node_name")
         return self._node_output_index[node_name]
