@@ -20,16 +20,17 @@ from typing import (
 import dagster._check as check
 import dagster._seven as seven
 from dagster._annotations import PublicAttr, public
+from dagster._core.definitions.data_version import DataVersion
 from dagster._core.storage.tags import MULTIDIMENSIONAL_PARTITION_PREFIX, SYSTEM_TAG_PREFIX
 from dagster._serdes import DefaultNamedTupleSerializer, whitelist_for_serdes
+from dagster._utils import last_file_comp
+from dagster._utils.backcompat import experimental_class_param_warning
 
 from .metadata import (
     MetadataEntry,
     MetadataMapping,
     MetadataValue,
-    PartitionMetadataEntry,
     RawMetadataValue,
-    last_file_comp,
     normalize_metadata,
 )
 from .utils import DEFAULT_OUTPUT, check_valid_name
@@ -39,7 +40,6 @@ if TYPE_CHECKING:
 
 ASSET_KEY_SPLIT_REGEX = re.compile("[^a-zA-Z0-9_]")
 ASSET_KEY_DELIMITER = "/"
-ASSET_KEY_LEGACY_DELIMITER = "."
 
 
 def parse_asset_key_string(s: str) -> Sequence[str]:
@@ -110,14 +110,10 @@ class AssetKey(NamedTuple("_AssetKey", [("path", PublicAttr[Sequence[str]])])):
                 return False
         return True
 
-    def to_string(self, legacy: Optional[bool] = False) -> Optional[str]:
+    def to_string(self) -> str:
         """
         E.g. '["first_component", "second_component"]'.
         """
-        if not self.path:
-            return None
-        if legacy:
-            return ASSET_KEY_LEGACY_DELIMITER.join(self.path)
         return seven.json.dumps(self.path)
 
     def to_user_string(self) -> str:
@@ -156,17 +152,13 @@ class AssetKey(NamedTuple("_AssetKey", [("path", PublicAttr[Sequence[str]])])):
         return AssetKey(path)
 
     @staticmethod
-    def get_db_prefix(path: Sequence[str], legacy: Optional[bool] = False):
+    def get_db_prefix(path: Sequence[str]):
         check.sequence_param(path, "path", of_type=str)
-        if legacy:
-            return ASSET_KEY_LEGACY_DELIMITER.join(path)
         return seven.json.dumps(path)[:-2]  # strip trailing '"]' from json string
 
     @staticmethod
-    def from_graphql_input(asset_key: Mapping[str, Sequence[str]]) -> Optional["AssetKey"]:
-        if asset_key and asset_key.get("path"):
-            return AssetKey(asset_key["path"])
-        return None
+    def from_graphql_input(graphql_input_asset_key: Mapping[str, Sequence[str]]) -> "AssetKey":
+        return AssetKey(graphql_input_asset_key["path"])
 
     def to_graphql_input(self) -> Mapping[str, Sequence[str]]:
         return {"path": self.path}
@@ -208,7 +200,7 @@ DynamicAssetKey = Callable[["OutputContext"], Optional[AssetKey]]
 class AssetLineageInfo(
     NamedTuple("_AssetLineageInfo", [("asset_key", AssetKey), ("partitions", AbstractSet[str])])
 ):
-    def __new__(cls, asset_key, partitions=None):
+    def __new__(cls, asset_key: AssetKey, partitions: Optional[AbstractSet[str]] = None):
         asset_key = check.inst_param(asset_key, "asset_key", AssetKey)
         partitions = check.opt_set_param(partitions, "partitions", str)
         return super(AssetLineageInfo, cls).__new__(cls, asset_key=asset_key, partitions=partitions)
@@ -232,45 +224,56 @@ class Output(Generic[T]):
         value (Any): The value returned by the compute function.
         output_name (Optional[str]): Name of the corresponding out. (default:
             "result")
-        metadata_entries (Optional[Union[MetadataEntry, PartitionMetadataEntry]]):
+        metadata_entries (Optional[MetadataEntry]):
             (Experimental) A set of metadata entries to attach to events related to this Output.
         metadata (Optional[Dict[str, Union[str, float, int, MetadataValue]]]):
             Arbitrary metadata about the failure.  Keys are displayed string labels, and values are
             one of the following: string, float, int, JSON-serializable dict, JSON-serializable
             list, and one of the data classes returned by a MetadataValue static method.
+        data_version (Optional[DataVersion]): (Experimental) A data version to manually set
+            for the asset.
     """
 
     def __init__(
         self,
         value: T,
         output_name: Optional[str] = DEFAULT_OUTPUT,
-        metadata_entries: Optional[Sequence[Union[MetadataEntry, PartitionMetadataEntry]]] = None,
+        metadata_entries: Optional[Sequence[MetadataEntry]] = None,
         metadata: Optional[Mapping[str, RawMetadataValue]] = None,
+        data_version: Optional[DataVersion] = None,
     ):
         metadata = check.opt_mapping_param(metadata, "metadata", key_type=str)
         metadata_entries = check.opt_sequence_param(
             metadata_entries,
             "metadata_entries",
-            of_type=(MetadataEntry, PartitionMetadataEntry),
+            of_type=MetadataEntry,
         )
         self._value = value
         self._output_name = check.str_param(output_name, "output_name")
         self._metadata_entries = normalize_metadata(metadata, metadata_entries)
+        if data_version is not None:
+            experimental_class_param_warning("data_version", "Output")
+        self._data_version = check.opt_inst_param(data_version, "data_version", DataVersion)
 
     @property
-    def metadata_entries(self) -> Sequence[Union[PartitionMetadataEntry, MetadataEntry]]:
+    def metadata_entries(self) -> Sequence[MetadataEntry]:
         return self._metadata_entries
 
-    @public  # type: ignore
+    @public
     @property
     def value(self) -> Any:
         return self._value
 
-    @public  # type: ignore
+    @public
     @property
     def output_name(self) -> str:
         return self._output_name
 
+    @public
+    @property
+    def data_version(self) -> Optional[DataVersion]:
+        return self._data_version
+
     def __eq__(self, other: object) -> bool:
         return (
             isinstance(other, Output)
@@ -299,7 +302,7 @@ class DynamicOutput(Generic[T]):
         output_name (Optional[str]):
             Name of the corresponding :py:class:`DynamicOut` defined on the op.
             (default: "result")
-        metadata_entries (Optional[Union[MetadataEntry, PartitionMetadataEntry]]):
+        metadata_entries (Optional[MetadataEntry]):
             (Experimental) A set of metadata entries to attach to events related to this output.
         metadata (Optional[Dict[str, Union[str, float, int, MetadataValue]]]):
             Arbitrary metadata about the failure.  Keys are displayed string labels, and values are
@@ -312,7 +315,7 @@ class DynamicOutput(Generic[T]):
         value: T,
         mapping_key: str,
         output_name: Optional[str] = DEFAULT_OUTPUT,
-        metadata_entries: Optional[Sequence[Union[PartitionMetadataEntry, MetadataEntry]]] = None,
+        metadata_entries: Optional[Sequence[MetadataEntry]] = None,
         metadata: Optional[Mapping[str, RawMetadataValue]] = None,
     ):
         metadata = check.opt_mapping_param(metadata, "metadata", key_type=str)
@@ -325,20 +328,20 @@ class DynamicOutput(Generic[T]):
         self._value = value
 
     @property
-    def metadata_entries(self) -> Sequence[Union[PartitionMetadataEntry, MetadataEntry]]:
+    def metadata_entries(self) -> Sequence[MetadataEntry]:
         return self._metadata_entries
 
-    @public  # type: ignore
+    @public
     @property
     def mapping_key(self) -> str:
         return self._mapping_key
 
-    @public  # type: ignore
+    @public
     @property
     def value(self) -> T:
         return self._value
 
-    @public  # type: ignore
+    @public
     @property
     def output_name(self) -> str:
         return self._output_name
@@ -433,7 +436,7 @@ class AssetMaterialization(
         [
             ("asset_key", PublicAttr[AssetKey]),
             ("description", PublicAttr[Optional[str]]),
-            ("metadata_entries", Sequence[Union[MetadataEntry, PartitionMetadataEntry]]),
+            ("metadata_entries", Sequence[MetadataEntry]),
             ("partition", PublicAttr[Optional[str]]),
             ("tags", Optional[Mapping[str, str]]),
         ],
@@ -454,7 +457,7 @@ class AssetMaterialization(
         asset_key (Union[str, List[str], AssetKey]): A key to identify the materialized asset across
             job runs
         description (Optional[str]): A longer human-readable description of the materialized value.
-        metadata_entries (Optional[List[Union[MetadataEntry, PartitionMetadataEntry]]]): Arbitrary
+        metadata_entries (Optional[List[MetadataEntry]]): Arbitrary
             metadata about the materialized value.
         partition (Optional[str]): The name of the partition
             that was materialized.
@@ -470,7 +473,7 @@ class AssetMaterialization(
         cls,
         asset_key: CoercibleToAssetKey,
         description: Optional[str] = None,
-        metadata_entries: Optional[Sequence[Union[MetadataEntry, PartitionMetadataEntry]]] = None,
+        metadata_entries: Optional[Sequence[MetadataEntry]] = None,
         partition: Optional[str] = None,
         tags: Optional[Mapping[str, str]] = None,
         metadata: Optional[Mapping[str, RawMetadataValue]] = None,
@@ -495,7 +498,7 @@ class AssetMaterialization(
 
         metadata = check.opt_mapping_param(metadata, "metadata", key_type=str)
         metadata_entries = check.opt_sequence_param(
-            metadata_entries, "metadata_entries", of_type=(MetadataEntry, PartitionMetadataEntry)
+            metadata_entries, "metadata_entries", of_type=MetadataEntry
         )
 
         partition = check.opt_str_param(partition, "partition")
@@ -546,11 +549,10 @@ class AssetMaterialization(
             metadata={"path": MetadataValue.path(path)},
         )
 
-    @public  # type: ignore
+    @public
     @property
     def metadata(self) -> MetadataMapping:
-        # PartitionMetadataEntry (unstable API) case is unhandled
-        return {entry.label: entry.entry_data for entry in self.metadata_entries}  # type: ignore
+        return {entry.label: entry.value for entry in self.metadata_entries}
 
 
 class MaterializationSerializer(DefaultNamedTupleSerializer):
