@@ -104,13 +104,13 @@ class ExecutorDefinition(NamedConfigurableDefinition):
         )
         self._description = check.opt_str_param(description, "description")
 
-    @public  # type: ignore
+    @public
     @property
     def name(self) -> str:
         """Name of the executor."""
         return self._name
 
-    @public  # type: ignore
+    @public
     @property
     def description(self) -> Optional[str]:
         """Description of executor, if provided."""
@@ -125,7 +125,7 @@ class ExecutorDefinition(NamedConfigurableDefinition):
     ) -> Sequence[ExecutorRequirement]:
         return self._requirements_fn(executor_config)
 
-    @public  # type: ignore
+    @public
     @property
     def executor_creation_fn(self) -> Optional[ExecutorCreationFunction]:
         return self._executor_creation_fn
@@ -133,12 +133,21 @@ class ExecutorDefinition(NamedConfigurableDefinition):
     def copy_for_configured(self, name, description, config_schema) -> "ExecutorDefinition":
         return ExecutorDefinition(
             name=name,
-            config_schema=config_schema,
+            config_schema=config_schema,  # type: ignore
             executor_creation_fn=self.executor_creation_fn,
             description=description or self.description,
             requirements=self._requirements_fn,
         )
 
+    @staticmethod
+    def hardcoded_executor(executor: "Executor"):
+        return ExecutorDefinition(
+            # Executor name was only relevant in the pipeline/solid/mode world, so we
+            # can put a dummy value
+            name="__executor__",
+            executor_creation_fn=lambda _init_context: executor,
+        )
+
     # Backcompat: Overrides configured method to provide name as a keyword argument.
     # If no name is provided, the name is pulled off of this ExecutorDefinition.
     @public
@@ -148,7 +157,7 @@ class ExecutorDefinition(NamedConfigurableDefinition):
         name: Optional[str] = None,
         config_schema: Optional[UserConfigSchema] = None,
         description: Optional[str] = None,
-    ) -> Self:  # type: ignore  # fmt: skip
+    ) -> Self:
         """
         Wraps this object in an object of the same type that provides configuration to the inner
         object.
@@ -257,8 +266,8 @@ def _core_in_process_executor_creation(config: ExecutorConfig) -> "InProcessExec
 
     return InProcessExecutor(
         # shouldn't need to .get() here - issue with defaults in config setup
-        retries=RetryMode.from_config(check.dict_elem(config, "retries")),
-        marker_to_close=config.get("marker_to_close"),
+        retries=RetryMode.from_config(check.dict_elem(config, "retries")),  # type: ignore  # (possible none)
+        marker_to_close=config.get("marker_to_close"),  # type: ignore  # (should be str)
     )
 
 
