@@ -1,4 +1,4 @@
-from typing import Callable, Dict, Mapping, NamedTuple, Optional, cast
+from typing import TYPE_CHECKING, Callable, Dict, Mapping, NamedTuple, Optional, cast
 
 import pendulum
 
@@ -21,17 +21,20 @@ from dagster._serdes import (
 )
 from dagster._serdes.errors import DeserializationError
 from dagster._seven import JSONDecodeError
-from dagster._utils.caching_instance_queryer import CachingInstanceQueryer
 
 from ..decorator_utils import get_function_params
 from .sensor_definition import (
     DefaultSensorStatus,
     SensorDefinition,
     SensorEvaluationContext,
+    SensorType,
     SkipReason,
-    is_context_provided,
+    has_at_least_one_parameter,
 )
 
+if TYPE_CHECKING:
+    pass
+
 
 @whitelist_for_serdes
 class FreshnessPolicySensorCursor(
@@ -209,6 +212,10 @@ class FreshnessPolicySensorDefinition(SensorDefinition):
         )
 
         def _wrapped_fn(context: SensorEvaluationContext):
+            from dagster._utils.caching_instance_queryer import (
+                CachingInstanceQueryer,  # expensive import
+            )
+
             if context.repository_def is None:
                 raise DagsterInvalidInvocationError(
                     "The `repository_def` property on the `SensorEvaluationContext` passed into a "
@@ -278,7 +285,7 @@ class FreshnessPolicySensorDefinition(SensorDefinition):
         )
 
     def __call__(self, *args, **kwargs):
-        if is_context_provided(self._freshness_policy_sensor_fn):
+        if has_at_least_one_parameter(self._freshness_policy_sensor_fn):
             if len(args) + len(kwargs) == 0:
                 raise DagsterInvalidInvocationError(
                     "Freshness policy sensor function expected context argument, but no context"
@@ -320,6 +327,10 @@ class FreshnessPolicySensorDefinition(SensorDefinition):
                 "Freshness policy sensor must accept a context argument."
             )
 
+    @property
+    def sensor_type(self) -> SensorType:
+        return SensorType.FRESHNESS_POLICY
+
 
 @experimental
 def freshness_policy_sensor(
