@@ -19,7 +19,6 @@ from dagster._annotations import PublicAttr
 from dagster._core.definitions.events import AssetKey
 from dagster._core.definitions.metadata import (
     MetadataEntry,
-    PartitionMetadataEntry,
     RawMetadataValue,
     normalize_metadata,
 )
@@ -103,7 +102,7 @@ class InputDefinition:
     _input_manager_key: Optional[str]
     _root_manager_key: Optional[str]
     _metadata: Mapping[str, RawMetadataValue]
-    _metadata_entries: Sequence[Union[MetadataEntry, PartitionMetadataEntry]]
+    _metadata_entries: Sequence[MetadataEntry]
     _asset_key: Optional[Union[AssetKey, Callable[["InputContext"], AssetKey]]]
     _asset_partitions_fn: Optional[Callable[["InputContext"], Set[str]]]
 
@@ -138,7 +137,8 @@ class InputDefinition:
 
         if root_manager_key and input_manager_key:
             raise DagsterInvalidDefinitionError(
-                f"Can't supply both root input manager key {root_manager_key} and input manager key {input_manager_key} on InputDefinition."
+                f"Can't supply both root input manager key {root_manager_key} and input manager key"
+                f" {input_manager_key} on InputDefinition."
             )
 
         self._root_manager_key = check.opt_str_param(root_manager_key, "root_manager_key")
@@ -209,7 +209,7 @@ class InputDefinition:
         return self._asset_key is not None
 
     @property
-    def metadata_entries(self) -> Sequence[Union[MetadataEntry, PartitionMetadataEntry]]:
+    def metadata_entries(self) -> Sequence[MetadataEntry]:
         return self._metadata_entries
 
     @property
@@ -259,7 +259,6 @@ class InputDefinition:
             fan_in_index (Optional[int]): The index in to a fanned in input, else None
 
         Examples:
-
             .. code-block:: python
 
                 input_mapping = InputDefinition('composite_input', Int).mapping_to(
@@ -293,10 +292,12 @@ class InputDefinition:
         Return a new InputDefinition that merges this ones properties with those inferred from type signature.
         This can update: dagster_type, description, and default_value if they are not set.
         """
-
         check.invariant(
             self.name == inferred.name,
-            f"InferredInputProps name {inferred.name} did not align with InputDefinition name {self.name}",
+            (
+                f"InferredInputProps name {inferred.name} did not align with InputDefinition name"
+                f" {self.name}"
+            ),
         )
 
         dagster_type = self._dagster_type
@@ -358,36 +359,28 @@ def _checked_inferred_type(inferred: InferredInputProps) -> DagsterType:
     return resolved_type
 
 
-class InputPointer(NamedTuple("_InputPointer", [("solid_name", str), ("input_name", str)])):
-    def __new__(cls, solid_name: str, input_name: str):
+class InputPointer(NamedTuple("_InputPointer", [("node_name", str), ("input_name", str)])):
+    def __new__(cls, node_name: str, input_name: str):
         return super(InputPointer, cls).__new__(
             cls,
-            check.str_param(solid_name, "solid_name"),
+            check.str_param(node_name, "node_name"),
             check.str_param(input_name, "input_name"),
         )
 
-    @property
-    def node_name(self) -> str:
-        return self.solid_name
-
 
 class FanInInputPointer(
     NamedTuple(
-        "_FanInInputPointer", [("solid_name", str), ("input_name", str), ("fan_in_index", int)]
+        "_FanInInputPointer", [("node_name", str), ("input_name", str), ("fan_in_index", int)]
     )
 ):
-    def __new__(cls, solid_name: str, input_name: str, fan_in_index: int):
+    def __new__(cls, node_name: str, input_name: str, fan_in_index: int):
         return super(FanInInputPointer, cls).__new__(
             cls,
-            check.str_param(solid_name, "solid_name"),
+            check.str_param(node_name, "node_name"),
             check.str_param(input_name, "input_name"),
             check.int_param(fan_in_index, "fan_in_index"),
         )
 
-    @property
-    def node_name(self) -> str:
-        return self.solid_name
-
 
 class InputMapping(NamedTuple):
     """Defines an input mapping for a graph.
@@ -402,7 +395,6 @@ class InputMapping(NamedTuple):
             being mapped from. Users should not use this argument when instantiating the class.
 
     Examples:
-
         .. code-block:: python
 
             from dagster import InputMapping, GraphDefinition, op, graph
@@ -449,9 +441,7 @@ class InputMapping(NamedTuple):
 
     def describe(self) -> str:
         idx = self.maps_to.fan_in_index if isinstance(self.maps_to, FanInInputPointer) else ""
-        return (
-            f"{self.graph_input_name} -> {self.maps_to.solid_name}:{self.maps_to.input_name}{idx}"
-        )
+        return f"{self.graph_input_name} -> {self.maps_to.node_name}:{self.maps_to.input_name}{idx}"
 
     def get_definition(self) -> "InputDefinition":
         return InputDefinition(
@@ -519,7 +509,8 @@ class In(
     ):
         if root_manager_key and input_manager_key:
             raise DagsterInvalidDefinitionError(
-                f"Can't supply both root input manager key {root_manager_key} and input manager key {input_manager_key} on InputDefinition."
+                f"Can't supply both root input manager key {root_manager_key} and input manager key"
+                f" {input_manager_key} on InputDefinition."
             )
 
         if root_manager_key:
@@ -538,7 +529,7 @@ class In(
             default_value=default_value,
             root_manager_key=check.opt_str_param(root_manager_key, "root_manager_key"),
             metadata=check.opt_mapping_param(metadata, "metadata", key_type=str),
-            asset_key=check.opt_inst_param(asset_key, "asset_key", (AssetKey, FunctionType)),  # type: ignore  # (mypy bug)
+            asset_key=check.opt_inst_param(asset_key, "asset_key", (AssetKey, FunctionType)),
             asset_partitions=asset_partitions,
             input_manager_key=check.opt_str_param(input_manager_key, "input_manager_key"),
         )
