@@ -1,6 +1,7 @@
 import importlib
 import os
 import warnings
+from datetime import datetime
 from functools import update_wrapper
 from typing import (
     TYPE_CHECKING,
@@ -17,6 +18,8 @@ from typing import (
     cast,
 )
 
+from typing_extensions import Self
+
 import dagster._check as check
 from dagster._annotations import public
 from dagster._config import Field, Shape, StringSource
@@ -24,17 +27,19 @@ from dagster._config.config_type import ConfigType
 from dagster._config.validate import validate_config
 from dagster._core.definitions.composition import MappedInputPlaceholder
 from dagster._core.definitions.dependency import (
-    DependencyDefinition,
     DynamicCollectDependencyDefinition,
     IDependencyDefinition,
     MultiDependencyDefinition,
     Node,
     NodeHandle,
+    NodeInputHandle,
     NodeInvocation,
     NodeOutput,
 )
 from dagster._core.definitions.events import AssetKey
+from dagster._core.definitions.metadata import MetadataEntry
 from dagster._core.definitions.node_definition import NodeDefinition
+from dagster._core.definitions.partition import DynamicPartitionsDefinition
 from dagster._core.definitions.policy import RetryPolicy
 from dagster._core.definitions.utils import check_valid_name
 from dagster._core.errors import (
@@ -45,13 +50,14 @@ from dagster._core.errors import (
 )
 from dagster._core.selector.subset_selector import (
     AssetSelectionData,
-    LeafNodeSelection,
     OpSelectionData,
+    SelectionTreeBranch,
+    SelectionTreeLeaf,
     parse_op_selection,
 )
 from dagster._core.storage.io_manager import IOManagerDefinition, io_manager
 from dagster._core.utils import str_format_set
-from dagster._utils import merge_dicts
+from dagster._utils.merger import merge_dicts
 
 from .asset_layer import AssetLayer, build_asset_selection_job
 from .config import ConfigMapping
@@ -60,9 +66,9 @@ from .executor_definition import ExecutorDefinition, multi_or_in_process_executo
 from .graph_definition import GraphDefinition, SubselectedGraphDefinition
 from .hook_definition import HookDefinition
 from .logger_definition import LoggerDefinition
-from .metadata import MetadataEntry, PartitionMetadataEntry, RawMetadataValue
+from .metadata import RawMetadataValue
 from .mode import ModeDefinition
-from .partition import PartitionSetDefinition, PartitionedConfig, PartitionsDefinition
+from .partition import PartitionedConfig, PartitionsDefinition, PartitionSetDefinition
 from .pipeline_definition import PipelineDefinition
 from .preset import PresetDefinition
 from .resource_definition import ResourceDefinition
@@ -78,7 +84,6 @@ if TYPE_CHECKING:
 
 
 class JobDefinition(PipelineDefinition):
-
     _cached_partition_set: Optional["PartitionSetDefinition"]
     _subset_selection_data: Optional[Union[OpSelectionData, AssetSelectionData]]
     input_values: Mapping[str, object]
@@ -102,11 +107,12 @@ class JobDefinition(PipelineDefinition):
         _subset_selection_data: Optional[Union[OpSelectionData, AssetSelectionData]] = None,
         asset_layer: Optional[AssetLayer] = None,
         input_values: Optional[Mapping[str, object]] = None,
-        _metadata_entries: Optional[Sequence[Union[MetadataEntry, PartitionMetadataEntry]]] = None,
+        _metadata_entries: Optional[Sequence[MetadataEntry]] = None,
         _executor_def_specified: Optional[bool] = None,
         _logger_defs_specified: Optional[bool] = None,
         _preset_defs: Optional[Sequence[PresetDefinition]] = None,
     ):
+        from dagster._core.definitions.run_config import RunConfig, convert_config_input
         from dagster._loggers import default_loggers
 
         check.inst_param(graph_def, "graph_def", GraphDefinition)
@@ -141,7 +147,11 @@ class JobDefinition(PipelineDefinition):
         logger_defs = logger_defs or default_loggers()
         name = check_valid_name(check.opt_str_param(name, "name", default=graph_def.name))
 
-        config = check.opt_inst_param(config, "config", (Mapping, ConfigMapping, PartitionedConfig))
+        config = check.opt_inst_param(
+            config, "config", (Mapping, ConfigMapping, PartitionedConfig, RunConfig)
+        )
+        config = convert_config_input(config)
+
         description = check.opt_str_param(description, "description")
         partitions_def = check.opt_inst_param(
             partitions_def, "partitions_def", PartitionsDefinition
@@ -185,7 +195,10 @@ class JobDefinition(PipelineDefinition):
             elif isinstance(config, dict):
                 check.invariant(
                     len(_preset_defs) == 0,
-                    "Bad state: attempted to pass preset definitions to job alongside config dictionary.",
+                    (
+                        "Bad state: attempted to pass preset definitions to job alongside config"
+                        " dictionary."
+                    ),
                 )
                 presets = [PresetDefinition(name="default", run_config=config)]
                 # Using config mapping here is a trick to make it so that the preset will be used even
@@ -204,8 +217,8 @@ class JobDefinition(PipelineDefinition):
                 self._explicit_config = True
             elif config is not None:
                 check.failed(
-                    f"config param must be a ConfigMapping, a PartitionedConfig, or a dictionary, but "
-                    f"is an object of type {type(config)}"
+                    "config param must be a ConfigMapping, a PartitionedConfig, or a dictionary,"
+                    f" but is an object of type {type(config)}"
                 )
 
         # Exists for backcompat - JobDefinition is implemented as a single-mode pipeline.
@@ -223,7 +236,8 @@ class JobDefinition(PipelineDefinition):
         for input_name in sorted(list(self.input_values.keys())):
             if not graph_def.has_input(input_name):
                 raise DagsterInvalidDefinitionError(
-                    f"Error when constructing JobDefinition '{name}': Input value provided for key '{input_name}', but job has no top-level input with that name."
+                    f"Error when constructing JobDefinition '{name}': Input value provided for key"
+                    f" '{input_name}', but job has no top-level input with that name."
                 )
 
         super(JobDefinition, self).__init__(
@@ -238,7 +252,7 @@ class JobDefinition(PipelineDefinition):
             solid_retry_policy=op_retry_policy,
             graph_def=graph_def,
             version_strategy=version_strategy,
-            asset_layer=asset_layer,
+            asset_layer=asset_layer or _infer_asset_layer_from_source_asset_deps(graph_def),
         )
 
     @property
@@ -252,27 +266,27 @@ class JobDefinition(PipelineDefinition):
     def describe_target(self):
         return f"{self.target_type} '{self.name}'"
 
-    @public  # type: ignore
+    @public
     @property
     def executor_def(self) -> ExecutorDefinition:
         return self.get_mode_definition().executor_defs[0]
 
-    @public  # type: ignore
+    @public
     @property
     def resource_defs(self) -> Mapping[str, ResourceDefinition]:
         return self.get_mode_definition().resource_defs
 
-    @public  # type: ignore
+    @public
     @property
     def partitioned_config(self) -> Optional[PartitionedConfig]:
         return self.get_mode_definition().partitioned_config
 
-    @public  # type: ignore
+    @public
     @property
     def config_mapping(self) -> Optional[ConfigMapping]:
         return self.get_mode_definition().config_mapping
 
-    @public  # type: ignore
+    @public
     @property
     def loggers(self) -> Mapping[str, LoggerDefinition]:
         return self.get_mode_definition().loggers
@@ -317,20 +331,25 @@ class JobDefinition(PipelineDefinition):
                 ancestors, ``other_op_a`` itself, and ``other_op_b`` and its direct child ops.
             input_values (Optional[Mapping[str, Any]]):
                 A dictionary that maps python objects to the top-level inputs of the job. Input values provided here will override input values that have been provided to the job directly.
+
         Returns:
             :py:class:`~dagster.ExecuteInProcessResult`
 
         """
         from dagster._core.definitions.executor_definition import execute_in_process_executor
+        from dagster._core.definitions.run_config import convert_config_input
         from dagster._core.execution.execute_in_process import core_execute_in_process
 
-        run_config = check.opt_mapping_param(run_config, "run_config")
+        run_config = check.opt_mapping_param(convert_config_input(run_config), "run_config")
         op_selection = check.opt_sequence_param(op_selection, "op_selection", str)
         asset_selection = check.opt_sequence_param(asset_selection, "asset_selection", AssetKey)
 
         check.invariant(
             not (op_selection and asset_selection),
-            "op_selection and asset_selection cannot both be provided as args to execute_in_process",
+            (
+                "op_selection and asset_selection cannot both be provided as args to"
+                " execute_in_process"
+            ),
         )
 
         partition_key = check.opt_str_param(partition_key, "partition_key")
@@ -369,15 +388,17 @@ class JobDefinition(PipelineDefinition):
         if partition_key:
             if not self.partitioned_config:
                 check.failed(
-                    f"Provided partition key `{partition_key}` for job `{self._name}` without a partitioned config"
+                    f"Provided partition key `{partition_key}` for job `{self._name}` without a"
+                    " partitioned config"
                 )
             partition_set = self.get_partition_set_def()
             if not partition_set:
                 check.failed(
-                    f"Provided partition key `{partition_key}` for job `{self._name}` without a partitioned config"
+                    f"Provided partition key `{partition_key}` for job `{self._name}` without a"
+                    " partitioned config"
                 )
 
-            partition = partition_set.get_partition(partition_key)
+            partition = partition_set.get_partition(partition_key, instance)
             run_config = (
                 run_config if run_config else partition_set.run_config_for_partition(partition)
             )
@@ -420,14 +441,17 @@ class JobDefinition(PipelineDefinition):
         self,
         op_selection: Optional[Sequence[str]] = None,
         asset_selection: Optional[AbstractSet[AssetKey]] = None,
-    ):
+    ) -> Self:
         check.invariant(
             not (op_selection and asset_selection),
-            "op_selection and asset_selection cannot both be provided as args to execute_in_process",
+            (
+                "op_selection and asset_selection cannot both be provided as args to"
+                " execute_in_process"
+            ),
         )
         if op_selection:
             return self._get_job_def_for_op_selection(op_selection)
-        if asset_selection:  # asset_selection:
+        if asset_selection:
             return self._get_job_def_for_asset_selection(asset_selection)
         else:
             return self
@@ -435,7 +459,7 @@ class JobDefinition(PipelineDefinition):
     def _get_job_def_for_asset_selection(
         self,
         asset_selection: Optional[AbstractSet[AssetKey]] = None,
-    ) -> "JobDefinition":
+    ) -> Self:
         asset_selection = check.opt_set_param(asset_selection, "asset_selection", AssetKey)
 
         nonexistent_assets = [
@@ -481,7 +505,7 @@ class JobDefinition(PipelineDefinition):
     def _get_job_def_for_op_selection(
         self,
         op_selection: Optional[Sequence[str]] = None,
-    ) -> "JobDefinition":
+    ) -> Self:
         if not op_selection:
             return self
 
@@ -535,13 +559,11 @@ class JobDefinition(PipelineDefinition):
             ) from exc
 
     def get_partition_set_def(self) -> Optional["PartitionSetDefinition"]:
-
         mode = self.get_mode_definition()
         if not mode.partitioned_config:
             return None
 
         if not self._cached_partition_set:
-
             tags_fn = mode.partitioned_config.tags_for_partition_fn
             if not tags_fn:
                 tags_fn = lambda _: {}
@@ -556,7 +578,7 @@ class JobDefinition(PipelineDefinition):
 
         return self._cached_partition_set
 
-    @public  # type: ignore
+    @public
     @property
     def partitions_def(self) -> Optional[PartitionsDefinition]:
         mode = self.get_mode_definition()
@@ -573,6 +595,8 @@ class JobDefinition(PipelineDefinition):
         tags: Optional[Mapping[str, str]] = None,
         asset_selection: Optional[Sequence[AssetKey]] = None,
         run_config: Optional[Mapping[str, Any]] = None,
+        instance: Optional["DagsterInstance"] = None,
+        current_time: Optional[datetime] = None,
     ) -> RunRequest:
         """
         Creates a RunRequest object for a run that processes the given partition.
@@ -588,6 +612,8 @@ class JobDefinition(PipelineDefinition):
             run_config (Optional[Mapping[str, Any]]: Configuration for the run. If the job has
                 a :py:class:`PartitionedConfig`, this value will override replace the config
                 provided by it.
+            current_time (Optional[datetime): Used to determine which time-partitions exist.
+                Defaults to now.
 
         Returns:
             RunRequest: an object that requests a run to process the given partition.
@@ -596,7 +622,16 @@ class JobDefinition(PipelineDefinition):
         if not partition_set:
             check.failed("Called run_request_for_partition on a non-partitioned job")
 
-        partition = partition_set.get_partition(partition_key)
+        if isinstance(partition_set.partitions_def, DynamicPartitionsDefinition):
+            if not instance:
+                check.failed(
+                    "Must provide a dagster instance when calling run_request_for_partition on a "
+                    "dynamic partition set"
+                )
+
+        partition = partition_set.get_partition(
+            partition_key, dynamic_partitions_store=instance, current_time=current_time
+        )
         run_request_tags = (
             {**tags, **partition_set.tags_for_partition(partition)}
             if tags
@@ -616,7 +651,6 @@ class JobDefinition(PipelineDefinition):
     @public
     def with_hooks(self, hook_defs: AbstractSet[HookDefinition]) -> "JobDefinition":
         """Apply a set of hooks to all op instances within the job."""
-
         hook_defs = check.set_param(hook_defs, "hook_defs", of_type=HookDefinition)
 
         job_def = JobDefinition(
@@ -655,7 +689,9 @@ class JobDefinition(PipelineDefinition):
     def get_direct_input_value(self, input_name: str) -> object:
         if input_name not in self.input_values:
             raise DagsterInvalidInvocationError(
-                f"On job '{self.name}', attempted to retrieve input value for input named '{input_name}', but no value was provided. Provided input values: {sorted(list(self.input_values.keys()))}"
+                f"On job '{self.name}', attempted to retrieve input value for input named"
+                f" '{input_name}', but no value was provided. Provided input values:"
+                f" {sorted(list(self.input_values.keys()))}"
             )
         return self.input_values[input_name]
 
@@ -735,7 +771,7 @@ def _dep_key_of(node: Node) -> NodeInvocation:
 
 def get_subselected_graph_definition(
     graph: GraphDefinition,
-    resolved_op_selection_dict: Mapping,
+    resolved_op_selection_dict: SelectionTreeBranch,
     parent_handle: Optional[NodeHandle] = None,
 ) -> SubselectedGraphDefinition:
     deps: Dict[
@@ -745,7 +781,7 @@ def get_subselected_graph_definition(
 
     selected_nodes: List[Tuple[str, NodeDefinition]] = []
 
-    for node in graph.solids_in_topological_order:
+    for node in graph.nodes_in_topological_order:
         node_handle = NodeHandle(node.name, parent=parent_handle)
         # skip if the node isn't selected
         if node.name not in resolved_op_selection_dict:
@@ -753,13 +789,11 @@ def get_subselected_graph_definition(
 
         # rebuild graph if any nodes inside the graph are selected
         definition: Union[SubselectedGraphDefinition, NodeDefinition]
-        if (
-            isinstance(node, GraphNode)
-            and resolved_op_selection_dict[node.name] is not LeafNodeSelection
-        ):
+        selection_node = resolved_op_selection_dict[node.name]
+        if isinstance(node, GraphNode) and not isinstance(selection_node, SelectionTreeLeaf):
             definition = get_subselected_graph_definition(
                 node.definition,
-                resolved_op_selection_dict[node.name],
+                selection_node,
                 parent_handle=node_handle,
             )
         # use definition if the node as a whole is selected. this includes selecting the entire graph
@@ -783,7 +817,7 @@ def get_subselected_graph_definition(
                     deps[_dep_key_of(node)][
                         node_input.input_def.name
                     ] = DynamicCollectDependencyDefinition(
-                        solid_name=node_output.node.name,
+                        node_name=node_output.node.name,
                         output_name=node_output.output_def.name,
                     )
             elif graph.dependency_structure.has_fan_in_deps(node_input):
@@ -809,14 +843,14 @@ def get_subselected_graph_definition(
     # filter out unselected input/output mapping
     new_input_mappings = list(
         filter(
-            lambda input_mapping: input_mapping.maps_to.solid_name
+            lambda input_mapping: input_mapping.maps_to.node_name
             in [name for name, _ in selected_nodes],
             graph._input_mappings,  # pylint: disable=protected-access
         )
     )
     new_output_mappings = list(
         filter(
-            lambda output_mapping: output_mapping.maps_from.solid_name
+            lambda output_mapping: output_mapping.maps_from.node_name
             in [name for name, _ in selected_nodes],
             graph._output_mappings,  # pylint: disable=protected-access
         )
@@ -855,7 +889,10 @@ def default_job_io_manager(init_context: "InitResourceContext"):
             attr = getattr(module, attribute_name)
             check.invariant(
                 isinstance(attr, IOManagerDefinition),
-                "DAGSTER_DEFAULT_IO_MANAGER_MODULE and DAGSTER_DEFAULT_IO_MANAGER_ATTRIBUTE must specify an IOManagerDefinition",
+                (
+                    "DAGSTER_DEFAULT_IO_MANAGER_MODULE and DAGSTER_DEFAULT_IO_MANAGER_ATTRIBUTE"
+                    " must specify an IOManagerDefinition"
+                ),
             )
             with build_resources({"io_manager": attr}, instance=init_context.instance) as resources:
                 return resources.io_manager
@@ -864,8 +901,8 @@ def default_job_io_manager(init_context: "InitResourceContext"):
                 raise
             else:
                 warnings.warn(
-                    f"Failed to load io manager override with module: {module_name} attribute: {attribute_name}: {e}\n"
-                    "Falling back to default io manager."
+                    f"Failed to load io manager override with module: {module_name} attribute:"
+                    f" {attribute_name}: {e}\nFalling back to default io manager."
                 )
 
     # normally, default to the fs_io_manager
@@ -893,7 +930,10 @@ def default_job_io_manager_with_fs_io_manager_schema(init_context: "InitResource
             attr = getattr(module, attribute_name)
             check.invariant(
                 isinstance(attr, IOManagerDefinition),
-                "DAGSTER_DEFAULT_IO_MANAGER_MODULE and DAGSTER_DEFAULT_IO_MANAGER_ATTRIBUTE must specify an IOManagerDefinition",
+                (
+                    "DAGSTER_DEFAULT_IO_MANAGER_MODULE and DAGSTER_DEFAULT_IO_MANAGER_ATTRIBUTE"
+                    " must specify an IOManagerDefinition"
+                ),
             )
             with build_resources({"io_manager": attr}, instance=init_context.instance) as resources:
                 return resources.io_manager
@@ -902,8 +942,8 @@ def default_job_io_manager_with_fs_io_manager_schema(init_context: "InitResource
                 raise
             else:
                 warnings.warn(
-                    f"Failed to load io manager override with module: {module_name} attribute: {attribute_name}: {e}\n"
-                    "Falling back to default io manager."
+                    f"Failed to load io manager override with module: {module_name} attribute:"
+                    f" {attribute_name}: {e}\nFalling back to default io manager."
                 )
     from dagster._core.storage.fs_io_manager import PickledObjectFilesystemIOManager
 
@@ -985,3 +1025,53 @@ def get_run_config_schema_for_job(
         .get_run_config_schema("default")
         .run_config_schema_type
     )
+
+
+def _infer_asset_layer_from_source_asset_deps(job_graph_def: GraphDefinition) -> AssetLayer:
+    """
+    For non-asset jobs that have some inputs that are fed from SourceAssets, constructs an
+    AssetLayer that includes those SourceAssets.
+    """
+    asset_keys_by_node_input_handle: Dict[NodeInputHandle, AssetKey] = {}
+    source_assets_list = []
+    source_asset_keys_set = set()
+    io_manager_keys_by_asset_key: Mapping[AssetKey, str] = {}
+
+    # each entry is a graph definition and its handle relative to the job root
+    stack: List[Tuple[GraphDefinition, Optional[NodeHandle]]] = [(job_graph_def, None)]
+
+    while stack:
+        graph_def, parent_node_handle = stack.pop()
+
+        for node_name, input_source_assets in graph_def.node_input_source_assets.items():
+            node_handle = NodeHandle(node_name, parent_node_handle)
+            for input_name, source_asset in input_source_assets.items():
+                if source_asset.key not in source_asset_keys_set:
+                    source_asset_keys_set.add(source_asset.key)
+                    source_assets_list.append(source_asset)
+
+                input_handle = NodeInputHandle(node_handle, input_name)
+                asset_keys_by_node_input_handle[input_handle] = source_asset.key
+                for resolved_input_handle in graph_def.node_dict[
+                    node_name
+                ].definition.resolve_input_to_destinations(input_handle):
+                    asset_keys_by_node_input_handle[resolved_input_handle] = source_asset.key
+
+                if source_asset.io_manager_key:
+                    io_manager_keys_by_asset_key[source_asset.key] = source_asset.io_manager_key
+
+        for node_name, node in graph_def.node_dict.items():
+            if isinstance(node.definition, GraphDefinition):
+                stack.append((node.definition, NodeHandle(node_name, parent_node_handle)))
+
+    return AssetLayer(
+        asset_keys_by_node_input_handle=asset_keys_by_node_input_handle,
+        asset_info_by_node_output_handle={},
+        asset_deps={},
+        dependency_node_handles_by_asset_key={},
+        assets_defs=[],
+        source_asset_defs=source_assets_list,
+        io_manager_keys_by_asset_key=io_manager_keys_by_asset_key,
+        node_output_handles_to_dep_asset_keys={},
+        partition_mappings_by_asset_dep={},
+    )
