@@ -85,17 +85,17 @@ class LoggerDefinition(AnonymousConfigurableDefinition):
 
             return logger_invocation_result(self, context)
 
-    @public  # type: ignore
+    @public
     @property
     def logger_fn(self) -> "InitLoggerFunction":
         return self._logger_fn
 
-    @public  # type: ignore
+    @public
     @property
     def config_schema(self) -> Any:
         return self._config_schema
 
-    @public  # type: ignore
+    @public
     @property
     def description(self) -> Optional[str]:
         return self._description
@@ -188,7 +188,10 @@ def build_init_logger_context(
 
     check.invariant(
         not (pipeline_def and job_def),
-        "In build_init_logger_context, you may only specify one of the pipeline_def and job_def parameters, not both.",
+        (
+            "In build_init_logger_context, you may only specify one of the pipeline_def and job_def"
+            " parameters, not both."
+        ),
     )
 
     return UnboundInitLoggerContext(
