@@ -1,34 +1,44 @@
-import functools
 import os
-import re
 from abc import ABC, abstractmethod
 from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
     Dict,
+    Generic,
     List,
     Mapping,
     NamedTuple,
     Optional,
     Sequence,
+    TypeVar,
     Union,
     cast,
     overload,
 )
 
+from typing_extensions import Self, TypeAlias
+
 import dagster._check as check
 import dagster._seven as seven
 from dagster._annotations import PublicAttr, experimental, public
 from dagster._core.errors import DagsterInvalidMetadata
 from dagster._serdes import whitelist_for_serdes
+from dagster._serdes.serdes import (
+    PackableValue,
+)
 from dagster._utils.backcompat import (
     canonicalize_backcompat_args,
     deprecation_warning,
-    experimental_class_warning,
 )
 
-from .table import TableColumn, TableColumnConstraints, TableConstraints, TableRecord, TableSchema
+from .table import (  # re-exported
+    TableColumn as TableColumn,
+    TableColumnConstraints as TableColumnConstraints,
+    TableConstraints as TableConstraints,
+    TableRecord as TableRecord,
+    TableSchema as TableSchema,
+)
 
 if TYPE_CHECKING:
     from dagster._core.definitions.events import AssetKey
@@ -40,15 +50,13 @@ RawMetadataValue = Union[
     int,
     List[Any],
     str,
+    None,
 ]
 
-MetadataMapping = Mapping[str, "MetadataValue"]
-MetadataUserInput = Mapping[str, RawMetadataValue]
-
-
-def last_file_comp(path: str) -> str:
-    return os.path.basename(os.path.normpath(path))
+MetadataMapping: TypeAlias = Mapping[str, "MetadataValue"]
+MetadataUserInput: TypeAlias = Mapping[str, RawMetadataValue]
 
+T_Packable = TypeVar("T_Packable", bound=PackableValue)
 
 # ########################
 # ##### NORMALIZATION
@@ -67,17 +75,17 @@ def normalize_metadata(
 @overload
 def normalize_metadata(
     metadata: Mapping[str, RawMetadataValue],
-    metadata_entries: Sequence[Union["MetadataEntry", "PartitionMetadataEntry"]],
+    metadata_entries: Sequence["MetadataEntry"],
     allow_invalid: bool = False,
-) -> Sequence[Union["MetadataEntry", "PartitionMetadataEntry"]]:
+) -> Sequence["MetadataEntry"]:
     ...
 
 
 def normalize_metadata(
     metadata: Mapping[str, RawMetadataValue],
-    metadata_entries: Sequence[Union["MetadataEntry", "PartitionMetadataEntry"]],
+    metadata_entries: Sequence["MetadataEntry"],
     allow_invalid: bool = False,
-) -> Sequence[Union["MetadataEntry", "PartitionMetadataEntry"]]:
+) -> Sequence["MetadataEntry"]:
     if metadata and metadata_entries:
         raise DagsterInvalidMetadata(
             "Attempted to provide both `metadata` and `metadata_entries` arguments to an event. "
@@ -88,12 +96,13 @@ def normalize_metadata(
         deprecation_warning(
             'Argument "metadata_entries"',
             "1.0.0",
-            additional_warn_txt="Use argument `metadata` instead. The `MetadataEntry` `description` attribute is also deprecated-- argument `metadata` takes a label: value dictionary.",
+            additional_warn_txt=(
+                "Use argument `metadata` instead. The `MetadataEntry` `description` attribute is"
+                " also deprecated-- argument `metadata` takes a label: value dictionary."
+            ),
             stacklevel=4,  # to get the caller of `normalize_metadata`
         )
-        return check.sequence_param(
-            metadata_entries, "metadata_entries", (MetadataEntry, PartitionMetadataEntry)
-        )
+        return check.sequence_param(metadata_entries, "metadata_entries", MetadataEntry)
 
     # This is a stopgap measure to deal with unsupported metadata values, which occur when we try
     # to convert arbitrary metadata (on e.g. OutputDefinition) to a MetadataValue, which is required
@@ -108,12 +117,15 @@ def normalize_metadata(
                 deprecation_warning(
                     "Support for arbitrary metadata values",
                     "1.0.0",
-                    additional_warn_txt=f"In the future, all user-supplied metadata values must be one of {RawMetadataValue}",
+                    additional_warn_txt=(
+                        "In the future, all user-supplied metadata values must be one of"
+                        f" {RawMetadataValue}"
+                    ),
                     stacklevel=4,  # to get the caller of `normalize_metadata`
                 )
                 metadata_entries.append(
                     MetadataEntry(
-                        entry_data=TextMetadataValue(f"[{v.__class__.__name__}] (unserializable)"),
+                        value=TextMetadataValue(f"[{v.__class__.__name__}] (unserializable)"),
                         label=k,
                     )
                 )
@@ -125,7 +137,7 @@ def normalize_metadata(
     ]
 
 
-def normalize_metadata_value(raw_value: RawMetadataValue):
+def normalize_metadata_value(raw_value: RawMetadataValue) -> "MetadataValue":
     from dagster._core.definitions.events import AssetKey
 
     if isinstance(raw_value, MetadataValue):
@@ -138,7 +150,7 @@ def normalize_metadata_value(raw_value: RawMetadataValue):
         return MetadataValue.bool(raw_value)
     elif isinstance(raw_value, int):
         return MetadataValue.int(raw_value)
-    elif isinstance(raw_value, dict):
+    elif isinstance(raw_value, (list, dict)):
         return MetadataValue.json(raw_value)
     elif isinstance(raw_value, os.PathLike):
         return MetadataValue.path(raw_value)
@@ -146,6 +158,8 @@ def normalize_metadata_value(raw_value: RawMetadataValue):
         return MetadataValue.asset(raw_value)
     elif isinstance(raw_value, TableSchema):
         return MetadataValue.table_schema(raw_value)
+    elif raw_value is None:
+        return MetadataValue.null()
 
     raise DagsterInvalidMetadata(
         f"Its type was {type(raw_value)}. Consider wrapping the value with the appropriate "
@@ -156,10 +170,10 @@ def normalize_metadata_value(raw_value: RawMetadataValue):
 def package_metadata_value(label: str, raw_value: RawMetadataValue) -> "MetadataEntry":
     check.str_param(label, "label")
 
-    if isinstance(raw_value, (MetadataEntry, PartitionMetadataEntry)):
+    if isinstance(raw_value, MetadataEntry):
         raise DagsterInvalidMetadata(
-            f"Expected a metadata value, found an instance of {raw_value.__class__.__name__}. Consider "
-            "instead using a MetadataValue wrapper for the value."
+            f"Expected a metadata value, found an instance of {raw_value.__class__.__name__}."
+            " Consider instead using a MetadataValue wrapper for the value."
         )
     try:
         value = normalize_metadata_value(raw_value)
@@ -175,7 +189,7 @@ def package_metadata_value(label: str, raw_value: RawMetadataValue) -> "Metadata
 # ########################
 
 
-class MetadataValue(ABC):
+class MetadataValue(ABC, Generic[T_Packable]):
     """Utility class to wrap metadata values passed into Dagster events so that they can be
     displayed in Dagit and other tooling.
 
@@ -193,10 +207,10 @@ class MetadataValue(ABC):
             )
     """
 
-    @public  # type: ignore
+    @public
     @property
     @abstractmethod
-    def value(self) -> object:
+    def value(self) -> T_Packable:
         raise NotImplementedError()
 
     @public
@@ -292,9 +306,9 @@ class MetadataValue(ABC):
 
     @public
     @staticmethod
-    def json(data: Mapping[str, Any]) -> "JsonMetadataValue":
-        """Static constructor for a metadata value wrapping a path as
-        :py:class:`JsonMetadataValue`. Can be used as the value type for the `metadata`
+    def json(data: Union[Sequence[Any], Mapping[str, Any]]) -> "JsonMetadataValue":
+        """Static constructor for a metadata value wrapping a json-serializable list or dict
+        as :py:class:`JsonMetadataValue`. Can be used as the value type for the `metadata`
         parameter for supported events. For example:
 
         .. code-block:: python
@@ -310,7 +324,7 @@ class MetadataValue(ABC):
                 )
 
         Args:
-            data (Dict[str, Any]): The JSON data for a metadata entry.
+            data (Union[Sequence[Any], Mapping[str, Any]]): The JSON data for a metadata entry.
         """
         return JsonMetadataValue(data)
 
@@ -384,7 +398,6 @@ class MetadataValue(ABC):
         Args:
             value (float): The float value for a metadata entry.
         """
-
         return FloatMetadataValue(value)
 
     @public
@@ -408,7 +421,6 @@ class MetadataValue(ABC):
         Args:
             value (int): The int value for a metadata entry.
         """
-
         return IntMetadataValue(value)
 
     @public
@@ -432,7 +444,6 @@ class MetadataValue(ABC):
         Args:
             value (bool): The bool value for a metadata entry.
         """
-
         return BoolMetadataValue(value)
 
     @public
@@ -466,7 +477,6 @@ class MetadataValue(ABC):
         Args:
             asset_key (AssetKey): The asset key referencing the asset.
         """
-
         from dagster._core.definitions.events import AssetKey
 
         check.inst_param(asset_key, "asset_key", AssetKey)
@@ -538,6 +548,14 @@ class MetadataValue(ABC):
         """
         return TableSchemaMetadataValue(schema)
 
+    @public
+    @staticmethod
+    def null() -> "NullMetadataValue":
+        """Static constructor for a metadata value representing null. Can be used as the value type
+        for the `metadata` parameter for supported events.
+        """
+        return NullMetadataValue()
+
 
 # ########################
 # ##### METADATA VALUE TYPES
@@ -552,14 +570,14 @@ class MetadataValue(ABC):
 
 
 @whitelist_for_serdes(storage_name="TextMetadataEntryData")
-class TextMetadataValue(  # type: ignore
+class TextMetadataValue(
     NamedTuple(
         "_TextMetadataValue",
         [
             ("text", PublicAttr[Optional[str]]),
         ],
     ),
-    MetadataValue,
+    MetadataValue[str],
 ):
     """Container class for text metadata entry data.
 
@@ -572,21 +590,21 @@ class TextMetadataValue(  # type: ignore
             cls, check.opt_str_param(text, "text", default="")
         )
 
-    @public  # type: ignore
+    @public
     @property
     def value(self) -> Optional[str]:
         return self.text
 
 
 @whitelist_for_serdes(storage_name="UrlMetadataEntryData")
-class UrlMetadataValue(  # type: ignore
+class UrlMetadataValue(
     NamedTuple(
         "_UrlMetadataValue",
         [
             ("url", PublicAttr[Optional[str]]),
         ],
     ),
-    MetadataValue,
+    MetadataValue[str],
 ):
     """Container class for URL metadata entry data.
 
@@ -599,15 +617,15 @@ class UrlMetadataValue(  # type: ignore
             cls, check.opt_str_param(url, "url", default="")
         )
 
-    @public  # type: ignore
+    @public
     @property
     def value(self) -> Optional[str]:
         return self.url
 
 
 @whitelist_for_serdes(storage_name="PathMetadataEntryData")
-class PathMetadataValue(  # type: ignore
-    NamedTuple("_PathMetadataValue", [("path", PublicAttr[Optional[str]])]), MetadataValue
+class PathMetadataValue(
+    NamedTuple("_PathMetadataValue", [("path", PublicAttr[Optional[str]])]), MetadataValue[str]
 ):
     """Container class for path metadata entry data.
 
@@ -620,15 +638,15 @@ class PathMetadataValue(  # type: ignore
             cls, check.opt_path_param(path, "path", default="")
         )
 
-    @public  # type: ignore
+    @public
     @property
     def value(self) -> Optional[str]:
         return self.path
 
 
 @whitelist_for_serdes(storage_name="NotebookMetadataEntryData")
-class NotebookMetadataValue(  # type: ignore
-    NamedTuple("_NotebookMetadataValue", [("path", PublicAttr[Optional[str]])]), MetadataValue
+class NotebookMetadataValue(
+    NamedTuple("_NotebookMetadataValue", [("path", PublicAttr[Optional[str]])]), MetadataValue[str]
 ):
     """Container class for notebook metadata entry data.
 
@@ -641,7 +659,7 @@ class NotebookMetadataValue(  # type: ignore
             cls, check.opt_path_param(path, "path", default="")
         )
 
-    @public  # type: ignore
+    @public
     @property
     def value(self) -> Optional[str]:
         return self.path
@@ -652,29 +670,29 @@ class JsonMetadataValue(
     NamedTuple(
         "_JsonMetadataValue",
         [
-            ("data", PublicAttr[Mapping[str, Any]]),
+            ("data", PublicAttr[Optional[Union[Sequence[Any], Mapping[str, Any]]]]),
         ],
     ),
-    MetadataValue,
+    MetadataValue[Union[Sequence[Any], Mapping[str, Any]]],
 ):
     """Container class for JSON metadata entry data.
 
     Args:
-        data (Dict[str, Any]): The JSON data.
+        data (Union[Sequence[Any], Dict[str, Any]]): The JSON data.
     """
 
-    def __new__(cls, data: Optional[Mapping[str, Any]]):
-        data = check.opt_mapping_param(data, "data", key_type=str)
+    def __new__(cls, data: Optional[Union[Sequence[Any], Mapping[str, Any]]]):
+        data = check.opt_inst_param(data, "data", (Sequence, Mapping))
         try:
             # check that the value is JSON serializable
             seven.dumps(data)
         except TypeError:
-            raise DagsterInvalidMetadata("Value is a dictionary but is not JSON serializable.")
+            raise DagsterInvalidMetadata("Value is not JSON serializable.")
         return super(JsonMetadataValue, cls).__new__(cls, data)
 
-    @public  # type: ignore
+    @public
     @property
-    def value(self) -> Mapping[str, Any]:
+    def value(self) -> Optional[Union[Sequence[Any], Mapping[str, Any]]]:
         return self.data
 
 
@@ -686,7 +704,7 @@ class MarkdownMetadataValue(
             ("md_str", PublicAttr[Optional[str]]),
         ],
     ),
-    MetadataValue,
+    MetadataValue[str],
 ):
     """Container class for markdown metadata entry data.
 
@@ -704,6 +722,7 @@ class MarkdownMetadataValue(
         return self.md_str
 
 
+# This should be deprecated or fixed so that `value` does not return itself.
 @whitelist_for_serdes(storage_name="PythonArtifactMetadataEntryData")
 class PythonArtifactMetadataValue(
     NamedTuple(
@@ -713,7 +732,7 @@ class PythonArtifactMetadataValue(
             ("name", PublicAttr[str]),
         ],
     ),
-    MetadataValue,
+    MetadataValue["PythonArtifactMetadataValue"],
 ):
     """Container class for python artifact metadata entry data.
 
@@ -727,9 +746,9 @@ class PythonArtifactMetadataValue(
             cls, check.str_param(module, "module"), check.str_param(name, "name")
         )
 
-    @public  # type: ignore
+    @public
     @property
-    def value(self) -> object:
+    def value(self) -> Self:
         return self
 
 
@@ -741,7 +760,7 @@ class FloatMetadataValue(
             ("value", PublicAttr[Optional[float]]),
         ],
     ),
-    MetadataValue,
+    MetadataValue[float],
 ):
     """Container class for float metadata entry data.
 
@@ -761,7 +780,7 @@ class IntMetadataValue(
             ("value", PublicAttr[Optional[int]]),
         ],
     ),
-    MetadataValue,
+    MetadataValue[int],
 ):
     """Container class for int metadata entry data.
 
@@ -776,7 +795,7 @@ class IntMetadataValue(
 @whitelist_for_serdes(storage_name="BoolMetadataEntryData")
 class BoolMetadataValue(
     NamedTuple("_BoolMetadataValue", [("value", PublicAttr[Optional[bool]])]),
-    MetadataValue,
+    MetadataValue[bool],
 ):
     """Container class for bool metadata entry data.
 
@@ -796,7 +815,7 @@ class DagsterRunMetadataValue(
             ("run_id", PublicAttr[str]),
         ],
     ),
-    MetadataValue,
+    MetadataValue[str],
 ):
     """Representation of a dagster run.
 
@@ -814,7 +833,8 @@ class DagsterRunMetadataValue(
 
 @whitelist_for_serdes(storage_name="DagsterAssetMetadataEntryData")
 class DagsterAssetMetadataValue(
-    NamedTuple("_DagsterAssetMetadataValue", [("asset_key", PublicAttr["AssetKey"])]), MetadataValue
+    NamedTuple("_DagsterAssetMetadataValue", [("asset_key", PublicAttr["AssetKey"])]),
+    MetadataValue["AssetKey"],
 ):
     """Representation of a dagster asset.
 
@@ -829,12 +849,13 @@ class DagsterAssetMetadataValue(
             cls, check.inst_param(asset_key, "asset_key", AssetKey)
         )
 
-    @public  # type: ignore
+    @public
     @property
     def value(self) -> "AssetKey":
         return self.value
 
 
+# This should be deprecated or fixed so that `value` does not return itself.
 @experimental
 @whitelist_for_serdes(storage_name="TableMetadataEntryData")
 class TableMetadataValue(
@@ -845,7 +866,7 @@ class TableMetadataValue(
             ("schema", PublicAttr[TableSchema]),
         ],
     ),
-    MetadataValue,
+    MetadataValue["TableMetadataValue"],
 ):
     """Container class for table metadata entry data.
 
@@ -854,9 +875,9 @@ class TableMetadataValue(
         schema (Optional[TableSchema]): A schema for the table.
     """
 
-    @public  # type: ignore
+    @public
     @staticmethod
-    def infer_column_type(value):
+    def infer_column_type(value: object) -> str:
         if isinstance(value, bool):
             return "bool"
         elif isinstance(value, int):
@@ -867,7 +888,6 @@ class TableMetadataValue(
             return "string"
 
     def __new__(cls, records: Sequence[TableRecord], schema: Optional[TableSchema]):
-
         check.sequence_param(records, "records", of_type=TableRecord)
         check.opt_inst_param(schema, "schema", TableSchema)
 
@@ -892,15 +912,16 @@ class TableMetadataValue(
             schema,
         )
 
-    @public  # type: ignore
+    @public
     @property
-    def value(self):
+    def value(self) -> Self:
         return self
 
 
 @whitelist_for_serdes(storage_name="TableSchemaMetadataEntryData")
 class TableSchemaMetadataValue(
-    NamedTuple("_TableSchemaMetadataValue", [("schema", PublicAttr[TableSchema])]), MetadataValue
+    NamedTuple("_TableSchemaMetadataValue", [("schema", PublicAttr[TableSchema])]),
+    MetadataValue[TableSchema],
 ):
     """Representation of a schema for arbitrary tabular data.
 
@@ -918,36 +939,22 @@ class TableSchemaMetadataValue(
         return self.schema
 
 
+@whitelist_for_serdes(storage_name="NullMetadataEntryData")
+class NullMetadataValue(NamedTuple("_NullMetadataValue", []), MetadataValue[None]):
+    """Representation of null."""
+
+    @property
+    def value(self) -> None:
+        return None
+
+
 # ########################
 # ##### METADATA ENTRY
 # ########################
 
-
-def deprecated_metadata_entry_constructor(fn):
-    @functools.wraps(fn)
-    def wrapper(*args, **kwargs):
-        deprecation_warning(
-            f"Function `MetadataEntry.{fn.__name__}`",
-            "1.0.0",
-            additional_warn_txt=re.sub(
-                r"\n\s*",
-                " ",
-                """
-            The recommended way to supply metadata is to pass a `Dict[str,
-            MetadataValue]` to the `metadata` keyword argument. To construct `MetadataEntry`
-            directly, call constructor and pass a `MetadataValue`: `MetadataEntry(label="foo",
-            value=MetadataValue.text("bar")",
-            """,
-            ),
-        )
-        return fn(*args, **kwargs)
-
-    return wrapper
+T_MetadataValue = TypeVar("T_MetadataValue", bound=MetadataValue, covariant=True)
 
 
-# NOTE: This would better be implemented as a generic with `MetadataValue` set as a
-# typevar, but as of 2022-01-25 mypy does not support generics on NamedTuple.
-#
 # NOTE: This currently stores value in the `entry_data` NamedTuple attribute. In the next release,
 # we will change the name of the NamedTuple property to `value`, and need to implement custom
 # serialization so that it continues to be saved as `entry_data` for backcompat purposes.
@@ -961,6 +968,7 @@ class MetadataEntry(
             ("entry_data", PublicAttr[MetadataValue]),
         ],
     ),
+    Generic[T_MetadataValue],
 ):
     """The standard structure for describing metadata for Dagster events.
 
@@ -971,9 +979,6 @@ class MetadataEntry(
     For other event types, passing a dict with `MetadataValue` values to the `metadata` argument
     is preferred.
 
-    **NOTE**: MetadataEntry static constructors are deprecated. Instead you should use:
-    MetadataEntry(<label>, value=MetadataValue.<type>(<value>)).
-
     Args:
         label (str): Short display label for this metadata entry.
         description (Optional[str]): A human-readable description of this metadata entry.
@@ -1016,364 +1021,3 @@ class MetadataEntry(
     def value(self):
         """Alias of `entry_data`."""
         return self.entry_data
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def text(text: Optional[str], label: str, description: Optional[str] = None) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing text as
-        :py:class:`TextMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context, df):
-                yield AssetMaterialization(
-                    asset_key="my_dataset",
-                    metadata_entries=[
-                        MetadataEntry.text("Text-based metadata for this event", "text_metadata")
-                    ],
-                )
-
-        Args:
-            text (Optional[str]): The text of this metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-        return MetadataEntry(label, description, TextMetadataValue(text))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def url(url: Optional[str], label: str, description: Optional[str] = None) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing a URL as
-        :py:class:`UrlMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context):
-                yield AssetMaterialization(
-                    asset_key="my_dashboard",
-                    metadata_entries=[
-                        MetadataEntry.url(
-                            "http://mycoolsite.com/my_dashboard", label="dashboard_url"
-                        ),
-                    ],
-                )
-
-        Args:
-            url (Optional[str]): The URL contained by this metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-        return MetadataEntry(label, description, UrlMetadataValue(url))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def path(path: Optional[str], label: str, description: Optional[str] = None) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing a path as
-        :py:class:`PathMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context):
-                yield AssetMaterialization(
-                    asset_key="my_dataset",
-                    metadata_entries=[MetadataEntry.path("path/to/file", label="filepath")],
-                )
-
-        Args:
-            path (Optional[str]): The path contained by this metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-        return MetadataEntry(label, description, PathMetadataValue(path))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def fspath(
-        path: Optional[str], label: Optional[str] = None, description: Optional[str] = None
-    ) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing a filesystem path as
-        :py:class:`PathMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context):
-                yield AssetMaterialization(
-                    asset_key="my_dataset",
-                    metadata_entries=[MetadataEntry.fspath("path/to/file")],
-                )
-
-        Args:
-            path (Optional[str]): The path contained by this metadata entry.
-            label (Optional[str]): Short display label for this metadata entry. Defaults to the
-              base name of the path.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-        if not label:
-            path = cast(str, check.str_param(path, "path"))
-            label = last_file_comp(path)
-
-        return MetadataEntry.path(path, label, description)
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def json(
-        data: Optional[Mapping[str, Any]],
-        label: str,
-        description: Optional[str] = None,
-    ) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing JSON data as
-        :py:class:`JsonMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context):
-                yield ExpectationResult(
-                    success=not missing_things,
-                    label="is_present",
-                    metadata_entries=[
-                        MetadataEntry.json(
-                            label="metadata", data={"missing_columns": missing_things},
-                        )
-                    ],
-                )
-
-        Args:
-            data (Optional[Dict[str, Any]]): The JSON data contained by this metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-        return MetadataEntry(label, description, JsonMetadataValue(data))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def md(md_str: Optional[str], label: str, description: Optional[str] = None) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing markdown data as
-        :py:class:`MarkdownMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context, md_str):
-                yield AssetMaterialization(
-                    asset_key="info",
-                    metadata_entries=[MetadataEntry.md(md_str=md_str)],
-                )
-
-        Args:
-            md_str (Optional[str]): The markdown contained by this metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-        return MetadataEntry(label, description, MarkdownMetadataValue(md_str))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def python_artifact(
-        python_artifact: Callable[..., Any], label: str, description: Optional[str] = None
-    ) -> "MetadataEntry":
-        check.callable_param(python_artifact, "python_artifact")
-        return MetadataEntry(
-            label,
-            description,
-            PythonArtifactMetadataValue(python_artifact.__module__, python_artifact.__name__),
-        )
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def float(
-        value: Optional[float], label: str, description: Optional[str] = None
-    ) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing float as
-        :py:class:`FloatMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context, df):
-                yield AssetMaterialization(
-                    asset_key="my_dataset",
-                    metadata_entries=[MetadataEntry.float(calculate_bytes(df), "size (bytes)")],
-                )
-
-        Args:
-            value (Optional[float]): The float value contained by this metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-
-        return MetadataEntry(label, description, FloatMetadataValue(value))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def int(value: Optional[int], label: str, description: Optional[str] = None) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing int as
-        :py:class:`IntMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context, df):
-                yield AssetMaterialization(
-                    asset_key="my_dataset",
-                    metadata_entries=[MetadataEntry.int(len(df), "number of rows")],
-                )
-
-        Args:
-            value (Optional[int]): The int value contained by this metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-
-        return MetadataEntry(label, description, IntMetadataValue(value))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def pipeline_run(run_id: str, label: str, description: Optional[str] = None) -> "MetadataEntry":
-        check.str_param(run_id, "run_id")
-        return MetadataEntry(label, description, DagsterRunMetadataValue(run_id))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def asset(
-        asset_key: "AssetKey", label: str, description: Optional[str] = None
-    ) -> "MetadataEntry":
-        """Static constructor for a metadata entry referencing a Dagster asset, by key.
-        For example:
-
-        .. code-block:: python
-
-            @op
-            def validate_table(context, df):
-                yield AssetMaterialization(
-                    asset_key=AssetKey("my_table"),
-                    metadata_entries=[
-                         MetadataEntry.asset(AssetKey('my_other_table'), "Related asset"),
-                    ],
-                )
-
-        Args:
-            asset_key (AssetKey): The asset key referencing the asset.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-
-        from dagster._core.definitions.events import AssetKey
-
-        check.inst_param(asset_key, "asset_key", AssetKey)
-        return MetadataEntry(label, description, DagsterAssetMetadataValue(asset_key))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    @experimental
-    def table(
-        records: Sequence[TableRecord],
-        label: str,
-        description: Optional[str] = None,
-        schema: Optional[TableSchema] = None,
-    ) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing tabluar data as
-        :py:class:`TableMetadataValue`. For example:
-
-        .. code-block:: python
-
-            @op
-            def emit_metadata(context):
-                yield ExpectationResult(
-                    success=not has_errors,
-                    label="is_valid",
-                    metadata_entries=[
-                        MetadataEntry.table(
-                            label="errors",
-                            records=[
-                                TableRecord(code="invalid-data-type", row=2, col="name"),
-                            ],
-                            schema=TableSchema(
-                                columns=[
-                                    TableColumn(name="code", type="string"),
-                                    TableColumn(name="row", type="int"),
-                                    TableColumn(name="col", type="string"),
-                                ]
-                            )
-                        ),
-                    ],
-                )
-
-        Args:
-            records (List[TableRecord]): The data as a list of records (i.e. rows).
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-            schema (Optional[TableSchema]): A schema for the table. If none is provided, one will be
-              automatically generated by examining the first record. The schema will include as columns all
-              field names present in the first record, with a type of `"string"`, `"int"`,
-              `"bool"` or `"float"` inferred from the first record's values. If a value does
-              not directly match one of the above types, it will be treated as a string.
-        """
-        return MetadataEntry(label, description, TableMetadataValue(records, schema))
-
-    @staticmethod
-    @deprecated_metadata_entry_constructor
-    def table_schema(
-        schema: TableSchema, label: str, description: Optional[str] = None
-    ) -> "MetadataEntry":
-        """Static constructor for a metadata entry containing a table schema as
-        :py:class:`TableSchemaMetadataValue`. For example:
-
-        .. code-block:: python
-
-            schema = TableSchema(
-                columns = [
-                    TableColumn(name="id", type="int"),
-                    TableColumn(name="status", type="bool"),
-                ]
-            )
-            DagsterType(
-                type_check_fn=some_validation_fn,
-                name='MyTable',
-                metadata_entries=[
-                    MetadataEntry.table_schema(
-                        schema,
-                        label='schema',
-                    )
-                ]
-            )
-
-        Args:
-            schema (TableSchema): The table schema for a metadata entry.
-            label (str): Short display label for this metadata entry.
-            description (Optional[str]): A human-readable description of this metadata entry.
-        """
-        return MetadataEntry(
-            label,
-            description,
-            TableSchemaMetadataValue(schema),
-        )
-
-
-class PartitionMetadataEntry(
-    NamedTuple(
-        "_PartitionMetadataEntry",
-        [
-            ("partition", PublicAttr[str]),
-            ("entry", PublicAttr["MetadataEntry"]),
-        ],
-    )
-):
-    """Event containing an :py:class:`MetadataEntry` and the name of a partition that the entry
-    applies to.
-
-    This can be yielded or returned in place of MetadataEntries for cases where you are trying
-    to associate metadata more precisely.
-    """
-
-    def __new__(cls, partition: str, entry: MetadataEntry):
-        experimental_class_warning("PartitionMetadataEntry")
-        return super(PartitionMetadataEntry, cls).__new__(
-            cls,
-            check.str_param(partition, "partition"),
-            check.inst_param(entry, "entry", MetadataEntry),
-        )
