@@ -15,13 +15,13 @@ from typing import (
     cast,
 )
 
-from typing_extensions import TypeAlias, get_origin
+from typing_extensions import TypeAlias, get_args, get_origin
 
 import dagster._check as check
 from dagster._annotations import public
 from dagster._config.config_schema import UserConfigSchema
 from dagster._core.decorator_utils import get_function_params
-from dagster._core.definitions.dependency import NodeHandle
+from dagster._core.definitions.dependency import NodeHandle, NodeInputHandle
 from dagster._core.definitions.node_definition import NodeDefinition
 from dagster._core.definitions.policy import RetryPolicy
 from dagster._core.definitions.resource_requirement import (
@@ -48,7 +48,7 @@ if TYPE_CHECKING:
     from dagster._core.definitions.asset_layer import AssetLayer
 
     from .composition import PendingNodeInvocation
-    from .decorators.solid_decorator import DecoratedOpFunction
+    from .decorators.op_decorator import DecoratedOpFunction
 
 OpComputeFunction: TypeAlias = Callable[..., Any]
 
@@ -125,7 +125,7 @@ class OpDefinition(NodeDefinition):
         retry_policy: Optional[RetryPolicy] = None,
         code_version: Optional[str] = None,
     ):
-        from .decorators.solid_decorator import DecoratedOpFunction, resolve_checked_solid_fn_inputs
+        from .decorators.op_decorator import DecoratedOpFunction, resolve_checked_solid_fn_inputs
 
         ins = check.opt_mapping_param(ins, "ins")
         input_defs = [
@@ -184,17 +184,17 @@ class OpDefinition(NodeDefinition):
     def is_graph_job_op_node(self) -> bool:
         return True
 
-    @public  # type: ignore
+    @public
     @property
     def name(self) -> str:
         return super(OpDefinition, self).name
 
-    @public  # type: ignore
+    @public
     @property
     def ins(self) -> Mapping[str, In]:
         return {input_def.name: In.from_definition(input_def) for input_def in self.input_defs}
 
-    @public  # type: ignore
+    @public
     @property
     def outs(self) -> Mapping[str, Out]:
         return {output_def.name: Out.from_definition(output_def) for output_def in self.output_defs}
@@ -203,28 +203,28 @@ class OpDefinition(NodeDefinition):
     def compute_fn(self) -> Union[Callable[..., Any], "DecoratedOpFunction"]:
         return self._compute_fn
 
-    @public  # type: ignore
+    @public
     @property
     def config_schema(self) -> IDefinitionConfigSchema:
         return self._config_schema
 
-    @public  # type: ignore
+    @public
     @property
     def required_resource_keys(self) -> AbstractSet[str]:
         return frozenset(self._required_resource_keys)
 
-    @public  # type: ignore
+    @public
     @property
     def version(self) -> Optional[str]:
         deprecation_warning("`version` property on OpDefinition", "2.0")
         return self._version
 
-    @public  # type: ignore
+    @public
     @property
     def retry_policy(self) -> Optional[RetryPolicy]:
         return self._retry_policy
 
-    @public  # type: ignore
+    @public
     @property
     def tags(self) -> Mapping[str, str]:
         return super(OpDefinition, self).tags
@@ -246,7 +246,7 @@ class OpDefinition(NodeDefinition):
         return super(OpDefinition, self).with_retry_policy(retry_policy)
 
     def is_from_decorator(self) -> bool:
-        from .decorators.solid_decorator import DecoratedOpFunction
+        from .decorators.op_decorator import DecoratedOpFunction
 
         return isinstance(self._compute_fn, DecoratedOpFunction)
 
@@ -264,7 +264,7 @@ class OpDefinition(NodeDefinition):
     def iterate_node_defs(self) -> Iterator[NodeDefinition]:
         yield self
 
-    def iterate_solid_defs(self) -> Iterator["OpDefinition"]:
+    def iterate_op_defs(self) -> Iterator["OpDefinition"]:
         yield self
 
     T_Handle = TypeVar("T_Handle", bound=Optional[NodeHandle])
@@ -288,6 +288,7 @@ class OpDefinition(NodeDefinition):
                 and not input_def.dagster_type.kind == DagsterTypeKind.NOTHING
                 and not input_def.root_manager_key
                 and not input_def.has_default_value
+                and not input_def.input_manager_key
             ):
                 input_asset_key = asset_layer.asset_key_for_input(handle, input_def.name)
                 # If input_asset_key is present, this input can be resolved
@@ -377,10 +378,15 @@ class OpDefinition(NodeDefinition):
                 output_name=output_def.name,
             )
 
+    def resolve_input_to_destinations(
+        self, input_handle: NodeInputHandle
+    ) -> Sequence[NodeInputHandle]:
+        return [input_handle]
+
     def __call__(self, *args, **kwargs) -> Any:
         from ..execution.context.invocation import UnboundOpExecutionContext
         from .composition import is_in_composition
-        from .decorators.solid_decorator import DecoratedOpFunction
+        from .decorators.op_decorator import DecoratedOpFunction
 
         if is_in_composition():
             return super(OpDefinition, self).__call__(*args, **kwargs)
@@ -389,15 +395,15 @@ class OpDefinition(NodeDefinition):
 
             if not isinstance(self.compute_fn, DecoratedOpFunction):
                 raise DagsterInvalidInvocationError(
-                    f"Attemped to invoke {node_label} that was not constructed using the `@{node_label}` "
-                    f"decorator. Only {node_label}s constructed using the `@{node_label}` decorator can be "
-                    "directly invoked."
+                    f"Attemped to invoke {node_label} that was not constructed using the"
+                    f" `@{node_label}` decorator. Only {node_label}s constructed using the"
+                    f" `@{node_label}` decorator can be directly invoked."
                 )
             if self.compute_fn.has_context_arg():
                 if len(args) + len(kwargs) == 0:
                     raise DagsterInvalidInvocationError(
-                        f"Compute function of {node_label} '{self.name}' has context argument, but no context "
-                        "was provided when invoking."
+                        f"Compute function of {node_label} '{self.name}' has context argument, but"
+                        " no context was provided when invoking."
                     )
                 if len(args) > 0:
                     if args[0] is not None and not isinstance(args[0], UnboundOpExecutionContext):
@@ -416,7 +422,7 @@ class OpDefinition(NodeDefinition):
                             f"'{context_param_name}', but no value for '{context_param_name}' was "
                             f"found when invoking. Provided kwargs: {kwargs}"
                         )
-                    context = kwargs[context_param_name]
+                    context = cast(UnboundOpExecutionContext, kwargs[context_param_name])
                     kwargs_sans_context = {
                         kwarg: val
                         for kwarg, val in kwargs.items()
@@ -427,8 +433,8 @@ class OpDefinition(NodeDefinition):
             else:
                 if len(args) > 0 and isinstance(args[0], UnboundOpExecutionContext):
                     raise DagsterInvalidInvocationError(
-                        f"Compute function of {node_label} '{self.name}' has no context argument, but "
-                        "context was provided when invoking."
+                        f"Compute function of {node_label} '{self.name}' has no context argument,"
+                        " but context was provided when invoking."
                     )
                 return op_invocation_result(self, None, *args, **kwargs)
 
@@ -438,12 +444,10 @@ def _resolve_output_defs_from_outs(
     outs: Optional[Mapping[str, Out]],
     default_code_version: Optional[str],
 ) -> Sequence[OutputDefinition]:
-    from .decorators.solid_decorator import DecoratedOpFunction
+    from .decorators.op_decorator import DecoratedOpFunction
 
     if isinstance(compute_fn, DecoratedOpFunction):
-        inferred_output_props = infer_output_props(
-            cast(DecoratedOpFunction, compute_fn).decorated_fn
-        )
+        inferred_output_props = infer_output_props(compute_fn.decorated_fn)
         annotation = inferred_output_props.annotation
         description = inferred_output_props.description
     else:
@@ -469,15 +473,15 @@ def _resolve_output_defs_from_outs(
         raise DagsterInvariantViolationError(
             "Expected Tuple annotation for multiple outputs, but received non-tuple annotation."
         )
-    if annotation != inspect.Parameter.empty and not len(annotation.__args__) == len(outs):
+    if annotation != inspect.Parameter.empty and not len(get_args(annotation)) == len(outs):
         raise DagsterInvariantViolationError(
             "Expected Tuple annotation to have number of entries matching the "
             f"number of outputs for more than one output. Expected {len(outs)} "
-            f"outputs but annotation has {len(annotation.__args__)}."
+            f"outputs but annotation has {len(get_args(annotation))}."
         )
     for idx, (name, cur_out) in enumerate(outs.items()):
         annotation_type = (
-            annotation.__args__[idx]
+            get_args(annotation)[idx]
             if annotation != inspect.Parameter.empty
             else inspect.Parameter.empty
         )
