@@ -1,22 +1,16 @@
 import inspect
-import warnings
 from typing import (
-    TYPE_CHECKING,
-    AbstractSet,
     Any,
-    Callable,
     NamedTuple,
     Optional,
     Sequence,
     Type,
     TypeVar,
     Union,
-    cast,
 )
 
 import dagster._check as check
 from dagster._annotations import PublicAttr
-from dagster._core.definitions.events import AssetKey, DynamicAssetKey
 from dagster._core.definitions.metadata import MetadataEntry, MetadataUserInput, normalize_metadata
 from dagster._core.errors import DagsterError, DagsterInvalidDefinitionError
 from dagster._core.types.dagster_type import (
@@ -24,33 +18,28 @@ from dagster._core.types.dagster_type import (
     is_dynamic_output_annotation,
     resolve_dagster_type,
 )
-from dagster._utils.backcompat import experimental_arg_warning
 
 from .inference import InferredOutputProps
 from .input import NoValueSentinel
 from .utils import DEFAULT_IO_MANAGER_KEY, DEFAULT_OUTPUT, check_valid_name
 
-if TYPE_CHECKING:
-    from dagster._core.definitions.partition import PartitionsDefinition
-    from dagster._core.execution.context.output import OutputContext
-
 TOutputDefinition = TypeVar("TOutputDefinition", bound="OutputDefinition")
 TOut = TypeVar("TOut", bound="Out")
 
 
 class OutputDefinition:
-    """Defines an output from a solid's compute function.
+    """Defines an output from an op's compute function.
 
-    Solids can have multiple outputs, in which case outputs cannot be anonymous.
+    Ops can have multiple outputs, in which case outputs cannot be anonymous.
 
-    Many solids have only one output, in which case the user can provide a single output definition
+    Many ops have only one output, in which case the user can provide a single output definition
     that will be given the default name, "result".
 
     Output definitions may be typed using the Dagster type system.
 
     Args:
         dagster_type (Optional[Union[Type, DagsterType]]]): The type of this output.
-            Users should provide the Python type of the objects that they expect the solid to yield
+            Users should provide the Python type of the objects that they expect the op to yield
             for this output, or a :py:class:`DagsterType` that defines a runtime check that they
             want to be run on this output. Defaults to :py:class:`Any`.
         name (Optional[str]): Name of the output. (default: "result")
@@ -62,11 +51,6 @@ class OutputDefinition:
             For example, users can provide a file path if the data object will be stored in a
             filesystem, or provide information of a database table when it is going to load the data
             into the table.
-        asset_key (Optional[AssetKey]]): (Experimental) An AssetKey which should be associated
-            with this OutputDefinition. Used for tracking lineage information through Dagster.
-        asset_partitions (Optional[Union[Set[str], OutputContext -> Set[str]]]): (Experimental) A
-            set of partitions of the given asset_key (or a function that produces this list of
-            partitions from the OutputContext) which should be associated with this OutputDefinition.
         code_version (Optional[str]): (Experimental) Version of the code that generates this output. In
             general, versions should be set only for code that deterministically produces the same
             output when given the same inputs.
@@ -81,16 +65,9 @@ class OutputDefinition:
         is_required: bool = True,
         io_manager_key: Optional[str] = None,
         metadata: Optional[MetadataUserInput] = None,
-        asset_key: Optional[Union[AssetKey, DynamicAssetKey]] = None,
-        asset_partitions: Optional[
-            Union[AbstractSet[str], Callable[["OutputContext"], AbstractSet[str]]]
-        ] = None,
-        asset_partitions_def: Optional["PartitionsDefinition"] = None,
         code_version: Optional[str] = None,
         # make sure new parameters are updated in combine_with_inferred below
     ):
-        from dagster._core.definitions.partition import PartitionsDefinition
-
         self._name = check_valid_name(check.opt_str_param(name, "name", DEFAULT_OUTPUT))
         self._type_not_set = dagster_type is None
         self._dagster_type = resolve_dagster_type(dagster_type)
@@ -107,48 +84,8 @@ class OutputDefinition:
             normalize_metadata(self._metadata, [], allow_invalid=True), MetadataEntry
         )
 
-        if asset_key:
-            experimental_arg_warning("asset_key", "OutputDefinition.__init__")
-
-        if callable(asset_key):
-            warnings.warn(
-                "Passing a function as the `asset_key` argument to `Out` or `OutputDefinition` is "
-                "deprecated behavior and will be removed in version 1.0.0."
-            )
-        else:
-            check.opt_inst_param(asset_key, "asset_key", AssetKey)
-
-        self._asset_key = asset_key
-
-        if asset_partitions:
-            experimental_arg_warning("asset_partitions", "OutputDefinition.__init__")
-            check.param_invariant(
-                asset_key is not None,
-                "asset_partitions",
-                'Cannot specify "asset_partitions" argument without also specifying "asset_key"',
-            )
-
-        self._asset_partitions_fn: Optional[Callable[["OutputContext"], AbstractSet[str]]]
-        if callable(asset_partitions):
-            self._asset_partitions_fn = asset_partitions
-        elif asset_partitions is not None:
-            asset_partitions = check.opt_set_param(asset_partitions, "asset_partitions", str)
-
-            def _fn(_context: "OutputContext") -> AbstractSet[str]:
-                return cast(AbstractSet[str], asset_partitions)  # mypy bug?
-
-            self._asset_partitions_fn = _fn
-        else:
-            self._asset_partitions_fn = None
-
-        if asset_partitions_def:
-            experimental_arg_warning("asset_partitions_def", "OutputDefinition.__init__")
-        self._asset_partitions_def = check.opt_inst_param(
-            asset_partitions_def, "asset_partition_def", PartitionsDefinition
-        )
-
     @property
-    def name(self):
+    def name(self) -> str:
         return self._name
 
     @property
@@ -187,68 +124,26 @@ class OutputDefinition:
     def is_dynamic(self) -> bool:
         return False
 
-    @property
-    def is_asset(self) -> bool:
-        return self._asset_key is not None
-
-    @property
-    def asset_partitions_def(self) -> Optional["PartitionsDefinition"]:
-        return self._asset_partitions_def
-
-    @property
-    def hardcoded_asset_key(self) -> Optional[AssetKey]:
-        if not callable(self._asset_key):
-            return self._asset_key
-        else:
-            return None
-
-    def get_asset_key(self, context: "OutputContext") -> Optional[AssetKey]:
-        """Get the AssetKey associated with this OutputDefinition for the given
-        :py:class:`OutputContext` (if any).
-
-        Args:
-            context (OutputContext): The OutputContext that this OutputDefinition is being evaluated
-                in
-        """
-        if callable(self._asset_key):
-            return self._asset_key(context)
-        else:
-            return self.hardcoded_asset_key
-
-    def get_asset_partitions(self, context: "OutputContext") -> Optional[AbstractSet[str]]:
-        """Get the set of partitions associated with this OutputDefinition for the given
-        :py:class:`OutputContext` (if any).
-
-        Args:
-            context (OutputContext): The OutputContext that this OutputDefinition is being evaluated
-            in
-        """
-        if self._asset_partitions_fn is None:
-            return None
-
-        return self._asset_partitions_fn(context)
-
     def mapping_from(
-        self, solid_name: str, output_name: Optional[str] = None, from_dynamic_mapping: bool = False
+        self, node_name: str, output_name: Optional[str] = None, from_dynamic_mapping: bool = False
     ) -> "OutputMapping":
-        """Create an output mapping from an output of a child solid.
+        """Create an output mapping from an output of a child node.
 
         In a CompositeSolidDefinition, you can use this helper function to construct
-        an :py:class:`OutputMapping` from the output of a child solid.
+        an :py:class:`OutputMapping` from the output of a child node.
 
         Args:
-            solid_name (str): The name of the child solid from which to map this output.
-            output_name (str): The name of the child solid's output from which to map this output.
+            node_name (str): The name of the child node from which to map this output.
+            output_name (str): The name of the child node's output from which to map this output.
 
         Examples:
-
             .. code-block:: python
 
-                output_mapping = OutputDefinition(Int).mapping_from('child_solid')
+                output_mapping = OutputDefinition(Int).mapping_from('child_node')
         """
         return OutputMapping(
             graph_output_name=self.name,
-            mapped_node_name=solid_name,
+            mapped_node_name=node_name,
             mapped_node_output_name=output_name or DEFAULT_OUTPUT,
             graph_output_description=self.description,
             dagster_type=self.dagster_type,
@@ -292,9 +187,6 @@ class OutputDefinition:
             is_required=self.is_required,
             io_manager_key=self.io_manager_key,
             metadata=self._metadata,
-            asset_key=self._asset_key,
-            asset_partitions=self._asset_partitions_fn,
-            asset_partitions_def=self.asset_partitions_def,
         )
 
 
@@ -324,21 +216,21 @@ class DynamicOutputDefinition(OutputDefinition):
     When using in a composition function such as :py:func:`@pipeline <dagster.pipeline>`,
     dynamic outputs must be used with either
 
-    * ``map`` - clone downstream solids for each separate :py:class:`DynamicOutput`
+    * ``map`` - clone downstream nodes for each separate :py:class:`DynamicOutput`
     * ``collect`` - gather across all :py:class:`DynamicOutput` in to a list
 
     Uses the same constructor as :py:class:`OutputDefinition <dagster.OutputDefinition>`
 
         .. code-block:: python
 
-            @solid(
+            @op(
                 config_schema={
                     "path": Field(str, default_value=file_relative_path(__file__, "sample"))
                 },
                 output_defs=[DynamicOutputDefinition(str)],
             )
             def files_in_directory(context):
-                path = context.solid_config["path"]
+                path = context.op_config["path"]
                 dirname, _, filenames = next(os.walk(path))
                 for file in filenames:
                     yield DynamicOutput(os.path.join(dirname, file), mapping_key=_clean(file))
@@ -347,7 +239,7 @@ class DynamicOutputDefinition(OutputDefinition):
             def process_directory():
                 files = files_in_directory()
 
-                # use map to invoke a solid on each dynamic output
+                # use map to invoke an op on each dynamic output
                 file_results = files.map(process_file)
 
                 # use collect to gather the results in to a list
@@ -359,18 +251,14 @@ class DynamicOutputDefinition(OutputDefinition):
         return True
 
 
-class OutputPointer(NamedTuple("_OutputPointer", [("solid_name", str), ("output_name", str)])):
-    def __new__(cls, solid_name: str, output_name: Optional[str] = None):
+class OutputPointer(NamedTuple("_OutputPointer", [("node_name", str), ("output_name", str)])):
+    def __new__(cls, node_name: str, output_name: Optional[str] = None):
         return super(OutputPointer, cls).__new__(
             cls,
-            check.str_param(solid_name, "solid_name"),
+            check.str_param(node_name, "node_name"),
             check.opt_str_param(output_name, "output_name", DEFAULT_OUTPUT),
         )
 
-    @property
-    def node_name(self):
-        return self.solid_name
-
 
 class OutputMapping(NamedTuple):
     """Defines an output mapping for a graph.
@@ -384,7 +272,6 @@ class OutputMapping(NamedTuple):
         dagster_type (Optional[DagsterType]): (Deprecated) The dagster type of the graph's output being mapped to. Users should not use this argument when instantiating the class.
 
     Examples:
-
         .. code-block:: python
 
             from dagster import OutputMapping, GraphDefinition, op, graph, GraphOut
@@ -442,14 +329,6 @@ class Out(
             ("is_required", PublicAttr[bool]),
             ("io_manager_key", PublicAttr[str]),
             ("metadata", PublicAttr[Optional[MetadataUserInput]]),
-            ("asset_key", PublicAttr[Optional[Union[AssetKey, DynamicAssetKey]]]),
-            (
-                "asset_partitions",
-                PublicAttr[
-                    Optional[Union[AbstractSet[str], Callable[["OutputContext"], AbstractSet[str]]]]
-                ],
-            ),
-            ("asset_partitions_def", PublicAttr[Optional["PartitionsDefinition"]]),
             ("code_version", PublicAttr[Optional[str]]),
         ],
     )
@@ -476,11 +355,6 @@ class Out(
             For example, users can provide a file path if the data object will be stored in a
             filesystem, or provide information of a database table when it is going to load the data
             into the table.
-        asset_key (Optional[AssetKey]): (Experimental) An AssetKey which should be associated
-            with this Out. Used for tracking lineage information through Dagster.
-        asset_partitions (Optional[Union[Set[str], OutputContext -> Set[str]]]): (Experimental) A
-            set of partitions of the given asset_key (or a function that produces this list of
-            partitions from the OutputContext) which should be associated with this Out.
         code_version (Optional[str]): (Experimental) Version of the code that generates this output. In
             general, versions should be set only for code that deterministically produces the same
             output when given the same inputs.
@@ -493,16 +367,9 @@ class Out(
         is_required: bool = True,
         io_manager_key: Optional[str] = None,
         metadata: Optional[MetadataUserInput] = None,
-        asset_key: Optional[AssetKey] = None,
-        asset_partitions: Optional[
-            Union[AbstractSet[str], Callable[["OutputContext"], AbstractSet[str]]]
-        ] = None,
-        asset_partitions_def: Optional["PartitionsDefinition"] = None,
         code_version: Optional[str] = None,
         # make sure new parameters are updated in combine_with_inferred below
     ):
-        if asset_partitions_def:
-            experimental_arg_warning("asset_partitions_definition", "Out.__new__")
         return super(Out, cls).__new__(
             cls,
             dagster_type=NoValueSentinel
@@ -514,9 +381,6 @@ class Out(
                 io_manager_key, "io_manager_key", default=DEFAULT_IO_MANAGER_KEY
             ),
             metadata=metadata,
-            asset_key=asset_key,
-            asset_partitions=asset_partitions,
-            asset_partitions_def=asset_partitions_def,
             code_version=code_version,
         )
 
@@ -529,9 +393,6 @@ class Out(
             is_required=output_def.is_required,
             io_manager_key=output_def.io_manager_key,
             metadata=output_def.metadata,
-            asset_key=output_def._asset_key,  # type: ignore # pylint: disable=protected-access
-            asset_partitions=output_def._asset_partitions_fn,  # pylint: disable=protected-access
-            asset_partitions_def=output_def.asset_partitions_def,  # pylint: disable=protected-access
             code_version=output_def.code_version,
         )
 
@@ -557,9 +418,6 @@ class Out(
             is_required=self.is_required,
             io_manager_key=self.io_manager_key,
             metadata=self.metadata,
-            asset_key=self.asset_key,
-            asset_partitions=self.asset_partitions,
-            asset_partitions_def=self.asset_partitions_def,
             code_version=self.code_version or code_version,
         )
 
@@ -626,8 +484,6 @@ class DynamicOut(Out):
             is_required=self.is_required,
             io_manager_key=self.io_manager_key,
             metadata=self.metadata,
-            asset_key=self.asset_key,
-            asset_partitions=self.asset_partitions,
             code_version=self.code_version or code_version,
         )
 
