@@ -3,7 +3,11 @@ import hashlib
 import inspect
 import json
 from abc import ABC, abstractmethod
-from datetime import datetime, time, timedelta
+from datetime import (
+    datetime,
+    time,
+    timedelta,
+)
 from enum import Enum
 from typing import (
     Any,
@@ -16,6 +20,7 @@ from typing import (
     Optional,
     Sequence,
     Set,
+    Type,
     TypeVar,
     Union,
     cast,
@@ -29,10 +34,12 @@ import dagster._check as check
 from dagster._annotations import PublicAttr, public
 from dagster._core.definitions.partition_key_range import PartitionKeyRange
 from dagster._core.definitions.target import ExecutableDefinition
+from dagster._core.instance import DynamicPartitionsStore
 from dagster._core.storage.tags import PARTITION_NAME_TAG
 from dagster._serdes import whitelist_for_serdes
 from dagster._seven.compat.pendulum import PendulumDateTime, to_timezone
 from dagster._utils import frozenlist
+from dagster._utils.backcompat import deprecation_warning, experimental_arg_warning
 from dagster._utils.merger import merge_dicts
 from dagster._utils.schedules import schedule_execution_time_iterator
 
@@ -63,20 +70,20 @@ from .utils import check_valid_name, validate_tags
 
 DEFAULT_DATE_FORMAT = "%Y-%m-%d"
 
-T = TypeVar("T")
+T_cov = TypeVar("T_cov", covariant=True)
 
 
 RawPartitionFunction: TypeAlias = Union[
-    Callable[[Optional[datetime]], Sequence[Union[str, "Partition[T]"]]],
-    Callable[[], Sequence[Union[str, "Partition[T]"]]],
+    Callable[[Optional[datetime]], Sequence[Union[str, "Partition[T_cov]"]]],
+    Callable[[], Sequence[Union[str, "Partition[T_cov]"]]],
 ]
 
 PartitionFunction: TypeAlias = Callable[[Optional[datetime]], Sequence["Partition[Any]"]]
 PartitionTagsFunction: TypeAlias = Callable[["Partition[object]"], Mapping[str, str]]
 PartitionScheduleFunction: TypeAlias = Callable[[datetime], Mapping[str, Any]]
 PartitionSelectorFunction: TypeAlias = Callable[
-    [ScheduleEvaluationContext, "PartitionSetDefinition[T]"],
-    Union["Partition[T]", Sequence["Partition[T]"], SkipReason],
+    [ScheduleEvaluationContext, "PartitionSetDefinition[T_cov]"],
+    Union["Partition[T_cov]", Sequence["Partition[T_cov]"], SkipReason],
 ]
 
 # Dagit selects partition ranges following the format '2022-01-13...2022-01-14'
@@ -85,7 +92,7 @@ PartitionSelectorFunction: TypeAlias = Callable[
 INVALID_PARTITION_SUBSTRINGS = ["...", "\a", "\b", "\f", "\n", "\r", "\t", "\v", "\0"]
 
 
-class Partition(Generic[T]):
+class Partition(Generic[T_cov]):
     """
     A Partition represents a single slice of the entire set of a job's possible work. It consists
     of a value, which is an object that represents that partition, and an optional name, which is
@@ -96,12 +103,12 @@ class Partition(Generic[T]):
         name (str): Name for this partition
     """
 
-    def __init__(self, value: T, name: Optional[str] = None):
+    def __init__(self, value: T_cov, name: Optional[str] = None):
         self._value = value
         self._name = check.str_param(name or str(value), "name")
 
     @property
-    def value(self) -> T:
+    def value(self) -> T_cov:
         return self._value
 
     @property
@@ -215,40 +222,82 @@ class ScheduleType(Enum):
         return self.ordinal < other.ordinal
 
 
-class PartitionsDefinition(ABC, Generic[T]):
+class PartitionsDefinition(ABC, Generic[T_cov]):
+    """
+    Defines a set of partitions, which can be attached to a software-defined asset or job.
+
+    Abstract class with implementations for different kinds of partitions.
+    """
+
+    @property
+    def partitions_subset_class(self) -> Type["PartitionsSubset"]:
+        return DefaultPartitionsSubset
+
     @abstractmethod
-    def get_partitions(self, current_time: Optional[datetime] = None) -> Sequence[Partition[T]]:
+    def get_partitions(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Sequence[Partition[T_cov]]:
         ...
 
+    def get_partition(
+        self,
+        partition_key: str,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Partition[T_cov]:
+        for partition in self.get_partitions(
+            current_time=current_time, dynamic_partitions_store=dynamic_partitions_store
+        ):
+            if partition.name == partition_key:
+                return partition
+
+        raise DagsterUnknownPartitionError(f"Could not find a partition with key `{partition_key}`")
+
     def __str__(self) -> str:
         joined_keys = ", ".join([f"'{key}'" for key in self.get_partition_keys()])
         return joined_keys
 
     @public
-    def get_partition_keys(self, current_time: Optional[datetime] = None) -> Sequence[str]:
-        return [partition.name for partition in self.get_partitions(current_time)]
+    def get_partition_keys(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Sequence[str]:
+        return [
+            partition.name
+            for partition in self.get_partitions(current_time, dynamic_partitions_store)
+        ]
 
-    def get_last_partition_key(self, current_time: Optional[datetime] = None) -> Optional[str]:
-        partitions = self.get_partitions(current_time)
+    def get_last_partition_key(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Optional[str]:
+        partitions = self.get_partitions(current_time, dynamic_partitions_store)
         if partitions:
             return partitions[-1].name
         else:
             return None
 
-    def get_first_partition_key(self, current_time: Optional[datetime] = None) -> Optional[str]:
-        partitions = self.get_partitions(current_time)
+    def get_first_partition_key(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Optional[str]:
+        partitions = self.get_partitions(current_time, dynamic_partitions_store)
         if partitions:
             return partitions[0].name
         else:
             return None
 
-    def get_default_partition_mapping(self):
-        from dagster._core.definitions.partition_mapping import IdentityPartitionMapping
-
-        return IdentityPartitionMapping()
-
-    def get_partition_keys_in_range(self, partition_key_range: PartitionKeyRange) -> Sequence[str]:
-        partition_keys = self.get_partition_keys()
+    def get_partition_keys_in_range(
+        self,
+        partition_key_range: PartitionKeyRange,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Sequence[str]:
+        partition_keys = self.get_partition_keys(dynamic_partitions_store=dynamic_partitions_store)
 
         keys_exist = {
             partition_key_range.start: partition_key_range.start in partition_keys,
@@ -268,11 +317,37 @@ class PartitionsDefinition(ABC, Generic[T]):
             + 1
         ]
 
-    def empty_subset(self) -> "PartitionsSubset":
-        return DefaultPartitionsSubset(self, set())
+    def empty_subset(self) -> "PartitionsSubset[T_cov]":
+        return self.partitions_subset_class.empty_subset(self)
 
-    def deserialize_subset(self, serialized: str) -> "PartitionsSubset":
-        return DefaultPartitionsSubset.from_serialized(self, serialized)
+    def subset_with_partition_keys(
+        self, partition_keys: Iterable[str]
+    ) -> "PartitionsSubset[T_cov]":
+        return self.empty_subset().with_partition_keys(partition_keys)
+
+    def subset_with_all_partitions(
+        self,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> "PartitionsSubset[T_cov]":
+        return self.subset_with_partition_keys(
+            self.get_partition_keys(dynamic_partitions_store=dynamic_partitions_store)
+        )
+
+    def deserialize_subset(self, serialized: str) -> "PartitionsSubset[T_cov]":
+        return self.partitions_subset_class.from_serialized(self, serialized)
+
+    def can_deserialize_subset(
+        self,
+        serialized: str,
+        serialized_partitions_def_unique_id: Optional[str],
+        serialized_partitions_def_class_name: Optional[str],
+    ) -> bool:
+        return self.partitions_subset_class.can_deserialize(
+            self,
+            serialized,
+            serialized_partitions_def_unique_id,
+            serialized_partitions_def_class_name,
+        )
 
     @property
     def serializable_unique_identifier(self) -> str:
@@ -282,28 +357,58 @@ class PartitionsDefinition(ABC, Generic[T]):
         tags = {PARTITION_NAME_TAG: partition_key}
         return tags
 
+    def get_num_partitions(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> int:
+        return len(self.get_partition_keys(current_time, dynamic_partitions_store))
+
+
+def raise_error_on_invalid_partition_key_substring(partition_keys: Sequence[str]) -> None:
+    for partition_key in partition_keys:
+        found_invalid_substrs = [
+            invalid_substr
+            for invalid_substr in INVALID_PARTITION_SUBSTRINGS
+            if invalid_substr in partition_key
+        ]
+        if found_invalid_substrs:
+            raise DagsterInvalidDefinitionError(
+                f"{found_invalid_substrs} are invalid substrings in a partition key"
+            )
+
 
 class StaticPartitionsDefinition(
-    PartitionsDefinition[str],
+    PartitionsDefinition[str]
 ):  # pylint: disable=unsubscriptable-object
+    """
+    A statically-defined set of partitions.
+
+    Example:
+        .. code-block:: python
+
+            from dagster import StaticPartitionsDefinition, asset
+
+            oceans_partitions_def = StaticPartitionsDefinition(
+                ["arctic", "atlantic", "indian", "pacific", "southern"]
+            )
+
+            @asset(partitions_def=oceans_partitions_defs)
+            def ml_model_for_each_ocean():
+                ...
+    """
+
     def __init__(self, partition_keys: Sequence[str]):
         check.sequence_param(partition_keys, "partition_keys", of_type=str)
 
-        for partition_key in partition_keys:
-            found_invalid_substrs = [
-                invalid_substr
-                for invalid_substr in INVALID_PARTITION_SUBSTRINGS
-                if invalid_substr in partition_key
-            ]
-            if found_invalid_substrs:
-                raise DagsterInvalidDefinitionError(
-                    f"{found_invalid_substrs} are invalid substrings in a partition key"
-                )
+        raise_error_on_invalid_partition_key_substring(partition_keys)
 
         self._partitions = [Partition(key) for key in partition_keys]
 
     def get_partitions(
-        self, current_time: Optional[datetime] = None  # pylint: disable=unused-argument
+        self,
+        current_time: Optional[datetime] = None,  # pylint: disable=unused-argument
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Sequence[Partition[str]]:
         return self._partitions
 
@@ -396,7 +501,9 @@ class ScheduleTimeBasedPartitionsDefinition(
         )
 
     def get_partitions(
-        self, current_time: Optional[datetime] = None
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Sequence[Partition[datetime]]:
         check.opt_inst_param(current_time, "current_time", datetime)
 
@@ -463,28 +570,136 @@ class DynamicPartitionsDefinition(
             (
                 "partition_fn",
                 PublicAttr[
-                    Callable[[Optional[datetime]], Union[Sequence[Partition], Sequence[str]]]
+                    Optional[
+                        Callable[[Optional[datetime]], Union[Sequence[Partition], Sequence[str]]]
+                    ]
                 ],
-            )
+            ),
+            ("name", PublicAttr[Optional[str]]),
         ],
     ),
 ):
+    """
+    A partitions definition whose partition keys can be dynamically added and removed.
+
+    This is useful for cases where the set of partitions is not known at definition time,
+    but is instead determined at runtime.
+
+    Partitions can be added and removed using `instance.add_dynamic_partitions` and
+    `instance.delete_dynamic_partition` methods.
+
+    Args:
+        name (Optional[str]): (Experimental) The name of the partitions definition.
+        partition_fn (Optional[Callable[[Optional[datetime]], Union[Sequence[Partition], Sequence[str]]]]):
+            A function that returns the current set of partitions. This argument is deprecated and
+            will be removed in 2.0.0.
+
+    Examples:
+        .. code-block:: python
+
+            fruits = DynamicPartitionsDefinition(name="fruits")
+
+            @sensor(job=my_job)
+            def my_sensor(context):
+                context.instance.add_dynamic_partitions(fruits.name, [partition_key])
+                return my_job.run_request_for_partition(partition_key, instance=context.instance)
+
+    """
+
     def __new__(  # pylint: disable=arguments-differ
-        cls, partition_fn: Callable[[Optional[datetime]], Union[Sequence[Partition], Sequence[str]]]
+        cls,
+        partition_fn: Optional[
+            Callable[[Optional[datetime]], Union[Sequence[Partition], Sequence[str]]]
+        ] = None,
+        name: Optional[str] = None,
     ):
+        partition_fn = check.opt_callable_param(partition_fn, "partition_fn")
+        name = check.opt_str_param(name, "name")
+
+        if name:
+            experimental_arg_warning("name", "DynamicPartitionsDefinition.__new__")
+
+        if partition_fn:
+            deprecation_warning(
+                "partition_fn", "2.0.0", "Provide partition definition name instead."
+            )
+
+        if partition_fn is None and name is None:
+            raise DagsterInvalidDefinitionError(
+                "Must provide either partition_fn or name to DynamicPartitionsDefinition."
+            )
+
+        if partition_fn and name:
+            raise DagsterInvalidDefinitionError(
+                "Cannot provide both partition_fn and name to DynamicPartitionsDefinition."
+            )
+
         return super(DynamicPartitionsDefinition, cls).__new__(
-            cls, check.callable_param(partition_fn, "partition_fn")
+            cls,
+            partition_fn=check.opt_callable_param(partition_fn, "partition_fn"),
+            name=check.opt_str_param(name, "name"),
         )
 
-    def get_partitions(self, current_time: Optional[datetime] = None) -> Sequence[Partition]:
-        partitions = self.partition_fn(current_time)
-        if all(isinstance(partition, Partition) for partition in partitions):
-            return cast(Sequence[Partition], partitions)
+    def _validated_name(self) -> str:
+        if self.name is None:
+            check.failed(
+                "Dynamic partitions definition must have a name to fetch dynamic partitions"
+            )
+        return self.name
+
+    def __eq__(self, other):
+        return (
+            isinstance(other, DynamicPartitionsDefinition)
+            and self.name == other.name
+            and self.partition_fn == other.partition_fn
+        )
+
+    def __hash__(self):
+        return hash(tuple(self.__repr__()))
+
+    def __str__(self) -> str:
+        if self.name:
+            return f"Dynamic partitions definition {self._validated_name()}"
         else:
-            return [Partition(p) for p in partitions]
+            return super().__str__()
+
+    @property
+    def serializable_unique_identifier(self) -> str:
+        if not self.name:
+            return super().serializable_unique_identifier
+
+        return hashlib.sha1(self.__repr__().encode("utf-8")).hexdigest()
+
+    def get_partitions(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Sequence[Partition]:
+        if self.partition_fn:
+            partitions = self.partition_fn(current_time)
+            if all(isinstance(partition, Partition) for partition in partitions):
+                return cast(Sequence[Partition], partitions)
+            else:
+                return [Partition(p) for p in partitions]
+        else:
+            check.opt_inst_param(
+                dynamic_partitions_store, "dynamic_partitions_store", DynamicPartitionsStore
+            )
+
+            if dynamic_partitions_store is None:
+                check.failed(
+                    "The instance is not available to load partitions. You may be seeing this error"
+                    " when using dynamic partitions with a version of dagit or dagster-cloud that"
+                    " is older than 1.1.18."
+                )
+
+            partitions = dynamic_partitions_store.get_dynamic_partitions(
+                partitions_def_name=self._validated_name()
+            )
+            return [Partition(key) for key in partitions]
 
 
-class PartitionSetDefinition(Generic[T]):
+class PartitionSetDefinition(Generic[T_cov]):
     """
     Defines a partition set, representing the set of slices making up an axis of a pipeline.
 
@@ -523,13 +738,13 @@ class PartitionSetDefinition(Generic[T]):
         solid_selection: Optional[Sequence[str]] = None,
         mode: Optional[str] = None,
         run_config_fn_for_partition: Callable[
-            [Partition[T]], Mapping[str, Any]
+            [Partition[T_cov]], Mapping[str, Any]
         ] = lambda _partition: {},
         tags_fn_for_partition: Callable[
-            [Partition[T]], Optional[Mapping[str, str]]
+            [Partition[T_cov]], Optional[Mapping[str, str]]
         ] = lambda _partition: {},
         partitions_def: Optional[
-            PartitionsDefinition[T]  # pylint: disable=unsubscriptable-object
+            PartitionsDefinition[T_cov]  # pylint: disable=unsubscriptable-object
         ] = None,
         job_name: Optional[str] = None,
     ):
@@ -550,10 +765,10 @@ class PartitionSetDefinition(Generic[T]):
         )
         self._mode = check.opt_str_param(mode, "mode", DEFAULT_MODE_NAME)
         # Type ignores workaround for mypy bug "cannot assign to a method"
-        self._user_defined_run_config_fn_for_partition = check.callable_param(  # type: ignore
+        self._user_defined_run_config_fn_for_partition = check.callable_param(
             run_config_fn_for_partition, "run_config_fn_for_partition"
         )
-        self._user_defined_tags_fn_for_partition = check.callable_param(  # type: ignore
+        self._user_defined_tags_fn_for_partition = check.callable_param(
             tags_fn_for_partition, "tags_fn_for_partition"
         )
         if partitions_def is not None:
@@ -584,11 +799,11 @@ class PartitionSetDefinition(Generic[T]):
             if not current_time:
                 current_time = pendulum.now("UTC")
 
-            check.callable_param(partition_fn, "partition_fn")  # type: ignore
+            check.callable_param(partition_fn, "partition_fn")
 
             if partition_fn_param_count == 1:
                 obj_list = cast(
-                    Callable[..., Sequence[Union[Partition[T], str]]],
+                    Callable[..., Sequence[Union[Partition[T_cov], str]]],
                     partition_fn,
                 )(current_time)
             else:
@@ -627,36 +842,50 @@ class PartitionSetDefinition(Generic[T]):
     def partitions_def(self) -> PartitionsDefinition:
         return self._partitions_def
 
-    def run_config_for_partition(self, partition: Partition[T]) -> Mapping[str, Any]:
-        return copy.deepcopy(self._user_defined_run_config_fn_for_partition(partition))  # type: ignore
+    def run_config_for_partition(self, partition: Partition[T_cov]) -> Mapping[str, Any]:
+        return copy.deepcopy(self._user_defined_run_config_fn_for_partition(partition))
 
-    def tags_for_partition(self, partition: Partition[T]) -> Mapping[str, str]:
+    def tags_for_partition(self, partition: Partition[T_cov]) -> Mapping[str, str]:
         user_tags = validate_tags(
-            self._user_defined_tags_fn_for_partition(partition), allow_reserved_tags=False  # type: ignore
+            self._user_defined_tags_fn_for_partition(partition), allow_reserved_tags=False
         )
         tags = merge_dicts(user_tags, DagsterRun.tags_for_partition_set(self, partition))
 
         return tags
 
-    def get_partitions(self, current_time: Optional[datetime] = None) -> Sequence[Partition[T]]:
+    def get_partitions(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Sequence[Partition[T_cov]]:
         """Return the set of known partitions.
 
         Arguments:
             current_time (Optional[datetime]): The evaluation time for the partition function, which
                 is passed through to the ``partition_fn`` (if it accepts a parameter).  Defaults to
                 the current time in UTC.
+
         """
-        return self._partitions_def.get_partitions(current_time)
+        return self._partitions_def.get_partitions(
+            current_time, dynamic_partitions_store=dynamic_partitions_store
+        )
 
-    def get_partition(self, name: str) -> Partition[T]:
-        for partition in self.get_partitions():
-            if partition.name == name:
-                return partition
+    def get_partition(
+        self,
+        name: str,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+        current_time: Optional[datetime] = None,
+    ) -> Partition[T_cov]:
+        return self._partitions_def.get_partition(
+            name, current_time=current_time, dynamic_partitions_store=dynamic_partitions_store
+        )
 
-        raise DagsterUnknownPartitionError(f"Could not find a partition with key `{name}`")
-
-    def get_partition_names(self, current_time: Optional[datetime] = None) -> Sequence[str]:
-        return [part.name for part in self.get_partitions(current_time)]
+    def get_partition_names(
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> Sequence[str]:
+        return [part.name for part in self.get_partitions(current_time, dynamic_partitions_store)]
 
     def create_schedule_definition(
         self,
@@ -859,13 +1088,13 @@ class PartitionScheduleDefinition(ScheduleDefinition):
                 )
             date = check.opt_inst_param(kwargs[date_param_name], date_param_name, datetime)
 
-        return self._decorated_fn(date)
+        return self._decorated_fn(date)  # type: ignore
 
     def get_partition_set(self) -> PartitionSetDefinition:
         return self._partition_set
 
 
-class PartitionedConfig(Generic[T]):
+class PartitionedConfig(Generic[T_cov]):
     """Defines a way of configuring a job where the job can be run on one of a discrete set of
     partitions, and each partition corresponds to run configuration for the job.
 
@@ -875,10 +1104,10 @@ class PartitionedConfig(Generic[T]):
 
     def __init__(
         self,
-        partitions_def: PartitionsDefinition[T],  # pylint: disable=unsubscriptable-object
-        run_config_for_partition_fn: Callable[[Partition[T]], Mapping[str, Any]],
+        partitions_def: PartitionsDefinition[T_cov],  # pylint: disable=unsubscriptable-object
+        run_config_for_partition_fn: Callable[[Partition[T_cov]], Mapping[str, Any]],
         decorated_fn: Optional[Callable[..., Mapping[str, Any]]] = None,
-        tags_for_partition_fn: Optional[Callable[[Partition[T]], Mapping[str, str]]] = None,
+        tags_for_partition_fn: Optional[Callable[[Partition[T_cov]], Mapping[str, str]]] = None,
     ):
         self._partitions = check.inst_param(partitions_def, "partitions_def", PartitionsDefinition)
         self._run_config_for_partition_fn = check.callable_param(
@@ -889,19 +1118,21 @@ class PartitionedConfig(Generic[T]):
             tags_for_partition_fn, "tags_for_partition_fn"
         )
 
-    @public  # type: ignore
+    @public
     @property
-    def partitions_def(self) -> PartitionsDefinition[T]:  # pylint: disable=unsubscriptable-object
+    def partitions_def(
+        self,
+    ) -> PartitionsDefinition[T_cov]:  # pylint: disable=unsubscriptable-object
         return self._partitions
 
-    @public  # type: ignore
+    @public
     @property
-    def run_config_for_partition_fn(self) -> Callable[[Partition[T]], Mapping[str, Any]]:
+    def run_config_for_partition_fn(self) -> Callable[[Partition[T_cov]], Mapping[str, Any]]:
         return self._run_config_for_partition_fn
 
-    @public  # type: ignore
+    @public
     @property
-    def tags_for_partition_fn(self) -> Optional[Callable[[Partition[T]], Mapping[str, str]]]:
+    def tags_for_partition_fn(self) -> Optional[Callable[[Partition[T_cov]], Mapping[str, str]]]:
         return self._tags_for_partition_fn
 
     def get_partition_keys(self, current_time: Optional[datetime] = None) -> Sequence[str]:
@@ -972,6 +1203,9 @@ def static_partitioned_config(
     Args:
         partition_keys (Sequence[str]): A list of valid partition keys, which serve as the range of
             values that can be provided to the decorated run config function.
+        tags_for_partition_fn (Optional[Callable[[str], Mapping[str, str]]]): A function that
+            accepts a partition key and returns a dictionary of tags to attach to runs for that
+            partition.
 
     Returns:
         PartitionedConfig
@@ -1014,6 +1248,9 @@ def dynamic_partitioned_config(
         partition_fn (Callable[[datetime.datetime], Sequence[str]]): A function that generates a
             list of valid partition keys, which serve as the range of values that can be provided
             to the decorated run config function.
+        tags_for_partition_fn (Optional[Callable[[str], Mapping[str, str]]]): A function that
+            accepts a partition key and returns a dictionary of tags to attach to runs for that
+            partition.
 
     Returns:
         PartitionedConfig
@@ -1055,85 +1292,127 @@ def cron_schedule_from_schedule_type_and_offsets(
         check.assert_never(schedule_type)
 
 
-class PartitionsSubset(ABC):
+class PartitionsSubset(ABC, Generic[T_cov]):
     """Represents a subset of the partitions within a PartitionsDefinition."""
 
     @abstractmethod
     def get_partition_keys_not_in_subset(
-        self, current_time: Optional[datetime] = None
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Iterable[str]:
-        raise NotImplementedError()
+        ...
 
     @abstractmethod
     def get_partition_keys(self, current_time: Optional[datetime] = None) -> Iterable[str]:
-        raise NotImplementedError()
+        ...
 
     @abstractmethod
     def get_partition_key_ranges(
-        self, current_time: Optional[datetime] = None
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Sequence[PartitionKeyRange]:
-        raise NotImplementedError()
+        ...
 
     @abstractmethod
-    def with_partition_keys(self, partition_keys: Iterable[str]) -> "PartitionsSubset":
-        raise NotImplementedError()
+    def with_partition_keys(self, partition_keys: Iterable[str]) -> "PartitionsSubset[T_cov]":
+        ...
 
     def with_partition_key_range(
-        self, partition_key_range: PartitionKeyRange
-    ) -> "PartitionsSubset":
+        self,
+        partition_key_range: PartitionKeyRange,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    ) -> "PartitionsSubset[T_cov]":
         return self.with_partition_keys(
-            self.partitions_def.get_partition_keys_in_range(partition_key_range)
+            self.partitions_def.get_partition_keys_in_range(
+                partition_key_range, dynamic_partitions_store=dynamic_partitions_store
+            )
         )
 
+    def __or__(self, other: "PartitionsSubset") -> "PartitionsSubset[T_cov]":
+        if self is other:
+            return self
+        return self.with_partition_keys(other.get_partition_keys())
+
     @abstractmethod
     def serialize(self) -> str:
-        raise NotImplementedError()
+        ...
 
     @classmethod
     @abstractmethod
     def from_serialized(
         cls, partitions_def: PartitionsDefinition, serialized: str
     ) -> "PartitionsSubset":
-        raise NotImplementedError()
+        ...
+
+    @classmethod
+    @abstractmethod
+    def can_deserialize(
+        cls,
+        partitions_def: PartitionsDefinition,
+        serialized: str,
+        serialized_partitions_def_unique_id: Optional[str],
+        serialized_partitions_def_class_name: Optional[str],
+    ) -> bool:
+        ...
 
     @property
     @abstractmethod
-    def partitions_def(self) -> PartitionsDefinition:
-        raise NotImplementedError()
+    def partitions_def(self) -> PartitionsDefinition[T_cov]:
+        ...
 
     @abstractmethod
     def __len__(self) -> int:
-        raise NotImplementedError()
+        ...
 
     @abstractmethod
     def __contains__(self, value) -> bool:
-        raise NotImplementedError()
+        ...
+
+    @classmethod
+    @abstractmethod
+    def empty_subset(cls, partitions_def: PartitionsDefinition) -> "PartitionsSubset[T_cov]":
+        ...
 
 
-class DefaultPartitionsSubset(PartitionsSubset):
+class DefaultPartitionsSubset(PartitionsSubset[T_cov]):
     # Every time we change the serialization format, we should increment the version number.
     # This will ensure that we can gracefully degrade when deserializing old data.
     SERIALIZATION_VERSION = 1
 
-    def __init__(self, partitions_def: PartitionsDefinition, subset: Optional[Set[str]] = None):
+    def __init__(
+        self, partitions_def: PartitionsDefinition[T_cov], subset: Optional[Set[str]] = None
+    ):
         check.opt_set_param(subset, "subset")
         self._partitions_def = partitions_def
         self._subset = subset or set()
 
     def get_partition_keys_not_in_subset(
-        self, current_time: Optional[datetime] = None
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Iterable[str]:
         return (
-            set(self._partitions_def.get_partition_keys(current_time=current_time)) - self._subset
+            set(
+                self._partitions_def.get_partition_keys(
+                    current_time=current_time, dynamic_partitions_store=dynamic_partitions_store
+                )
+            )
+            - self._subset
         )
 
     def get_partition_keys(self, current_time: Optional[datetime] = None) -> Iterable[str]:
         return self._subset
 
     def get_partition_key_ranges(
-        self, current_time: Optional[datetime] = None
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Sequence[PartitionKeyRange]:
-        partition_keys = self._partitions_def.get_partition_keys(current_time)
+        partition_keys = self._partitions_def.get_partition_keys(
+            current_time, dynamic_partitions_store=dynamic_partitions_store
+        )
         cur_range_start = None
         cur_range_end = None
         result = []
@@ -1152,19 +1431,14 @@ class DefaultPartitionsSubset(PartitionsSubset):
 
         return result
 
-    def with_partition_keys(self, partition_keys: Iterable[str]) -> "DefaultPartitionsSubset":
+    def with_partition_keys(
+        self, partition_keys: Iterable[str]
+    ) -> "DefaultPartitionsSubset[T_cov]":
         return DefaultPartitionsSubset(
             self._partitions_def,
             self._subset | set(partition_keys),
         )
 
-    def with_partition_key_range(
-        self, partition_key_range: PartitionKeyRange
-    ) -> "PartitionsSubset":
-        return self.with_partition_keys(
-            self._partitions_def.get_partition_keys_in_range(partition_key_range)
-        )
-
     def serialize(self) -> str:
         # Serialize version number, so attempting to deserialize old versions can be handled gracefully.
         # Any time the serialization format changes, we should increment the version number.
@@ -1172,8 +1446,8 @@ class DefaultPartitionsSubset(PartitionsSubset):
 
     @classmethod
     def from_serialized(
-        cls, partitions_def: PartitionsDefinition, serialized: str
-    ) -> "PartitionsSubset":
+        cls, partitions_def: PartitionsDefinition[T_cov], serialized: str
+    ) -> "PartitionsSubset[T_cov]":
         # Check the version number, so only valid versions can be deserialized.
         data = json.loads(serialized)
 
@@ -1188,11 +1462,27 @@ class DefaultPartitionsSubset(PartitionsSubset):
                 )
             return cls(subset=set(data.get("subset")), partitions_def=partitions_def)
 
+    @classmethod
+    def can_deserialize(
+        cls,
+        partitions_def: PartitionsDefinition[T_cov],
+        serialized: str,
+        serialized_partitions_def_unique_id: Optional[str],
+        serialized_partitions_def_class_name: Optional[str],
+    ) -> bool:
+        if serialized_partitions_def_class_name is not None:
+            return serialized_partitions_def_class_name == partitions_def.__class__.__name__
+
+        data = json.loads(serialized)
+        return isinstance(data, list) or (
+            data.get("subset") is not None and data.get("version") == cls.SERIALIZATION_VERSION
+        )
+
     @property
-    def partitions_def(self) -> PartitionsDefinition:
+    def partitions_def(self) -> PartitionsDefinition[T_cov]:
         return self._partitions_def
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         return (
             isinstance(other, DefaultPartitionsSubset)
             and self._partitions_def == other._partitions_def
@@ -1209,3 +1499,7 @@ class DefaultPartitionsSubset(PartitionsSubset):
         return (
             f"DefaultPartitionsSubset(subset={self._subset}, partitions_def={self._partitions_def})"
         )
+
+    @classmethod
+    def empty_subset(cls, partitions_def: PartitionsDefinition[T_cov]) -> "PartitionsSubset[T_cov]":
+        return cls(partitions_def=partitions_def)
