@@ -5,6 +5,7 @@ from typing import (
     Any,
     Dict,
     FrozenSet,
+    Iterable,
     Iterator,
     Mapping,
     Optional,
@@ -15,6 +16,7 @@ from typing import (
 )
 
 import dagster._check as check
+from dagster._core.definitions.metadata import MetadataEntry
 from dagster._core.definitions.policy import RetryPolicy
 from dagster._core.definitions.resource_definition import ResourceDefinition
 from dagster._core.errors import (
@@ -23,6 +25,7 @@ from dagster._core.errors import (
     DagsterInvariantViolationError,
 )
 from dagster._core.storage.tags import MEMOIZED_RUN_TAG
+from dagster._core.types.dagster_type import DagsterType
 from dagster._core.utils import str_format_set
 from dagster._utils import frozentags
 from dagster._utils.backcompat import experimental_class_warning
@@ -43,7 +46,7 @@ from .dependency import (
 )
 from .graph_definition import GraphDefinition, SubselectedGraphDefinition
 from .hook_definition import HookDefinition
-from .metadata import MetadataEntry, PartitionMetadataEntry, RawMetadataValue, normalize_metadata
+from .metadata import RawMetadataValue, normalize_metadata
 from .mode import ModeDefinition
 from .node_definition import NodeDefinition
 from .op_definition import OpDefinition
@@ -154,7 +157,7 @@ class PipelineDefinition:
     _graph_def: GraphDefinition
     _description: Optional[str]
     _tags: Mapping[str, str]
-    _metadata: Sequence[Union[MetadataEntry, PartitionMetadataEntry]]
+    _metadata: Sequence[MetadataEntry]
     _current_level_node_defs: Sequence[NodeDefinition]
     _mode_definitions: Sequence[ModeDefinition]
     _hook_defs: AbstractSet[HookDefinition]
@@ -189,7 +192,7 @@ class PipelineDefinition:
         ] = None,  # https://github.com/dagster-io/dagster/issues/2115
         version_strategy: Optional[VersionStrategy] = None,
         asset_layer: Optional[AssetLayer] = None,
-        metadata_entries: Optional[Sequence[Union[MetadataEntry, PartitionMetadataEntry]]] = None,
+        metadata_entries: Optional[Sequence[MetadataEntry]] = None,
     ):
         # If a graph is specified directly use it
         if isinstance(graph_def, GraphDefinition):
@@ -269,7 +272,7 @@ class PipelineDefinition:
             self._preset_dict[preset.name] = preset
 
         self._asset_layer = check.opt_inst_param(
-            asset_layer, "asset_layer", AssetLayer, default=AssetLayer.from_graph(self.graph)
+            asset_layer, "asset_layer", AssetLayer, default=AssetLayer()
         )
 
         resource_requirements = {}
@@ -332,7 +335,7 @@ class PipelineDefinition:
         return frozentags(**merge_dicts(self._graph_def.tags, self._tags))
 
     @property
-    def metadata(self) -> Sequence[Union[MetadataEntry, PartitionMetadataEntry]]:
+    def metadata(self) -> Sequence[MetadataEntry]:
         return self._metadata_entries
 
     @property
@@ -456,30 +459,30 @@ class PipelineDefinition:
         check.str_param(name, "name")
         return name in self._all_node_defs
 
-    def get_solid(self, handle):
-        return self._graph_def.get_solid(handle)
+    def get_solid(self, handle: NodeHandle) -> Node:
+        return self._graph_def.get_node(handle)
 
-    def has_solid_named(self, name):
-        return self._graph_def.has_solid_named(name)
+    def has_solid_named(self, name: str) -> bool:
+        return self._graph_def.has_node_named(name)
 
-    def solid_named(self, name):
-        return self._graph_def.solid_named(name)
+    def solid_named(self, name: str) -> Node:
+        return self._graph_def.node_named(name)
 
     @property
-    def solids(self):
-        return self._graph_def.solids
+    def solids(self) -> Sequence[Node]:
+        return self._graph_def.nodes
 
     @property
-    def solids_in_topological_order(self):
-        return self._graph_def.solids_in_topological_order
+    def solids_in_topological_order(self) -> Sequence[Node]:
+        return self._graph_def.nodes_in_topological_order
 
-    def all_dagster_types(self):
+    def all_dagster_types(self) -> Iterable[DagsterType]:
         return self._graph_def.all_dagster_types()
 
-    def has_dagster_type(self, name):
+    def has_dagster_type(self, name: str) -> bool:
         return self._graph_def.has_dagster_type(name)
 
-    def dagster_type_named(self, name):
+    def dagster_type_named(self, name: str) -> DagsterType:
         return self._graph_def.dagster_type_named(name)
 
     def get_pipeline_subset_def(
@@ -573,7 +576,7 @@ class PipelineDefinition:
 
         # hooks on top-level solid
         name = lineage.pop()
-        solid = self._graph_def.solid_named(name)
+        solid = self._graph_def.node_named(name)
         hook_defs = hook_defs.union(solid.hook_defs)
 
         # hooks on non-top-level solids
@@ -581,7 +584,7 @@ class PipelineDefinition:
             name = lineage.pop()
             # While lineage is non-empty, definition is guaranteed to be a graph
             definition = cast(GraphDefinition, solid.definition)
-            solid = definition.solid_named(name)
+            solid = definition.node_named(name)
             hook_defs = hook_defs.union(solid.hook_defs)
 
         # hooks applied to a pipeline definition will run on every solid
@@ -689,7 +692,7 @@ def _get_pipeline_subset_def(
     check.set_param(solids_to_execute, "solids_to_execute", of_type=str)
     graph = pipeline_def.graph
     for solid_name in solids_to_execute:
-        if not graph.has_solid_named(solid_name):
+        if not graph.has_node_named(solid_name):
             raise DagsterInvalidSubsetError(
                 "{target_type} {pipeline_name} has no {node_type} named {name}.".format(
                     target_type=pipeline_def.target_type,
@@ -701,7 +704,7 @@ def _get_pipeline_subset_def(
 
     # go in topo order to ensure deps dict is ordered
     solids = list(
-        filter(lambda solid: solid.name in solids_to_execute, graph.solids_in_topological_order)
+        filter(lambda solid: solid.name in solids_to_execute, graph.nodes_in_topological_order)
     )
 
     deps: Dict[
@@ -723,7 +726,7 @@ def _get_pipeline_subset_def(
                     deps[_dep_key_of(node)][
                         node_input.input_def.name
                     ] = DynamicCollectDependencyDefinition(
-                        solid_name=node_output.node.name,
+                        node_name=node_output.node.name,
                         output_name=node_output.output_def.name,
                     )
             elif graph.dependency_structure.has_fan_in_deps(node_input):
@@ -816,7 +819,7 @@ def _create_run_config_schema(
 
             ignored_solids = [
                 solid
-                for solid in parent_job.graph.solids
+                for solid in parent_job.graph.nodes
                 if not pipeline_def.has_solid_named(solid.name)
             ]
     elif pipeline_def.is_subset_pipeline:
@@ -825,7 +828,7 @@ def _create_run_config_schema(
 
         ignored_solids = [
             solid
-            for solid in pipeline_def.parent_pipeline_def.graph.solids
+            for solid in pipeline_def.parent_pipeline_def.graph.nodes
             if not pipeline_def.has_solid_named(solid.name)
         ]
     else:
@@ -834,7 +837,7 @@ def _create_run_config_schema(
     run_config_schema_type = define_run_config_schema_type(
         RunConfigSchemaCreationData(
             pipeline_name=pipeline_def.name,
-            solids=pipeline_def.graph.solids,
+            solids=pipeline_def.graph.nodes,
             graph_def=pipeline_def.graph,
             dependency_structure=pipeline_def.graph.dependency_structure,
             mode_definition=mode_definition,
