@@ -224,7 +224,7 @@ class ReconstructablePipeline(
 
     # Keep the most recent 1 definition (globally since this is a NamedTuple method)
     # This allows repeated calls to get_definition in execution paths to not reload the job
-    @lru_cache(maxsize=1)  # type: ignore
+    @lru_cache(maxsize=1)
     def get_definition(self) -> Union[JobDefinition, "PipelineDefinition"]:
         return self.repository.get_definition().get_maybe_subset_job_def(
             self.pipeline_name,
@@ -268,7 +268,7 @@ class ReconstructablePipeline(
                 solids_to_execute=None,
                 asset_selection=asset_selection,
             )
-        elif isinstance(pipeline_def, PipelineDefinition):  # type: ignore
+        elif isinstance(pipeline_def, PipelineDefinition):
             # when subselecting a pipeline
             # * pipeline subselection depend on solids_to_excute rather than solid_selection
             # * we resolve a list of solid selection queries to a frozenset of qualified solid names
@@ -340,11 +340,11 @@ class ReconstructablePipeline(
     def for_module(module: str, fn_name: str) -> ReconstructablePipeline:
         return bootstrap_standalone_recon_pipeline(ModuleCodePointer(module, fn_name, os.getcwd()))
 
-    def to_dict(self) -> Mapping[str, object]:
-        return pack_value(self)
+    def to_dict(self) -> Mapping[str, Any]:
+        return pack_value(self)  # type: ignore
 
     @staticmethod
-    def from_dict(val: Mapping[str, object]) -> ReconstructablePipeline:
+    def from_dict(val: Mapping[str, Any]) -> ReconstructablePipeline:
         check.mapping_param(val, "val")
 
         inst = unpack_value(val)
@@ -354,7 +354,7 @@ class ReconstructablePipeline(
                 type=type(inst)
             ),
         )
-        return inst
+        return inst  # type: ignore  # (illegible runtime check)
 
     def get_python_origin(self) -> PipelinePythonOrigin:
         return PipelinePythonOrigin(self.pipeline_name, self.repository.get_python_origin())
@@ -363,7 +363,7 @@ class ReconstructablePipeline(
         return self.get_python_origin().get_id()
 
     def get_module(self) -> Optional[str]:
-        """Return the module the pipeline is found in, the origin is a module code pointer"""
+        """Return the module the pipeline is found in, the origin is a module code pointer."""
         pointer = self.get_python_origin().get_repo_pointer()
         if isinstance(pointer, ModuleCodePointer):
             return pointer.module
@@ -411,26 +411,25 @@ def reconstructable(target: Callable[..., "PipelineDefinition"]) -> Reconstructa
     specify your own reconstruction strategy.
 
     Examples:
+        .. code-block:: python
 
-    .. code-block:: python
+            from dagster import job, reconstructable
 
-        from dagster import job, reconstructable
+            @job
+            def foo_job():
+                ...
 
-        @job
-        def foo_job():
-            ...
-
-        reconstructable_foo_job = reconstructable(foo_job)
+            reconstructable_foo_job = reconstructable(foo_job)
 
 
-        @graph
-        def foo():
-            ...
+            @graph
+            def foo():
+                ...
 
-        def make_bar_job():
-            return foo.to_job()
+            def make_bar_job():
+                return foo.to_job()
 
-        reconstructable_bar_job = reconstructable(make_bar_job)
+            reconstructable_bar_job = reconstructable(make_bar_job)
     """
     from dagster._core.definitions import JobDefinition, PipelineDefinition
 
@@ -526,40 +525,39 @@ def build_reconstructable_job(
             job. Values of the dict must be JSON serializable.
 
     Examples:
+        .. code-block:: python
 
-    .. code-block:: python
+            # module: mymodule
 
-        # module: mymodule
+            from dagster import JobDefinition, job, build_reconstructable_job
 
-        from dagster import JobDefinition, job, build_reconstructable_job
+            class JobFactory:
+                def make_job(*args, **kwargs):
 
-        class JobFactory:
-            def make_job(*args, **kwargs):
+                    @job
+                    def _job(...):
+                        ...
 
-                @job
-                def _job(...):
-                    ...
+                    return _job
 
-                return _job
+            def reconstruct_job(*args):
+                factory = JobFactory()
+                return factory.make_job(*args)
 
-        def reconstruct_job(*args):
             factory = JobFactory()
-            return factory.make_job(*args)
 
-        factory = JobFactory()
+            foo_job_args = (...,...)
 
-        foo_job_args = (...,...)
+            foo_job_kwargs = {...:...}
 
-        foo_job_kwargs = {...:...}
+            foo_job = factory.make_job(*foo_job_args, **foo_job_kwargs)
 
-        foo_job = factory.make_job(*foo_job_args, **foo_job_kwargs)
-
-        reconstructable_foo_job = build_reconstructable_job(
-            'mymodule',
-            'reconstruct_job',
-            foo_job_args,
-            foo_job_kwargs,
-        )
+            reconstructable_foo_job = build_reconstructable_job(
+                'mymodule',
+                'reconstruct_job',
+                foo_job_args,
+                foo_job_kwargs,
+            )
     """
     check.str_param(reconstructor_module_name, "reconstructor_module_name")
     check.str_param(reconstructor_function_name, "reconstructor_function_name")
@@ -642,12 +640,10 @@ def _check_is_loadable(definition: T_LoadableDefinition) -> T_LoadableDefinition
         ),
     ):
         raise DagsterInvariantViolationError(
-            (
-                "Loadable attributes must be either a JobDefinition, GraphDefinition, "
-                f"PipelineDefinition, AssetGroup, or RepositoryDefinition. Got {repr(definition)}."
-            )
+            "Loadable attributes must be either a JobDefinition, GraphDefinition, "
+            f"PipelineDefinition, AssetGroup, or RepositoryDefinition. Got {repr(definition)}."
         )
-    return definition  # type: ignore
+    return definition
 
 
 def load_def_in_module(
@@ -684,11 +680,11 @@ def def_from_pointer(
     if isinstance(
         target,
         (
-            PipelineDefinition,
-            RepositoryDefinition,
-            PendingRepositoryDefinition,
-            GraphDefinition,
             AssetGroup,
+            GraphDefinition,
+            PipelineDefinition,
+            PendingRepositoryDefinition,
+            RepositoryDefinition,
         ),
     ) or not callable(target):
         return _check_is_loadable(target)  # type: ignore
@@ -704,7 +700,7 @@ def def_from_pointer(
             )
         )
 
-    return _check_is_loadable(target())  # type: ignore
+    return _check_is_loadable(target())
 
 
 def pipeline_def_from_pointer(pointer: CodePointer) -> "PipelineDefinition":
@@ -716,14 +712,14 @@ def pipeline_def_from_pointer(pointer: CodePointer) -> "PipelineDefinition":
         return target
 
     raise DagsterInvariantViolationError(
-        "CodePointer ({str}) must resolve to a JobDefinition (or PipelineDefinition for legacy code). "
-        "Received a {type}".format(str=pointer.describe(), type=type(target))
+        "CodePointer ({str}) must resolve to a JobDefinition (or PipelineDefinition for legacy"
+        " code). Received a {type}".format(str=pointer.describe(), type=type(target))
     )
 
 
 @overload
 # NOTE: mypy can't handle these overloads but pyright can
-def repository_def_from_target_def(  # type: ignore
+def repository_def_from_target_def(
     target: Union["RepositoryDefinition", "PipelineDefinition", "GraphDefinition", "AssetGroup"],
     repository_load_data: Optional["RepositoryLoadData"] = None,
 ) -> "RepositoryDefinition":
