@@ -1,14 +1,31 @@
-from typing import AbstractSet, Any, Iterator, Mapping, NamedTuple, Optional, Sequence, Tuple, cast
+from typing import (
+    TYPE_CHECKING,
+    AbstractSet,
+    Any,
+    Dict,
+    Iterator,
+    Mapping,
+    NamedTuple,
+    Optional,
+    Sequence,
+    Tuple,
+    TypeVar,
+    Union,
+    cast,
+)
 
+from typing_extensions import TypeAlias
+
+from dagster._annotations import experimental
 from dagster._config import (
     ALL_CONFIG_BUILTINS,
-    Array,
     ConfigType,
     Field,
     Permissive,
     Selector,
     Shape,
 )
+from dagster._config.structured_config import Config
 from dagster._core.definitions.asset_layer import AssetLayer
 from dagster._core.definitions.executor_definition import (
     ExecutorDefinition,
@@ -32,6 +49,9 @@ from .mode import ModeDefinition
 from .op_definition import NodeDefinition, OpDefinition
 from .resource_definition import ResourceDefinition
 
+if TYPE_CHECKING:
+    from .source_asset import SourceAsset
+
 
 def define_resource_dictionary_cls(
     resource_defs: Mapping[str, ResourceDefinition],
@@ -163,6 +183,7 @@ def define_run_config_schema_type(creation_data: RunConfigSchemaCreationData) ->
             resource_defs=creation_data.mode_definition.resource_defs,
             solid_ignored=False,
             direct_inputs=creation_data.direct_inputs,
+            input_source_assets={},
             asset_layer=creation_data.asset_layer,
             is_using_graph_job_op_apis=creation_data.is_using_graph_job_op_apis,
         ),
@@ -183,6 +204,7 @@ def define_run_config_schema_type(creation_data: RunConfigSchemaCreationData) ->
                 resource_defs=creation_data.mode_definition.resource_defs,
                 is_using_graph_job_op_apis=creation_data.is_using_graph_job_op_apis,
                 asset_layer=creation_data.asset_layer,
+                node_input_source_assets=creation_data.graph_def.node_input_source_assets,
             ),
             description="Configure runtime parameters for ops or assets.",
         )
@@ -214,6 +236,7 @@ def get_inputs_field(
     solid_ignored: bool,
     asset_layer: AssetLayer,
     is_using_graph_job_op_apis: bool,
+    input_source_assets: Mapping[str, "SourceAsset"],
     direct_inputs: Optional[Mapping[str, Any]] = None,
 ):
     direct_inputs = check.opt_mapping_param(direct_inputs, "direct_inputs")
@@ -232,6 +255,8 @@ def get_inputs_field(
             input_field = None
         elif name in direct_inputs and not has_upstream:
             input_field = None
+        elif name in input_source_assets and not has_upstream:
+            input_field = None
         elif inp.root_manager_key and not has_upstream:
             input_field = get_input_manager_input_field(solid, inp, resource_defs)
         elif inp.dagster_type.loader and not has_upstream:
@@ -330,8 +355,6 @@ def get_outputs_field(
     solid: Node,
     resource_defs: Mapping[str, ResourceDefinition],
 ) -> Optional[Field]:
-    # if any outputs have configurable output managers, use those for the schema and ignore all type
-    # materializers
     output_manager_fields = {}
     for name, output_def in solid.definition.output_dict.items():
         output_manager_output_field = get_output_manager_output_field(
@@ -340,20 +363,7 @@ def get_outputs_field(
         if output_manager_output_field:
             output_manager_fields[name] = output_manager_output_field
 
-    if output_manager_fields:
-        return Field(Shape(output_manager_fields))
-
-    # otherwise, use any type materializers for the schema
-    type_materializer_fields = {}
-    for name, output_def in solid.definition.output_dict.items():
-        type_output_field = get_type_output_field(output_def)
-        if type_output_field:
-            type_materializer_fields[name] = type_output_field
-
-    if type_materializer_fields:
-        return Field(Array(Shape(type_materializer_fields)), is_required=False)
-
-    return None
+    return Field(Shape(output_manager_fields)) if output_manager_fields else None
 
 
 def get_output_manager_output_field(
@@ -382,13 +392,6 @@ def get_output_manager_output_field(
     return None
 
 
-def get_type_output_field(output_def: OutputDefinition) -> Optional[Field]:
-    if output_def.dagster_type.materializer:
-        return Field(output_def.dagster_type.materializer.schema_type, is_required=False)
-
-    return None
-
-
 def solid_config_field(
     fields: Mapping[str, Optional[Field]], ignored: bool, is_using_graph_job_op_apis: bool
 ) -> Optional[Field]:
@@ -420,6 +423,7 @@ def construct_leaf_solid_config(
     ignored: bool,
     is_using_graph_job_op_apis: bool,
     asset_layer: AssetLayer,
+    input_source_assets: Mapping[str, "SourceAsset"],
 ) -> Optional[Field]:
     return solid_config_field(
         {
@@ -431,6 +435,7 @@ def construct_leaf_solid_config(
                 ignored,
                 asset_layer,
                 is_using_graph_job_op_apis,
+                input_source_assets,
             ),
             "outputs": get_outputs_field(solid, resource_defs),
             "config": config_schema.as_field() if config_schema else None,
@@ -448,6 +453,7 @@ def define_isolid_field(
     ignored: bool,
     is_using_graph_job_op_apis: bool,
     asset_layer: AssetLayer,
+    input_source_assets: Mapping[str, "SourceAsset"],
 ) -> Optional[Field]:
     # All solids regardless of compositing status get the same inputs and outputs
     # config. The only thing the varies is on extra element of configuration
@@ -469,6 +475,7 @@ def define_isolid_field(
             ignored,
             is_using_graph_job_op_apis,
             asset_layer,
+            input_source_assets,
         )
 
     graph_def = solid.definition.ensure_graph_def()
@@ -486,6 +493,7 @@ def define_isolid_field(
             ignored,
             is_using_graph_job_op_apis,
             asset_layer,
+            input_source_assets,
         )
         # This case omits a 'solids' key, thus if a composite solid is `configured` or has a field
         # mapping, the user cannot stub any config, inputs, or outputs for inner (child) solids.
@@ -499,18 +507,20 @@ def define_isolid_field(
                 ignored,
                 asset_layer,
                 is_using_graph_job_op_apis,
+                input_source_assets,
             ),
             "outputs": get_outputs_field(solid, resource_defs),
         }
         nodes_field = Field(
             define_solid_dictionary_cls(
-                solids=graph_def.solids,
+                solids=graph_def.nodes,
                 ignored_solids=None,
                 dependency_structure=graph_def.dependency_structure,
                 parent_handle=handle,
                 resource_defs=resource_defs,
                 is_using_graph_job_op_apis=is_using_graph_job_op_apis,
                 asset_layer=asset_layer,
+                node_input_source_assets=graph_def.node_input_source_assets,
             )
         )
         if is_using_graph_job_op_apis:
@@ -530,8 +540,28 @@ def define_solid_dictionary_cls(
     resource_defs: Mapping[str, ResourceDefinition],
     is_using_graph_job_op_apis: bool,
     asset_layer: AssetLayer,
+    node_input_source_assets: Mapping[str, Mapping[str, "SourceAsset"]],
     parent_handle: Optional[NodeHandle] = None,
 ) -> Shape:
+    """
+    Examples of what this method is used to generate the schema for:
+      1.
+          inputs: ...
+          ops:
+        >    op1: ...
+        >    op2: ...
+
+      2.
+          inputs:
+          ops:
+            graph1: ...
+              inputs: ...
+              ops:
+        >       op1: ...
+        >       inner_graph: ...
+
+
+    """
     ignored_solids = check.opt_sequence_param(ignored_solids, "ignored_solids", of_type=Node)
 
     fields = {}
@@ -544,6 +574,7 @@ def define_solid_dictionary_cls(
             ignored=False,
             is_using_graph_job_op_apis=is_using_graph_job_op_apis,
             asset_layer=asset_layer,
+            input_source_assets=node_input_source_assets.get(solid.name, {}),
         )
 
         if solid_field:
@@ -558,6 +589,7 @@ def define_solid_dictionary_cls(
             ignored=True,
             is_using_graph_job_op_apis=is_using_graph_job_op_apis,
             asset_layer=asset_layer,
+            input_source_assets=node_input_source_assets.get(solid.name, {}),
         )
         if solid_field:
             fields[solid.name] = solid_field
@@ -571,7 +603,7 @@ def iterate_node_def_config_types(node_def: NodeDefinition) -> Iterator[ConfigTy
         if node_def.has_config_field:
             yield from node_def.get_config_field().config_type.type_iterator()
     elif isinstance(node_def, GraphDefinition):
-        for solid in node_def.solids:
+        for solid in node_def.nodes:
             yield from iterate_node_def_config_types(solid.definition)
 
     else:
@@ -583,8 +615,6 @@ def _gather_all_schemas(node_defs: Sequence[NodeDefinition]) -> Iterator[ConfigT
     for dagster_type in list(dagster_types.values()) + list(ALL_RUNTIME_BUILTINS):
         if dagster_type.loader:
             yield from dagster_type.loader.schema_type.type_iterator()
-        if dagster_type.materializer:
-            yield from dagster_type.materializer.schema_type.type_iterator()
 
 
 def _gather_all_config_types(
@@ -622,3 +652,42 @@ def construct_config_type_dictionary(
         type_dict_by_key[config_type.key] = config_type
 
     return type_dict_by_name, type_dict_by_key
+
+
+def _convert_config_classes(configs: Dict[str, Any]) -> Dict[str, Any]:
+    return {
+        k: {"config": v._as_config_dict() if isinstance(v, Config) else v}
+        for k, v in configs.items()
+    }
+
+
+@experimental
+class RunConfig:
+    def __init__(
+        self,
+        ops: Optional[Dict[str, Any]] = None,
+        resources: Optional[Dict[str, Any]] = None,
+        loggers: Optional[Dict[str, Any]] = None,
+    ):
+        self.ops = check.opt_dict_param(ops, "ops")
+        self.resources = check.opt_dict_param(resources, "resources")
+        self.loggers = check.opt_dict_param(loggers, "loggers")
+
+    def to_config_dict(self):
+        return {
+            "loggers": self.loggers,
+            "resources": _convert_config_classes(self.resources),
+            "ops": _convert_config_classes(self.ops),
+        }
+
+
+CoercibleToRunConfig: TypeAlias = Union[Dict[str, Any], RunConfig]
+
+T = TypeVar("T")
+
+
+def convert_config_input(input: Union[CoercibleToRunConfig, T]) -> Union[T, Mapping[str, Any]]:
+    if isinstance(input, RunConfig):
+        return input.to_config_dict()
+    else:
+        return input
