@@ -42,7 +42,6 @@ from dagster._utils.error import serializable_error_info_from_exc_info
 
 from ..decorator_utils import get_function_params
 from .graph_definition import GraphDefinition
-from .job_definition import JobDefinition
 from .pipeline_definition import PipelineDefinition
 from .sensor_definition import (
     DefaultSensorStatus,
@@ -51,13 +50,15 @@ from .sensor_definition import (
     RunRequest,
     SensorDefinition,
     SensorEvaluationContext,
+    SensorType,
     SkipReason,
-    is_context_provided,
+    has_at_least_one_parameter,
 )
+from .target import ExecutableDefinition
 from .unresolved_asset_job_definition import UnresolvedAssetJobDefinition
 
 if TYPE_CHECKING:
-    from dagster._core.host_representation.selector import (
+    from dagster._core.definitions.selector import (
         CodeLocationSelector,
         JobSelector,
         RepositorySelector,
@@ -136,27 +137,27 @@ class RunStatusSensorContext:
             context=self._context,
         )
 
-    @public  # type: ignore
+    @public
     @property
     def sensor_name(self) -> str:
         return self._sensor_name
 
-    @public  # type: ignore
+    @public
     @property
     def dagster_run(self) -> DagsterRun:
         return self._dagster_run
 
-    @public  # type: ignore
+    @public
     @property
     def dagster_event(self) -> DagsterEvent:
         return self._dagster_event
 
-    @public  # type: ignore
+    @public
     @property
     def instance(self) -> DagsterInstance:
         return self._instance
 
-    @public  # type: ignore
+    @public
     @property
     def log(self) -> logging.Logger:
         if self._context:
@@ -274,8 +275,8 @@ def run_failure_sensor(
     ] = None,
     monitor_all_repositories: bool = False,
     default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
-    request_job: Optional[Union[GraphDefinition, JobDefinition]] = None,
-    request_jobs: Optional[Sequence[Union[GraphDefinition, JobDefinition]]] = None,
+    request_job: Optional[ExecutableDefinition] = None,
+    request_jobs: Optional[Sequence[ExecutableDefinition]] = None,
 ) -> Callable[[RunFailureSensorEvaluationFn], SensorDefinition,]:
     ...
 
@@ -310,8 +311,8 @@ def run_failure_sensor(
     ] = None,
     monitor_all_repositories: bool = False,
     default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
-    request_job: Optional[Union[GraphDefinition, JobDefinition]] = None,
-    request_jobs: Optional[Sequence[Union[GraphDefinition, JobDefinition]]] = None,
+    request_job: Optional[ExecutableDefinition] = None,
+    request_jobs: Optional[Sequence[ExecutableDefinition]] = None,
 ) -> Union[SensorDefinition, Callable[[RunFailureSensorEvaluationFn], SensorDefinition,]]:
     """
     Creates a sensor that reacts to job failure events, where the decorated function will be
@@ -338,9 +339,9 @@ def run_failure_sensor(
             when any job in the repository fails.
         default_status (DefaultSensorStatus): Whether the sensor starts as running or not. The default
             status can be overridden from Dagit or via the GraphQL API.
-        request_job (Optional[Union[GraphDefinition, JobDefinition]]): The job a RunRequest should
+        request_job (Optional[Union[GraphDefinition, JobDefinition, UnresolvedAssetJob]]): The job a RunRequest should
             execute if yielded from the sensor.
-        request_jobs (Optional[Sequence[Union[GraphDefinition, JobDefinition]]]): (experimental)
+        request_jobs (Optional[Sequence[Union[GraphDefinition, JobDefinition, UnresolvedAssetJob]]]): (experimental)
             A list of jobs to be executed if RunRequests are yielded from the sensor.
     """
 
@@ -429,15 +430,15 @@ class RunStatusSensorDefinition(SensorDefinition):
         ] = None,
         monitor_all_repositories: bool = False,
         default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
-        request_job: Optional[Union[GraphDefinition, JobDefinition]] = None,
-        request_jobs: Optional[Sequence[Union[GraphDefinition, JobDefinition]]] = None,
+        request_job: Optional[ExecutableDefinition] = None,
+        request_jobs: Optional[Sequence[ExecutableDefinition]] = None,
     ):
-        from dagster._core.event_api import RunShardedEventsCursor
-        from dagster._core.host_representation.selector import (
+        from dagster._core.definitions.selector import (
             CodeLocationSelector,
             JobSelector,
             RepositorySelector,
         )
+        from dagster._core.event_api import RunShardedEventsCursor
         from dagster._core.storage.event_log.base import EventRecordsFilter
 
         check.str_param(name, "name")
@@ -556,7 +557,7 @@ class RunStatusSensorDefinition(SensorDefinition):
                     )
                     continue
 
-                pipeline_run = run_records[0].pipeline_run
+                pipeline_run = run_records[0].dagster_run
                 update_timestamp = run_records[0].update_timestamp
 
                 job_match = False
@@ -621,8 +622,8 @@ class RunStatusSensorDefinition(SensorDefinition):
                         lambda: f'Error occurred during the execution sensor "{name}".',
                     ):
                         # one user code invocation maps to one failure event
-                        sensor_return = run_status_sensor_fn(  # type: ignore  # fmt: skip
-                            RunStatusSensorContext(
+                        sensor_return = run_status_sensor_fn(
+                            RunStatusSensorContext(  # type: ignore
                                 sensor_name=name,
                                 dagster_run=pipeline_run,
                                 dagster_event=event_log_entry.dagster_event,
@@ -678,7 +679,7 @@ class RunStatusSensorDefinition(SensorDefinition):
         )
 
     def __call__(self, *args, **kwargs):
-        if is_context_provided(self._run_status_sensor_fn):
+        if has_at_least_one_parameter(self._run_status_sensor_fn):
             if len(args) + len(kwargs) == 0:
                 raise DagsterInvalidInvocationError(
                     "Run status sensor function expected context argument, but no context argument "
@@ -719,6 +720,10 @@ class RunStatusSensorDefinition(SensorDefinition):
 
             return self._run_status_sensor_fn()
 
+    @property
+    def sensor_type(self) -> SensorType:
+        return SensorType.RUN_STATUS
+
 
 def run_status_sensor(
     run_status: DagsterRunStatus,
@@ -751,8 +756,8 @@ def run_status_sensor(
     ] = None,
     monitor_all_repositories: bool = False,
     default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
-    request_job: Optional[Union[GraphDefinition, JobDefinition]] = None,
-    request_jobs: Optional[Sequence[Union[GraphDefinition, JobDefinition]]] = None,
+    request_job: Optional[ExecutableDefinition] = None,
+    request_jobs: Optional[Sequence[ExecutableDefinition]] = None,
 ) -> Callable[[RunStatusSensorEvaluationFunction], RunStatusSensorDefinition,]:
     """
     Creates a sensor that reacts to a given status of pipeline execution, where the decorated
@@ -780,9 +785,9 @@ def run_status_sensor(
             any job in the repository matches the requested run_status.
         default_status (DefaultSensorStatus): Whether the sensor starts as running or not. The default
             status can be overridden from Dagit or via the GraphQL API.
-        request_job (Optional[Union[GraphDefinition, JobDefinition]]): The job that should be
+        request_job (Optional[Union[GraphDefinition, JobDefinition, UnresolvedAssetJobDefinition]]): The job that should be
             executed if a RunRequest is yielded from the sensor.
-        request_jobs (Optional[Sequence[Union[GraphDefinition, JobDefinition]]]): (experimental)
+        request_jobs (Optional[Sequence[Union[GraphDefinition, JobDefinition, UnresolvedAssetJobDefinition]]]): (experimental)
             A list of jobs to be executed if RunRequests are yielded from the sensor.
     """
 
