@@ -1,5 +1,3 @@
-# type: ignore
-
 # NOTE: This file has been factored out from "resource_definition" and type-ignored due to a mypy bug
 # when processing dynamically generated namedtuples. This code corrupts the mypy cache and causes
 # mypy to fail. When mypy fixes this bug, the type-ignore can be removed and the file contents
@@ -8,7 +6,7 @@
 # See: https://github.com/python/mypy/issues/7281
 
 from collections import namedtuple
-from typing import AbstractSet, Mapping, NamedTuple, Optional
+from typing import AbstractSet, Any, Mapping, NamedTuple, Optional
 
 import dagster._check as check
 from dagster._core.errors import DagsterUnknownResourceError
@@ -16,14 +14,19 @@ from dagster._core.errors import DagsterUnknownResourceError
 
 class IContainsGenerator:
     """This class adds an additional tag to indicate that the resources object has at least one
-    resource that has been yielded from a generator, and thus may require teardown."""
+    resource that has been yielded from a generator, and thus may require teardown.
+    """
 
 
 class Resources:
     """This class functions as a "tag" that we can use to type the namedtuple returned by
     ScopedResourcesBuilder.build(). The way that we create the namedtuple returned by build() is
     incompatible with type annotations on its own due to its dynamic attributes, so this tag class
-    provides a workaround."""
+    provides a workaround.
+    """
+
+    def __getattr__(self, name: str) -> Any:
+        raise DagsterUnknownResourceError(name)
 
 
 class ScopedResourcesBuilder(
@@ -35,7 +38,8 @@ class ScopedResourcesBuilder(
     """There are concepts in the codebase (e.g. ops, system storage) that receive
     only the resources that they have specified in required_resource_keys.
     ScopedResourcesBuilder is responsible for dynamically building a class with
-    only those required resources and returning an instance of that class."""
+    only those required resources and returning an instance of that class.
+    """
 
     def __new__(
         cls,
@@ -51,7 +55,6 @@ class ScopedResourcesBuilder(
         )
 
     def build(self, required_resource_keys: Optional[AbstractSet[str]]) -> Resources:
-
         """We dynamically create a type that has the resource keys as properties, to enable dotting into
         the resources from a context.
 
@@ -81,22 +84,22 @@ class ScopedResourcesBuilder(
         if self.contains_generator:
 
             class _ScopedResourcesContainsGenerator(
-                namedtuple("_ScopedResourcesContainsGenerator", list(resource_instance_dict.keys())),  # type: ignore[misc]
+                namedtuple(
+                    "_ScopedResourcesContainsGenerator", list(resource_instance_dict.keys())
+                ),
                 Resources,
                 IContainsGenerator,
             ):
-                def __getattr__(self, attr):
-                    raise DagsterUnknownResourceError(attr)
+                ...
 
             return _ScopedResourcesContainsGenerator(**resource_instance_dict)  # type: ignore[call-arg]
 
         else:
 
             class _ScopedResources(
-                namedtuple("_ScopedResources", list(resource_instance_dict.keys())),  # type: ignore[misc]
+                namedtuple("_ScopedResources", list(resource_instance_dict.keys())),
                 Resources,
             ):
-                def __getattr__(self, attr):
-                    raise DagsterUnknownResourceError(attr)
+                ...
 
             return _ScopedResources(**resource_instance_dict)  # type: ignore[call-arg]
