@@ -1,5 +1,7 @@
 from datetime import datetime
-from typing import Mapping, NamedTuple, Optional, Sequence, Union
+from typing import Callable, Mapping, NamedTuple, Optional, Sequence, Union
+
+from typing_extensions import TypeAlias
 
 import dagster._check as check
 from dagster._annotations import PublicAttr
@@ -9,6 +11,8 @@ from dagster._core.events import DagsterEventType
 from dagster._core.events.log import EventLogEntry
 from dagster._serdes import whitelist_for_serdes
 
+EventHandlerFn: TypeAlias = Callable[[EventLogEntry, str], None]
+
 
 class RunShardedEventsCursor(NamedTuple):
     """Pairs an id-based event log cursor with a timestamp-based run cursor, for improved
@@ -20,6 +24,7 @@ class RunShardedEventsCursor(NamedTuple):
     run_updated_after: datetime
 
 
+@whitelist_for_serdes
 class EventLogRecord(NamedTuple):
     """Internal representation of an event record, as stored in a
     :py:class:`~dagster._core.storage.event_log.EventLogStorage`.
@@ -126,10 +131,10 @@ class EventRecordsFilter(
             event_type=event_type,
             asset_key=check.opt_inst_param(asset_key, "asset_key", AssetKey),
             asset_partitions=asset_partitions,
-            after_cursor=check.opt_inst_param(  # type: ignore
+            after_cursor=check.opt_inst_param(
                 after_cursor, "after_cursor", (int, RunShardedEventsCursor)
             ),
-            before_cursor=check.opt_inst_param(  # type: ignore
+            before_cursor=check.opt_inst_param(
                 before_cursor, "before_cursor", (int, RunShardedEventsCursor)
             ),
             after_timestamp=check.opt_float_param(after_timestamp, "after_timestamp"),
