@@ -24,9 +24,10 @@ from dagster._core.definitions.events import AssetKey, AssetKeyPartitionKey
 from dagster._core.definitions.external_asset_graph import ExternalAssetGraph
 from dagster._core.definitions.mode import DEFAULT_MODE_NAME
 from dagster._core.definitions.run_request import RunRequest
+from dagster._core.definitions.selector import PipelineSelector
+from dagster._core.errors import DagsterBackfillFailedError
 from dagster._core.events import DagsterEventType
-from dagster._core.host_representation.selector import PipelineSelector
-from dagster._core.instance import DagsterInstance
+from dagster._core.instance import DagsterInstance, DynamicPartitionsStore
 from dagster._core.storage.pipeline_run import DagsterRunStatus, RunsFilter
 from dagster._core.storage.tags import BACKFILL_ID_TAG, PARTITION_NAME_TAG
 from dagster._core.workspace.context import BaseWorkspaceRequestContext
@@ -66,11 +67,11 @@ class AssetBackfillData(NamedTuple):
             self.target_subset.filter_asset_keys(root_asset_keys).iterate_asset_partitions()
         )
 
-    def get_num_partitions(self) -> int:
+    def get_num_partitions(self) -> Optional[int]:
         """
         Only valid when the same number of partitions are targeted in every asset.
 
-        When not valid, raises an error.
+        When not valid, returns None.
         """
         asset_partition_nums = {
             len(subset) for subset in self.target_subset.partitions_subsets_by_asset_key.values()
@@ -80,27 +81,21 @@ class AssetBackfillData(NamedTuple):
         elif len(asset_partition_nums) == 1:
             return next(iter(asset_partition_nums))
         else:
-            check.failed(
-                "Can't compute number of partitions for asset backfill because different assets "
-                "have different numbers of partitions"
-            )
+            return None
 
-    def get_partition_names(self) -> Sequence[str]:
+    def get_partition_names(self) -> Optional[Sequence[str]]:
         """
         Only valid when the same number of partitions are targeted in every asset.
 
-        When not valid, raises an error.
+        When not valid, returns None.
         """
         subsets = self.target_subset.partitions_subsets_by_asset_key.values()
         if len(subsets) == 0:
             return []
 
         first_subset = next(iter(subsets))
-        if any(subset != subset for subset in subsets):
-            check.failed(
-                "Can't find partition names for asset backfill because different assets "
-                "have different partitions"
-            )
+        if any(subset != first_subset for subset in subsets):
+            return None
 
         return list(first_subset.get_partition_keys())
 
@@ -116,6 +111,13 @@ class AssetBackfillData(NamedTuple):
             latest_storage_id=None,
         )
 
+    @classmethod
+    def is_valid_serialization(cls, serialized: str, asset_graph: AssetGraph) -> bool:
+        storage_dict = json.loads(serialized)
+        return AssetGraphSubset.can_deserialize(
+            storage_dict["serialized_target_subset"], asset_graph
+        )
+
     @classmethod
     def from_serialized(cls, serialized: str, asset_graph: AssetGraph) -> "AssetBackfillData":
         storage_dict = json.loads(serialized)
@@ -137,6 +139,54 @@ class AssetBackfillData(NamedTuple):
             latest_storage_id=storage_dict["latest_storage_id"],
         )
 
+    @classmethod
+    def from_asset_partitions(
+        cls,
+        asset_graph: AssetGraph,
+        partition_names: Sequence[str],
+        asset_selection: Sequence[AssetKey],
+        dynamic_partitions_store: DynamicPartitionsStore,
+    ) -> "AssetBackfillData":
+        partitioned_asset_keys = {
+            asset_key
+            for asset_key in asset_selection
+            if asset_graph.get_partitions_def(asset_key) is not None
+        }
+
+        root_partitioned_asset_keys = (
+            AssetSelection.keys(*partitioned_asset_keys).sources().resolve(asset_graph)
+        )
+        root_partitions_defs = {
+            asset_graph.get_partitions_def(asset_key) for asset_key in root_partitioned_asset_keys
+        }
+        if len(root_partitions_defs) > 1:
+            raise DagsterBackfillFailedError(
+                "All the assets at the root of the backfill must have the same PartitionsDefinition"
+            )
+
+        root_partitions_def = next(iter(root_partitions_defs))
+        if not root_partitions_def:
+            raise DagsterBackfillFailedError(
+                "If assets within the backfill have different partitionings, then root assets"
+                " must be partitioned"
+            )
+
+        root_partitions_subset = root_partitions_def.subset_with_partition_keys(partition_names)
+        target_subset = AssetGraphSubset(
+            asset_graph, non_partitioned_asset_keys=set(asset_selection) - partitioned_asset_keys
+        )
+        for root_asset_key in root_partitioned_asset_keys:
+            target_subset |= asset_graph.bfs_filter_subsets(
+                dynamic_partitions_store,
+                lambda asset_key, _: asset_key in partitioned_asset_keys,
+                AssetGraphSubset(
+                    asset_graph,
+                    partitions_subsets_by_asset_key={root_asset_key: root_partitions_subset},
+                ),
+            )
+
+        return cls.empty(target_subset)
+
     def serialize(self) -> str:
         storage_dict = {
             "requested_runs_for_target_roots": self.requested_runs_for_target_roots,
@@ -348,6 +398,7 @@ def execute_asset_backfill_iteration_inner(
 
         failed_and_downstream_subset = AssetGraphSubset.from_asset_partition_set(
             asset_graph.bfs_filter_asset_partitions(
+                instance_queryer,
                 lambda asset_partitions, _: any(
                     asset_partition in asset_backfill_data.target_subset
                     for asset_partition in asset_partitions
@@ -360,6 +411,7 @@ def execute_asset_backfill_iteration_inner(
         yield None
 
     asset_partitions_to_request = asset_graph.bfs_filter_asset_partitions(
+        instance_queryer,
         lambda unit, visited: should_backfill_atomic_asset_partitions_unit(
             candidates_unit=unit,
             asset_partitions_to_request=visited,
@@ -367,6 +419,7 @@ def execute_asset_backfill_iteration_inner(
             materialized_subset=updated_materialized_subset,
             target_subset=asset_backfill_data.target_subset,
             failed_and_downstream_subset=failed_and_downstream_subset,
+            dynamic_partitions_store=instance_queryer,
         ),
         initial_asset_partitions=initial_candidates,
     )
@@ -400,6 +453,7 @@ def should_backfill_atomic_asset_partitions_unit(
     target_subset: AssetGraphSubset,
     materialized_subset: AssetGraphSubset,
     failed_and_downstream_subset: AssetGraphSubset,
+    dynamic_partitions_store: DynamicPartitionsStore,
 ) -> bool:
     """
     Args:
@@ -414,7 +468,7 @@ def should_backfill_atomic_asset_partitions_unit(
         ):
             return False
 
-        for parent in asset_graph.get_parents_partitions(*candidate):
+        for parent in asset_graph.get_parents_partitions(dynamic_partitions_store, *candidate):
             can_run_with_parent = (
                 parent in asset_partitions_to_request
                 and asset_graph.have_same_partitioning(parent.asset_key, candidate.asset_key)
