@@ -1,10 +1,14 @@
 from abc import ABC, abstractmethod
-from typing import AbstractSet, Any, Dict, Iterator, List, Mapping, Optional, Sequence, cast
+from typing import AbstractSet, Any, Dict, Iterator, List, Mapping, Optional, Sequence, Set, cast
 
 from typing_extensions import TypeAlias
 
 import dagster._check as check
-from dagster._annotations import public
+from dagster._annotations import experimental, public
+from dagster._core.definitions.data_version import (
+    DataProvenance,
+    extract_data_provenance_from_entry,
+)
 from dagster._core.definitions.dependency import Node, NodeHandle
 from dagster._core.definitions.events import (
     AssetKey,
@@ -38,7 +42,7 @@ class AbstractComputeExecutionContext(ABC):  # pylint: disable=no-init
     """
 
     @abstractmethod
-    def has_tag(self, key) -> bool:
+    def has_tag(self, key: str) -> bool:
         """Implement this method to check if a logging tag is set."""
 
     @abstractmethod
@@ -112,32 +116,28 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         self._events: List[DagsterEvent] = []
         self._output_metadata: Dict[str, Any] = {}
 
-    @property
-    def solid_config(self) -> Any:
-        return self._step_execution_context.op_config
-
-    @public  # type: ignore
+    @public
     @property
     def op_config(self) -> Any:
-        return self.solid_config
+        return self._step_execution_context.op_config
 
     @property
     def pipeline_run(self) -> DagsterRun:
         """PipelineRun: The current pipeline run."""
-        return self._step_execution_context.pipeline_run
+        return self._step_execution_context.dagster_run
 
     @property
     def run(self) -> DagsterRun:
         """DagsterRun: The current run."""
-        return cast(DagsterRun, self.pipeline_run)
+        return self.pipeline_run
 
-    @public  # type: ignore
+    @public
     @property
     def instance(self) -> DagsterInstance:
         """DagsterInstance: The current Dagster instance."""
         return self._step_execution_context.instance
 
-    @public  # type: ignore
+    @public
     @property
     def pdb(self) -> ForkedPdb:
         """dagster.utils.forked_pdb.ForkedPdb: Gives access to pdb debugging from within the op.
@@ -165,7 +165,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
             " 0.10.0. Please access it via `context.resources.file_manager` instead."
         )
 
-    @public  # type: ignore
+    @public
     @property
     def resources(self) -> Any:
         """Resources: The currently available resources."""
@@ -176,13 +176,13 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """Optional[StepLauncher]: The current step launcher, if any."""
         return self._step_execution_context.step_launcher
 
-    @public  # type: ignore
+    @public
     @property
     def run_id(self) -> str:
         """str: The id of the current execution's run."""
         return self._step_execution_context.run_id
 
-    @public  # type: ignore
+    @public
     @property
     def run_config(self) -> Mapping[str, object]:
         """dict: The run config for the current execution."""
@@ -193,7 +193,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """PipelineDefinition: The currently executing pipeline."""
         return self._step_execution_context.pipeline_def
 
-    @public  # type: ignore
+    @public
     @property
     def job_def(self) -> JobDefinition:
         """JobDefinition: The currently executing job."""
@@ -211,7 +211,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """str: The name of the currently executing pipeline."""
         return self._step_execution_context.pipeline_name
 
-    @public  # type: ignore
+    @public
     @property
     def job_name(self) -> str:
         """str: The name of the currently executing job."""
@@ -222,7 +222,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """ModeDefinition: The mode of the current execution."""
         return self._step_execution_context.mode_def
 
-    @public  # type: ignore
+    @public
     @property
     def log(self) -> DagsterLogManager:
         """DagsterLogManager: The log manager available in the execution context."""
@@ -234,7 +234,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
 
         :meta private:
         """
-        return self._step_execution_context.solid_handle
+        return self._step_execution_context.node_handle
 
     @property
     def op_handle(self) -> NodeHandle:
@@ -262,19 +262,19 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         return self.solid
 
-    @public  # type: ignore
+    @public
     @property
     def op_def(self) -> OpDefinition:
         """OpDefinition: The current op definition."""
         return cast(OpDefinition, self.op.definition)
 
-    @public  # type: ignore
+    @public
     @property
     def has_partition_key(self) -> bool:
         """Whether the current run is a partitioned run."""
         return self._step_execution_context.has_partition_key
 
-    @public  # type: ignore
+    @public
     @property
     def partition_key(self) -> str:
         """The partition key for the current run.
@@ -283,7 +283,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         return self._step_execution_context.partition_key
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partition_key_range(self) -> PartitionKeyRange:
         """The asset partition key for the current run.
@@ -292,7 +292,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         return self._step_execution_context.asset_partition_key_range
 
-    @public  # type: ignore
+    @public
     @property
     def partition_time_window(self) -> str:
         """The partition time window for the current run.
@@ -302,7 +302,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         return self._step_execution_context.partition_time_window
 
-    @public  # type: ignore
+    @public
     @property
     def selected_asset_keys(self) -> AbstractSet[AssetKey]:
         assets_def = self.job_def.asset_layer.assets_def_for_node(self.solid_handle)
@@ -310,12 +310,12 @@ class OpExecutionContext(AbstractComputeExecutionContext):
             return set()
         return assets_def.keys
 
-    @public  # type: ignore
+    @public
     @property
     def selected_output_names(self) -> AbstractSet[str]:
         # map selected asset keys to the output names they correspond to
         selected_asset_keys = self.selected_asset_keys
-        selected_outputs = set()
+        selected_outputs: Set[str] = set()
         for output_name in self.op.output_dict.keys():
             asset_info = self.job_def.asset_layer.asset_info_for_output(
                 self.solid_handle, output_name
@@ -435,10 +435,11 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         return result
 
     @public
-    def asset_partition_keys_for_output(self, output_name: str) -> Sequence[str]:
+    def asset_partition_keys_for_output(self, output_name: str = "result") -> Sequence[str]:
         """Returns a list of the partition keys for the given output."""
         return self.asset_partitions_def_for_output(output_name).get_partition_keys_in_range(
-            self._step_execution_context.asset_partition_key_range_for_output(output_name)
+            self._step_execution_context.asset_partition_key_range_for_output(output_name),
+            dynamic_partitions_store=self.instance,
         )
 
     @public
@@ -446,8 +447,10 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """Returns a list of the partition keys of the upstream asset corresponding to the
         given input.
         """
-        return self.asset_partitions_def_for_input(input_name).get_partition_keys_in_range(
-            self._step_execution_context.asset_partition_key_range_for_input(input_name)
+        return list(
+            self._step_execution_context.asset_partitions_subset_for_input(
+                input_name
+            ).get_partition_keys()
         )
 
     @public
@@ -507,11 +510,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         if isinstance(event, (AssetMaterialization, Materialization)):
             self._events.append(
-                DagsterEvent.asset_materialization(
-                    self._step_execution_context,
-                    event,
-                    self._step_execution_context.get_input_lineage(),
-                )
+                DagsterEvent.asset_materialization(self._step_execution_context, event)
             )
         elif isinstance(event, AssetObservation):
             self._events.append(DagsterEvent.asset_observation(self._step_execution_context, event))
@@ -582,7 +581,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         return self._step_execution_context
 
-    @public  # type: ignore
+    @public
     @property
     def retry_number(self) -> int:
         """
@@ -600,5 +599,25 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         return self._step_execution_context.step.get_mapping_key()
 
+    @public
+    @experimental
+    def get_asset_provenance(self, asset_key: AssetKey) -> Optional[DataProvenance]:
+        """
+        Return the provenance information for the most recent materialization of an asset.
+
+        Args:
+            asset_key (AssetKey): Key of the asset for which to retrieve provenance.
+
+        Returns:
+            Optional[DataProvenance]: Provenance information for the most recent
+                materialization of the asset. Returns `None` if the asset was never materialized or
+                the materialization record is too old to contain provenance information.
+        """
+        record = self.instance.get_latest_data_version_record(asset_key)
+
+        return (
+            None if record is None else extract_data_provenance_from_entry(record.event_log_entry)
+        )
+
 
 SourceAssetObserveContext: TypeAlias = OpExecutionContext
