@@ -27,12 +27,10 @@ class InitResourceContext:
         log_manager (DagsterLogManager): The log manager for this run of the job or pipeline
         resources (ScopedResources): The resources that are available to the resource that we are
             initalizing.
-        dagster_run (Optional[PipelineRun]): The dagster run to use. When initializing resources
+        dagster_run (Optional[DagsterRun]): The dagster run to use. When initializing resources
             outside of execution context, this will be None.
         run_id (Optional[str]): The id for this run of the job or pipeline. When initializing resources
             outside of execution context, this will be None.
-        pipeline_run (Optional[PipelineRun]): (legacy) The dagster run to use. When initializing resources
-            outside of execution context, this will be None.
 
     Example:
 
@@ -62,22 +60,22 @@ class InitResourceContext:
         self._resources = resources
         self._dagster_run = dagster_run
 
-    @public  # type: ignore
+    @public
     @property
     def resource_config(self) -> Any:
         return self._resource_config
 
-    @public  # type: ignore
+    @public
     @property
     def resource_def(self) -> Optional[ResourceDefinition]:
         return self._resource_def
 
-    @public  # type: ignore
+    @public
     @property
     def resources(self) -> Resources:
         return self._resources
 
-    @public  # type: ignore
+    @public
     @property
     def instance(self) -> Optional[DagsterInstance]:
         return self._instance
@@ -86,18 +84,18 @@ class InitResourceContext:
     def dagster_run(self) -> Optional[DagsterRun]:
         return self._dagster_run
 
-    @public  # type: ignore
+    @public
     @property
     def log(self) -> Optional[DagsterLogManager]:
         return self._log_manager
 
     # backcompat: keep around this property from when InitResourceContext used to be a NamedTuple
-    @public  # type: ignore
+    @public
     @property
     def log_manager(self) -> Optional[DagsterLogManager]:
         return self._log_manager
 
-    @public  # type: ignore
+    @public
     @property
     def run_id(self) -> Optional[str]:
         return self.dagster_run.run_id if self.dagster_run else None
@@ -205,10 +203,6 @@ class UnboundInitResourceContext(InitResourceContext):
     def instance(self) -> Optional[DagsterInstance]:
         return self._instance
 
-    @property
-    def pipeline_run(self) -> Optional[DagsterRun]:
-        return None
-
     @property
     def log(self) -> Optional[DagsterLogManager]:
         return self._log_manager
