@@ -9,21 +9,22 @@ from typing import (
     Optional,
     Sequence,
     Union,
-    cast,
 )
 
 import dagster._check as check
 from dagster._annotations import public
 from dagster._core.definitions.events import AssetKey, AssetObservation
-from dagster._core.definitions.metadata import MetadataEntry, PartitionMetadataEntry
+from dagster._core.definitions.metadata import (
+    MetadataEntry,
+)
 from dagster._core.definitions.partition import PartitionsSubset
 from dagster._core.definitions.partition_key_range import PartitionKeyRange
 from dagster._core.definitions.time_window_partitions import TimeWindow, TimeWindowPartitionsSubset
 from dagster._core.errors import DagsterInvariantViolationError
-from dagster._core.instance import DagsterInstance
+from dagster._core.instance import DagsterInstance, DynamicPartitionsStore
 
 if TYPE_CHECKING:
-    from dagster._core.definitions import OpDefinition, PartitionsDefinition
+    from dagster._core.definitions import PartitionsDefinition
     from dagster._core.definitions.op_definition import OpDefinition
     from dagster._core.definitions.resource_definition import Resources
     from dagster._core.events import DagsterEvent
@@ -83,7 +84,7 @@ class InputContext:
         *,
         name: Optional[str] = None,
         job_name: Optional[str] = None,
-        solid_def: Optional["OpDefinition"] = None,
+        op_def: Optional["OpDefinition"] = None,
         config: Optional[Any] = None,
         metadata: Optional[Mapping[str, Any]] = None,
         upstream_output: Optional["OutputContext"] = None,
@@ -92,7 +93,6 @@ class InputContext:
         resource_config: Optional[Mapping[str, Any]] = None,
         resources: Optional[Union["Resources", Mapping[str, Any]]] = None,
         step_context: Optional["StepExecutionContext"] = None,
-        op_def: Optional["OpDefinition"] = None,
         asset_key: Optional[AssetKey] = None,
         partition_key: Optional[str] = None,
         asset_partitions_subset: Optional[PartitionsSubset] = None,
@@ -104,10 +104,7 @@ class InputContext:
 
         self._name = name
         self._job_name = job_name
-        check.invariant(
-            solid_def is None or op_def is None, "Can't provide both a solid_def and an op_def arg"
-        )
-        self._solid_def = solid_def or op_def
+        self._op_def = op_def
         self._config = config
         self._metadata = metadata
         self._upstream_output = upstream_output
@@ -137,7 +134,7 @@ class InputContext:
 
         self._events: List["DagsterEvent"] = []
         self._observations: List[AssetObservation] = []
-        self._metadata_entries: List[Union[MetadataEntry, PartitionMetadataEntry]] = []
+        self._metadata_entries: List[MetadataEntry] = []
         self._instance = instance
 
     def __enter__(self):
@@ -162,14 +159,15 @@ class InputContext:
             )
         return self._instance
 
-    @public  # type: ignore
+    @public
     @property
     def has_input_name(self) -> bool:
         """If we're the InputContext is being used to load the result of a run from outside the run,
-        then it won't have an input name."""
+        then it won't have an input name.
+        """
         return self._name is not None
 
-    @public  # type: ignore
+    @public
     @property
     def name(self) -> str:
         if self._name is None:
@@ -193,45 +191,33 @@ class InputContext:
     def pipeline_name(self) -> str:
         return self.job_name
 
-    @property
-    def solid_def(self) -> "OpDefinition":
-        if self._solid_def is None:
-            raise DagsterInvariantViolationError(
-                "Attempting to access solid_def, "
-                "but it was not provided when constructing the InputContext"
-            )
-
-        return self._solid_def
-
-    @public  # type: ignore
+    @public
     @property
     def op_def(self) -> "OpDefinition":
-        from dagster._core.definitions import OpDefinition
-
-        if self._solid_def is None:
+        if self._op_def is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access op_def, "
                 "but it was not provided when constructing the InputContext"
             )
 
-        return cast(OpDefinition, self._solid_def)
+        return self._op_def
 
-    @public  # type: ignore
+    @public
     @property
     def config(self) -> Any:
         return self._config
 
-    @public  # type: ignore
+    @public
     @property
     def metadata(self) -> Optional[Mapping[str, Any]]:
         return self._metadata
 
-    @public  # type: ignore
+    @public
     @property
     def upstream_output(self) -> Optional["OutputContext"]:
         return self._upstream_output
 
-    @public  # type: ignore
+    @public
     @property
     def dagster_type(self) -> "DagsterType":
         if self._dagster_type is None:
@@ -242,7 +228,7 @@ class InputContext:
 
         return self._dagster_type
 
-    @public  # type: ignore
+    @public
     @property
     def log(self) -> "DagsterLogManager":
         if self._log is None:
@@ -253,12 +239,12 @@ class InputContext:
 
         return self._log
 
-    @public  # type: ignore
+    @public
     @property
     def resource_config(self) -> Optional[Mapping[str, Any]]:
         return self._resource_config
 
-    @public  # type: ignore
+    @public
     @property
     def resources(self) -> Any:
         if self._resources is None:
@@ -275,12 +261,12 @@ class InputContext:
             )
         return self._resources
 
-    @public  # type: ignore
+    @public
     @property
     def has_asset_key(self) -> bool:
         return self._asset_key is not None
 
-    @public  # type: ignore
+    @public
     @property
     def asset_key(self) -> AssetKey:
         if self._asset_key is None:
@@ -290,18 +276,20 @@ class InputContext:
 
         return self._asset_key
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partitions_def(self) -> "PartitionsDefinition":
         """The PartitionsDefinition on the upstream asset corresponding to this input."""
         if self._asset_partitions_def is None:
             if self.asset_key:
                 raise DagsterInvariantViolationError(
-                    f"Attempting to access partitions def for asset {self.asset_key}, but it is not partitioned"
+                    f"Attempting to access partitions def for asset {self.asset_key}, but it is not"
+                    " partitioned"
                 )
             else:
                 raise DagsterInvariantViolationError(
-                    "Attempting to access partitions def for asset, but input does not correspond to an asset"
+                    "Attempting to access partitions def for asset, but input does not correspond"
+                    " to an asset"
                 )
 
         return self._asset_partitions_def
@@ -316,13 +304,13 @@ class InputContext:
 
         return self._step_context
 
-    @public  # type: ignore
+    @public
     @property
     def has_partition_key(self) -> bool:
-        """Whether the current run is a partitioned run"""
+        """Whether the current run is a partitioned run."""
         return self._partition_key is not None
 
-    @public  # type: ignore
+    @public
     @property
     def partition_key(self) -> str:
         """The partition key for the current run.
@@ -336,12 +324,12 @@ class InputContext:
 
         return self._partition_key
 
-    @public  # type: ignore
+    @public
     @property
     def has_asset_partitions(self) -> bool:
         return self._asset_partitions_subset is not None
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partition_key(self) -> str:
         """The partition key for input asset.
@@ -363,7 +351,7 @@ class InputContext:
                 f"but the number of input partitions != 1: '{subset}'."
             )
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partition_key_range(self) -> PartitionKeyRange:
         """The partition key range for input asset.
@@ -377,16 +365,20 @@ class InputContext:
                 "Tried to access asset_partition_key_range, but the asset is not partitioned.",
             )
 
-        partition_key_ranges = subset.get_partition_key_ranges()
+        partition_key_ranges = subset.get_partition_key_ranges(
+            dynamic_partitions_store=self.instance
+        )
         if len(partition_key_ranges) != 1:
             check.failed(
-                "Tried to access asset_partition_key_range, but there are "
-                f"({len(partition_key_ranges)}) key ranges associated with this input.",
+                (
+                    "Tried to access asset_partition_key_range, but there are "
+                    f"({len(partition_key_ranges)}) key ranges associated with this input."
+                ),
             )
 
         return partition_key_ranges[0]
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partition_keys(self) -> Sequence[str]:
         """The partition keys for input asset.
@@ -400,7 +392,7 @@ class InputContext:
 
         return list(self._asset_partitions_subset.get_partition_keys())
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partitions_time_window(self) -> TimeWindow:
         """The time window for the partitions of the input asset.
@@ -418,14 +410,19 @@ class InputContext:
 
         if not isinstance(subset, TimeWindowPartitionsSubset):
             check.failed(
-                "Tried to access asset_partitions_time_window, but the asset is not partitioned with time windows.",
+                (
+                    "Tried to access asset_partitions_time_window, but the asset is not partitioned"
+                    " with time windows."
+                ),
             )
 
         time_windows = subset.included_time_windows
         if len(time_windows) != 1:
             check.failed(
-                "Tried to access asset_partition_key_range, but there are "
-                f"({len(time_windows)}) partitions associated with this input.",
+                (
+                    "Tried to access asset_partition_key_range, but there are "
+                    f"({len(time_windows)}) partitions associated with this input."
+                ),
             )
 
         return time_windows[0]
@@ -452,7 +449,7 @@ class InputContext:
         """
         if self.upstream_output is None:
             raise DagsterInvariantViolationError(
-                "InputContext.upstream_output not defined. " "Cannot compute an identifier"
+                "InputContext.upstream_output not defined. Cannot compute an identifier"
             )
 
         return self.upstream_output.get_identifier()
@@ -472,7 +469,6 @@ class InputContext:
 
         If consume_events has not yet been called, this will yield all logged events since the call to `handle_input`. If consume_events has been called, it will yield all events since the last time consume_events was called. Designed for internal use. Users should never need to invoke this method.
         """
-
         events = self._events
         self._events = []
         yield from events
@@ -532,7 +528,7 @@ class InputContext:
         """
         return self._observations
 
-    def consume_metadata_entries(self) -> Sequence[Union[MetadataEntry, PartitionMetadataEntry]]:
+    def consume_metadata_entries(self) -> Sequence[MetadataEntry]:
         result = self._metadata_entries
         self._metadata_entries = []
         return result
@@ -583,7 +579,6 @@ def build_input_context(
             being loaded.
 
     Examples:
-
         .. code-block:: python
 
             build_input_context()
@@ -615,7 +610,7 @@ def build_input_context(
     )
     if asset_partitions_def and asset_partition_key_range:
         asset_partitions_subset = asset_partitions_def.empty_subset().with_partition_key_range(
-            asset_partition_key_range
+            asset_partition_key_range, dynamic_partitions_store=instance
         )
     elif asset_partition_key_range:
         asset_partitions_subset = KeyRangeNoPartitionsDefPartitionsSubset(asset_partition_key_range)
@@ -649,7 +644,9 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
         self._key_range = key_range
 
     def get_partition_keys_not_in_subset(
-        self, current_time: Optional[datetime] = None
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Iterable[str]:
         raise NotImplementedError()
 
@@ -660,7 +657,9 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
             raise NotImplementedError()
 
     def get_partition_key_ranges(
-        self, current_time: Optional[datetime] = None
+        self,
+        current_time: Optional[datetime] = None,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> Sequence[PartitionKeyRange]:
         return [self._key_range]
 
@@ -668,7 +667,9 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
         raise NotImplementedError()
 
     def with_partition_key_range(
-        self, partition_key_range: PartitionKeyRange
+        self,
+        partition_key_range: PartitionKeyRange,
+        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
     ) -> "PartitionsSubset":
         raise NotImplementedError()
 
@@ -684,3 +685,23 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
 
     def __contains__(self, value) -> bool:
         raise NotImplementedError()
+
+    @classmethod
+    def from_serialized(
+        cls, partitions_def: "PartitionsDefinition", serialized: str
+    ) -> "PartitionsSubset":
+        raise NotImplementedError()
+
+    @classmethod
+    def can_deserialize(
+        cls,
+        partitions_def: "PartitionsDefinition",
+        serialized: str,
+        serialized_partitions_def_unique_id: Optional[str],
+        serialized_partitions_def_class_name: Optional[str],
+    ) -> bool:
+        raise NotImplementedError()
+
+    @classmethod
+    def empty_subset(cls, partitions_def: "PartitionsDefinition") -> "PartitionsSubset":
+        raise NotImplementedError()
