@@ -15,7 +15,7 @@ from typing import (
 
 import dagster._check as check
 from dagster._core.definitions.composition import PendingNodeInvocation
-from dagster._core.definitions.decorators.solid_decorator import DecoratedOpFunction
+from dagster._core.definitions.decorators.op_decorator import DecoratedOpFunction
 from dagster._core.definitions.dependency import Node, NodeHandle
 from dagster._core.definitions.events import (
     AssetMaterialization,
@@ -46,8 +46,8 @@ from dagster._core.instance import DagsterInstance
 from dagster._core.log_manager import DagsterLogManager
 from dagster._core.storage.pipeline_run import DagsterRun
 from dagster._core.types.dagster_type import DagsterType
-from dagster._utils import merge_dicts
 from dagster._utils.forked_pdb import ForkedPdb
+from dagster._utils.merger import merge_dicts
 
 from .compute import OpExecutionContext
 from .system import StepExecutionContext, TypeCheckContext
@@ -66,7 +66,7 @@ class UnboundOpExecutionContext(OpExecutionContext):
 
     def __init__(
         self,
-        solid_config: Any,
+        op_config: Any,
         resources_dict: Mapping[str, Any],
         resources_config: Mapping[str, Any],
         instance: Optional[DagsterInstance],
@@ -76,7 +76,7 @@ class UnboundOpExecutionContext(OpExecutionContext):
         from dagster._core.execution.api import ephemeral_instance_if_missing
         from dagster._core.execution.context_creation_pipeline import initialize_console_manager
 
-        self._solid_config = solid_config
+        self._op_config = op_config
         self._mapping_key = mapping_key
 
         self._instance_provided = (
@@ -123,8 +123,8 @@ class UnboundOpExecutionContext(OpExecutionContext):
             self._instance_cm.__exit__(None, None, None)  # pylint: disable=no-member
 
     @property
-    def solid_config(self) -> Any:
-        return self._solid_config
+    def op_config(self) -> Any:
+        return self._op_config
 
     @property
     def resources(self) -> Resources:
@@ -149,7 +149,6 @@ class UnboundOpExecutionContext(OpExecutionContext):
         """dagster.utils.forked_pdb.ForkedPdb: Gives access to pdb debugging from within the solid.
 
         Example:
-
         .. code-block:: python
 
             @solid
@@ -230,7 +229,6 @@ class UnboundOpExecutionContext(OpExecutionContext):
         self,
         op_def_or_invocation: Union[OpDefinition, PendingNodeInvocation],
     ) -> "BoundOpExecutionContext":
-
         op_def = (
             op_def_or_invocation
             if isinstance(op_def_or_invocation, OpDefinition)
@@ -241,11 +239,11 @@ class UnboundOpExecutionContext(OpExecutionContext):
 
         from dagster._core.definitions.resource_invocation import resolve_bound_config
 
-        solid_config = resolve_bound_config(self.solid_config, op_def)
+        op_config = resolve_bound_config(self.op_config, op_def)
 
         return BoundOpExecutionContext(
             op_def=op_def,
-            op_config=solid_config,
+            op_config=op_config,
             resources=self.resources,
             resources_config=self._resources_config,
             instance=self.instance,
@@ -287,7 +285,6 @@ class UnboundOpExecutionContext(OpExecutionContext):
                 expectation_results = [event for event in all_user_events if isinstance(event, ExpectationResult)]
                 ...
         """
-
         return self._user_events
 
     def get_output_metadata(
@@ -316,7 +313,7 @@ class UnboundOpExecutionContext(OpExecutionContext):
 def _validate_resource_requirements(
     resource_defs: Mapping[str, ResourceDefinition], op_def: OpDefinition
 ) -> None:
-    """Validate correctness of resources against required resource keys"""
+    """Validate correctness of resources against required resource keys."""
     if cast(DecoratedOpFunction, op_def.compute_fn).has_context_arg():
         for requirement in op_def.get_resource_requirements():
             if not requirement.is_io_manager_requirement:
@@ -324,9 +321,9 @@ def _validate_resource_requirements(
 
 
 class BoundOpExecutionContext(OpExecutionContext):
-    """The solid execution context that is passed to the compute function during invocation.
+    """The op execution context that is passed to the compute function during invocation.
 
-    This context is bound to a specific solid definition, for which the resources and config have
+    This context is bound to a specific op definition, for which the resources and config have
     been validated.
     """
 
@@ -380,7 +377,7 @@ class BoundOpExecutionContext(OpExecutionContext):
         self._partition_key = partition_key
 
     @property
-    def solid_config(self) -> Any:
+    def op_config(self) -> Any:
         return self._op_config
 
     @property
@@ -400,7 +397,6 @@ class BoundOpExecutionContext(OpExecutionContext):
         """dagster.utils.forked_pdb.ForkedPdb: Gives access to pdb debugging from within the solid.
 
         Example:
-
         .. code-block:: python
 
             @solid
@@ -426,7 +422,7 @@ class BoundOpExecutionContext(OpExecutionContext):
     def run_config(self) -> Mapping[str, object]:
         run_config: Dict[str, object] = {}
         if self._op_config:
-            run_config["solids"] = {self._op_def.name: {"config": self._op_config}}
+            run_config["ops"] = {self._op_def.name: {"config": self._op_config}}
         run_config["resources"] = self._resources_config
         return run_config
 
@@ -488,7 +484,6 @@ class BoundOpExecutionContext(OpExecutionContext):
         return f'solid "{self.op_def.name}"'
 
     def log_event(self, event: UserEvent) -> None:
-
         check.inst_param(
             event,
             "event",
@@ -563,7 +558,9 @@ class BoundOpExecutionContext(OpExecutionContext):
             output_name = output_def.name
         elif output_name is None:
             raise DagsterInvariantViolationError(
-                "Attempted to log metadata without providing output_name, but multiple outputs exist. Please provide an output_name to the invocation of `context.add_output_metadata`."
+                "Attempted to log metadata without providing output_name, but multiple outputs"
+                " exist. Please provide an output_name to the invocation of"
+                " `context.add_output_metadata`."
             )
         else:
             output_def = self.op_def.output_def_named(output_name)
@@ -575,21 +572,26 @@ class BoundOpExecutionContext(OpExecutionContext):
                 else f"output '{output_def.name}' with mapping_key '{mapping_key}'"
             )
             raise DagsterInvariantViolationError(
-                f"In {self.op_def.node_type_str} '{self.op_def.name}', attempted to log output metadata for {output_desc} which has already been yielded. Metadata must be logged before the output is yielded."
+                f"In {self.op_def.node_type_str} '{self.op_def.name}', attempted to log output"
+                f" metadata for {output_desc} which has already been yielded. Metadata must be"
+                " logged before the output is yielded."
             )
         if output_def.is_dynamic and not mapping_key:
             raise DagsterInvariantViolationError(
-                f"In {self.op_def.node_type_str} '{self.op_def.name}', attempted to log metadata for dynamic output '{output_def.name}' without providing a mapping key. When logging metadata for a dynamic output, it is necessary to provide a mapping key."
+                f"In {self.op_def.node_type_str} '{self.op_def.name}', attempted to log metadata"
+                f" for dynamic output '{output_def.name}' without providing a mapping key. When"
+                " logging metadata for a dynamic output, it is necessary to provide a mapping key."
             )
 
         output_name = output_def.name
         if output_name in self._output_metadata:
             if not mapping_key or mapping_key in self._output_metadata[output_name]:
                 raise DagsterInvariantViolationError(
-                    f"In {self.op_def.node_type_str} '{self.op_def.name}', attempted to log metadata for output '{output_name}' more than once."
+                    f"In {self.op_def.node_type_str} '{self.op_def.name}', attempted to log"
+                    f" metadata for output '{output_name}' more than once."
                 )
         if mapping_key:
-            if not output_name in self._output_metadata:
+            if output_name not in self._output_metadata:
                 self._output_metadata[output_name] = {}
             self._output_metadata[output_name][mapping_key] = metadata
 
@@ -605,7 +607,7 @@ def build_op_context(
     config: Any = None,
     partition_key: Optional[str] = None,
     mapping_key: Optional[str] = None,
-) -> OpExecutionContext:
+) -> UnboundOpExecutionContext:
     """Builds op execution context from provided parameters.
 
     ``build_op_context`` can be used as either a function or context manager. If there is a
@@ -632,7 +634,6 @@ def build_op_context(
             with build_op_context(resources={"foo": context_manager_resource}) as context:
                 op_to_invoke(context)
     """
-
     if op_config and config:
         raise DagsterInvalidInvocationError(
             "Attempted to invoke ``build_op_context`` with both ``op_config``, and its "
@@ -640,67 +641,12 @@ def build_op_context(
         )
 
     op_config = op_config if op_config else config
-    return build_solid_context(
-        resources=resources,
-        resources_config=resources_config,
-        solid_config=op_config,
-        instance=instance,
-        partition_key=partition_key,
-        mapping_key=mapping_key,
-    )
-
-
-def build_solid_context(
-    resources: Optional[Mapping[str, Any]] = None,
-    solid_config: Any = None,
-    resources_config: Optional[Mapping[str, Any]] = None,
-    instance: Optional[DagsterInstance] = None,
-    config: Any = None,
-    partition_key: Optional[str] = None,
-    mapping_key: Optional[str] = None,
-) -> UnboundOpExecutionContext:
-    """Builds solid execution context from provided parameters.
-
-    ``build_solid_context`` can be used as either a function or context manager. If there is a
-    provided resource that is a context manager, then ``build_solid_context`` must be used as a
-    context manager. This function can be used to provide the context argument when directly
-    invoking a solid.
-
-    Args:
-        resources (Optional[Dict[str, Any]]): The resources to provide to the context. These can be
-            either values or resource definitions.
-        solid_config (Optional[Any]): The solid config to provide to the context. The value provided
-            here will be available as ``context.solid_config``.
-        resources_config (Optional[Dict[str, Any]]): Configuration for any resource definitions
-            provided to the resources arg. The configuration under a specific key should match the
-            resource under a specific key in the resources dictionary.
-        instance (Optional[DagsterInstance]): The dagster instance configured for the context.
-            Defaults to DagsterInstance.ephemeral().
-
-    Examples:
-        .. code-block:: python
-
-            context = build_solid_context()
-            solid_to_invoke(context)
-
-            with build_solid_context(resources={"foo": context_manager_resource}) as context:
-                solid_to_invoke(context)
-    """
-
-    if solid_config and config:
-        raise DagsterInvalidInvocationError(
-            "Attempted to invoke ``build_solid_context`` with both ``solid_config``, and its "
-            "legacy version, ``config``. Please provide one or the other."
-        )
-
-    solid_config = solid_config if solid_config else config
-
     return UnboundOpExecutionContext(
         resources_dict=check.opt_mapping_param(resources, "resources", key_type=str),
         resources_config=check.opt_mapping_param(
             resources_config, "resources_config", key_type=str
         ),
-        solid_config=solid_config,
+        op_config=op_config,
         instance=check.opt_inst_param(instance, "instance", DagsterInstance),
         partition_key=check.opt_str_param(partition_key, "partition_key"),
         mapping_key=check.opt_str_param(mapping_key, "mapping_key"),
