@@ -20,10 +20,8 @@ from dagster._core.definitions.events import (
     AssetMaterialization,
     AssetObservation,
     Materialization,
-    MetadataEntry,
-    PartitionMetadataEntry,
 )
-from dagster._core.definitions.metadata import RawMetadataValue
+from dagster._core.definitions.metadata import MetadataEntry, RawMetadataValue
 from dagster._core.definitions.partition_key_range import PartitionKeyRange
 from dagster._core.definitions.time_window_partitions import TimeWindow
 from dagster._core.errors import DagsterInvalidMetadata, DagsterInvariantViolationError
@@ -182,7 +180,7 @@ class OutputContext:
         ):
             self._resources_cm.__exit__(None, None, None)  # pylint: disable=no-member
 
-    @public  # type: ignore
+    @public
     @property
     def step_key(self) -> str:
         if self._step_key is None:
@@ -193,7 +191,7 @@ class OutputContext:
 
         return self._step_key
 
-    @public  # type: ignore
+    @public
     @property
     def name(self) -> str:
         if self._name is None:
@@ -214,7 +212,7 @@ class OutputContext:
 
         return self._pipeline_name
 
-    @public  # type: ignore
+    @public
     @property
     def run_id(self) -> str:
         if self._run_id is None:
@@ -225,22 +223,22 @@ class OutputContext:
 
         return self._run_id
 
-    @public  # type: ignore
+    @public
     @property
     def metadata(self) -> Optional[Mapping[str, object]]:
         return self._metadata
 
-    @public  # type: ignore
+    @public
     @property
     def mapping_key(self) -> Optional[str]:
         return self._mapping_key
 
-    @public  # type: ignore
+    @public
     @property
     def config(self) -> Any:
         return self._config
 
-    @public  # type: ignore
+    @public
     @property
     def op_def(self) -> "OpDefinition":
         from dagster._core.definitions import OpDefinition
@@ -253,7 +251,7 @@ class OutputContext:
 
         return cast(OpDefinition, self._op_def)
 
-    @public  # type: ignore
+    @public
     @property
     def dagster_type(self) -> "DagsterType":
         if self._dagster_type is None:
@@ -264,7 +262,7 @@ class OutputContext:
 
         return self._dagster_type
 
-    @public  # type: ignore
+    @public
     @property
     def log(self) -> "DagsterLogManager":
         if self._log is None:
@@ -275,17 +273,17 @@ class OutputContext:
 
         return self._log
 
-    @public  # type: ignore
+    @public
     @property
     def version(self) -> Optional[str]:
         return self._version
 
-    @public  # type: ignore
+    @public
     @property
     def resource_config(self) -> Optional[Mapping[str, object]]:
         return self._resource_config
 
-    @public  # type: ignore
+    @public
     @property
     def resources(self) -> Any:
         if self._resources is None:
@@ -306,12 +304,12 @@ class OutputContext:
     def asset_info(self) -> Optional[AssetOutputInfo]:
         return self._asset_info
 
-    @public  # type: ignore
+    @public
     @property
     def has_asset_key(self) -> bool:
         return self._asset_info is not None
 
-    @public  # type: ignore
+    @public
     @property
     def asset_key(self) -> AssetKey:
         if self._asset_info is None:
@@ -322,7 +320,7 @@ class OutputContext:
 
         return self._asset_info.key
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partitions_def(self) -> "PartitionsDefinition":
         """The PartitionsDefinition on the asset corresponding to this output."""
@@ -354,7 +352,7 @@ class OutputContext:
 
         return self._step_context
 
-    @public  # type: ignore
+    @public
     @property
     def has_partition_key(self) -> bool:
         """Whether the current run is a partitioned run."""
@@ -368,7 +366,7 @@ class OutputContext:
 
         return self._partition_key is not None
 
-    @public  # type: ignore
+    @public
     @property
     def partition_key(self) -> str:
         """The partition key for the current run.
@@ -390,7 +388,7 @@ class OutputContext:
 
         return self._partition_key
 
-    @public  # type: ignore
+    @public
     @property
     def has_asset_partitions(self) -> bool:
         if self._warn_on_step_context_use:
@@ -406,7 +404,7 @@ class OutputContext:
         else:
             return False
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partition_key(self) -> str:
         """The partition key for output asset.
@@ -424,7 +422,7 @@ class OutputContext:
 
         return self.step_context.asset_partition_key_for_output(self.name)
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partition_key_range(self) -> PartitionKeyRange:
         """The partition key range for output asset.
@@ -441,7 +439,7 @@ class OutputContext:
 
         return self.step_context.asset_partition_key_range_for_output(self.name)
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partition_keys(self) -> Sequence[str]:
         """The partition keys for the output asset.
@@ -457,10 +455,11 @@ class OutputContext:
             )
 
         return self.asset_partitions_def.get_partition_keys_in_range(
-            self.step_context.asset_partition_key_range_for_output(self.name)
+            self.step_context.asset_partition_key_range_for_output(self.name),
+            dynamic_partitions_store=self.step_context.instance,
         )
 
-    @public  # type: ignore
+    @public
     @property
     def asset_partitions_time_window(self) -> TimeWindow:
         """The time window for the partitions of the output asset.
@@ -611,13 +610,7 @@ class OutputContext:
 
         if isinstance(event, (AssetMaterialization, Materialization)):
             if self._step_context:
-                self._events.append(
-                    DagsterEvent.asset_materialization(
-                        self._step_context,
-                        event,
-                        self._step_context.get_input_lineage(),
-                    )
-                )
+                self._events.append(DagsterEvent.asset_materialization(self._step_context, event))
             self._user_events.append(event)
         elif isinstance(event, AssetObservation):
             if self._step_context:
@@ -695,13 +688,13 @@ class OutputContext:
 
     def get_logged_metadata_entries(
         self,
-    ) -> Sequence[Union[MetadataEntry, PartitionMetadataEntry]]:
+    ) -> Sequence[MetadataEntry]:
         """Get the list of metadata entries that have been logged for use with this output."""
         return self._metadata_entries or []
 
     def consume_logged_metadata_entries(
         self,
-    ) -> Sequence[Union[MetadataEntry, PartitionMetadataEntry]]:
+    ) -> Sequence[MetadataEntry]:
         """Pops and yields all user-generated metadata entries that have been recorded from this context.
 
         If consume_logged_metadata_entries has not yet been called, this will yield all logged events since the call to `handle_output`. If consume_logged_metadata_entries has been called, it will yield all events since the last time consume_logged_metadata_entries was called. Designed for internal use. Users should never need to invoke this method.
@@ -730,8 +723,8 @@ def get_output_context(
     """
     step = execution_plan.get_step_by_key(step_output_handle.step_key)
     # get config
-    solid_config = resolved_run_config.solids[step.solid_handle.to_string()]
-    outputs_config = solid_config.outputs
+    op_config = resolved_run_config.ops[step.node_handle.to_string()]
+    outputs_config = op_config.outputs
 
     if outputs_config:
         output_config = outputs_config.get_output_manager_config(step_output_handle.output_name)
@@ -744,7 +737,7 @@ def get_output_context(
     io_manager_key = output_def.io_manager_key
     resource_config = resolved_run_config.resources[io_manager_key].config
 
-    node_handle = execution_plan.get_step_by_key(step.key).solid_handle
+    node_handle = execution_plan.get_step_by_key(step.key).node_handle
     asset_info = pipeline_def.asset_layer.asset_info_for_output(
         node_handle=node_handle, output_name=step_output.name
     )
@@ -768,7 +761,7 @@ def get_output_context(
         metadata=output_def.metadata,
         mapping_key=step_output_handle.mapping_key,
         config=output_config,
-        op_def=pipeline_def.get_solid(step.solid_handle).definition,
+        op_def=pipeline_def.get_solid(step.node_handle).definition,  # type: ignore  # (should be OpDefinition not NodeDefinition)
         dagster_type=output_def.dagster_type,
         log_manager=log_manager,
         version=version,
