@@ -4,13 +4,13 @@ import time
 from typing import Iterable, Mapping, Optional, Sequence, Tuple, cast
 
 import dagster._check as check
+from dagster._core.definitions.selector import PipelineSelector
 from dagster._core.errors import DagsterBackfillFailedError
 from dagster._core.execution.plan.resume_retry import ReexecutionStrategy
 from dagster._core.execution.plan.state import KnownExecutionState
 from dagster._core.host_representation import (
     ExternalPartitionSet,
     ExternalPipeline,
-    PipelineSelector,
     RepositoryLocation,
 )
 from dagster._core.host_representation.external_data import (
@@ -190,7 +190,7 @@ def submit_backfill_runs(
     partition_set_name = origin.partition_set_name
     external_partition_set = external_repo.get_external_partition_set(partition_set_name)
     result = repo_location.get_external_partition_set_execution_param_data(
-        external_repo.handle, partition_set_name, partition_names
+        external_repo.handle, partition_set_name, partition_names, instance
     )
 
     assert isinstance(result, ExternalPartitionSetExecutionParamData)
@@ -210,7 +210,7 @@ def submit_backfill_runs(
             external_partition_set.pipeline_name
         )
     for partition_data in result.partition_data:
-        pipeline_run = create_backfill_run(
+        dagster_run = create_backfill_run(
             instance,
             repo_location,
             external_pipeline,
@@ -218,12 +218,12 @@ def submit_backfill_runs(
             backfill_job,
             partition_data,
         )
-        if pipeline_run:
+        if dagster_run:
             # we skip runs in certain cases, e.g. we are running a `from_failure` backfill job
             # and the partition has had a successful run since the time the backfill was
             # scheduled
-            instance.submit_run(pipeline_run.run_id, workspace)
-            yield pipeline_run.run_id
+            instance.submit_run(dagster_run.run_id, workspace)
+            yield dagster_run.run_id
         yield None
 
 
@@ -280,7 +280,7 @@ def create_backfill_run(
             use_parent_run_tags=False,  # don't inherit tags from the previous run
         )
 
-    elif backfill_job.reexecution_steps:
+    else:  # backfill_job.reexecution_steps
         last_run = _fetch_last_run(instance, external_partition_set, partition_data.name)
         parent_run_id = last_run.run_id if last_run else None
         root_run_id = (last_run.root_run_id or last_run.run_id) if last_run else None
