@@ -1,5 +1,21 @@
 import time
-from typing import Any, Callable, Dict, Iterator, List, Mapping, Optional, Sequence, Set, cast
+from types import TracebackType
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    Mapping,
+    Optional,
+    Sequence,
+    Set,
+    Type,
+    Union,
+    cast,
+)
+
+from typing_extensions import Self
 
 import dagster._check as check
 from dagster._core.errors import (
@@ -8,7 +24,11 @@ from dagster._core.errors import (
     DagsterUnknownStepStateError,
 )
 from dagster._core.events import DagsterEvent
-from dagster._core.execution.context.system import PlanOrchestrationContext
+from dagster._core.execution.context.system import (
+    IPlanContext,
+    PlanExecutionContext,
+    PlanOrchestrationContext,
+)
 from dagster._core.execution.plan.state import KnownExecutionState
 from dagster._core.execution.retries import RetryMode, RetryState
 from dagster._core.storage.tags import PRIORITY_TAG
@@ -25,7 +45,7 @@ def _default_sort_key(step: ExecutionStep) -> float:
 
 
 class ActiveExecution:
-    """State machine used to track progress through execution of an ExecutionPlan"""
+    """State machine used to track progress through execution of an ExecutionPlan."""
 
     def __init__(
         self,
@@ -64,13 +84,16 @@ class ActiveExecution:
 
         # track mapping keys from DynamicOutputs, step_key, output_name -> list of keys
         # to _gathering while in flight
-        self._gathering_dynamic_outputs: Dict[str, Mapping[str, List[str]]] = {}
-        # then on success move to _successful
-        self._successful_dynamic_outputs: Dict[str, Mapping[str, Sequence[str]]] = (
+        self._gathering_dynamic_outputs: Dict[str, Mapping[str, Optional[List[str]]]] = {}
+        # then on resolution move to _completed
+        self._completed_dynamic_outputs: Dict[str, Mapping[str, Optional[Sequence[str]]]] = (
             dict(self._plan.known_state.dynamic_mappings) if self._plan.known_state else {}
         )
         self._new_dynamic_mappings: bool = False
 
+        # track which upstream deps caused a step to skip
+        self._skipped_deps: Dict[str, Sequence[str]] = {}
+
         # steps move in to these buckets as a result of _update calls
         self._executable: List[str] = []
         self._pending_skip: List[str] = []
@@ -95,11 +118,13 @@ class ActiveExecution:
         # Start the show by loading _executable with the set of _pending steps that have no deps
         self._update()
 
-    def __enter__(self):
+    def __enter__(self) -> Self:
         self._context_guard = True
         return self
 
-    def __exit__(self, exc_type, exc_value, traceback):
+    def __exit__(
+        self, exc_type: Type[Exception], exc_value: Exception, traceback: TracebackType
+    ) -> None:
         self._context_guard = False
 
         # Exiting due to exception, return to allow exception to bubble
@@ -143,25 +168,24 @@ class ActiveExecution:
                 )
             else:
                 raise DagsterUnknownStepStateError(
-                    "Execution exited with steps {step_list} in an unknown state to this process.\n"
-                    "This was likely caused by losing communication with the process performing step execution.".format(
-                        step_list=self._unknown_state
-                    )
+                    "Execution exited with steps {step_list} in an unknown state to this"
+                    " process.\nThis was likely caused by losing communication with the process"
+                    " performing step execution.".format(step_list=self._unknown_state)
                 )
 
     def _update(self) -> None:
         """Moves steps from _pending to _executable / _pending_skip / _pending_retry
-        as a function of what has been _completed
+        as a function of what has been _completed.
         """
-        new_steps_to_execute = []
-        new_steps_to_skip = []
-        new_steps_to_abandon = []
+        new_steps_to_execute: List[str] = []
+        new_steps_to_skip: List[str] = []
+        new_steps_to_abandon: List[str] = []
 
         successful_or_skipped_steps = self._success | self._skipped
         failed_or_abandoned_steps = self._failed | self._abandoned
 
         if self._new_dynamic_mappings:
-            new_step_deps = self._plan.resolve(self._successful_dynamic_outputs)
+            new_step_deps = self._plan.resolve(self._completed_dynamic_outputs)
             for step_key, deps in new_step_deps.items():
                 self._pending[step_key] = deps
 
@@ -193,6 +217,9 @@ class ActiveExecution:
                             step_input.get_step_output_handle_dependencies()
                         ):
                             should_skip = True
+                            self._skipped_deps[step_key] = [
+                                f"{h.step_key}.{h.output_name}" for h in missing_source_handles
+                            ]
                             break
 
                 if should_skip:
@@ -241,7 +268,7 @@ class ActiveExecution:
             step = self.get_next_step()
 
         check.invariant(step is not None, "Unexpected ActiveExecution state")
-        return cast(ExecutionStep, step)
+        return step  # type: ignore  # (possible none)
 
     def get_step_by_key(self, step_key: str) -> ExecutionStep:
         step = self._plan.get_step_by_key(step_key)
@@ -250,7 +277,7 @@ class ActiveExecution:
     def get_steps_to_execute(
         self,
         limit: Optional[int] = None,
-    ) -> List[ExecutionStep]:
+    ) -> Sequence[ExecutionStep]:
         check.invariant(
             self._context_guard,
             "ActiveExecution must be used as a context manager",
@@ -309,7 +336,8 @@ class ActiveExecution:
             steps.append(step)
             self._in_flight.add(key)
             self._pending_skip.remove(key)
-            self._prep_for_dynamic_outputs(step)
+            self._gathering_dynamic_outputs
+            self._skip_for_dynamic_outputs(step)
 
         return sorted(steps, key=self._sort_key_fn)
 
@@ -325,21 +353,17 @@ class ActiveExecution:
 
         return sorted(steps, key=self._sort_key_fn)
 
-    def plan_events_iterator(self, pipeline_context) -> Iterator[DagsterEvent]:
-        """Process all steps that can be skipped and abandoned"""
-
+    def plan_events_iterator(
+        self, pipeline_context: Union[PlanExecutionContext, PlanOrchestrationContext]
+    ) -> Iterator[DagsterEvent]:
+        """Process all steps that can be skipped and abandoned."""
         steps_to_skip = self.get_steps_to_skip()
         while steps_to_skip:
             for step in steps_to_skip:
                 step_context = pipeline_context.for_step(step)
-                skipped_inputs: List[str] = []
-                for step_input in step.step_inputs:
-                    skipped_inputs.extend(self._skipped.intersection(step_input.dependency_keys))
-
                 step_context.log.info(
-                    "Skipping step {step} due to skipped dependencies: {skipped_inputs}.".format(
-                        step=step.key, skipped_inputs=skipped_inputs
-                    )
+                    f"Skipping step {step.key} due to skipped dependencies:"
+                    f" {self._skipped_deps[step.key]}."
                 )
                 yield DagsterEvent.step_skipped_event(step_context)
 
@@ -462,17 +486,19 @@ class ActiveExecution:
             event_specific_data = cast(StepOutputData, dagster_event.event_specific_data)
             self.mark_step_produced_output(event_specific_data.step_output_handle)
             if dagster_event.step_output_data.step_output_handle.mapping_key:
-                self._gathering_dynamic_outputs[step_key][
-                    dagster_event.step_output_data.step_output_handle.output_name
-                ].append(dagster_event.step_output_data.step_output_handle.mapping_key)
+                check.not_none(
+                    self._gathering_dynamic_outputs[step_key][
+                        dagster_event.step_output_data.step_output_handle.output_name
+                    ],
+                ).append(dagster_event.step_output_data.step_output_handle.mapping_key)
 
-    def verify_complete(self, pipeline_context: PlanOrchestrationContext, step_key: str) -> None:
-        """Ensure that a step has reached a terminal state, if it has not mark it as an unexpected failure"""
+    def verify_complete(self, pipeline_context: IPlanContext, step_key: str) -> None:
+        """Ensure that a step has reached a terminal state, if it has not mark it as an unexpected failure.
+        """
         if step_key in self._in_flight:
             pipeline_context.log.error(
-                "Step {key} finished without success or failure event. Downstream steps will not execute.".format(
-                    key=step_key
-                )
+                "Step {key} finished without success or failure event. Downstream steps will not"
+                " execute.".format(key=step_key)
             )
             self.mark_unknown_state(step_key)
 
@@ -506,7 +532,7 @@ class ActiveExecution:
     def get_known_state(self) -> KnownExecutionState:
         return KnownExecutionState(
             previous_retry_attempts=self._retry_state.snapshot_attempts(),
-            dynamic_mappings=dict(self._successful_dynamic_outputs),
+            dynamic_mappings=dict(self._completed_dynamic_outputs),
             ready_outputs=self._step_outputs,
             step_output_versions=self._plan.known_state.step_output_versions,
             parent_state=self._plan.known_state.parent_state,
@@ -514,13 +540,28 @@ class ActiveExecution:
 
     def _prep_for_dynamic_outputs(self, step: ExecutionStep):
         dyn_outputs = [step_out for step_out in step.step_outputs if step_out.is_dynamic]
-
         if dyn_outputs:
             self._gathering_dynamic_outputs[step.key] = {out.name: [] for out in dyn_outputs}
 
+    def _skip_for_dynamic_outputs(self, step: ExecutionStep):
+        dyn_outputs = [step_out for step_out in step.step_outputs if step_out.is_dynamic]
+        if dyn_outputs:
+            # place None to indicate the dynamic output was skipped, different than having 0 entries
+            self._gathering_dynamic_outputs[step.key] = {out.name: None for out in dyn_outputs}
+
     def _resolve_any_dynamic_outputs(self, step_key: str) -> None:
         if step_key in self._gathering_dynamic_outputs:
-            self._successful_dynamic_outputs[step_key] = self._gathering_dynamic_outputs[step_key]
+            step = self.get_step_by_key(step_key)
+            completed_mappings: Dict[str, Optional[Sequence[str]]] = {}
+            for output_name, mappings in self._gathering_dynamic_outputs[step_key].items():
+                # if no dynamic outputs were returned and the output was marked is_required=False
+                # set to None to indicate a skip should occur
+                if not mappings and not step.step_output_dict[output_name].is_required:
+                    completed_mappings[output_name] = None
+                else:
+                    completed_mappings[output_name] = mappings
+
+            self._completed_dynamic_outputs[step_key] = completed_mappings
             self._new_dynamic_mappings = True
 
     def rebuild_from_events(
@@ -533,7 +574,6 @@ class ActiveExecution:
         that the previous run worker might have crashed before launching these steps, or it may have
         launched them but they have yet to report a STEP_START event.
         """
-
         self.get_steps_to_execute()
 
         for event in dagster_events:
