@@ -26,7 +26,7 @@ from dagster._core.definitions import (
     Output,
     OutputDefinition,
 )
-from dagster._core.definitions.decorators.solid_decorator import DecoratedOpFunction
+from dagster._core.definitions.decorators.op_decorator import DecoratedOpFunction
 from dagster._core.definitions.op_definition import OpDefinition
 from dagster._core.errors import DagsterInvariantViolationError
 from dagster._core.types.dagster_type import DagsterTypeKind, is_generic_output_annotation
@@ -38,11 +38,11 @@ class NoAnnotationSentinel:
     pass
 
 
-def create_solid_compute_wrapper(solid_def: OpDefinition):
-    compute_fn = cast(DecoratedOpFunction, solid_def.compute_fn)
+def create_op_compute_wrapper(op_def: OpDefinition):
+    compute_fn = cast(DecoratedOpFunction, op_def.compute_fn)
     fn = compute_fn.decorated_fn
-    input_defs = solid_def.input_defs
-    output_defs = solid_def.output_defs
+    input_defs = op_def.input_defs
+    output_defs = op_def.output_defs
     context_arg_provided = compute_fn.has_context_arg()
     config_arg_cls = compute_fn.get_config_arg().annotation if compute_fn.has_config_arg() else None
     resource_arg_mapping = {arg.name: arg.name for arg in compute_fn.get_resource_args()}
@@ -251,16 +251,16 @@ def validate_and_coerce_op_result_to_iterator(
                         f" output '{output_def.name}' which does not have an Output annotation."
                         f" Annotation has type {annotation}."
                     )
-                output = cast(Output, element)
-                _check_output_object_name(output, output_def, position)
+                _check_output_object_name(element, output_def, position)
 
                 with warnings.catch_warnings():
                     warnings.simplefilter("ignore", category=DeprecationWarning)
 
                     yield Output(
                         output_name=output_def.name,
-                        value=output.value,
-                        metadata_entries=output.metadata_entries,
+                        value=element.value,
+                        metadata_entries=element.metadata_entries,
+                        data_version=element.data_version,
                     )
             else:
                 # If annotation indicates a generic output annotation, and an
