@@ -72,8 +72,8 @@ def inner_plan_execution_iterator(
                 check.invariant(
                     len(missing_resources) == 0,
                     (
-                        "Expected step context for solid {solid_name} to have all required resources, but "
-                        "missing {missing_resources}."
+                        "Expected step context for solid {solid_name} to have all required"
+                        " resources, but missing {missing_resources}."
                     ).format(
                         solid_name=step_context.solid.name, missing_resources=missing_resources
                     ),
@@ -85,7 +85,7 @@ def inner_plan_execution_iterator(
                         try:
                             step_stack.enter_context(
                                 pipeline_context.instance.compute_log_manager.watch(
-                                    step_context.pipeline_run, step_context.step.key
+                                    step_context.dagster_run, step_context.step.key
                                 )
                             )
                             yield DagsterEvent.legacy_compute_log_step_event(step_context)
@@ -136,7 +136,9 @@ def inner_plan_execution_iterator(
                 yield from _handle_compute_log_teardown_error(pipeline_context, sys.exc_info())
 
 
-def _handle_compute_log_setup_error(context, exc_info):
+def _handle_compute_log_setup_error(
+    context: PlanExecutionContext, exc_info
+) -> Iterator[DagsterEvent]:
     yield DagsterEvent.engine_event(
         plan_context=context,
         message="Exception while setting up compute log capture",
@@ -144,7 +146,9 @@ def _handle_compute_log_setup_error(context, exc_info):
     )
 
 
-def _handle_compute_log_teardown_error(context, exc_info):
+def _handle_compute_log_teardown_error(
+    context: PlanExecutionContext, exc_info
+) -> Iterator[DagsterEvent]:
     yield DagsterEvent.engine_event(
         plan_context=context,
         message="Exception while cleaning up compute log capture",
@@ -155,8 +159,8 @@ def _handle_compute_log_teardown_error(context, exc_info):
 def _trigger_hook(
     step_context: StepExecutionContext, step_event_list: Sequence[DagsterEvent]
 ) -> Iterator[DagsterEvent]:
-    """Trigger hooks and record hook's operatonal events"""
-    hook_defs = step_context.pipeline_def.get_all_hooks_for_handle(step_context.solid_handle)
+    """Trigger hooks and record hook's operatonal events."""
+    hook_defs = step_context.pipeline_def.get_all_hooks_for_handle(step_context.node_handle)
     # when the solid doesn't have a hook configured
     if hook_defs is None:
         return
@@ -253,7 +257,6 @@ def dagster_event_sequence_for_step(
     of launching steps that then launch steps, and so on, the remote process will run this with
     the force_local_execution argument set to True.
     """
-
     check.inst_param(step_context, "step_context", StepExecutionContext)
 
     try:
