@@ -1,20 +1,21 @@
 import inspect
 import warnings
-from collections import defaultdict
 from typing import (
     AbstractSet,
     Any,
     Dict,
     Iterator,
     List,
+    Mapping,
     Optional,
     Sequence,
-    Set,
     Tuple,
     Union,
     cast,
 )
 
+from typing_extensions import TypedDict
+
 import dagster._check as check
 from dagster._core.definitions import (
     AssetKey,
@@ -26,21 +27,20 @@ from dagster._core.definitions import (
     OutputDefinition,
     TypeCheck,
 )
-from dagster._core.definitions.decorators.solid_decorator import DecoratedOpFunction
-from dagster._core.definitions.events import AssetLineageInfo, DynamicOutput
-from dagster._core.definitions.logical_version import (
-    CODE_VERSION_TAG_KEY,
-    DEFAULT_LOGICAL_VERSION,
-    LOGICAL_VERSION_TAG_KEY,
-    LogicalVersion,
-    compute_logical_version,
-    extract_logical_version_from_entry,
-    get_input_event_pointer_tag_key,
-    get_input_logical_version_tag_key,
+from dagster._core.definitions.data_version import (
+    CODE_VERSION_TAG,
+    DATA_VERSION_TAG,
+    DEFAULT_DATA_VERSION,
+    DataVersion,
+    compute_logical_data_version,
+    extract_data_version_from_entry,
+    get_input_data_version_tag,
+    get_input_event_pointer_tag,
 )
+from dagster._core.definitions.decorators.op_decorator import DecoratedOpFunction
+from dagster._core.definitions.events import DynamicOutput
 from dagster._core.definitions.metadata import (
     MetadataEntry,
-    PartitionMetadataEntry,
     normalize_metadata,
 )
 from dagster._core.definitions.multi_dimensional_partitions import (
@@ -53,7 +53,6 @@ from dagster._core.errors import (
     DagsterStepOutputNotFoundError,
     DagsterTypeCheckDidNotPass,
     DagsterTypeCheckError,
-    DagsterTypeMaterializationError,
     user_code_error_boundary,
 )
 from dagster._core.events import DagsterEvent
@@ -66,18 +65,18 @@ from dagster._core.execution.plan.outputs import StepOutputData, StepOutputHandl
 from dagster._core.execution.resolve_versions import resolve_step_output_versions
 from dagster._core.storage.tags import BACKFILL_ID_TAG, MEMOIZED_RUN_TAG
 from dagster._core.types.dagster_type import DagsterType
-from dagster._utils import ensure_gen, iterate_with_context
+from dagster._utils import iterate_with_context
 from dagster._utils.backcompat import ExperimentalWarning, experimental_functionality_warning
 from dagster._utils.timing import time_execution_scope
 
-from .compute import SolidOutputUnion
-from .compute_generator import create_solid_compute_wrapper
+from .compute import OpOutputUnion
+from .compute_generator import create_op_compute_wrapper
 from .utils import op_execution_error_boundary
 
 
 def _step_output_error_checked_user_event_sequence(
-    step_context: StepExecutionContext, user_event_sequence: Iterator[SolidOutputUnion]
-) -> Iterator[SolidOutputUnion]:
+    step_context: StepExecutionContext, user_event_sequence: Iterator[OpOutputUnion]
+) -> Iterator[OpOutputUnion]:
     """
     Process the event sequence to check for invariant violations in the event
     sequence related to Output events emitted from the compute_fn.
@@ -135,6 +134,7 @@ def _step_output_error_checked_user_event_sequence(
                         *output.metadata_entries,
                         *normalize_metadata(cast(Dict[str, Any], metadata), []),
                     ],
+                    data_version=output.data_version,
                 )
         else:
             if not output_def.is_dynamic:
@@ -164,7 +164,7 @@ def _step_output_error_checked_user_event_sequence(
         yield output
 
     for step_output in step.step_outputs:
-        step_output_def = step_context.solid_def.output_def_named(step_output.name)
+        step_output_def = step_context.op_def.output_def_named(step_output.name)
         if not step_context.has_seen_output(step_output_def.name) and not step_output_def.optional:
             if step_output_def.dagster_type.is_nothing:
                 step_context.log.info(
@@ -225,7 +225,7 @@ def _type_checked_event_sequence_for_input(
     check.str_param(input_name, "input_name")
 
     step_input = step_context.step.step_input_named(input_name)
-    input_def = step_context.solid_def.input_def_named(step_input.name)
+    input_def = step_context.op_def.input_def_named(step_input.name)
 
     check.invariant(
         input_def.name == input_name,
@@ -270,7 +270,7 @@ def _type_check_output(
     check.inst_param(output, "output", (Output, DynamicOutput))
 
     step_output = step_context.step.step_output_named(output.output_name)
-    step_output_def = step_context.solid_def.output_def_named(step_output.name)
+    step_output_def = step_context.op_def.output_def_named(step_output.name)
 
     dagster_type = step_output_def.dagster_type
     type_check_context = step_context.for_type(dagster_type)
@@ -335,15 +335,13 @@ def core_dagster_event_sequence_for_step(
         step_context.fetch_external_input_asset_records()
 
     for step_input in step_context.step.step_inputs:
-        input_def = step_context.solid_def.input_def_named(step_input.name)
+        input_def = step_context.op_def.input_def_named(step_input.name)
         dagster_type = input_def.dagster_type
 
         if dagster_type.is_nothing:
             continue
 
-        for event_or_input_value in ensure_gen(
-            step_input.source.load_input_object(step_context, input_def)
-        ):
+        for event_or_input_value in step_input.source.load_input_object(step_context, input_def):
             if isinstance(event_or_input_value, DagsterEvent):
                 yield event_or_input_value
             else:
@@ -356,17 +354,15 @@ def core_dagster_event_sequence_for_step(
         ):
             yield evt
 
-    input_lineage = step_context.get_input_lineage()
-
     # The core execution loop expects a compute generator in a specific format: a generator that
     # takes a context and dictionary of inputs as input, yields output events. If a solid definition
     # was generated from the @solid or @lambda_solid decorator, then compute_fn needs to be coerced
     # into this format. If the solid definition was created directly, then it is expected that the
     # compute_fn is already in this format.
-    if isinstance(step_context.solid_def.compute_fn, DecoratedOpFunction):
-        core_gen = create_solid_compute_wrapper(step_context.solid_def)
+    if isinstance(step_context.op_def.compute_fn, DecoratedOpFunction):
+        core_gen = create_op_compute_wrapper(step_context.op_def)
     else:
-        core_gen = step_context.solid_def.compute_fn
+        core_gen = step_context.op_def.compute_fn
 
     with time_execution_scope() as timer_result:
         user_event_sequence = check.generator(
@@ -385,12 +381,12 @@ def core_dagster_event_sequence_for_step(
             if isinstance(user_event, DagsterEvent):
                 yield user_event
             elif isinstance(user_event, (Output, DynamicOutput)):
-                for evt in _type_check_and_store_output(step_context, user_event, input_lineage):
+                for evt in _type_check_and_store_output(step_context, user_event):
                     yield evt
             # for now, I'm ignoring AssetMaterializations yielded manually, but we might want
             # to do something with these in the above path eventually
             elif isinstance(user_event, (AssetMaterialization, Materialization)):
-                yield DagsterEvent.asset_materialization(step_context, user_event, input_lineage)
+                yield DagsterEvent.asset_materialization(step_context, user_event)
             elif isinstance(user_event, AssetObservation):
                 yield DagsterEvent.asset_observation(step_context, user_event)
             elif isinstance(user_event, ExpectationResult):
@@ -408,13 +404,10 @@ def core_dagster_event_sequence_for_step(
 
 
 def _type_check_and_store_output(
-    step_context: StepExecutionContext,
-    output: Union[DynamicOutput, Output],
-    input_lineage: Sequence[AssetLineageInfo],
+    step_context: StepExecutionContext, output: Union[DynamicOutput, Output]
 ) -> Iterator[DagsterEvent]:
     check.inst_param(step_context, "step_context", StepExecutionContext)
     check.inst_param(output, "output", (Output, DynamicOutput))
-    check.sequence_param(input_lineage, "input_lineage", AssetLineageInfo)
 
     mapping_key = output.mapping_key if isinstance(output, DynamicOutput) else None
 
@@ -441,10 +434,7 @@ def _type_check_and_store_output(
     for output_event in _type_check_output(step_context, step_output_handle, output, version):
         yield output_event
 
-    for evt in _store_output(step_context, step_output_handle, output, input_lineage):
-        yield evt
-
-    for evt in _create_type_materializations(step_context, output.output_name, output.value):
+    for evt in _store_output(step_context, step_output_handle, output):
         yield evt
 
 
@@ -464,31 +454,12 @@ def _asset_key_and_partitions_for_output(
     return None, set()
 
 
-def _dedup_asset_lineage(asset_lineage: Sequence[AssetLineageInfo]) -> Sequence[AssetLineageInfo]:
-    """Method to remove duplicate specifications of the same Asset/Partition pair from the lineage
-    information. Duplicates can occur naturally when calculating transitive dependencies from solids
-    with multiple Outputs, which in turn have multiple Inputs (because each Output of the solid will
-    inherit all dependencies from all of the solid Inputs).
-    """
-    key_partition_mapping: Dict[AssetKey, Set[str]] = defaultdict(set)
-
-    for lineage_info in asset_lineage:
-        if not lineage_info.partitions:
-            key_partition_mapping[lineage_info.asset_key] |= set()
-        for partition in lineage_info.partitions:
-            key_partition_mapping[lineage_info.asset_key].add(partition)
-    return [
-        AssetLineageInfo(asset_key=asset_key, partitions=partitions)
-        for asset_key, partitions in key_partition_mapping.items()
-    ]
-
-
 def _get_output_asset_materializations(
     asset_key: AssetKey,
     asset_partitions: AbstractSet[str],
     output: Union[Output, DynamicOutput],
     output_def: OutputDefinition,
-    io_manager_metadata_entries: Sequence[Union[MetadataEntry, PartitionMetadataEntry]],
+    io_manager_metadata_entries: Sequence[MetadataEntry],
     step_context: StepExecutionContext,
 ) -> Iterator[AssetMaterialization]:
     all_metadata = [*output.metadata_entries, *io_manager_metadata_entries]
@@ -502,9 +473,21 @@ def _get_output_asset_materializations(
         step_context.is_external_input_asset_records_loaded
         and asset_key in step_context.pipeline_def.asset_layer.asset_keys
     ):
-        tags = _build_logical_version_tags(asset_key, step_context)
-        logical_version = LogicalVersion(tags[LOGICAL_VERSION_TAG_KEY])
-        step_context.record_logical_version(asset_key, logical_version)
+        assert isinstance(output, Output)
+        code_version = _get_code_version(asset_key, step_context)
+        input_provenance_data = _get_input_provenance_data(asset_key, step_context)
+        data_version = (
+            compute_logical_data_version(
+                code_version,
+                {k: meta["data_version"] for k, meta in input_provenance_data.items()},
+            )
+            if output.data_version is None
+            else output.data_version
+        )
+        tags = _build_data_version_tags(data_version, code_version, input_provenance_data)
+        if not step_context.has_data_version(asset_key):
+            data_version = DataVersion(tags[DATA_VERSION_TAG])
+            step_context.set_data_version(asset_key, data_version)
     else:
         tags = {}
 
@@ -513,28 +496,6 @@ def _get_output_asset_materializations(
         tags[BACKFILL_ID_TAG] = backfill_id
 
     if asset_partitions:
-        metadata_mapping: Dict[
-            str,
-            List[Union[MetadataEntry, PartitionMetadataEntry]],
-        ] = {partition: [] for partition in asset_partitions}
-
-        for entry in all_metadata:
-            # TODO: Allow users to specify a multi-dimensional partition key in a PartitionMetadataEntry
-
-            # if you target a given entry at a partition, only apply it to the requested partition
-            # otherwise, apply it to all partitions
-            if isinstance(entry, PartitionMetadataEntry):
-                if entry.partition not in asset_partitions:
-                    raise DagsterInvariantViolationError(
-                        f"Output {output_def.name} associated a metadata entry ({entry}) with the"
-                        f" partition `{entry.partition}`, which is not one of the declared"
-                        f" partition mappings ({asset_partitions})."
-                    )
-                metadata_mapping[entry.partition].append(entry.entry)
-            else:
-                for partition in metadata_mapping.keys():
-                    metadata_mapping[partition].append(entry)
-
         for partition in asset_partitions:
             with warnings.catch_warnings():
                 warnings.simplefilter("ignore", category=DeprecationWarning)
@@ -548,16 +509,10 @@ def _get_output_asset_materializations(
                 yield AssetMaterialization(
                     asset_key=asset_key,
                     partition=partition,
-                    metadata_entries=metadata_mapping[partition],
+                    metadata_entries=all_metadata,
                     tags=tags,
                 )
     else:
-        for entry in all_metadata:
-            if isinstance(entry, PartitionMetadataEntry):
-                raise DagsterInvariantViolationError(
-                    f"Output {output_def.name} got a PartitionMetadataEntry ({entry}), but "
-                    "is not associated with any specific partitions."
-                )
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=DeprecationWarning)
 
@@ -566,14 +521,22 @@ def _get_output_asset_materializations(
             )
 
 
-def _build_logical_version_tags(
+def _get_code_version(asset_key: AssetKey, step_context: StepExecutionContext) -> str:
+    return (
+        step_context.pipeline_def.asset_layer.code_version_for_asset(asset_key)
+        or step_context.dagster_run.run_id
+    )
+
+
+class _InputProvenanceData(TypedDict):
+    data_version: DataVersion
+    storage_id: Optional[int]
+
+
+def _get_input_provenance_data(
     asset_key: AssetKey, step_context: StepExecutionContext
-) -> Dict[str, str]:
-    asset_layer = step_context.pipeline_def.asset_layer
-    code_version = asset_layer.code_version_for_asset(asset_key) or step_context.pipeline_run.run_id
-    input_logical_versions: Dict[AssetKey, LogicalVersion] = {}
-    tags: Dict[str, str] = {}
-    tags[CODE_VERSION_TAG_KEY] = code_version
+) -> Mapping[AssetKey, _InputProvenanceData]:
+    input_provenance: Dict[AssetKey, _InputProvenanceData] = {}
     deps = step_context.pipeline_def.asset_layer.upstream_assets_for_asset(asset_key)
     for key in deps:
         # For deps external to this step, this will retrieve the cached record that was stored prior
@@ -583,17 +546,31 @@ def _build_logical_version_tags(
         # generated in topological order -- we assume this.
         event = step_context.get_input_asset_record(key)
         if event is not None:
-            logical_version = (
-                extract_logical_version_from_entry(event.event_log_entry) or DEFAULT_LOGICAL_VERSION
+            data_version = (
+                extract_data_version_from_entry(event.event_log_entry) or DEFAULT_DATA_VERSION
             )
         else:
-            logical_version = DEFAULT_LOGICAL_VERSION
-        input_logical_versions[key] = logical_version
-        tags[get_input_logical_version_tag_key(key)] = logical_version.value
-        tags[get_input_event_pointer_tag_key(key)] = str(event.storage_id) if event else "NULL"
+            data_version = DEFAULT_DATA_VERSION
+        input_provenance[key] = {
+            "data_version": data_version,
+            "storage_id": event.storage_id if event else None,
+        }
+    return input_provenance
 
-    logical_version = compute_logical_version(code_version, input_logical_versions)
-    tags[LOGICAL_VERSION_TAG_KEY] = logical_version.value
+
+def _build_data_version_tags(
+    data_version: DataVersion,
+    code_version: str,
+    input_provenance_data: Mapping[AssetKey, _InputProvenanceData],
+) -> Dict[str, str]:
+    tags: Dict[str, str] = {}
+    tags[CODE_VERSION_TAG] = code_version
+    for key, meta in input_provenance_data.items():
+        tags[get_input_data_version_tag(key)] = meta["data_version"].value
+        tags[get_input_event_pointer_tag(key)] = (
+            str(meta["storage_id"]) if meta["storage_id"] else "NULL"
+        )
+    tags[DATA_VERSION_TAG] = data_version.value
     return tags
 
 
@@ -601,14 +578,13 @@ def _store_output(
     step_context: StepExecutionContext,
     step_output_handle: StepOutputHandle,
     output: Union[Output, DynamicOutput],
-    input_lineage: Sequence[AssetLineageInfo],
 ) -> Iterator[DagsterEvent]:
-    output_def = step_context.solid_def.output_def_named(step_output_handle.output_name)
+    output_def = step_context.op_def.output_def_named(step_output_handle.output_name)
     output_manager = step_context.get_io_manager(step_output_handle)
     output_context = step_context.get_output_context(step_output_handle)
 
     manager_materializations = []
-    manager_metadata_entries: List[Union[PartitionMetadataEntry, MetadataEntry]] = []
+    manager_metadata_entries: List[MetadataEntry] = []
 
     # output_manager.handle_output is either a generator function, or a normal function with or
     # without a return value. In the case that handle_output is a normal function, we need to
@@ -646,7 +622,7 @@ def _store_output(
             yield elt
         elif isinstance(elt, AssetMaterialization):
             manager_materializations.append(elt)
-        elif isinstance(elt, (MetadataEntry, PartitionMetadataEntry)):
+        elif isinstance(elt, MetadataEntry):
             experimental_functionality_warning(
                 "Yielding metadata from an IOManager's handle_output() function"
             )
@@ -655,7 +631,7 @@ def _store_output(
             raise DagsterInvariantViolationError(
                 f"IO manager on output {output_def.name} has returned "
                 f"value {elt} of type {type(elt).__name__}. The return type can only be "
-                "one of AssetMaterialization, MetadataEntry, PartitionMetadataEntry."
+                "one of AssetMaterialization, MetadataEntry."
             )
 
     for event in output_context.consume_events():
@@ -684,7 +660,7 @@ def _store_output(
                     partition=materialization.partition,
                     metadata=None,
                 )
-        yield DagsterEvent.asset_materialization(step_context, materialization, input_lineage)
+        yield DagsterEvent.asset_materialization(step_context, materialization)
 
     asset_key, partitions = _asset_key_and_partitions_for_output(output_context)
     if asset_key:
@@ -696,11 +672,7 @@ def _store_output(
             manager_metadata_entries,
             step_context,
         ):
-            yield DagsterEvent.asset_materialization(
-                step_context,
-                materialization,
-                input_lineage,
-            )
+            yield DagsterEvent.asset_materialization(step_context, materialization)
 
     yield DagsterEvent.handled_output(
         step_context,
@@ -710,57 +682,3 @@ def _store_output(
             entry for entry in manager_metadata_entries if isinstance(entry, MetadataEntry)
         ],
     )
-
-
-def _create_type_materializations(
-    step_context: StepExecutionContext, output_name: str, value: Any
-) -> Iterator[DagsterEvent]:
-    """If the output has any dagster type materializers, runs them."""
-    step = step_context.step
-    current_handle = step.solid_handle
-
-    # check for output mappings at every point up the composition hierarchy
-    while current_handle:
-        solid_config = step_context.resolved_run_config.solids.get(current_handle.to_string())
-        current_handle = current_handle.parent
-
-        if solid_config is None:
-            continue
-
-        for output_spec in solid_config.outputs.type_materializer_specs:
-            check.invariant(len(output_spec) == 1)  # type: ignore
-            config_output_name, output_spec = list(output_spec.items())[0]  # type: ignore
-            if config_output_name == output_name:
-                step_output = step.step_output_named(output_name)
-                with user_code_error_boundary(
-                    DagsterTypeMaterializationError,
-                    msg_fn=lambda: f'Error occurred during output materialization:\n    output name: "{output_name}"\n    solid invocation: "{step_context.solid.name}"\n    solid definition: "{step_context.solid_def.name}"',
-                    log_manager=step_context.log,
-                ):
-                    output_def = step_context.solid_def.output_def_named(step_output.name)
-                    dagster_type = output_def.dagster_type
-                    materializer = dagster_type.materializer
-                    if materializer is None:
-                        check.failed(
-                            "Unexpected attempt to materialize with no materializer available on"
-                            " dagster_type"
-                        )
-                    materializations = materializer.materialize_runtime_values(
-                        step_context.get_type_materializer_context(), output_spec, value
-                    )
-
-                for materialization in materializations:
-                    if not isinstance(materialization, (AssetMaterialization, Materialization)):
-                        raise DagsterInvariantViolationError(
-                            (
-                                "materialize_runtime_values on type {type_name} has returned "
-                                "value {value} of type {python_type}. You must return an "
-                                "AssetMaterialization."
-                            ).format(
-                                type_name=dagster_type.display_name,
-                                value=repr(materialization),
-                                python_type=type(materialization).__name__,
-                            )
-                        )
-
-                    yield DagsterEvent.asset_materialization(step_context, materialization)
