@@ -3,7 +3,7 @@ import pickle
 import shutil
 import subprocess
 import sys
-from typing import TYPE_CHECKING, Callable, Iterator, Optional, cast
+from typing import TYPE_CHECKING, Callable, Iterator, Optional, Sequence, cast
 
 import dagster._check as check
 from dagster._config import Field, StringSource
@@ -33,7 +33,7 @@ if TYPE_CHECKING:
 @resource(
     config_schema={
         "scratch_dir": Field(
-            StringSource,  # type: ignore  # (mypy bug)
+            StringSource,
             description="Directory used to pass files between the plan process and step process.",
         ),
     },
@@ -53,7 +53,7 @@ class LocalExternalStepLauncher(StepLauncher):
         step_context: StepExecutionContext,
     ) -> Iterator[DagsterEvent]:
         step_run_ref = step_context_to_step_run_ref(step_context)
-        run_id = step_context.pipeline_run.run_id
+        run_id = step_context.dagster_run.run_id
 
         step_run_dir = os.path.join(self.scratch_dir, run_id, step_run_ref.step_key)
         if os.path.exists(step_run_dir):
@@ -80,13 +80,13 @@ class LocalExternalStepLauncher(StepLauncher):
         file_manager = LocalFileManager(".")
         events_file_handle = LocalFileHandle(events_file_path)
         events_data = file_manager.read_data(events_file_handle)
-        all_events = deserialize_value(pickle.loads(events_data))
+        all_events = cast(Sequence[EventLogEntry], deserialize_value(pickle.loads(events_data)))
 
         for event in all_events:
             # write each pickled event from the external instance to the local instance
             step_context.instance.handle_new_event(event)
             if event.is_dagster_event:
-                yield event.dagster_event
+                yield event.dagster_event  # type: ignore  # (possible none)
 
 
 def _module_in_package_dir(file_path: str, package_dir: str) -> str:
@@ -151,8 +151,8 @@ def step_context_to_step_run_ref(
 
     return StepRunRef(
         run_config=step_context.run_config,
-        pipeline_run=step_context.pipeline_run,
-        run_id=step_context.pipeline_run.run_id,
+        dagster_run=step_context.dagster_run,
+        run_id=step_context.dagster_run.run_id,
         step_key=step_context.step.key,
         retry_mode=retry_mode,
         recon_pipeline=recon_pipeline,  # type: ignore
@@ -189,17 +189,17 @@ def step_run_ref_to_step_context(
 
     pipeline = step_run_ref.recon_pipeline
 
-    solids_to_execute = step_run_ref.pipeline_run.solids_to_execute
-    if solids_to_execute or step_run_ref.pipeline_run.asset_selection:
+    solids_to_execute = step_run_ref.dagster_run.solids_to_execute
+    if solids_to_execute or step_run_ref.dagster_run.asset_selection:
         pipeline = step_run_ref.recon_pipeline.subset_for_execution_from_existing_pipeline(
             frozenset(solids_to_execute) if solids_to_execute else None,
-            asset_selection=step_run_ref.pipeline_run.asset_selection,
+            asset_selection=step_run_ref.dagster_run.asset_selection,
         )
 
     execution_plan = create_execution_plan(
         pipeline,
         step_run_ref.run_config,
-        mode=step_run_ref.pipeline_run.mode,
+        mode=step_run_ref.dagster_run.mode,
         step_keys_to_execute=[step_run_ref.step_key],
         known_state=step_run_ref.known_state,
         # we packaged repository_load_data onto the reconstructable pipeline when creating the
@@ -212,7 +212,7 @@ def step_run_ref_to_step_context(
         pipeline=pipeline,
         execution_plan=execution_plan,
         run_config=step_run_ref.run_config,
-        pipeline_run=step_run_ref.pipeline_run,
+        dagster_run=step_run_ref.dagster_run,
         instance=instance,
     )
     for _ in initialization_manager.prepare_context():
