@@ -3,7 +3,6 @@ from abc import ABC, abstractmethod
 from typing import (
     TYPE_CHECKING,
     AbstractSet,
-    Any,
     Iterator,
     List,
     Mapping,
@@ -15,9 +14,10 @@ from typing import (
     cast,
 )
 
+from typing_extensions import TypeAlias
+
 import dagster._check as check
 from dagster._core.definitions import InputDefinition, NodeHandle, PipelineDefinition
-from dagster._core.definitions.events import AssetLineageInfo
 from dagster._core.definitions.job_definition import JobDefinition
 from dagster._core.definitions.metadata import MetadataEntry
 from dagster._core.definitions.version_strategy import ResourceVersionContext
@@ -30,36 +30,26 @@ from dagster._core.errors import (
 from dagster._core.storage.io_manager import IOManager
 from dagster._core.system_config.objects import ResolvedRunConfig
 from dagster._serdes import whitelist_for_serdes
-from dagster._utils import ensure_gen
 
 from .objects import TypeCheckData
 from .outputs import StepOutputHandle, UnresolvedStepOutputHandle
 from .utils import build_resources_for_manager, op_execution_error_boundary
 
 if TYPE_CHECKING:
-    from dagster._core.events import DagsterEvent
     from dagster._core.execution.context.input import InputContext
     from dagster._core.execution.context.system import StepExecutionContext
     from dagster._core.storage.input_manager import InputManager
 
-
-def _get_asset_lineage_from_fns(
-    context, asset_key_fn, asset_partitions_fn
-) -> Optional[AssetLineageInfo]:
-    asset_key = asset_key_fn(context)
-    if not asset_key:
-        return None
-    return AssetLineageInfo(
-        asset_key=asset_key,
-        partitions=asset_partitions_fn(context),
-    )
+StepInputUnion: TypeAlias = Union[
+    "StepInput", "UnresolvedMappedStepInput", "UnresolvedCollectStepInput"
+]
 
 
 @whitelist_for_serdes
 class StepInputData(
     NamedTuple("_StepInputData", [("input_name", str), ("type_check_data", TypeCheckData)])
 ):
-    """ "Serializable payload of information for the result of processing a step input"""
+    """Serializable payload of information for the result of processing a step input."""
 
     def __new__(cls, input_name: str, type_check_data: TypeCheckData):
         return super(StepInputData, cls).__new__(
@@ -75,9 +65,9 @@ class StepInput(
         [("name", str), ("dagster_type_key", str), ("source", "StepInputSource")],
     )
 ):
-    """Holds information for how to prepare an input for an ExecutionStep"""
+    """Holds information for how to prepare an input for an ExecutionStep."""
 
-    def __new__(cls, name, dagster_type_key, source):
+    def __new__(cls, name: str, dagster_type_key: str, source: "StepInputSource"):
         return super(StepInput, cls).__new__(
             cls,
             name=check.str_param(name, "name"),
@@ -86,7 +76,7 @@ class StepInput(
         )
 
     @property
-    def dependency_keys(self) -> Set[str]:
+    def dependency_keys(self) -> AbstractSet[str]:
         return self.source.step_key_dependencies
 
     def get_step_output_handle_dependencies(self) -> Sequence[StepOutputHandle]:
@@ -104,7 +94,7 @@ def join_and_hash(*args: Optional[str]) -> Optional[str]:
 
 
 class StepInputSource(ABC):
-    """How to load the data for a step input"""
+    """How to load the data for a step input."""
 
     @property
     def step_key_dependencies(self) -> Set[str]:
@@ -115,19 +105,14 @@ class StepInputSource(ABC):
         return []
 
     @abstractmethod
-    def load_input_object(self, step_context: "StepExecutionContext", input_def: InputDefinition):
+    def load_input_object(
+        self, step_context: "StepExecutionContext", input_def: InputDefinition
+    ) -> Iterator[object]:
         ...
 
     def required_resource_keys(self, _pipeline_def: PipelineDefinition) -> AbstractSet[str]:
         return set()
 
-    def get_asset_lineage(
-        self,
-        _step_context: "StepExecutionContext",
-        _input_def: InputDefinition,
-    ) -> Sequence[AssetLineageInfo]:
-        return []
-
     @abstractmethod
     def compute_version(
         self,
@@ -135,7 +120,7 @@ class StepInputSource(ABC):
         pipeline_def: PipelineDefinition,
         resolved_run_config: ResolvedRunConfig,
     ) -> Optional[str]:
-        """See resolve_step_versions in resolve_versions.py for explanation of step_versions"""
+        """See resolve_step_versions in resolve_versions.py for explanation of step_versions."""
         raise NotImplementedError()
 
 
@@ -151,14 +136,14 @@ class FromSourceAsset(
     StepInputSource,
 ):
     """
-    Load input value from an asset
+    Load input value from an asset.
     """
 
     def load_input_object(
         self,
         step_context: "StepExecutionContext",
         input_def: InputDefinition,
-    ) -> Iterator["DagsterEvent"]:
+    ) -> Iterator[object]:
         from dagster._core.definitions.asset_layer import AssetOutputInfo
         from dagster._core.events import DagsterEvent
         from dagster._core.execution.context.output import OutputContext
@@ -176,7 +161,7 @@ class FromSourceAsset(
             else asset_layer.io_manager_key_for_asset(input_asset_key)
         )
 
-        op_config = step_context.resolved_run_config.solids.get(str(self.solid_handle))
+        op_config = step_context.resolved_run_config.ops.get(str(self.solid_handle))
         config_data = op_config.inputs.get(self.input_name) if op_config else None
 
         loader = getattr(step_context.resources, input_manager_key)
@@ -215,18 +200,24 @@ class FromSourceAsset(
             ],
         )
 
-    def compute_version(self, step_versions, pipeline_def, resolved_run_config) -> Optional[str]:
+    def compute_version(
+        self,
+        step_versions: Mapping[str, Optional[str]],
+        pipeline_def: PipelineDefinition,
+        resolved_run_config: ResolvedRunConfig,
+    ) -> Optional[str]:
         from ..resolve_versions import check_valid_version, resolve_config_version
 
         op = pipeline_def.get_solid(self.solid_handle)
-        io_manager_key = op.input_def_named(self.input_name).io_manager_key
+        input_manager_key = check.not_none(op.input_def_named(self.input_name).input_manager_key)
         io_manager_def = pipeline_def.get_mode_definition(resolved_run_config.mode).resource_defs[
-            io_manager_key
+            input_manager_key
         ]
 
-        op_config = resolved_run_config.solids.get(op.name)
+        op_config = check.not_none(resolved_run_config.ops.get(op.name))
         input_config = op_config.inputs.get(self.input_name)
-        resource_config = resolved_run_config.resources.get(io_manager_key).config
+        resource_entry = check.not_none(resolved_run_config.resources.get(input_manager_key))
+        resource_config = resource_entry.config
 
         version_context = ResourceVersionContext(
             resource_def=io_manager_def,
@@ -260,12 +251,22 @@ class FromSourceAsset(
         )
         if input_asset_key is None:
             check.failed(
-                f"Must have an asset key associated with input {self.input_name} to load it using FromSourceAsset",
+                (
+                    f"Must have an asset key associated with input {self.input_name} to load it"
+                    " using FromSourceAsset"
+                ),
             )
-        input_manager_key = pipeline_def.asset_layer.io_manager_key_for_asset(input_asset_key)
+
+        input_def = pipeline_def.get_solid(self.solid_handle).input_def_named(self.input_name)
+        if input_def.input_manager_key is not None:
+            input_manager_key = input_def.input_manager_key
+        else:
+            input_manager_key = pipeline_def.asset_layer.io_manager_key_for_asset(input_asset_key)
+
         if input_manager_key is None:
             check.failed(
-                f"Must have an io_manager associated with asset {input_asset_key} to load it using FromSourceAsset"
+                f"Must have an io_manager associated with asset {input_asset_key} to load it using"
+                " FromSourceAsset"
             )
         return {input_manager_key}
 
@@ -289,19 +290,21 @@ class FromRootInputManager(
         self,
         step_context: "StepExecutionContext",
         input_def: InputDefinition,
-    ) -> Iterator["DagsterEvent"]:
+    ) -> Iterator[object]:
         from dagster._core.events import DagsterEvent
 
         check.invariant(
-            step_context.solid_handle == self.solid_handle and input_def.name == self.input_name,
-            "RootInputManager source must be op input and not one along composition mapping. "
-            f"Loading for op {step_context.solid_handle}.{input_def.name} "
-            f"but source is {self.solid_handle}.{self.input_name}.",
+            step_context.node_handle == self.solid_handle and input_def.name == self.input_name,
+            (
+                "RootInputManager source must be op input and not one along composition mapping. "
+                f"Loading for op {step_context.node_handle}.{input_def.name} "
+                f"but source is {self.solid_handle}.{self.input_name}."
+            ),
         )
 
-        input_def = step_context.solid_def.input_def_named(input_def.name)
+        input_def = step_context.op_def.input_def_named(input_def.name)
 
-        solid_config = step_context.resolved_run_config.solids.get(str(self.solid_handle))
+        solid_config = step_context.resolved_run_config.ops.get(str(self.solid_handle))
         config_data = solid_config.inputs.get(self.input_name) if solid_config else None
 
         input_manager_key = check.not_none(
@@ -352,7 +355,7 @@ class FromRootInputManager(
             resolved_run_config.mode
         ).resource_defs[input_manager_key]
 
-        solid_config = resolved_run_config.solids[solid.name]
+        solid_config = resolved_run_config.ops[solid.name]
         input_config = solid_config.inputs.get(self.input_name)
         resource_config = check.not_none(
             resolved_run_config.resources.get(input_manager_key)
@@ -448,14 +451,20 @@ class FromStepOutput(
         self,
         step_context: "StepExecutionContext",
         input_def: InputDefinition,
+        io_manager_key: Optional[str] = None,
     ) -> "InputContext":
-        io_manager_key = step_context.execution_plan.get_manager_key(
-            self.step_output_handle, step_context.pipeline_def
+        resolved_io_manager_key = (
+            step_context.execution_plan.get_manager_key(
+                self.step_output_handle, step_context.pipeline_def
+            )
+            if io_manager_key is None
+            else io_manager_key
         )
-        resource_config = step_context.resolved_run_config.resources[io_manager_key].config
-        resources = build_resources_for_manager(io_manager_key, step_context)
 
-        solid_config = step_context.resolved_run_config.solids.get(str(step_context.solid_handle))
+        resource_config = step_context.resolved_run_config.resources[resolved_io_manager_key].config
+        resources = build_resources_for_manager(resolved_io_manager_key, step_context)
+
+        solid_config = step_context.resolved_run_config.ops.get(str(step_context.node_handle))
         config_data = solid_config.inputs.get(input_def.name) if solid_config else None
 
         return step_context.for_input_manager(
@@ -472,7 +481,7 @@ class FromStepOutput(
         self,
         step_context: "StepExecutionContext",
         input_def: InputDefinition,
-    ) -> Iterator["DagsterEvent"]:
+    ) -> Iterator[object]:
         from dagster._core.events import DagsterEvent
         from dagster._core.storage.input_manager import InputManager
 
@@ -483,10 +492,12 @@ class FromStepOutput(
             input_manager = getattr(step_context.resources, manager_key)
             check.invariant(
                 isinstance(input_manager, InputManager),
-                f'Input "{input_def.name}" for step "{step_context.step.key}" is depending on '
-                f'the manager "{manager_key}" to load it, but it is not an InputManager. '
-                f"Please ensure that the resource returned for resource key "
-                f'"{manager_key}" is an InputManager.',
+                (
+                    f'Input "{input_def.name}" for step "{step_context.step.key}" is depending on '
+                    f'the manager "{manager_key}" to load it, but it is not an InputManager. '
+                    "Please ensure that the resource returned for resource key "
+                    f'"{manager_key}" is an InputManager.'
+                ),
             )
         else:
             manager_key = step_context.execution_plan.get_manager_key(
@@ -495,13 +506,17 @@ class FromStepOutput(
             input_manager = step_context.get_io_manager(source_handle)
             check.invariant(
                 isinstance(input_manager, IOManager),
-                f'Input "{input_def.name}" for step "{step_context.step.key}" is depending on '
-                f'the manager of upstream output "{source_handle.output_name}" from step '
-                f'"{source_handle.step_key}" to load it, but that manager is not an IOManager. '
-                f"Please ensure that the resource returned for resource key "
-                f'"{manager_key}" is an IOManager.',
+                (
+                    f'Input "{input_def.name}" for step "{step_context.step.key}" is depending on '
+                    f'the manager of upstream output "{source_handle.output_name}" from step '
+                    f'"{source_handle.step_key}" to load it, but that manager is not an IOManager. '
+                    "Please ensure that the resource returned for resource key "
+                    f'"{manager_key}" is an IOManager.'
+                ),
             )
-        load_input_context = self.get_load_context(step_context, input_def)
+        load_input_context = self.get_load_context(
+            step_context, input_def, io_manager_key=manager_key
+        )
         yield from _load_input_with_input_manager(input_manager, load_input_context)
 
         metadata_entries = load_input_context.consume_metadata_entries()
@@ -536,35 +551,6 @@ class FromStepOutput(
     def required_resource_keys(self, _pipeline_def: PipelineDefinition) -> Set[str]:
         return set()
 
-    def get_asset_lineage(
-        self,
-        step_context: "StepExecutionContext",
-        input_def: InputDefinition,
-    ) -> Sequence[AssetLineageInfo]:
-        load_context = self.get_load_context(step_context, input_def)
-
-        # check input_def
-        if input_def.is_asset:
-            lineage_info = _get_asset_lineage_from_fns(
-                load_context, input_def.get_asset_key, input_def.get_asset_partitions
-            )
-            return [lineage_info] if lineage_info else []
-
-        # check output_def
-        upstream_output = step_context.execution_plan.get_step_output(self.step_output_handle)
-        if upstream_output.is_asset:
-            output_def = step_context.pipeline_def.get_solid(
-                upstream_output.solid_handle
-            ).output_def_named(upstream_output.name)
-            lineage_info = _get_asset_lineage_from_fns(
-                load_context.upstream_output,
-                output_def.get_asset_key,
-                output_def.get_asset_partitions,
-            )
-            return [lineage_info] if lineage_info else []
-
-        return []
-
 
 @whitelist_for_serdes
 class FromConfig(
@@ -606,7 +592,7 @@ class FromConfig(
         including the root.
         """
         if self.solid_handle:
-            op_config = resolved_run_config.solids.get(str(self.solid_handle))
+            op_config = resolved_run_config.ops.get(str(self.solid_handle))
             return op_config.inputs.get(self.input_name) if op_config else None
         else:
             input_config = resolved_run_config.inputs
@@ -616,19 +602,16 @@ class FromConfig(
         self,
         step_context: "StepExecutionContext",
         input_def: InputDefinition,
-    ) -> Any:
+    ) -> Iterator[object]:
         with user_code_error_boundary(
             DagsterTypeLoadingError,
-            msg_fn=lambda: (
-                f'Error occurred while loading input "{self.input_name}" of '
-                f'step "{step_context.step.key}":'
-            ),
+            msg_fn=lambda: f'Error occurred while loading input "{self.input_name}" of step "{step_context.step.key}":',
             log_manager=step_context.log,
         ):
             dagster_type = self.get_associated_input_def(step_context.pipeline_def).dagster_type
             config_data = self.get_associated_config(step_context.resolved_run_config)
             loader = check.not_none(dagster_type.loader)
-            return loader.construct_from_config_value(
+            yield loader.construct_from_config_value(
                 step_context.get_type_loader_context(), config_data
             )
 
@@ -642,7 +625,6 @@ class FromConfig(
         pipeline_def: PipelineDefinition,
         resolved_run_config: ResolvedRunConfig,
     ) -> Optional[str]:
-
         config_data = self.get_associated_config(resolved_run_config)
         input_def = self.get_associated_input_def(pipeline_def)
         dagster_type = input_def.dagster_type
@@ -668,9 +650,8 @@ class FromDirectInputValue(
         )
 
     def load_input_object(
-        self, step_context: "StepExecutionContext", _input_def: InputDefinition
-    ) -> Any:
-
+        self, step_context: "StepExecutionContext", input_def: InputDefinition
+    ) -> Iterator[object]:
         pipeline_def = step_context.pipeline_def
         if not pipeline_def.is_job:
             raise DagsterInvariantViolationError(
@@ -678,7 +659,7 @@ class FromDirectInputValue(
             )
 
         job_def = cast(JobDefinition, pipeline_def)
-        return job_def.get_direct_input_value(self.input_name)
+        yield job_def.get_direct_input_value(self.input_name)
 
     def required_resource_keys(self, _pipeline_def: PipelineDefinition) -> Set[str]:
         return set()
@@ -719,8 +700,8 @@ class FromDefaultValue(
         self,
         step_context: "StepExecutionContext",
         input_def: InputDefinition,
-    ):
-        return self._load_value(step_context.pipeline_def)
+    ) -> Iterator[object]:
+        yield self._load_value(step_context.pipeline_def)
 
     def compute_version(
         self,
@@ -744,7 +725,8 @@ class FromMultipleSources(
     ),
     StepInputSource,
 ):
-    """This step input is fans-in multiple sources in to a single input. The input will receive a list."""
+    """This step input is fans-in multiple sources in to a single input. The input will receive a list.
+    """
 
     def __new__(
         cls,
@@ -770,7 +752,7 @@ class FromMultipleSources(
         )
 
     @property
-    def step_key_dependencies(self):
+    def step_key_dependencies(self) -> AbstractSet[str]:
         keys = set()
         for source in self.sources:
             keys.update(source.step_key_dependencies)
@@ -778,8 +760,8 @@ class FromMultipleSources(
         return keys
 
     @property
-    def step_output_handle_dependencies(self):
-        handles = []
+    def step_output_handle_dependencies(self) -> Sequence[StepOutputHandle]:
+        handles: List[StepOutputHandle] = []
         for source in self.sources:
             handles.extend(source.step_output_handle_dependencies)
 
@@ -789,7 +771,7 @@ class FromMultipleSources(
         self,
         step_context: "StepExecutionContext",
         input_def: InputDefinition,
-    ):
+    ) -> Iterator[object]:
         from dagster._core.events import DagsterEvent
 
         values = []
@@ -809,9 +791,7 @@ class FromMultipleSources(
             ):
                 continue
 
-            for event_or_input_value in ensure_gen(
-                inner_source.load_input_object(step_context, input_def)
-            ):
+            for event_or_input_value in inner_source.load_input_object(step_context, input_def):
                 if isinstance(event_or_input_value, DagsterEvent):
                     yield event_or_input_value
                 else:
@@ -825,7 +805,12 @@ class FromMultipleSources(
             resource_keys = resource_keys.union(source.required_resource_keys(pipeline_def))
         return resource_keys
 
-    def compute_version(self, step_versions, pipeline_def, resolved_run_config) -> Optional[str]:
+    def compute_version(
+        self,
+        step_versions: Mapping[str, Optional[str]],
+        pipeline_def: PipelineDefinition,
+        resolved_run_config: ResolvedRunConfig,
+    ) -> Optional[str]:
         return join_and_hash(
             *[
                 inner_source.compute_version(step_versions, pipeline_def, resolved_run_config)
@@ -833,26 +818,16 @@ class FromMultipleSources(
             ]
         )
 
-    def get_asset_lineage(
-        self, step_context: "StepExecutionContext", input_def: InputDefinition
-    ) -> Sequence[AssetLineageInfo]:
-        return [
-            relation
-            for source in self.sources
-            for relation in source.get_asset_lineage(step_context, input_def)
-        ]
 
-
-def _load_input_with_input_manager(input_manager: "InputManager", context: "InputContext"):
+def _load_input_with_input_manager(
+    input_manager: "InputManager", context: "InputContext"
+) -> Iterator[object]:
     from dagster._core.execution.context.system import StepExecutionContext
 
     step_context = cast(StepExecutionContext, context.step_context)
     with op_execution_error_boundary(
         DagsterExecutionLoadInputError,
-        msg_fn=lambda: (
-            f'Error occurred while loading input "{context.name}" of '
-            f'step "{step_context.step.key}":'
-        ),
+        msg_fn=lambda: f'Error occurred while loading input "{context.name}" of step "{step_context.step.key}":',
         step_context=step_context,
         step_key=step_context.step.key,
         input_name=context.name,
@@ -912,7 +887,7 @@ class FromPendingDynamicStepOutput(
     def resolved_by_output_name(self) -> str:
         return self.step_output_handle.output_name
 
-    def resolve(self, mapping_key) -> FromStepOutput:
+    def resolve(self, mapping_key: str) -> FromStepOutput:
         check.str_param(mapping_key, "mapping_key")
         return FromStepOutput(
             step_output_handle=StepOutputHandle(
@@ -1034,14 +1009,24 @@ class FromDynamicCollect(
     def required_resource_keys(self, _pipeline_def: PipelineDefinition) -> Set[str]:
         return set()
 
-    def resolve(self, mapping_keys):
+    def resolve(self, mapping_keys: Optional[Sequence[str]]):
+        if mapping_keys is None:
+            # None means that the dynamic output was skipped, so create
+            # a dependency on the dynamic output that will continue cascading the skip
+            return FromStepOutput(
+                step_output_handle=StepOutputHandle(
+                    step_key=self.resolved_by_step_key,
+                    output_name=self.resolved_by_output_name,
+                ),
+                fan_in=False,
+            )
         return FromMultipleSources(
             sources=[self.source.resolve(map_key) for map_key in mapping_keys],
         )
 
 
 class UnresolvedMappedStepInput(NamedTuple):
-    """Holds information for how to resolve a StepInput once the upstream mapping is done"""
+    """Holds information for how to resolve a StepInput once the upstream mapping is done."""
 
     name: str
     dagster_type_key: str
@@ -1063,13 +1048,13 @@ class UnresolvedMappedStepInput(NamedTuple):
         )
 
     def get_step_output_handle_deps_with_placeholders(self) -> Sequence[StepOutputHandle]:
-        """Return StepOutputHandles with placeholders, unresolved step keys and None mapping keys"""
-
+        """Return StepOutputHandles with placeholders, unresolved step keys and None mapping keys.
+        """
         return [self.source.get_step_output_handle_dep_with_placeholder()]
 
 
 class UnresolvedCollectStepInput(NamedTuple):
-    """Holds information for how to resolve a StepInput once the upstream mapping is done"""
+    """Holds information for how to resolve a StepInput once the upstream mapping is done."""
 
     name: str
     dagster_type_key: str
@@ -1083,7 +1068,7 @@ class UnresolvedCollectStepInput(NamedTuple):
     def resolved_by_output_name(self) -> str:
         return self.source.resolved_by_output_name
 
-    def resolve(self, mapping_keys: Sequence[str]) -> StepInput:
+    def resolve(self, mapping_keys: Optional[Sequence[str]]) -> StepInput:
         return StepInput(
             name=self.name,
             dagster_type_key=self.dagster_type_key,
@@ -1091,8 +1076,8 @@ class UnresolvedCollectStepInput(NamedTuple):
         )
 
     def get_step_output_handle_deps_with_placeholders(self) -> Sequence[StepOutputHandle]:
-        """Return StepOutputHandles with placeholders, unresolved step keys and None mapping keys"""
-
+        """Return StepOutputHandles with placeholders, unresolved step keys and None mapping keys.
+        """
         return [self.source.get_step_output_handle_dep_with_placeholder()]
 
 
@@ -1115,5 +1100,5 @@ class FromRootInputConfig(
     StepInputSource,
 ):
     """
-    DEPRECATED replaced by FromConfig with None node handle
+    DEPRECATED replaced by FromConfig with None node handle.
     """
