@@ -66,6 +66,8 @@ from .inputs import (
     FromUnresolvedStepOutput,
     StepInput,
     StepInputSource,
+    StepInputSourceUnion,
+    StepInputUnion,
     UnresolvedCollectStepInput,
     UnresolvedMappedStepInput,
 )
@@ -100,9 +102,9 @@ class _PlanBuilder:
 
     steps List[ExecutionStep]: a list of the execution steps that have been created.
 
-    step_output_map Dict[NodeOutput, StepOutputHandle]:  maps logical solid outputs
-    (solid_name, output_name) to particular step outputs. This covers the case where a solid maps to
-    multiple steps and one wants to be able to attach to the logical output of a solid during
+    step_output_map Dict[NodeOutput, StepOutputHandle]:  maps logical node outputs
+    (node_name, output_name) to particular step outputs. This covers the case where a node maps to
+    multiple steps and one wants to be able to attach to the logical output of a node during
     execution.
     """
 
@@ -162,9 +164,9 @@ class _PlanBuilder:
                 )
             )
         self._seen_handles.add(step.handle)
-        self._steps[step.solid_handle.to_string()] = step
+        self._steps[step.node_handle.to_string()] = step
 
-    def get_step_by_solid_handle(self, handle: NodeHandle) -> IExecutionStep:
+    def get_step_by_node_handle(self, handle: NodeHandle) -> IExecutionStep:
         check.inst_param(handle, "handle", NodeHandle)
         return self._steps[handle.to_string()]
 
@@ -217,7 +219,7 @@ class _PlanBuilder:
                 )
             )
 
-        self._build_from_sorted_solids(
+        self._build_from_sorted_nodes(
             pipeline_def.solids_in_topological_order,
             pipeline_def.dependency_structure,
             parent_step_inputs=root_inputs,
@@ -275,30 +277,26 @@ class _PlanBuilder:
 
         return plan
 
-    def _build_from_sorted_solids(
+    def _build_from_sorted_nodes(
         self,
-        solids: Sequence[Node],
+        nodes: Sequence[Node],
         dependency_structure: DependencyStructure,
         parent_handle: Optional[NodeHandle] = None,
-        parent_step_inputs: Optional[
-            Sequence[Union[StepInput, UnresolvedMappedStepInput, UnresolvedCollectStepInput]]
-        ] = None,
+        parent_step_inputs: Optional[Sequence[StepInputUnion]] = None,
     ) -> None:
         asset_layer = self.pipeline.get_definition().asset_layer
-        for solid in solids:
-            handle = NodeHandle(solid.name, parent_handle)
+        for node in nodes:
+            handle = NodeHandle(node.name, parent_handle)
 
             ### 1. INPUTS
-            # Create and add execution plan steps for solid inputs
+            # Create and add execution plan steps for node inputs
             has_unresolved_input = False
             has_pending_input = False
-            step_inputs: List[
-                Union[StepInput, UnresolvedMappedStepInput, UnresolvedCollectStepInput]
-            ] = []
-            for input_name, input_def in solid.definition.input_dict.items():
+            step_inputs: List[StepInputUnion] = []
+            for input_name, input_def in node.definition.input_dict.items():
                 step_input_source = get_step_input_source(
                     self,
-                    solid,
+                    node,
                     input_name,
                     input_def,
                     dependency_structure,
@@ -347,24 +345,24 @@ class _PlanBuilder:
                     )
 
             ### 2a. COMPUTE FUNCTION
-            # Create and add execution plan step for the solid compute function
-            if isinstance(solid.definition, OpDefinition):
+            # Create and add execution plan step for the op compute function
+            if isinstance(node.definition, OpDefinition):
                 step_outputs = create_step_outputs(
-                    solid, handle, self.resolved_run_config, asset_layer
+                    node, handle, self.resolved_run_config, asset_layer
                 )
 
                 if has_pending_input and has_unresolved_input:
                     check.failed("Can not have pending and unresolved step inputs")
 
                 elif has_unresolved_input:
-                    new_step: IExecutionStep = UnresolvedMappedExecutionStep(
+                    new_step = UnresolvedMappedExecutionStep(
                         handle=UnresolvedStepHandle(solid_handle=handle),
                         pipeline_name=self.pipeline_name,
                         step_inputs=cast(
                             List[Union[StepInput, UnresolvedMappedStepInput]], step_inputs
                         ),
                         step_outputs=step_outputs,
-                        tags=solid.tags,
+                        tags=node.tags,
                     )
                 elif has_pending_input:
                     new_step = UnresolvedCollectExecutionStep(
@@ -374,7 +372,7 @@ class _PlanBuilder:
                             List[Union[StepInput, UnresolvedCollectStepInput]], step_inputs
                         ),
                         step_outputs=step_outputs,
-                        tags=solid.tags,
+                        tags=node.tags,
                     )
                 else:
                     new_step = ExecutionStep(
@@ -382,17 +380,17 @@ class _PlanBuilder:
                         pipeline_name=self.pipeline_name,
                         step_inputs=cast(List[StepInput], step_inputs),
                         step_outputs=step_outputs,
-                        tags=solid.tags,
+                        tags=node.tags,
                     )
 
                 self.add_step(new_step)
 
             ### 2b. RECURSE
-            # Recurse over the solids contained in an instance of GraphDefinition
-            elif isinstance(solid.definition, GraphDefinition):
-                self._build_from_sorted_solids(
-                    solid.definition.solids_in_topological_order,
-                    solid.definition.dependency_structure,
+            # Recurse over the nodes contained in an instance of GraphDefinition
+            elif isinstance(node.definition, GraphDefinition):
+                self._build_from_sorted_nodes(
+                    node.definition.nodes_in_topological_order,
+                    node.definition.dependency_structure,
                     parent_handle=handle,
                     parent_step_inputs=step_inputs,
                 )
@@ -401,21 +399,21 @@ class _PlanBuilder:
                 check.invariant(
                     False,
                     "Unexpected solid type {type} encountered during execution planning".format(
-                        type=type(solid.definition)
+                        type=type(node.definition)
                     ),
                 )
 
             ### 3. OUTPUTS
-            # Create output handles for solid outputs
-            for name, output_def in solid.definition.output_dict.items():
-                node_output = solid.get_output(name)
+            # Create output handles for node outputs
+            for name, output_def in node.definition.output_dict.items():
+                node_output = node.get_output(name)
 
                 # Punch through layers of composition scope to map to the output of the
                 # actual compute step
-                resolved_output_def, resolved_handle = solid.definition.resolve_output_to_origin(
+                resolved_output_def, resolved_handle = node.definition.resolve_output_to_origin(
                     output_def.name, handle
                 )
-                step = self.get_step_by_solid_handle(check.not_none(resolved_handle))
+                step = self.get_step_by_node_handle(check.not_none(resolved_handle))
                 if isinstance(step, (ExecutionStep, UnresolvedCollectExecutionStep)):
                     step_output_handle: Union[
                         StepOutputHandle, UnresolvedStepOutputHandle
@@ -467,17 +465,15 @@ def get_root_graph_input_source(
 
 def get_step_input_source(
     plan_builder: _PlanBuilder,
-    solid: Node,
+    node: Node,
     input_name: str,
     input_def: InputDefinition,
     dependency_structure: DependencyStructure,
     handle: NodeHandle,
-    parent_step_inputs: Optional[
-        Sequence[Union[StepInput, UnresolvedMappedStepInput, UnresolvedCollectStepInput]]
-    ],
-):
+    parent_step_inputs: Optional[Sequence[StepInputUnion]],
+) -> Optional[StepInputSourceUnion]:
     check.inst_param(plan_builder, "plan_builder", _PlanBuilder)
-    check.inst_param(solid, "solid", Node)
+    check.inst_param(node, "node", Node)
     check.str_param(input_name, "input_name")
     check.inst_param(input_def, "input_def", InputDefinition)
     check.inst_param(dependency_structure, "dependency_structure", DependencyStructure)
@@ -488,10 +484,10 @@ def get_step_input_source(
         of_type=(StepInput, UnresolvedMappedStepInput, UnresolvedCollectStepInput),
     )
 
-    input_handle = solid.get_input(input_name)
-    solid_config = plan_builder.resolved_run_config.solids.get(str(handle))
+    input_handle = node.get_input(input_name)
+    node_config = plan_builder.resolved_run_config.ops.get(str(handle))
 
-    input_def = solid.definition.input_def_named(input_name)
+    input_def = node.definition.input_def_named(input_name)
     asset_layer = plan_builder.pipeline.get_definition().asset_layer
 
     if (
@@ -499,25 +495,23 @@ def get_step_input_source(
         not dependency_structure.has_deps(input_handle)
         and
         #  make sure input is unconnected in the outer dependency structure too
-        not solid.container_maps_input(input_handle.input_name)
+        not node.container_maps_input(input_handle.input_name)
     ):
         # can only load from source asset if assets defs are available
-        if asset_layer.has_assets_defs and asset_layer.asset_key_for_input(
-            handle, input_handle.input_name
-        ):
+        if asset_layer.asset_key_for_input(handle, input_handle.input_name):
             return FromSourceAsset(solid_handle=handle, input_name=input_name)
         elif input_def.root_manager_key or input_def.input_manager_key:
             return FromRootInputManager(solid_handle=handle, input_name=input_name)
 
     if dependency_structure.has_direct_dep(input_handle):
-        solid_output_handle = dependency_structure.get_direct_dep(input_handle)
-        step_output_handle = plan_builder.get_output_handle(solid_output_handle)
+        node_output_handle = dependency_structure.get_direct_dep(input_handle)
+        step_output_handle = plan_builder.get_output_handle(node_output_handle)
         if isinstance(step_output_handle, UnresolvedStepOutputHandle):
             return FromUnresolvedStepOutput(
                 unresolved_step_output_handle=step_output_handle,
             )
 
-        if solid_output_handle.output_def.is_dynamic:
+        if node_output_handle.output_def.is_dynamic:
             return FromPendingDynamicStepOutput(
                 step_output_handle=step_output_handle,
             )
@@ -556,7 +550,7 @@ def get_step_input_source(
                 if parent_step_inputs is None:
                     check.failed("unexpected error in composition descent during plan building")
 
-                parent_name = solid.container_mapped_fan_in_input(input_name, idx).graph_input_name
+                parent_name = node.container_mapped_fan_in_input(input_name, idx).graph_input_name
                 parent_inputs = {step_input.name: step_input for step_input in parent_step_inputs}
                 parent_input = parent_inputs[parent_name]
                 source = parent_input.source
@@ -567,36 +561,36 @@ def get_step_input_source(
         return FromMultipleSources(sources=sources)
 
     if dependency_structure.has_dynamic_fan_in_dep(input_handle):
-        solid_output_handle = dependency_structure.get_dynamic_fan_in_dep(input_handle)
-        step_output_handle = plan_builder.get_output_handle(solid_output_handle)
+        node_output_handle = dependency_structure.get_dynamic_fan_in_dep(input_handle)
+        step_output_handle = plan_builder.get_output_handle(node_output_handle)
         if isinstance(step_output_handle, UnresolvedStepOutputHandle):
             return FromDynamicCollect(
                 source=FromUnresolvedStepOutput(
                     unresolved_step_output_handle=step_output_handle,
                 ),
             )
-        elif solid_output_handle.output_def.is_dynamic:
+        elif node_output_handle.output_def.is_dynamic:
             return FromDynamicCollect(
                 source=FromPendingDynamicStepOutput(
                     step_output_handle=step_output_handle,
                 ),
             )
 
-    if solid_config and input_name in solid_config.inputs:
+    if node_config and input_name in node_config.inputs:
         return FromConfig(solid_handle=handle, input_name=input_name)
 
-    if solid.container_maps_input(input_name):
+    if node.container_maps_input(input_name):
         if parent_step_inputs is None:
             check.failed("unexpected error in composition descent during plan building")
 
-        parent_name = solid.container_mapped_input(input_name).graph_input_name
+        parent_name = node.container_mapped_input(input_name).graph_input_name
         parent_inputs = {step_input.name: step_input for step_input in parent_step_inputs}
         if parent_name in parent_inputs:
             parent_input = parent_inputs[parent_name]
             return parent_input.source
         # else fall through to Nothing case or raise
 
-    if solid.definition.input_has_default(input_name):
+    if node.definition.input_has_default(input_name):
         return FromDefaultValue(solid_handle=handle, input_name=input_name)
 
     # At this point we have an input that is not hooked up to
@@ -614,7 +608,7 @@ def get_step_input_source(
             "inputs section of its configuration."
         ).format(
             described_target=plan_builder.pipeline.get_definition().describe_target(),
-            described_node=solid.describe_node(),
+            described_node=node.describe_node(),
             input_name=input_name,
         )
     )
@@ -747,7 +741,7 @@ class ExecutionPlan(
         for step in self.step_dict.values():
             if isinstance(step, ExecutionStep):
                 deps[step.key] = step.get_execution_dependency_keys()
-            elif isinstance(step, UnresolvedMappedExecutionStep):
+            elif isinstance(step, (UnresolvedMappedExecutionStep, UnresolvedCollectExecutionStep)):
                 deps[step.key] = step.get_all_dependency_keys()
             else:
                 check.failed(f"Unexpected execution step type {step}")
@@ -792,7 +786,7 @@ class ExecutionPlan(
         step_keys_to_execute: Sequence[str],
         pipeline_def: PipelineDefinition,
         resolved_run_config: ResolvedRunConfig,
-        step_output_versions: Optional[Mapping[StepOutputHandle, str]] = None,
+        step_output_versions: Optional[Mapping[StepOutputHandle, Optional[str]]] = None,
     ) -> "ExecutionPlan":
         check.sequence_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
         step_output_versions = check.opt_mapping_param(
@@ -851,7 +845,7 @@ class ExecutionPlan(
         # If step output versions were provided when constructing the subset plan, add them to the
         # known state.
         if len(step_output_versions) > 0:
-            versions = StepOutputVersionData.get_version_list_from_dict(step_output_versions)
+            versions = StepOutputVersionData.get_version_list_from_dict(step_output_versions)  # type: ignore  # (possible none)
             if self.known_state:
                 known_state = self.known_state._replace(step_output_versions=versions)
             else:
@@ -1009,10 +1003,9 @@ class ExecutionPlan(
         # https://github.com/dagster-io/dagster/issues/2239
         if len(self.step_handles_to_execute) == 1:
             only_step = self.step_dict[self.step_handles_to_execute[0]]
-            check.invariant(
-                isinstance(only_step, ExecutionStep),
-                "Unexpected unresolved single step plan",
-            )
+            if not isinstance(only_step, ExecutionStep):
+                return None
+
             return cast(ExecutionStep, only_step).handle
 
         return None
@@ -1029,8 +1022,8 @@ class ExecutionPlan(
     ) -> "ExecutionPlan":
         """Here we build a new ExecutionPlan from a pipeline definition and the resolved run config.
 
-        To do this, we iterate through the pipeline's solids in topological order, and hand off the
-        execution steps for each solid to a companion _PlanBuilder object.
+        To do this, we iterate through the pipeline's nodes in topological order, and hand off the
+        execution steps for each node to a companion _PlanBuilder object.
 
         Once we've processed the entire pipeline, we invoke _PlanBuilder.build() to construct the
         ExecutionPlan object.
@@ -1064,7 +1057,9 @@ class ExecutionPlan(
         return plan_builder.build()
 
     @staticmethod
-    def rebuild_step_input(step_input_snap: "ExecutionStepInputSnap"):
+    def rebuild_step_input(
+        step_input_snap: "ExecutionStepInputSnap",
+    ) -> Union["StepInput", "UnresolvedMappedStepInput", "UnresolvedCollectStepInput"]:
         from dagster._core.snap.execution_plan_snapshot import ExecutionStepInputSnap
 
         check.inst_param(step_input_snap, "step_input_snap", ExecutionStepInputSnap)
@@ -1091,7 +1086,7 @@ class ExecutionPlan(
             return StepInput(
                 step_input_snap.name,
                 step_input_snap.dagster_type_key,
-                step_input_snap.source,
+                step_input_snap.source,  # type: ignore  # (possible none)
             )
 
     @staticmethod
@@ -1136,7 +1131,7 @@ class ExecutionPlan(
                         ttype=(StepHandle, ResolvedFromDynamicStepHandle),
                     ),
                     pipeline_name,
-                    step_inputs,  # type: ignore
+                    step_inputs,  # type: ignore  # (plain StepInput only)
                     step_outputs,
                     step_snap.tags,
                 )
@@ -1147,7 +1142,7 @@ class ExecutionPlan(
                         ttype=UnresolvedStepHandle,
                     ),
                     pipeline_name,
-                    step_inputs,  # type: ignore
+                    step_inputs,  # type: ignore  # (StepInput or UnresolvedMappedStepInput only)
                     step_outputs,
                     step_snap.tags,
                 )
@@ -1155,7 +1150,7 @@ class ExecutionPlan(
                 step = UnresolvedCollectExecutionStep(
                     check.inst(cast(StepHandle, step_snap.step_handle), ttype=StepHandle),
                     pipeline_name,
-                    step_inputs,  # type: ignore
+                    step_inputs,  # type: ignore  # (StepInput or UnresolvedCollectStepInput only)
                     step_outputs,
                     step_snap.tags,
                 )
@@ -1239,9 +1234,7 @@ def can_isolate_steps(pipeline_def: PipelineDefinition, mode_def: ModeDefinition
     # pylint: disable=comparison-with-callable
 
     output_defs = [
-        output_def
-        for solid_def in pipeline_def.all_node_defs
-        for output_def in solid_def.output_defs
+        output_def for node_def in pipeline_def.all_node_defs for output_def in node_def.output_defs
     ]
     for output_def in output_defs:
         if mode_def.resource_defs[output_def.io_manager_key] == mem_io_manager:
@@ -1385,14 +1378,6 @@ def _compute_artifacts_persisted(
     return True
 
 
-def _get_step_by_key(step_dict: Dict[StepHandleUnion, IExecutionStep], key: str) -> IExecutionStep:
-    check.str_param(key, "key")
-    for step in step_dict.values():
-        if step.key == key:
-            return step
-    check.failed(f"plan has no step with key {key}")
-
-
 def _get_steps_to_execute_by_level(
     step_dict: Mapping[StepHandleUnion, IExecutionStep],
     step_dict_by_key: Mapping[str, IExecutionStep],
@@ -1457,8 +1442,8 @@ def _get_manager_key(
     pipeline_def: PipelineDefinition,
 ) -> str:
     step_output = _get_step_output(step_dict_by_key, step_output_handle)
-    solid_handle = step_output.solid_handle
-    output_def = pipeline_def.get_solid(solid_handle).output_def_named(step_output.name)
+    node_handle = step_output.solid_handle
+    output_def = pipeline_def.get_solid(node_handle).output_def_named(step_output.name)
     return output_def.io_manager_key
 
 
@@ -1493,6 +1478,7 @@ def _compute_step_maps(
         )
 
     step_keys_to_execute = [step_handle.to_key() for step_handle in step_handles_to_execute]
+    past_mappings = known_state.dynamic_mappings if known_state else {}
 
     executable_map: Dict[str, Union[StepHandle, ResolvedFromDynamicStepHandle]] = {}
     resolvable_map: Dict[
@@ -1504,10 +1490,10 @@ def _compute_step_maps(
             executable_map[step.key] = step.handle
         elif isinstance(step, (UnresolvedMappedExecutionStep, UnresolvedCollectExecutionStep)):
             for key in step.resolved_by_step_keys:
-                if key not in step_keys_to_execute:
+                if key not in step_keys_to_execute and key not in past_mappings:
                     raise DagsterInvariantViolationError(
-                        f'Unresolved ExecutionStep "{step.key}" is resolved by "{key}" '
-                        "which is not part of the current step selection"
+                        f'Unresolved ExecutionStep "{step.key}" is resolved by "{key}" which is not'
+                        " part of the current step selection or known state from parent run."
                     )
 
             resolvable_map[step.resolved_by_step_keys].append(step.handle)
@@ -1516,14 +1502,14 @@ def _compute_step_maps(
                 step.key in executable_map, "Expect all steps to be executable or resolvable"
             )
 
-    if known_state:
+    if past_mappings:
         _update_from_resolved_dynamic_outputs(
             step_dict,
             step_dict_by_key,
             executable_map,
             dict(resolvable_map),
             step_handles_to_execute,
-            known_state.dynamic_mappings,
+            past_mappings,
         )
 
     return (executable_map, dict(resolvable_map))
