@@ -3,6 +3,7 @@ from enum import Enum
 from typing import (
     TYPE_CHECKING,
     FrozenSet,
+    List,
     Mapping,
     NamedTuple,
     Optional,
@@ -18,15 +19,14 @@ from typing_extensions import TypeGuard
 import dagster._check as check
 from dagster._core.definitions.utils import validate_tags
 from dagster._serdes.serdes import DefaultEnumSerializer, whitelist_for_serdes
-from dagster._utils import merge_dicts
+from dagster._utils.merger import merge_dicts
 
 from .handle import ResolvedFromDynamicStepHandle, StepHandle, UnresolvedStepHandle
 from .inputs import StepInput, UnresolvedCollectStepInput, UnresolvedMappedStepInput
 from .outputs import StepOutput
 
 if TYPE_CHECKING:
-    from dagster._core.definitions.dependency import Node, NodeHandle
-    from dagster._core.definitions.hook_definition import HookDefinition
+    from dagster._core.definitions.dependency import NodeHandle
 
 
 class StepKindSerializer(DefaultEnumSerializer):
@@ -72,7 +72,7 @@ class IExecutionStep:
 
     @property
     @abstractmethod
-    def solid_handle(self) -> "NodeHandle":
+    def node_handle(self) -> "NodeHandle":
         pass
 
     @property
@@ -173,12 +173,12 @@ class ExecutionStep(
         )
 
     @property
-    def solid_handle(self) -> "NodeHandle":
+    def node_handle(self) -> "NodeHandle":
         return self.handle.solid_handle
 
     @property
     def solid_name(self) -> str:
-        return self.solid_handle.name
+        return self.node_handle.name
 
     @property
     def kind(self) -> StepKind:
@@ -214,14 +214,14 @@ class ExecutionStep(
             deps.update(inp.dependency_keys)
         return deps
 
-    def get_mapping_key(self):
+    def get_mapping_key(self) -> Optional[str]:
         if isinstance(self.handle, ResolvedFromDynamicStepHandle):
             return self.handle.mapping_key
 
         return None
 
 
-class UnresolvedMappedExecutionStep(  # type: ignore
+class UnresolvedMappedExecutionStep(
     NamedTuple(
         "_UnresolvedMappedExecutionStep",
         [
@@ -264,7 +264,7 @@ class UnresolvedMappedExecutionStep(  # type: ignore
         )
 
     @property
-    def solid_handle(self) -> "NodeHandle":
+    def node_handle(self) -> "NodeHandle":
         return self.handle.solid_handle
 
     @property
@@ -341,15 +341,21 @@ class UnresolvedMappedExecutionStep(  # type: ignore
         return frozenset(keys)
 
     def resolve(
-        self, mappings: Mapping[str, Mapping[str, Sequence[str]]]
+        self, mappings: Mapping[str, Mapping[str, Optional[Sequence[str]]]]
     ) -> Sequence[ExecutionStep]:
         check.invariant(
             all(key in mappings for key in self.resolved_by_step_keys),
             "resolving with mappings that do not contain all required step keys",
         )
-        execution_steps = []
+        execution_steps: List[ExecutionStep] = []
 
-        for mapped_key in mappings[self.resolved_by_step_key][self.resolved_by_output_name]:
+        mapping_keys = mappings[self.resolved_by_step_key][self.resolved_by_output_name]
+
+        # dynamic output skipped
+        if mapping_keys is None:
+            return execution_steps
+
+        for mapped_key in mapping_keys:
             resolved_inputs = [_resolved_input(inp, mapped_key) for inp in self.step_inputs]
 
             execution_steps.append(
@@ -375,7 +381,7 @@ def _resolved_input(
     return step_input.resolve(map_key)
 
 
-class UnresolvedCollectExecutionStep(  # type: ignore
+class UnresolvedCollectExecutionStep(
     NamedTuple(
         "_UnresolvedCollectExecutionStep",
         [
@@ -418,7 +424,7 @@ class UnresolvedCollectExecutionStep(  # type: ignore
         )
 
     @property
-    def solid_handle(self) -> "NodeHandle":
+    def node_handle(self) -> "NodeHandle":
         return self.handle.solid_handle
 
     @property
@@ -473,7 +479,9 @@ class UnresolvedCollectExecutionStep(  # type: ignore
 
         return frozenset(keys)
 
-    def resolve(self, mappings: Mapping[str, Mapping[str, Sequence[str]]]) -> ExecutionStep:
+    def resolve(
+        self, mappings: Mapping[str, Mapping[str, Optional[Sequence[str]]]]
+    ) -> ExecutionStep:
         check.invariant(
             all(key in mappings for key in self.resolved_by_step_keys),
             "resolving with mappings that do not contain all required step keys",
