@@ -103,7 +103,7 @@ class GraphExecutionResult:
             Union[CompositeSolidExecutionResult, SolidExecutionResult]: The result of the solid
             execution within the pipeline.
         """
-        if not self.container.has_solid_named(name):
+        if not self.container.has_node_named(name):
             raise DagsterInvariantViolationError(
                 "Tried to get result for solid '{name}' in '{container}'. No such top level "
                 "solid.".format(name=name, container=self.container.name)
@@ -132,7 +132,7 @@ class GraphExecutionResult:
         """List[Union[CompositeSolidExecutionResult, SolidExecutionResult]]: The results for each
         top level solid.
         """
-        return [self.result_for_node(node.name) for node in self.container.solids]
+        return [self.result_for_node(node.name) for node in self.container.nodes]
 
     def _result_for_handle(
         self, node: Node, handle: NodeHandle
@@ -199,7 +199,7 @@ class GraphExecutionResult:
         else:
             check.inst_param(handle, "handle", NodeHandle)
 
-        node = self.container.get_solid(handle)
+        node = self.container.get_node(handle)
 
         return self._result_for_handle(node, handle)
 
@@ -292,8 +292,8 @@ class CompositeSolidExecutionResult(GraphExecutionResult):
             output_mapping = self.node.definition.get_output_mapping(output_name)
 
             inner_solid_values = self._result_for_handle(
-                self.node.definition.solid_named(output_mapping.maps_from.solid_name),
-                NodeHandle(output_mapping.maps_from.solid_name, None),
+                self.node.definition.node_named(output_mapping.maps_from.node_name),
+                NodeHandle(output_mapping.maps_from.node_name, None),
             ).output_values
 
             if inner_solid_values is not None:  # may be None if inner solid was skipped
@@ -323,8 +323,8 @@ class CompositeSolidExecutionResult(GraphExecutionResult):
         output_mapping = self.node.definition.get_output_mapping(output_name)
 
         return self._result_for_handle(
-            self.node.definition.solid_named(output_mapping.maps_from.solid_name),
-            NodeHandle(output_mapping.maps_from.solid_name, None),
+            self.node.definition.node_named(output_mapping.maps_from.node_name),
+            NodeHandle(output_mapping.maps_from.node_name, None),
         ).output_value(output_mapping.maps_from.output_name)
 
 
