@@ -2,8 +2,11 @@ from collections import defaultdict
 from enum import Enum
 from typing import Mapping, Optional
 
-from dagster import Field, Selector
-from dagster import _check as check
+from dagster import (
+    Field,
+    Selector,
+    _check as check,
+)
 from dagster._serdes.serdes import whitelist_for_serdes
 
 
