@@ -2,6 +2,7 @@ from typing import Any, Mapping, Optional, cast
 
 import dagster._check as check
 from dagster._core.definitions import JobDefinition, PipelineDefinition
+from dagster._core.definitions.run_config import convert_config_input
 from dagster._core.system_config.objects import ResolvedRunConfig
 
 
@@ -28,10 +29,11 @@ def validate_run_config(
     Returns:
         Dict[str, Any]: A dictionary representation of the validated config.
     """
-
     job_def = check.opt_inst_param(job_def, "job_def", (JobDefinition, PipelineDefinition))
     pipeline_def = check.opt_inst_param(pipeline_def, "pipeline_def", PipelineDefinition)
-    run_config = check.opt_mapping_param(run_config, "run_config", key_type=str)
+    run_config = check.opt_mapping_param(
+        convert_config_input(run_config), "run_config", key_type=str
+    )
 
     if job_def and pipeline_def:
         check.failed("Cannot specify both a job_def and a pipeline_def")
