@@ -4,8 +4,10 @@ import sys
 from multiprocessing.context import BaseContext as MultiprocessingBaseContext
 from typing import Any, Dict, Iterator, List, Optional, Sequence
 
-from dagster import MetadataEntry
-from dagster import _check as check
+from dagster import (
+    MetadataEntry,
+    _check as check,
+)
 from dagster._core.definitions.reconstruct import ReconstructablePipeline
 from dagster._core.definitions.repository_definition import RepositoryLoadData
 from dagster._core.errors import (
@@ -25,7 +27,7 @@ from dagster._core.execution.plan.step import ExecutionStep
 from dagster._core.execution.retries import RetryMode
 from dagster._core.executor.base import Executor
 from dagster._core.instance import DagsterInstance
-from dagster._utils import start_termination_thread
+from dagster._utils import get_run_crash_explanation, start_termination_thread
 from dagster._utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
 from dagster._utils.timing import format_duration, time_execution_scope
 
@@ -126,8 +128,10 @@ class MultiprocessExecutor(Executor):
 
         if start_method not in valid_starts:
             raise DagsterUnmetExecutorRequirementsError(
-                f"The selected start_method '{start_method}' is not available. "
-                f"Only {valid_starts} are valid options on {sys.platform} python {sys.version}.",
+                (
+                    f"The selected start_method '{start_method}' is not available. "
+                    f"Only {valid_starts} are valid options on {sys.platform} python {sys.version}."
+                ),
             )
         self._start_method = start_method
         self._explicit_forkserver_preload = explicit_forkserver_preload
@@ -186,7 +190,7 @@ class MultiprocessExecutor(Executor):
                 max_concurrent=limit,
                 tag_concurrency_limits=tag_concurrency_limits,
             ) as active_execution:
-                active_iters: Dict[str, Iterator[DagsterEvent]] = {}
+                active_iters: Dict[str, Iterator[Optional[DagsterEvent]]] = {}
                 errors: Dict[int, SerializableErrorInfo] = {}
                 term_events: Dict[str, Any] = {}
                 stopping: bool = False
@@ -195,8 +199,10 @@ class MultiprocessExecutor(Executor):
                     if active_execution.check_for_interrupts():
                         yield DagsterEvent.engine_event(
                             plan_context,
-                            "Multiprocess executor: received termination signal - "
-                            "forwarding to active child processes",
+                            (
+                                "Multiprocess executor: received termination signal - "
+                                "forwarding to active child processes"
+                            ),
                             EngineEventData.interrupted(list(term_events.keys())),
                         )
                         stopping = True
@@ -247,10 +253,10 @@ class MultiprocessExecutor(Executor):
                             )
                             yield DagsterEvent.engine_event(
                                 step_context,
-                                (
-                                    "Multiprocess executor: child process for step {step_key} "
-                                    "unexpectedly exited with code {exit_code}"
-                                ).format(step_key=key, exit_code=crash.exit_code),
+                                get_run_crash_explanation(
+                                    prefix=f"Multiprocess executor: child process for step {key}",
+                                    exit_code=crash.exit_code,
+                                ),
                                 EngineEventData.engine_error(serializable_error),
                             )
                             step_failure_event = DagsterEvent.step_failure_event(
@@ -298,7 +304,8 @@ class MultiprocessExecutor(Executor):
                     raise DagsterExecutionInterruptedError()
                 elif errs:
                     raise DagsterSubprocessError(
-                        "During multiprocess execution errors occurred in child processes:\n{error_list}".format(
+                        "During multiprocess execution errors occurred in child"
+                        " processes:\n{error_list}".format(
                             error_list="\n".join(
                                 [
                                     "In process {pid}: {err}".format(pid=pid, err=err.to_string())
@@ -328,10 +335,10 @@ def execute_step_out_of_process(
     retries: RetryMode,
     known_state: KnownExecutionState,
     repository_load_data: Optional[RepositoryLoadData],
-) -> Iterator[DagsterEvent]:
+) -> Iterator[Optional[DagsterEvent]]:
     command = MultiprocessExecutorChildProcessCommand(
         run_config=step_context.run_config,
-        pipeline_run=step_context.pipeline_run,
+        pipeline_run=step_context.dagster_run,
         step_key=step.key,
         instance_ref=step_context.instance.get_ref(),
         term_event=term_events[step.key],
