@@ -84,14 +84,14 @@ class StepDelegatingExecutor(Executor):
             steps=steps,
             execute_step_args=ExecuteStepArgs(
                 pipeline_origin=plan_context.reconstructable_pipeline.get_python_origin(),
-                pipeline_run_id=plan_context.pipeline_run.run_id,
+                pipeline_run_id=plan_context.dagster_run.run_id,
                 step_keys_to_execute=[step.key for step in steps],
                 instance_ref=plan_context.plan_data.instance.get_ref(),
                 retry_mode=self.retries.for_inner_plan(),
                 known_state=active_execution.get_known_state(),
                 should_verify_step=self._should_verify_step,
             ),
-            pipeline_run=plan_context.pipeline_run,
+            dagster_run=plan_context.dagster_run,
         )
 
     def execute(self, plan_context: PlanOrchestrationContext, execution_plan: ExecutionPlan):
@@ -225,7 +225,7 @@ class StepDelegatingExecutor(Executor):
                 for dagster_event in self._pop_events(
                     plan_context.instance,
                     plan_context.run_id,
-                ):  # type: ignore
+                ):
                     yield dagster_event
                     # STEP_SKIPPED events are only emitted by ActiveExecution, which already handles
                     # and yields them.
