@@ -29,6 +29,7 @@ from .external_data import (
     ExternalPipelineSubsetResult as ExternalPipelineSubsetResult,
     ExternalPresetData as ExternalPresetData,
     ExternalRepositoryData as ExternalRepositoryData,
+    ExternalRepositoryErrorData as ExternalRepositoryErrorData,
     ExternalScheduleData as ExternalScheduleData,
     ExternalScheduleExecutionErrorData as ExternalScheduleExecutionErrorData,
     ExternalSensorExecutionErrorData as ExternalSensorExecutionErrorData,
@@ -58,12 +59,3 @@ from .repository_location import (
     RepositoryLocation as RepositoryLocation,
 )
 from .represented import RepresentedPipeline as RepresentedPipeline
-from .selector import (
-    GraphSelector as GraphSelector,
-    InstigatorSelector as InstigatorSelector,
-    JobSelector as JobSelector,
-    PipelineSelector as PipelineSelector,
-    RepositorySelector as RepositorySelector,
-    ScheduleSelector as ScheduleSelector,
-    SensorSelector as SensorSelector,
-)
