@@ -7,6 +7,7 @@ from typing import (
     AbstractSet,
     Callable,
     Dict,
+    Iterable,
     Iterator,
     List,
     Mapping,
@@ -16,13 +17,23 @@ from typing import (
 )
 
 import dagster._check as check
+from dagster._config.snap import ConfigFieldSnap, ConfigSchemaSnapshot
 from dagster._core.definitions.events import AssetKey
-from dagster._core.definitions.metadata import MetadataEntry, PartitionMetadataEntry
+from dagster._core.definitions.metadata import (
+    MetadataEntry,
+)
 from dagster._core.definitions.run_request import InstigatorType
 from dagster._core.definitions.schedule_definition import DefaultScheduleStatus
+from dagster._core.definitions.selector import (
+    InstigatorSelector,
+    RepositorySelector,
+    ScheduleSelector,
+    SensorSelector,
+)
 from dagster._core.definitions.sensor_definition import (
     DEFAULT_SENSOR_DAEMON_INTERVAL,
     DefaultSensorStatus,
+    SensorType,
 )
 from dagster._core.execution.plan.handle import ResolvedFromDynamicStepHandle, StepHandle
 from dagster._core.host_representation.origin import (
@@ -47,6 +58,7 @@ from .external_data import (
     ExternalPipelineData,
     ExternalPresetData,
     ExternalRepositoryData,
+    ExternalResourceData,
     ExternalScheduleData,
     ExternalSensorData,
     ExternalSensorMetadata,
@@ -55,7 +67,6 @@ from .external_data import (
 from .handle import InstigatorHandle, JobHandle, PartitionSetHandle, RepositoryHandle
 from .pipeline_index import PipelineIndex
 from .represented import RepresentedPipeline
-from .selector import InstigatorSelector, RepositorySelector
 
 if TYPE_CHECKING:
     from dagster._core.scheduler.instigation import InstigatorState
@@ -132,6 +143,25 @@ class ExternalRepository:
     def get_external_schedules(self) -> Sequence[ExternalSchedule]:
         return iter_to_list(self._external_schedules.values())
 
+    @property
+    @cached_method
+    def _external_resources(self) -> Dict[str, ExternalResource]:
+        return {
+            external_resource_data.name: ExternalResource(external_resource_data, self._handle)
+            for external_resource_data in (
+                self.external_repository_data.external_resource_data or []
+            )
+        }
+
+    def has_external_resource(self, resource_name: str) -> bool:
+        return resource_name in self._external_resources
+
+    def get_external_resource(self, resource_name: str) -> ExternalResource:
+        return self._external_resources[resource_name]
+
+    def get_external_resources(self) -> Iterable[ExternalResource]:
+        return self._external_resources.values()
+
     @property
     @cached_method
     def _external_sensors(self) -> Dict[str, ExternalSensor]:
@@ -225,7 +255,9 @@ class ExternalRepository:
         """
         return self.get_external_origin().get_id()
 
-    def get_external_asset_nodes(self, job_name=None) -> Sequence[ExternalAssetNode]:
+    def get_external_asset_nodes(
+        self, job_name: Optional[str] = None
+    ) -> Sequence[ExternalAssetNode]:
         return (
             self.external_repository_data.external_asset_graph_data
             if job_name is None
@@ -296,7 +328,7 @@ class ExternalPipeline(RepresentedPipeline):
                     self.external_pipeline_data.pipeline_snapshot,
                     self.external_pipeline_data.parent_pipeline_snapshot,
                 )
-            return self._index  # type: ignore
+            return self._index
 
     @property
     def name(self) -> str:
@@ -390,7 +422,7 @@ class ExternalPipeline(RepresentedPipeline):
         return self._pipeline_index.pipeline_snapshot.tags
 
     @property
-    def metadata(self) -> Sequence[Union[MetadataEntry, PartitionMetadataEntry]]:
+    def metadata(self) -> Sequence[MetadataEntry]:
         return self._pipeline_index.pipeline_snapshot.metadata
 
     @property
@@ -508,6 +540,40 @@ class ExternalExecutionPlan:
         return self._topological_step_levels
 
 
+class ExternalResource:
+    """
+    Represents a top-level resource in a repository, e.g. one passed through the Definitions API.
+    """
+
+    def __init__(self, external_resource_data: ExternalResourceData, handle: RepositoryHandle):
+        self._external_resource_data = check.inst_param(
+            external_resource_data, "external_resource_data", ExternalResourceData
+        )
+        self._handle = InstigatorHandle(
+            self._external_resource_data.name, check.inst_param(handle, "handle", RepositoryHandle)
+        )
+
+    @property
+    def name(self) -> str:
+        return self._external_resource_data.name
+
+    @property
+    def description(self) -> Optional[str]:
+        return self._external_resource_data.resource_snapshot.description
+
+    @property
+    def config_field_snaps(self) -> List[ConfigFieldSnap]:
+        return self._external_resource_data.config_field_snaps
+
+    @property
+    def configured_values(self) -> Dict[str, str]:
+        return self._external_resource_data.configured_values
+
+    @property
+    def config_schema_snap(self) -> ConfigSchemaSnapshot:
+        return self._external_resource_data.config_schema_snap
+
+
 class ExternalSchedule:
     def __init__(self, external_schedule_data: ExternalScheduleData, handle: RepositoryHandle):
         self._external_schedule_data = check.inst_param(
@@ -571,6 +637,14 @@ class ExternalSchedule:
             self._external_schedule_data.name,
         )
 
+    @property
+    def schedule_selector(self) -> ScheduleSelector:
+        return ScheduleSelector(
+            self.handle.location_name,
+            self.handle.repository_name,
+            self._external_schedule_data.name,
+        )
+
     @property
     def selector_id(self) -> str:
         return create_snapshot_id(self.selector)
@@ -617,9 +691,11 @@ class ExternalSchedule:
                 ScheduleInstigatorData(self.cron_schedule, start_timestamp=None),
             )
 
-    def execution_time_iterator(self, start_timestamp: float) -> Iterator[datetime]:
+    def execution_time_iterator(
+        self, start_timestamp: float, ascending: bool = True
+    ) -> Iterator[datetime]:
         return schedule_execution_time_iterator(
-            start_timestamp, self.cron_schedule, self.execution_timezone
+            start_timestamp, self.cron_schedule, self.execution_timezone, ascending
         )
 
 
@@ -697,10 +773,22 @@ class ExternalSensor:
             self._external_sensor_data.name,
         )
 
+    @property
+    def sensor_selector(self) -> SensorSelector:
+        return SensorSelector(
+            self.handle.location_name,
+            self.handle.repository_name,
+            self._external_sensor_data.name,
+        )
+
     @property
     def selector_id(self) -> str:
         return create_snapshot_id(self.selector)
 
+    @property
+    def sensor_type(self) -> SensorType:
+        return self._external_sensor_data.sensor_type or SensorType.UNKNOWN
+
     def get_current_instigator_state(
         self, stored_state: Optional["InstigatorState"]
     ) -> InstigatorState:
