@@ -1,18 +1,31 @@
+from __future__ import annotations
+
 import sys
 import threading
 import uuid
-from abc import abstractmethod
 from contextlib import AbstractContextManager
-from typing import TYPE_CHECKING, Generic, NamedTuple, Optional, TypeVar, Union, cast
+from typing import (
+    TYPE_CHECKING,
+    Dict,
+    List,
+    NamedTuple,
+    Optional,
+    TypeVar,
+    Union,
+    cast,
+)
 
 import pendulum
+from typing_extensions import TypeGuard
 
 import dagster._check as check
 from dagster._core.errors import DagsterUserCodeProcessError
 from dagster._core.host_representation.origin import (
+    GrpcServerRepositoryLocationOrigin,
     ManagedGrpcPythonEnvRepositoryLocationOrigin,
     RepositoryLocationOrigin,
 )
+from dagster._core.instance import DagsterInstance
 from dagster._core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster._grpc.server import GrpcServerProcess
 from dagster._utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
@@ -32,7 +45,7 @@ class GrpcServerEndpoint(
         ],
     )
 ):
-    def __new__(cls, server_id, host, port, socket):
+    def __new__(cls, server_id: str, host: str, port: Optional[int], socket: Optional[str]):
         return super(GrpcServerEndpoint, cls).__new__(
             cls,
             check.str_param(server_id, "server_id"),
@@ -47,79 +60,51 @@ class GrpcServerEndpoint(
         return DagsterGrpcClient(port=self.port, socket=self.socket, host=self.host)
 
 
-T = TypeVar("T")
+T_GrpcRepositoryLocationOrigin = TypeVar(
+    "T_GrpcRepositoryLocationOrigin",
+    GrpcServerRepositoryLocationOrigin,
+    ManagedGrpcPythonEnvRepositoryLocationOrigin,
+    # default=ManagedGrpcPythonEnvRepositoryLocationOrigin,
+)
 
 
-# Daemons in different threads can use a shared GrpcServerRegistry to ensure that
-# a single GrpcServerProcess is created for each origin
-class GrpcServerRegistry(AbstractContextManager, Generic[T]):
-    @abstractmethod
-    def supports_origin(self, repository_location_origin: RepositoryLocationOrigin) -> bool:
-        pass
-
-    @abstractmethod
-    def get_grpc_endpoint(self, repository_location_origin: T) -> GrpcServerEndpoint:
-        pass
-
-    @abstractmethod
-    def reload_grpc_endpoint(self, repository_location_origin: T) -> GrpcServerEndpoint:
-        pass
-
-    @property
-    @abstractmethod
-    def supports_reload(self) -> bool:
-        pass
+class ServerRegistryEntry(NamedTuple):
+    loadable_target_origin: LoadableTargetOrigin
+    creation_timestamp: float
+    process: GrpcServerProcess
+    server_id: str
 
 
-class ProcessRegistryEntry(
-    NamedTuple(
-        "_ProcessRegistryEntry",
-        [
-            ("process_or_error", Union[GrpcServerProcess, SerializableErrorInfo]),
-            ("loadable_target_origin", LoadableTargetOrigin),
-            ("creation_timestamp", float),
-            ("server_id", Optional[str]),
-        ],
-    )
-):
-    def __new__(cls, process_or_error, loadable_target_origin, creation_timestamp, server_id):
-        return super(ProcessRegistryEntry, cls).__new__(
-            cls,
-            check.inst_param(
-                process_or_error, "process_or_error", (GrpcServerProcess, SerializableErrorInfo)
-            ),
-            check.inst_param(
-                loadable_target_origin, "loadable_target_origin", LoadableTargetOrigin
-            ),
-            check.float_param(creation_timestamp, "creation_timestamp"),
-            check.opt_str_param(server_id, "server_id"),
-        )
+class ErrorRegistryEntry(NamedTuple):
+    loadable_target_origin: LoadableTargetOrigin
+    creation_timestamp: float
+    error: SerializableErrorInfo
 
 
-# GrpcServerRegistry that creates local gRPC python processes from
-# ManagedGrpcPythonEnvRepositoryLocationOrigins and shares them between threads.
-class ProcessGrpcServerRegistry(GrpcServerRegistry):
+# Creates local gRPC python processes from ManagedGrpcPythonEnvRepositoryLocationOrigins and shares
+# them between threads.
+class GrpcServerRegistry(AbstractContextManager):
     def __init__(
         self,
-        instance,
+        instance: DagsterInstance,
         # How long each process should run before a new process should be created the next
         # time a given origin is requested (which will pick up any changes that have been
         # made to the code)
-        reload_interval,
+        reload_interval: int,
         # How long the process can live without a heartbeat before it dies. You should ensure
         # that either heartbeat_ttl is greater than reload_interval (so that the process will reload
         # before it ends due to heartbeat failure), or if reload_interval is 0, that any processes
         # returned by this registry have at least one GrpcServerRepositoryLocation hitting the
         # server with a heartbeat while you want the process to stay running.
-        heartbeat_ttl,
+        heartbeat_ttl: int,
         # How long to wait for the server to start up and receive connections before timing out
-        startup_timeout,
-        log_level="INFO",
+        startup_timeout: int,
+        log_level: str = "INFO",
     ):
         self.instance = instance
 
-        # ProcessRegistryEntry map of servers being currently returned, keyed by origin ID
-        self._active_entries = {}
+        # map of servers being currently returned, keyed by origin ID
+        self._active_entries: Dict[str, Union[ServerRegistryEntry, ErrorRegistryEntry]] = {}
 
         self._waited_for_processes = False
 
@@ -137,10 +122,10 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
 
         self._lock = threading.Lock()
 
-        self._all_processes = []
+        self._all_processes: List[GrpcServerProcess] = []
 
-        self._cleanup_thread_shutdown_event = None
-        self._cleanup_thread = None
+        self._cleanup_thread_shutdown_event: Optional[threading.Event] = None
+        self._cleanup_thread: Optional[threading.Thread] = None
 
         self._log_level = check.str_param(log_level, "log_level")
 
@@ -155,11 +140,13 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
             self._cleanup_thread.daemon = True
             self._cleanup_thread.start()
 
-    def supports_origin(self, repository_location_origin):
+    def supports_origin(
+        self, repository_location_origin: RepositoryLocationOrigin
+    ) -> TypeGuard[ManagedGrpcPythonEnvRepositoryLocationOrigin]:
         return isinstance(repository_location_origin, ManagedGrpcPythonEnvRepositoryLocationOrigin)
 
     @property
-    def supports_reload(self):
+    def supports_reload(self) -> bool:
         return True
 
     def reload_grpc_endpoint(
@@ -189,7 +176,7 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
 
     def _get_loadable_target_origin(
         self, repository_location_origin: ManagedGrpcPythonEnvRepositoryLocationOrigin
-    ):
+    ) -> LoadableTargetOrigin:
         check.inst_param(
             repository_location_origin,
             "repository_location_origin",
@@ -214,7 +201,6 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
             active_entry = self._active_entries[origin_id]
             refresh_server = loadable_target_origin != active_entry.loadable_target_origin
 
-        server_process: Union[GrpcServerProcess, SerializableErrorInfo]
         new_server_id: Optional[str]
         if refresh_server:
             try:
@@ -230,36 +216,38 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
                     log_level=self._log_level,
                 )
                 self._all_processes.append(server_process)
+                self._active_entries[origin_id] = ServerRegistryEntry(
+                    process=server_process,
+                    loadable_target_origin=loadable_target_origin,
+                    creation_timestamp=pendulum.now("UTC").timestamp(),
+                    server_id=new_server_id,
+                )
             except Exception:
-                server_process = serializable_error_info_from_exc_info(sys.exc_info())
-                new_server_id = None
-
-            self._active_entries[origin_id] = ProcessRegistryEntry(
-                process_or_error=server_process,
-                loadable_target_origin=loadable_target_origin,
-                creation_timestamp=pendulum.now("UTC").timestamp(),
-                server_id=new_server_id,
-            )
+                self._active_entries[origin_id] = ErrorRegistryEntry(
+                    error=serializable_error_info_from_exc_info(sys.exc_info()),
+                    loadable_target_origin=loadable_target_origin,
+                    creation_timestamp=pendulum.now("UTC").timestamp(),
+                )
 
         active_entry = self._active_entries[origin_id]
 
-        if isinstance(active_entry.process_or_error, SerializableErrorInfo):
+        if isinstance(active_entry, ErrorRegistryEntry):
             raise DagsterUserCodeProcessError(
-                active_entry.process_or_error.to_string(),
-                user_code_process_error_infos=[active_entry.process_or_error],
+                active_entry.error.to_string(),
+                user_code_process_error_infos=[active_entry.error],
             )
 
         return GrpcServerEndpoint(
             server_id=active_entry.server_id,
             host="localhost",
-            port=active_entry.process_or_error.port,
-            socket=active_entry.process_or_error.socket,
+            port=active_entry.process.port,
+            socket=active_entry.process.socket,
         )
 
     # Clear out processes from the map periodically so that they'll be re-created the next
     # time the origins are requested. Lack of any heartbeats will ensure that the server will
     # eventually die once they're no longer being held by any threads.
-    def _clear_old_processes(self, shutdown_event, reload_interval):
+    def _clear_old_processes(self, shutdown_event: threading.Event, reload_interval: int) -> None:
         while True:
             shutdown_event.wait(5)
             if shutdown_event.is_set():
@@ -267,7 +255,7 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
 
             current_time = pendulum.now("UTC").timestamp()
             with self._lock:
-                origin_ids_to_clear = []
+                origin_ids_to_clear: List[str] = []
 
                 for origin_id, entry in self._active_entries.items():
                     if (
@@ -279,7 +267,7 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
                     del self._active_entries[origin_id]
 
                 # Remove any dead processes from the all_processes map
-                dead_process_indexes = []
+                dead_process_indexes: List[int] = []
                 for index in range(len(self._all_processes)):
                     process = self._all_processes[index]
                     if process.server_process.poll() is not None:
@@ -296,7 +284,7 @@ class ProcessGrpcServerRegistry(GrpcServerRegistry):
         for process in self._all_processes:
             process.create_ephemeral_client().cleanup_server()
 
-    def wait_for_processes(self):
+    def wait_for_processes(self) -> None:
         # Wait for any processes created by this registry. Generally not needed outside
         # of tests, since the processes have heartbeats and will end on their own once
         # they finish any outstanding executions.
