@@ -32,6 +32,7 @@ from typing import (
 )
 
 import yaml
+from typing_extensions import Protocol, runtime_checkable
 
 import dagster._check as check
 from dagster._annotations import public
@@ -43,6 +44,7 @@ from dagster._core.definitions.pipeline_definition import (
 )
 from dagster._core.errors import (
     DagsterHomeNotSetError,
+    DagsterInvalidInvocationError,
     DagsterInvariantViolationError,
     DagsterRunAlreadyExists,
     DagsterRunConflict,
@@ -59,7 +61,14 @@ from dagster._core.storage.pipeline_run import (
     RunsFilter,
     TagBucket,
 )
-from dagster._core.storage.tags import PARENT_RUN_ID_TAG, RESUME_RETRY_TAG, ROOT_RUN_ID_TAG
+from dagster._core.storage.tags import (
+    ASSET_PARTITION_RANGE_END_TAG,
+    ASSET_PARTITION_RANGE_START_TAG,
+    PARENT_RUN_ID_TAG,
+    PARTITION_NAME_TAG,
+    RESUME_RETRY_TAG,
+    ROOT_RUN_ID_TAG,
+)
 from dagster._core.utils import str_format_list
 from dagster._serdes import ConfigurableClass
 from dagster._seven import get_current_datetime_in_utc
@@ -117,6 +126,7 @@ if TYPE_CHECKING:
     from dagster._core.storage.partition_status_cache import AssetStatusCacheValue
     from dagster._core.storage.root import LocalArtifactStorage
     from dagster._core.storage.runs import RunStorage
+    from dagster._core.storage.runs.base import RunGroupInfo
     from dagster._core.storage.schedules import ScheduleStorage
     from dagster._core.workspace.workspace import IWorkspace
     from dagster._daemon.types import DaemonHeartbeat, DaemonStatus
@@ -169,7 +179,7 @@ class _EventListenerLogHandler(logging.Handler):
                 name=record.name,
                 message=record.msg,
                 level=record.levelno,
-                meta=record.dagster_meta,  # type: ignore
+                meta=record.dagster_meta,
                 record=record,
             )
         )
@@ -234,7 +244,13 @@ class MayHaveInstanceWeakref(Generic[T_DagsterInstance]):
         self._instance_weakref = weakref.ref(instance)
 
 
-class DagsterInstance:
+@runtime_checkable
+class DynamicPartitionsStore(Protocol):
+    def get_dynamic_partitions(self, partitions_def_name: str) -> Sequence[str]:
+        return self.get_dynamic_partitions(partitions_def_name=partitions_def_name)
+
+
+class DagsterInstance(DynamicPartitionsStore):
     """Core abstraction for managing Dagster's access to storage and other resources.
 
     Use DagsterInstance.get() to grab the current DagsterInstance which will load based on
@@ -497,7 +513,7 @@ class DagsterInstance:
             unified_storage.schedule_storage if unified_storage else instance_ref.schedule_storage
         )
 
-        return klass(  # type: ignore
+        return klass(
             instance_type=InstanceType.PERSISTENT,
             local_artifact_storage=instance_ref.local_artifact_storage,
             run_storage=run_storage,
@@ -819,9 +835,19 @@ class DagsterInstance:
 
     # run storage
     @public
-    @traced
     def get_run_by_id(self, run_id: str) -> Optional[DagsterRun]:
-        return cast(DagsterRun, self._run_storage.get_run_by_id(run_id))
+        record = self.get_run_record_by_id(run_id)
+        if record is None:
+            return None
+        return record.dagster_run
+
+    @public
+    @traced
+    def get_run_record_by_id(self, run_id: str) -> Optional[RunRecord]:
+        records = self._run_storage.get_run_records(RunsFilter(run_ids=[run_id]))
+        if not records:
+            return None
+        return records[0]
 
     @traced
     def get_pipeline_snapshot(self, snapshot_id: str) -> "PipelineSnapshot":
@@ -864,8 +890,19 @@ class DagsterInstance:
         return self._event_storage.get_step_stats_for_run(run_id, step_keys)
 
     @traced
-    def get_run_tags(self) -> Sequence[Tuple[str, Set[str]]]:
-        return self._run_storage.get_run_tags()
+    def get_run_tags(
+        self,
+        tag_keys: Optional[Sequence[str]] = None,
+        value_prefix: Optional[str] = None,
+        limit: Optional[int] = None,
+    ) -> Sequence[Tuple[str, Set[str]]]:
+        return self._run_storage.get_run_tags(
+            tag_keys=tag_keys, value_prefix=value_prefix, limit=limit
+        )
+
+    @traced
+    def get_run_tag_keys(self) -> Sequence[str]:
+        return self._run_storage.get_run_tag_keys()
 
     @traced
     def get_run_group(self, run_id: str) -> Optional[Tuple[str, Iterable[DagsterRun]]]:
@@ -1103,21 +1140,45 @@ class DagsterInstance:
 
         return execution_plan_snapshot_id
 
-    def _log_asset_materialization_planned_events(self, pipeline_run, execution_plan_snapshot):
+    def _log_asset_materialization_planned_events(
+        self, run: DagsterRun, execution_plan_snapshot: ExecutionPlanSnapshot
+    ):
         from dagster._core.events import (
             AssetMaterializationPlannedData,
             DagsterEvent,
             DagsterEventType,
         )
 
-        pipeline_name = pipeline_run.pipeline_name
+        pipeline_name = run.pipeline_name
 
         for step in execution_plan_snapshot.steps:
             if step.key in execution_plan_snapshot.step_keys_to_execute:
                 for output in step.outputs:
-                    asset_key = output.properties.asset_key
+                    asset_key = check.not_none(output.properties).asset_key
                     if asset_key:
                         # Logs and stores asset_materialization_planned event
+                        partition_tag = run.tags.get(PARTITION_NAME_TAG)
+                        partition_range_start, partition_range_end = run.tags.get(
+                            ASSET_PARTITION_RANGE_START_TAG
+                        ), run.tags.get(ASSET_PARTITION_RANGE_END_TAG)
+
+                        check.invariant(
+                            not (partition_tag and partition_range_start),
+                            "Cannot have both a partition and a partition range",
+                        )
+
+                        if partition_range_start:
+                            check.invariant(
+                                partition_range_end, "Partition range start set but not end"
+                            )
+                            # TODO: resolve which partitions are in the range, and emit an event for each
+
+                        partition = (
+                            partition_tag
+                            if check.not_none(output.properties).is_asset_partitioned
+                            else None
+                        )
+
                         event = DagsterEvent(
                             event_type_value=DagsterEventType.ASSET_MATERIALIZATION_PLANNED.value,
                             pipeline_name=pipeline_name,
@@ -1125,9 +1186,11 @@ class DagsterInstance:
                                 f"{pipeline_name} intends to materialize asset"
                                 f" {asset_key.to_string()}"
                             ),
-                            event_specific_data=AssetMaterializationPlannedData(asset_key),
+                            event_specific_data=AssetMaterializationPlannedData(
+                                asset_key, partition=partition
+                            ),
                         )
-                        self.report_dagster_event(event, pipeline_run.run_id, logging.DEBUG)
+                        self.report_dagster_event(event, run.run_id, logging.DEBUG)
 
     def create_run(
         self,
@@ -1290,8 +1353,8 @@ class DagsterInstance:
     ) -> DagsterRun:
         from dagster._core.execution.plan.resume_retry import (
             ReexecutionStrategy,
-            get_retry_steps_from_parent_run,
         )
+        from dagster._core.execution.plan.state import KnownExecutionState
         from dagster._core.host_representation import ExternalPipeline, RepositoryLocation
 
         check.inst_param(parent_run, "parent_run", DagsterRun)
@@ -1327,7 +1390,10 @@ class DagsterInstance:
                 "Cannot reexecute from failure a run that is not failed",
             )
 
-            step_keys_to_execute, known_state = get_retry_steps_from_parent_run(
+            (
+                step_keys_to_execute,
+                known_state,
+            ) = KnownExecutionState.build_resume_retry_reexecution(
                 self,
                 parent_run=parent_run,
             )
@@ -1476,7 +1542,7 @@ class DagsterInstance:
         filters: Optional[RunsFilter] = None,
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
-    ) -> Mapping[str, Mapping[str, Union[Iterable[DagsterRun], int]]]:
+    ) -> Mapping[str, "RunGroupInfo"]:
         return self._run_storage.get_run_groups(filters=filters, cursor=cursor, limit=limit)
 
     @public
@@ -1665,9 +1731,57 @@ class DagsterInstance:
 
     @traced
     def get_materialization_count_by_partition(
-        self, asset_keys: Sequence[AssetKey]
+        self, asset_keys: Sequence[AssetKey], after_cursor: Optional[int] = None
     ) -> Mapping[AssetKey, Mapping[str, int]]:
-        return self._event_storage.get_materialization_count_by_partition(asset_keys)
+        return self._event_storage.get_materialization_count_by_partition(asset_keys, after_cursor)
+
+    @public
+    @traced
+    def get_dynamic_partitions(self, partitions_def_name: str) -> Sequence[str]:
+        check.str_param(partitions_def_name, "partitions_def_name")
+        return self._event_storage.get_dynamic_partitions(partitions_def_name)
+
+    @public
+    @traced
+    def add_dynamic_partitions(
+        self, partitions_def_name: str, partition_keys: Sequence[str]
+    ) -> None:
+        """
+        Add partitions to the specified dynamic partitions definition idempotently.
+        Does not add any partitions that already exist.
+        """
+        from dagster._core.definitions.partition import (
+            raise_error_on_invalid_partition_key_substring,
+        )
+
+        check.str_param(partitions_def_name, "partitions_def_name")
+        check.sequence_param(partition_keys, "partition_keys", of_type=str)
+        if isinstance(partition_keys, str):
+            # Guard against a single string being passed in `partition_keys`
+            raise DagsterInvalidInvocationError("partition_keys must be a sequence of strings")
+        raise_error_on_invalid_partition_key_substring(partition_keys)
+        return self._event_storage.add_dynamic_partitions(partitions_def_name, partition_keys)
+
+    @public
+    @traced
+    def delete_dynamic_partition(self, partitions_def_name: str, partition_key: str) -> None:
+        """
+        Delete a partition for the specified dynamic partitions definition.
+        If the partition does not exist, exits silently.
+        """
+        check.str_param(partitions_def_name, "partitions_def_name")
+        check.sequence_param(partition_key, "partition_key", of_type=str)
+        self._event_storage.delete_dynamic_partition(partitions_def_name, partition_key)
+
+    @public
+    @traced
+    def has_dynamic_partition(self, partitions_def_name: str, partition_key: str) -> bool:
+        """
+        Checks if a partition key exists for the dynamic partitions definition.
+        """
+        check.str_param(partitions_def_name, "partitions_def_name")
+        check.str_param(partition_key, "partition_key")
+        return self._event_storage.has_dynamic_partition(partitions_def_name, partition_key)
 
     # event subscriptions
 
@@ -1963,7 +2077,7 @@ class DagsterInstance:
             check.failed(f"Failed to reload run {run_id}")
 
         try:
-            self.run_launcher.launch_run(LaunchRunContext(pipeline_run=run, workspace=workspace))
+            self.run_launcher.launch_run(LaunchRunContext(dagster_run=run, workspace=workspace))
         except:
             error = serializable_error_info_from_exc_info(sys.exc_info())
             self.report_engine_event(
@@ -2007,7 +2121,7 @@ class DagsterInstance:
         try:
             self.run_launcher.resume_run(
                 ResumeRunContext(
-                    pipeline_run=run,
+                    dagster_run=run,
                     workspace=workspace,
                     resume_attempt_number=attempt_number,
                 )
@@ -2322,7 +2436,7 @@ class DagsterInstance:
         for k, v in new_env.items():
             os.environ[k] = v
 
-    def get_latest_logical_version_record(
+    def get_latest_data_version_record(
         self,
         key: AssetKey,
         is_source: Optional[bool] = None,
