@@ -1,14 +1,14 @@
-# pylint: disable=unused-argument
-
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from contextlib import contextmanager
-from typing import IO, Callable, Generator, NamedTuple, Optional, Sequence
+from typing import IO, Callable, Generator, Iterator, NamedTuple, Optional, Sequence
+
+from typing_extensions import Final, Self
 
 from dagster._core.storage.compute_log_manager import ComputeIOType
 
-MAX_BYTES_CHUNK_READ = 4194304  # 4 MB
+MAX_BYTES_CHUNK_READ: Final = 4194304  # 4 MB
 
 
 class CapturedLogContext(
@@ -96,7 +96,7 @@ class CapturedLogSubscription:
         self._observer: Optional[Callable[[CapturedLogData], None]] = None
         self.is_complete = False
 
-    def __call__(self, observer: Optional[Callable[[CapturedLogData], None]]):
+    def __call__(self, observer: Optional[Callable[[CapturedLogData], None]]) -> Self:
         self._observer = observer
         self.fetch()
         if self._manager.is_capture_complete(self._log_key):
@@ -104,14 +104,14 @@ class CapturedLogSubscription:
         return self
 
     @property
-    def log_key(self):
+    def log_key(self) -> Sequence[str]:
         return self._log_key
 
-    def dispose(self):
+    def dispose(self) -> None:
         self._observer = None
         self._manager.unsubscribe(self)
 
-    def fetch(self):
+    def fetch(self) -> None:
         if not self._observer:
             return
 
@@ -127,17 +127,19 @@ class CapturedLogSubscription:
                 self._cursor = log_data.cursor
             should_fetch = _has_max_data(log_data.stdout) or _has_max_data(log_data.stderr)
 
-    def complete(self):
+    def complete(self) -> None:
         self.is_complete = True
 
 
-def _has_max_data(chunk) -> bool:
-    return chunk and len(chunk) >= MAX_BYTES_CHUNK_READ
+def _has_max_data(chunk: Optional[bytes]) -> bool:
+    # function is used as predicate but does not actually return a boolean
+    return chunk and len(chunk) >= MAX_BYTES_CHUNK_READ  # type: ignore
 
 
 class CapturedLogManager(ABC):
     """Abstract base class for capturing the unstructured logs (stdout/stderr) in the current
-    process, stored / retrieved with a provided log_key."""
+    process, stored / retrieved with a provided log_key.
+    """
 
     @abstractmethod
     @contextmanager
@@ -154,7 +156,7 @@ class CapturedLogManager(ABC):
     @contextmanager
     def open_log_stream(
         self, log_key: Sequence[str], io_type: ComputeIOType
-    ) -> Generator[Optional[IO], None, None]:
+    ) -> Iterator[Optional[IO[bytes]]]:
         """
         Context manager for providing an IO stream that enables the caller to write to a log stream
         managed by the captured log manager, to be read later using the given log key.
@@ -181,7 +183,7 @@ class CapturedLogManager(ABC):
         cursor: Optional[str] = None,
         max_bytes: Optional[int] = None,
     ) -> CapturedLogData:
-        """Returns a chunk of the captured stdout logs for a given log key
+        """Returns a chunk of the captured stdout logs for a given log key.
 
         Args:
             log_key (List[String]): The log key identifying the captured logs
@@ -207,7 +209,7 @@ class CapturedLogManager(ABC):
     @abstractmethod
     def delete_logs(
         self, log_key: Optional[Sequence[str]] = None, prefix: Optional[Sequence[str]] = None
-    ):
+    ) -> None:
         """Deletes the captured logs for a given log key.
 
         Args:
@@ -219,7 +221,7 @@ class CapturedLogManager(ABC):
     def subscribe(
         self, log_key: Sequence[str], cursor: Optional[str] = None
     ) -> CapturedLogSubscription:
-        """Registers an observable object for log data
+        """Registers an observable object for log data.
 
         Args:
             log_key (List[String]): The log key identifying the captured logs
@@ -229,8 +231,8 @@ class CapturedLogManager(ABC):
         """
 
     @abstractmethod
-    def unsubscribe(self, subscription: CapturedLogSubscription):
-        """Deregisters an observable object from receiving log updates
+    def unsubscribe(self, subscription: CapturedLogSubscription) -> None:
+        """Deregisters an observable object from receiving log updates.
 
         Args:
             subscription (CapturedLogSubscription): subscription object which manages when to send
@@ -238,5 +240,5 @@ class CapturedLogManager(ABC):
         """
 
     def build_log_key_for_run(self, run_id: str, step_key: str) -> Sequence[str]:
-        """Legacy adapter to translate run_id/key to captured log manager-based log_key"""
+        """Legacy adapter to translate run_id/key to captured log manager-based log_key."""
         return [run_id, "compute_logs", step_key]
