@@ -2,7 +2,7 @@ from abc import abstractmethod
 from functools import update_wrapper
 from typing import TYPE_CHECKING, AbstractSet, Any, Callable, Optional, Set, Union, cast, overload
 
-from typing_extensions import TypeAlias
+from typing_extensions import TypeAlias, TypeGuard
 
 import dagster._check as check
 from dagster._annotations import public
@@ -18,17 +18,26 @@ from dagster._core.storage.input_manager import InputManager
 from dagster._core.storage.output_manager import IOutputManagerDefinition, OutputManager
 from dagster._core.storage.root_input_manager import IInputManagerDefinition
 
+from ..decorator_utils import get_function_params
+
 if TYPE_CHECKING:
     from dagster._core.execution.context.init import InitResourceContext
     from dagster._core.execution.context.input import InputContext
     from dagster._core.execution.context.output import OutputContext
 
+IOManagerFunctionWithContext = Callable[["InitResourceContext"], "IOManager"]
 IOManagerFunction: TypeAlias = Union[
-    Callable[["InitResourceContext"], "IOManager"],
+    IOManagerFunctionWithContext,
     Callable[[], "IOManager"],
 ]
 
 
+def is_io_manager_context_provided(
+    fn: IOManagerFunction,
+) -> TypeGuard[IOManagerFunctionWithContext]:
+    return len(get_function_params(fn)) >= 1
+
+
 class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputManagerDefinition):
     """Definition of an IO manager resource.
 
@@ -54,11 +63,9 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
         self._input_config_schema = convert_user_facing_definition_config_schema(
             input_config_schema
         )
-        # Unlike other configurable objects, whose config schemas default to Any, output_config_schema
-        # defaults to None. This the because IOManager input / output config shares config
-        # namespace with dagster type loaders and materializers. The absence of provided
-        # output_config_schema means that we should fall back to using the materializer that
-        # corresponds to the output dagster type.
+        # Unlike other configurable objects, whose config schemas default to Any,
+        # output_config_schema defaults to None. This the because IOManager input / output config
+        # shares config namespace with dagster type loaders.
         self._output_config_schema = (
             convert_user_facing_definition_config_schema(output_config_schema)
             if output_config_schema is not None
@@ -84,7 +91,6 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
         self,
         description: Optional[str],
         config_schema: CoercableToConfigSchema,
-        _,
     ) -> "IOManagerDefinition":
         return IOManagerDefinition(
             config_schema=config_schema,
@@ -95,7 +101,7 @@ class IOManagerDefinition(ResourceDefinition, IInputManagerDefinition, IOutputMa
             output_config_schema=self.output_config_schema,
         )
 
-    @public  # type: ignore
+    @public
     @staticmethod
     def hardcoded_io_manager(
         value: "IOManager", description: Optional[str] = None
@@ -123,7 +129,7 @@ class IOManager(InputManager, OutputManager):
     ``handle_output`` to store an object and ``load_input`` to retrieve an object.
     """
 
-    @public  # type: ignore
+    @public
     @abstractmethod
     def load_input(self, context: "InputContext") -> Any:
         """User-defined method that loads an input to an op.
@@ -136,7 +142,7 @@ class IOManager(InputManager, OutputManager):
             Any: The data object.
         """
 
-    @public  # type: ignore
+    @public
     @abstractmethod
     def handle_output(self, context: "OutputContext", obj: Any) -> None:
         """User-defined method that stores an output of an op.
