@@ -1,7 +1,20 @@
-from typing import TYPE_CHECKING, Callable, Iterable, Mapping, Optional, Sequence, Set, Tuple, Union
+from typing import (
+    TYPE_CHECKING,
+    Iterable,
+    Mapping,
+    Optional,
+    Sequence,
+    Set,
+    Tuple,
+    Union,
+    cast,
+)
 
 from dagster import _check as check
+from dagster._config.config_schema import UserConfigSchema
+from dagster._core.event_api import EventHandlerFn
 from dagster._serdes import ConfigurableClass, ConfigurableClassData
+from dagster._utils import PrintFn
 
 from .base_storage import DagsterStorage
 from .event_log.base import (
@@ -11,7 +24,7 @@ from .event_log.base import (
     EventLogStorage,
     EventRecordsFilter,
 )
-from .runs.base import RunStorage
+from .runs.base import RunGroupInfo, RunStorage
 from .schedules.base import ScheduleStorage
 
 if TYPE_CHECKING:
@@ -22,6 +35,7 @@ if TYPE_CHECKING:
     from dagster._core.execution.backfill import BulkActionStatus, PartitionBackfill
     from dagster._core.execution.stats import RunStepKeyStatsSnapshot
     from dagster._core.host_representation.origin import ExternalPipelineOrigin
+    from dagster._core.instance import DagsterInstance
     from dagster._core.scheduler.instigation import (
         InstigatorState,
         InstigatorTick,
@@ -53,7 +67,7 @@ class CompositeStorage(DagsterStorage, ConfigurableClass):
         run_storage: RunStorage,
         event_log_storage: EventLogStorage,
         schedule_storage: ScheduleStorage,
-        inst_data=None,
+        inst_data: Optional[ConfigurableClassData] = None,
     ):
         self._run_storage = run_storage
         self._event_log_storage = check.inst_param(
@@ -66,11 +80,11 @@ class CompositeStorage(DagsterStorage, ConfigurableClass):
         super().__init__()
 
     @property
-    def inst_data(self):
+    def inst_data(self) -> Optional[ConfigurableClassData]:
         return self._inst_data
 
     @classmethod
-    def config_type(cls):
+    def config_type(cls) -> UserConfigSchema:
         return {
             "run_storage": {
                 "module_name": str,
@@ -90,25 +104,36 @@ class CompositeStorage(DagsterStorage, ConfigurableClass):
         }
 
     @staticmethod
-    def from_config_value(inst_data, config_value):
+    def from_config_value(
+        inst_data: Optional[ConfigurableClassData], config_value: Mapping[str, Mapping[str, str]]
+    ) -> "CompositeStorage":
         run_storage_config = config_value["run_storage"]
-        run_storage = ConfigurableClassData(
-            module_name=run_storage_config["module_name"],
-            class_name=run_storage_config["class_name"],
-            config_yaml=run_storage_config["config_yaml"],
-        ).rehydrate()
+        run_storage = cast(
+            RunStorage,
+            ConfigurableClassData(
+                module_name=run_storage_config["module_name"],
+                class_name=run_storage_config["class_name"],
+                config_yaml=run_storage_config["config_yaml"],
+            ).rehydrate(),
+        )
         event_log_storage_config = config_value["event_log_storage"]
-        event_log_storage = ConfigurableClassData(
-            module_name=event_log_storage_config["module_name"],
-            class_name=event_log_storage_config["class_name"],
-            config_yaml=event_log_storage_config["config_yaml"],
-        ).rehydrate()
+        event_log_storage = cast(
+            EventLogStorage,
+            ConfigurableClassData(
+                module_name=event_log_storage_config["module_name"],
+                class_name=event_log_storage_config["class_name"],
+                config_yaml=event_log_storage_config["config_yaml"],
+            ).rehydrate(),
+        )
         schedule_storage_config = config_value["schedule_storage"]
-        schedule_storage = ConfigurableClassData(
-            module_name=schedule_storage_config["module_name"],
-            class_name=schedule_storage_config["class_name"],
-            config_yaml=schedule_storage_config["config_yaml"],
-        ).rehydrate()
+        schedule_storage = cast(
+            ScheduleStorage,
+            ConfigurableClassData(
+                module_name=schedule_storage_config["module_name"],
+                class_name=schedule_storage_config["class_name"],
+                config_yaml=schedule_storage_config["config_yaml"],
+            ).rehydrate(),
+        )
         return CompositeStorage(
             run_storage, event_log_storage, schedule_storage, inst_data=inst_data
         )
@@ -127,25 +152,25 @@ class CompositeStorage(DagsterStorage, ConfigurableClass):
 
 
 class LegacyRunStorage(RunStorage, ConfigurableClass):
-    def __init__(self, storage, inst_data=None):
+    def __init__(self, storage: DagsterStorage, inst_data: Optional[ConfigurableClassData] = None):
         self._storage = check.inst_param(storage, "storage", DagsterStorage)
         self._inst_data = check.opt_inst_param(inst_data, "inst_data", ConfigurableClassData)
         super().__init__()
 
     @property
-    def inst_data(self):
+    def inst_data(self) -> Optional[ConfigurableClassData]:
         return self._inst_data
 
     @property
-    def _instance(self):
-        return self._storage._instance  # pylint: disable=protected-access
+    def _instance(self) -> Optional["DagsterInstance"]:
+        return self._storage._instance
 
-    def register_instance(self, instance):
-        if not self._storage._instance:  # pylint: disable=protected-access
+    def register_instance(self, instance: "DagsterInstance") -> None:
+        if not self._storage._instance:
             self._storage.register_instance(instance)
 
     @classmethod
-    def config_type(cls):
+    def config_type(cls) -> UserConfigSchema:
         return {
             "module_name": str,
             "class_name": str,
@@ -153,18 +178,22 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
         }
 
     @staticmethod
-    def from_config_value(inst_data, config_value):
+    def from_config_value(
+        inst_data: Optional[ConfigurableClassData], config_value: Mapping[str, str]
+    ) -> "LegacyRunStorage":
         storage = ConfigurableClassData(
             module_name=config_value["module_name"],
             class_name=config_value["class_name"],
             config_yaml=config_value["config_yaml"],
         ).rehydrate()
-        return LegacyRunStorage(storage, inst_data=inst_data)
+        # Type checker says LegacyRunStorage is abstract and can't be instantiated. Not sure whether
+        # type check is wrong, or is unused code path.
+        return LegacyRunStorage(storage, inst_data=inst_data)  # type: ignore
 
     def add_run(self, pipeline_run: "DagsterRun") -> "DagsterRun":
         return self._storage.run_storage.add_run(pipeline_run)
 
-    def handle_run_event(self, run_id: str, event: "DagsterEvent"):
+    def handle_run_event(self, run_id: str, event: "DagsterEvent") -> None:
         return self._storage.run_storage.handle_run_event(run_id, event)
 
     def get_runs(
@@ -187,12 +216,9 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
         filters: Optional["RunsFilter"] = None,
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
-    ) -> Mapping[str, Mapping[str, Union[Iterable["DagsterRun"], int]]]:
+    ) -> Mapping[str, RunGroupInfo]:
         return self._storage.run_storage.get_run_groups(filters, cursor, limit)
 
-    def get_run_by_id(self, run_id: str) -> Optional["DagsterRun"]:
-        return self._storage.run_storage.get_run_by_id(run_id)
-
     def get_run_records(
         self,
         filters: Optional["RunsFilter"] = None,
@@ -206,8 +232,16 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
             filters, limit, order_by, ascending, cursor, bucket_by
         )
 
-    def get_run_tags(self) -> Sequence[Tuple[str, Set[str]]]:
-        return self._storage.run_storage.get_run_tags()
+    def get_run_tags(
+        self,
+        tag_keys: Optional[Sequence[str]] = None,
+        value_prefix: Optional[str] = None,
+        limit: Optional[int] = None,
+    ) -> Sequence[Tuple[str, Set[str]]]:
+        return self._storage.run_storage.get_run_tags(tag_keys, value_prefix, limit)
+
+    def get_run_tag_keys(self) -> Sequence[str]:
+        return self._storage.run_storage.get_run_tag_keys()
 
     def add_run_tags(self, run_id: str, new_tags: Mapping[str, str]):
         return self._storage.run_storage.add_run_tags(run_id, new_tags)
@@ -219,10 +253,10 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
         self,
         snapshot: Union["PipelineSnapshot", "ExecutionPlanSnapshot"],
         snapshot_id: Optional[str] = None,
-    ):
+    ) -> None:
         return self._storage.run_storage.add_snapshot(snapshot, snapshot_id)
 
-    def has_snapshot(self, snapshot_id: str):
+    def has_snapshot(self, snapshot_id: str) -> bool:
         return self._storage.run_storage.has_snapshot(snapshot_id)
 
     def has_pipeline_snapshot(self, pipeline_snapshot_id: str) -> bool:
@@ -251,35 +285,35 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
     ) -> "ExecutionPlanSnapshot":
         return self._storage.run_storage.get_execution_plan_snapshot(execution_plan_snapshot_id)
 
-    def wipe(self):
+    def wipe(self) -> None:
         return self._storage.run_storage.wipe()
 
-    def delete_run(self, run_id: str):
+    def delete_run(self, run_id: str) -> None:
         return self._storage.run_storage.delete_run(run_id)
 
     @property
-    def supports_bucket_queries(self):
+    def supports_bucket_queries(self) -> bool:
         return self._storage.run_storage.supports_bucket_queries
 
-    def migrate(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def migrate(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         return self._storage.run_storage.migrate(print_fn, force_rebuild_all)
 
-    def optimize(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def optimize(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         return self._storage.run_storage.optimize(print_fn, force_rebuild_all)
 
-    def dispose(self):
+    def dispose(self) -> None:
         return self._storage.run_storage.dispose()
 
-    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int):
+    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int) -> None:
         return self._storage.run_storage.optimize_for_dagit(statement_timeout, pool_recycle)
 
-    def add_daemon_heartbeat(self, daemon_heartbeat: "DaemonHeartbeat"):
+    def add_daemon_heartbeat(self, daemon_heartbeat: "DaemonHeartbeat") -> None:
         return self._storage.run_storage.add_daemon_heartbeat(daemon_heartbeat)
 
     def get_daemon_heartbeats(self) -> Mapping[str, "DaemonHeartbeat"]:
         return self._storage.run_storage.get_daemon_heartbeats()
 
-    def wipe_daemon_heartbeats(self):
+    def wipe_daemon_heartbeats(self) -> None:
         return self._storage.run_storage.wipe_daemon_heartbeats()
 
     def get_backfills(
@@ -293,10 +327,10 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
     def get_backfill(self, backfill_id: str) -> Optional["PartitionBackfill"]:
         return self._storage.run_storage.get_backfill(backfill_id)
 
-    def add_backfill(self, partition_backfill: "PartitionBackfill"):
+    def add_backfill(self, partition_backfill: "PartitionBackfill") -> None:
         return self._storage.run_storage.add_backfill(partition_backfill)
 
-    def update_backfill(self, partition_backfill: "PartitionBackfill"):
+    def update_backfill(self, partition_backfill: "PartitionBackfill") -> None:
         return self._storage.run_storage.update_backfill(partition_backfill)
 
     def get_run_partition_data(self, runs_filter: "RunsFilter") -> Sequence["RunPartitionData"]:
@@ -308,22 +342,22 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
     def kvs_set(self, pairs: Mapping[str, str]) -> None:
         return self._storage.run_storage.kvs_set(pairs)
 
-    def replace_job_origin(self, run: "DagsterRun", job_origin: "ExternalPipelineOrigin"):
+    def replace_job_origin(self, run: "DagsterRun", job_origin: "ExternalPipelineOrigin") -> None:
         return self._storage.run_storage.replace_job_origin(run, job_origin)
 
 
 class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
-    def __init__(self, storage, inst_data=None):
+    def __init__(self, storage: DagsterStorage, inst_data: Optional[ConfigurableClassData] = None):
         self._storage = check.inst_param(storage, "storage", DagsterStorage)
         self._inst_data = check.opt_inst_param(inst_data, "inst_data", ConfigurableClassData)
         super().__init__()
 
     @property
-    def inst_data(self):
+    def inst_data(self) -> Optional[ConfigurableClassData]:
         return self._inst_data
 
     @classmethod
-    def config_type(cls):
+    def config_type(cls) -> UserConfigSchema:
         return {
             "module_name": str,
             "class_name": str,
@@ -331,19 +365,26 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         }
 
     @staticmethod
-    def from_config_value(inst_data, config_value):
-        storage = ConfigurableClassData(
-            module_name=config_value["module_name"],
-            class_name=config_value["class_name"],
-            config_yaml=config_value["config_yaml"],
-        ).rehydrate()
+    def from_config_value(
+        inst_data: Optional[ConfigurableClassData], config_value: Mapping[str, str]
+    ) -> "LegacyEventLogStorage":
+        storage = cast(
+            DagsterStorage,
+            ConfigurableClassData(
+                module_name=config_value["module_name"],
+                class_name=config_value["class_name"],
+                config_yaml=config_value["config_yaml"],
+            ).rehydrate(),
+        )
+        # Type checker says LegacyEventStorage is abstract and can't be instantiated. Not sure whether
+        # type check is wrong, or is unused code path.
         return LegacyEventLogStorage(storage, inst_data=inst_data)
 
     @property
-    def _instance(self):
+    def _instance(self) -> Optional["DagsterInstance"]:
         return self._storage._instance  # pylint: disable=protected-access
 
-    def register_instance(self, instance):
+    def register_instance(self, instance: "DagsterInstance") -> None:
         if not self._storage._instance:  # pylint: disable=protected-access
             self._storage.register_instance(instance)
 
@@ -360,42 +401,42 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         return self._storage.event_log_storage.get_stats_for_run(run_id)
 
     def get_step_stats_for_run(
-        self, run_id: str, step_keys=None
+        self, run_id: str, step_keys: Optional[Sequence[str]] = None
     ) -> Sequence["RunStepKeyStatsSnapshot"]:
         return self._storage.event_log_storage.get_step_stats_for_run(run_id, step_keys)
 
-    def store_event(self, event: "EventLogEntry"):
+    def store_event(self, event: "EventLogEntry") -> None:
         return self._storage.event_log_storage.store_event(event)
 
-    def delete_events(self, run_id: str):
+    def delete_events(self, run_id: str) -> None:
         return self._storage.event_log_storage.delete_events(run_id)
 
-    def upgrade(self):
+    def upgrade(self) -> None:
         return self._storage.event_log_storage.upgrade()
 
-    def reindex_events(self, print_fn: Optional[Callable] = None, force: bool = False):
+    def reindex_events(self, print_fn: Optional[PrintFn] = None, force: bool = False) -> None:
         return self._storage.event_log_storage.reindex_events(print_fn, force)
 
-    def reindex_assets(self, print_fn: Optional[Callable] = None, force: bool = False):
+    def reindex_assets(self, print_fn: Optional[PrintFn] = None, force: bool = False) -> None:
         return self._storage.event_log_storage.reindex_assets(print_fn, force)
 
-    def wipe(self):
+    def wipe(self) -> None:
         return self._storage.event_log_storage.wipe()
 
-    def watch(self, run_id: str, cursor: str, callback: Callable):
+    def watch(self, run_id: str, cursor: str, callback: EventHandlerFn) -> None:
         return self._storage.event_log_storage.watch(run_id, cursor, callback)
 
-    def end_watch(self, run_id: str, handler: Callable):
+    def end_watch(self, run_id: str, handler: EventHandlerFn) -> None:
         return self._storage.event_log_storage.end_watch(run_id, handler)
 
     @property
     def is_persistent(self) -> bool:
         return self._storage.event_log_storage.is_persistent
 
-    def dispose(self):
+    def dispose(self) -> None:
         return self._storage.event_log_storage.dispose()
 
-    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int):
+    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int) -> None:
         return self._storage.event_log_storage.optimize_for_dagit(statement_timeout, pool_recycle)
 
     def get_event_records(
@@ -404,8 +445,10 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         limit: Optional[int] = None,
         ascending: bool = False,
     ) -> Iterable[EventLogRecord]:
+        # type ignored because `get_event_records` does not accept None. Unclear which type
+        # annotation is wrong.
         return self._storage.event_log_storage.get_event_records(
-            event_records_filter, limit, ascending
+            event_records_filter, limit, ascending  # type: ignore
         )
 
     def get_asset_records(
@@ -432,40 +475,45 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
     ) -> Mapping["AssetKey", Optional["EventLogEntry"]]:
         return self._storage.event_log_storage.get_latest_materialization_events(asset_keys)
 
-    def get_asset_events(
-        self,
-        asset_key: "AssetKey",
-        partitions: Optional[Sequence[str]] = None,
-        before_cursor: Optional[int] = None,
-        after_cursor: Optional[int] = None,
-        limit: Optional[int] = None,
-        ascending: bool = False,
-        include_cursor: bool = False,
-        before_timestamp=None,
-        cursor: Optional[int] = None,  # deprecated
-    ) -> Union[Iterable["EventLogEntry"], Iterable[Tuple[int, "EventLogEntry"]]]:
-        return self._storage.event_log_storage.get_asset_events(
-            asset_key,
-            partitions,
-            before_cursor,
-            after_cursor,
-            limit,
-            ascending,
-            include_cursor,
-            before_timestamp,
-            cursor,
-        )
-
     def get_asset_run_ids(self, asset_key: "AssetKey") -> Iterable[str]:
         return self._storage.event_log_storage.get_asset_run_ids(asset_key)
 
-    def wipe_asset(self, asset_key: "AssetKey"):
+    def wipe_asset(self, asset_key: "AssetKey") -> None:
         return self._storage.event_log_storage.wipe_asset(asset_key)
 
     def get_materialization_count_by_partition(
-        self, asset_keys: Sequence["AssetKey"]
+        self, asset_keys: Sequence["AssetKey"], after_cursor: Optional[int] = None
     ) -> Mapping["AssetKey", Mapping[str, int]]:
-        return self._storage.event_log_storage.get_materialization_count_by_partition(asset_keys)
+        return self._storage.event_log_storage.get_materialization_count_by_partition(
+            asset_keys, after_cursor
+        )
+
+    def get_latest_asset_partition_materialization_attempts_without_materializations(
+        self, asset_key: "AssetKey"
+    ) -> Mapping[str, Tuple[str, int]]:
+        return self._storage.event_log_storage.get_latest_asset_partition_materialization_attempts_without_materializations(
+            asset_key
+        )
+
+    def get_dynamic_partitions(self, partitions_def_name: str) -> Sequence[str]:
+        return self._storage.event_log_storage.get_dynamic_partitions(partitions_def_name)
+
+    def has_dynamic_partition(self, partitions_def_name: str, partition_key: str) -> bool:
+        return self._storage.event_log_storage.has_dynamic_partition(
+            partitions_def_name, partition_key
+        )
+
+    def add_dynamic_partitions(
+        self, partitions_def_name: str, partition_keys: Sequence[str]
+    ) -> None:
+        return self._storage.event_log_storage.add_dynamic_partitions(
+            partitions_def_name, partition_keys
+        )
+
+    def delete_dynamic_partition(self, partitions_def_name: str, partition_key: str) -> None:
+        return self._storage.event_log_storage.delete_dynamic_partition(
+            partitions_def_name, partition_key
+        )
 
     def get_event_tags_for_asset(
         self,
@@ -489,26 +537,26 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
 
     def get_records_for_run(
         self,
-        run_id,
-        cursor=None,
-        of_type=None,
-        limit=None,
+        run_id: str,
+        cursor: Optional[str] = None,
+        of_type: Optional[Union["DagsterEventType", Set["DagsterEventType"]]] = None,
+        limit: Optional[int] = None,
     ) -> EventLogConnection:
         return self._storage.event_log_storage.get_records_for_run(run_id, cursor, of_type, limit)
 
 
 class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
-    def __init__(self, storage, inst_data=None):
+    def __init__(self, storage: DagsterStorage, inst_data: Optional[ConfigurableClassData] = None):
         self._storage = check.inst_param(storage, "storage", DagsterStorage)
         self._inst_data = check.opt_inst_param(inst_data, "inst_data", ConfigurableClassData)
         super().__init__()
 
     @property
-    def inst_data(self):
+    def inst_data(self) -> Optional[ConfigurableClassData]:
         return self._inst_data
 
     @classmethod
-    def config_type(cls):
+    def config_type(cls) -> UserConfigSchema:
         return {
             "module_name": str,
             "class_name": str,
@@ -516,23 +564,28 @@ class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
         }
 
     @staticmethod
-    def from_config_value(inst_data, config_value):
-        storage = ConfigurableClassData(
-            module_name=config_value["module_name"],
-            class_name=config_value["class_name"],
-            config_yaml=config_value["config_yaml"],
-        ).rehydrate()
+    def from_config_value(
+        inst_data: Optional[ConfigurableClassData], config_value: Mapping[str, str]
+    ) -> "LegacyScheduleStorage":
+        storage = cast(
+            DagsterStorage,
+            ConfigurableClassData(
+                module_name=config_value["module_name"],
+                class_name=config_value["class_name"],
+                config_yaml=config_value["config_yaml"],
+            ).rehydrate(),
+        )
         return LegacyScheduleStorage(storage, inst_data=inst_data)
 
     @property
-    def _instance(self):
-        return self._storage._instance  # pylint: disable=protected-access
+    def _instance(self) -> Optional["DagsterInstance"]:
+        return self._storage._instance  # pyright: disable=reportPrivateUsage
 
-    def register_instance(self, instance):
-        if not self._storage._instance:  # pylint: disable=protected-access
+    def register_instance(self, instance: "DagsterInstance") -> None:
+        if not self._storage._instance:  # pyright: disable=reportPrivateUsage
             self._storage.register_instance(instance)
 
-    def wipe(self):
+    def wipe(self) -> None:
         return self._storage.schedule_storage.wipe()
 
     def all_instigator_state(
@@ -543,20 +596,20 @@ class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
     ) -> Iterable["InstigatorState"]:
         return self._storage.schedule_storage.all_instigator_state()
 
-    def get_instigator_state(self, origin_id: str, selector_id: str) -> "InstigatorState":
+    def get_instigator_state(self, origin_id: str, selector_id: str) -> Optional["InstigatorState"]:
         return self._storage.schedule_storage.get_instigator_state(origin_id, selector_id)
 
-    def add_instigator_state(self, state: "InstigatorState"):
+    def add_instigator_state(self, state: "InstigatorState") -> "InstigatorState":
         return self._storage.schedule_storage.add_instigator_state(state)
 
-    def update_instigator_state(self, state: "InstigatorState"):
+    def update_instigator_state(self, state: "InstigatorState") -> "InstigatorState":
         return self._storage.schedule_storage.update_instigator_state(state)
 
-    def delete_instigator_state(self, origin_id: str, selector_id: str):
+    def delete_instigator_state(self, origin_id: str, selector_id: str) -> None:
         return self._storage.schedule_storage.delete_instigator_state(origin_id, selector_id)
 
     @property
-    def supports_batch_queries(self):
+    def supports_batch_queries(self) -> bool:
         return self._storage.schedule_storage.supports_batch_queries
 
     def get_batch_ticks(
@@ -580,10 +633,10 @@ class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
             origin_id, selector_id, before, after, limit, statuses
         )
 
-    def create_tick(self, tick_data: "TickData"):
+    def create_tick(self, tick_data: "TickData") -> "InstigatorTick":
         return self._storage.schedule_storage.create_tick(tick_data)
 
-    def update_tick(self, tick: "InstigatorTick"):
+    def update_tick(self, tick: "InstigatorTick") -> "InstigatorTick":
         return self._storage.schedule_storage.update_tick(tick)
 
     def purge_ticks(
@@ -592,22 +645,22 @@ class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
         selector_id: str,
         before: float,
         tick_statuses: Optional[Sequence["TickStatus"]] = None,
-    ):
+    ) -> None:
         return self._storage.schedule_storage.purge_ticks(
             origin_id, selector_id, before, tick_statuses
         )
 
-    def upgrade(self):
+    def upgrade(self) -> None:
         return self._storage.schedule_storage.upgrade()
 
-    def migrate(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def migrate(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         return self._storage.schedule_storage.migrate(print_fn, force_rebuild_all)
 
-    def optimize(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def optimize(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         return self._storage.schedule_storage.optimize(print_fn, force_rebuild_all)
 
-    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int):
+    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int) -> None:
         return self._storage.schedule_storage.optimize_for_dagit(statement_timeout, pool_recycle)
 
-    def dispose(self):
+    def dispose(self) -> None:
         return self._storage.schedule_storage.dispose()
