@@ -49,6 +49,7 @@ if TYPE_CHECKING:
         Partition,
         PartitionSetDefinition,
     )
+    from dagster._core.host_representation.external import ExternalSchedule, ExternalSensor
     from dagster._core.host_representation.origin import ExternalPipelineOrigin
 
 
@@ -185,7 +186,7 @@ class DagsterRunSerializer(DefaultNamedTupleSerializer):
             for key, value in storage_dict.items()
         }
         # called by the serdes layer, delegates to helper method with expanded kwargs
-        return pipeline_run_from_storage(**unpacked_dict)
+        return dagster_run_from_storage(**unpacked_dict)
 
     @classmethod
     def value_to_storage_dict(
@@ -204,7 +205,7 @@ class DagsterRunSerializer(DefaultNamedTupleSerializer):
         return storage
 
 
-def pipeline_run_from_storage(
+def dagster_run_from_storage(
     pipeline_name=None,
     run_id=None,
     run_config=None,
@@ -429,7 +430,7 @@ class DagsterRun(
             ),
         )
 
-    def with_status(self, status: DagsterRunStatus) -> Self:  # type: ignore  # fmt: skip
+    def with_status(self, status: DagsterRunStatus) -> Self:
         if status == DagsterRunStatus.QUEUED:
             # Placing this with the other imports causes a cyclic import
             # https://github.com/dagster-io/dagster/issues/3181
@@ -443,25 +444,25 @@ class DagsterRun(
 
         return self._replace(status=status)
 
-    def with_job_origin(self, origin: "ExternalPipelineOrigin") -> Self:  # type: ignore  # fmt: skip
+    def with_job_origin(self, origin: "ExternalPipelineOrigin") -> Self:
         from dagster._core.host_representation.origin import ExternalPipelineOrigin
 
         check.inst_param(origin, "origin", ExternalPipelineOrigin)
         return self._replace(external_pipeline_origin=origin)
 
-    def with_mode(self, mode: str) -> Self:  # type: ignore  # fmt: skip
+    def with_mode(self, mode: str) -> Self:
         return self._replace(mode=mode)
 
-    def with_tags(self, tags: Mapping[str, str]) -> Self:  # type: ignore  # fmt: skip
+    def with_tags(self, tags: Mapping[str, str]) -> Self:
         return self._replace(tags=tags)
 
-    def get_root_run_id(self):
+    def get_root_run_id(self) -> Optional[str]:
         return self.tags.get(ROOT_RUN_ID_TAG)
 
-    def get_parent_run_id(self):
+    def get_parent_run_id(self) -> Optional[str]:
         return self.tags.get(PARENT_RUN_ID_TAG)
 
-    def tags_for_storage(self):
+    def tags_for_storage(self) -> Mapping[str, str]:
         repository_tags = {}
         if self.external_pipeline_origin:
             # tag the run with a label containing the repository name / location name, to allow for
@@ -475,27 +476,27 @@ class DagsterRun(
 
         return {**repository_tags, **self.tags}
 
-    @public  # type: ignore
+    @public
     @property
-    def is_finished(self):
+    def is_finished(self) -> bool:
         return self.status in FINISHED_STATUSES
 
-    @public  # type: ignore
+    @public
     @property
     def is_success(self) -> bool:
         return self.status == DagsterRunStatus.SUCCESS
 
-    @public  # type: ignore
+    @public
     @property
     def is_failure(self) -> bool:
         return self.status == DagsterRunStatus.FAILURE
 
-    @public  # type: ignore
+    @public
     @property
     def is_failure_or_canceled(self):
         return self.status == DagsterRunStatus.FAILURE or self.status == DagsterRunStatus.CANCELED
 
-    @public  # type: ignore
+    @public
     @property
     def is_resume_retry(self) -> bool:
         return self.tags.get(RESUME_RETRY_TAG) == "true"
@@ -505,7 +506,7 @@ class DagsterRun(
         # Compat
         return self.parent_run_id
 
-    @public  # type: ignore
+    @public
     @property
     def job_name(self) -> str:
         return self.pipeline_name
@@ -645,29 +646,29 @@ class RunsFilter(
         )
 
     @property
-    def pipeline_name(self):
+    def pipeline_name(self) -> Optional[str]:
         return self.job_name
 
     @staticmethod
-    def for_schedule(schedule):
+    def for_schedule(schedule: "ExternalSchedule") -> "RunsFilter":
         return RunsFilter(tags=DagsterRun.tags_for_schedule(schedule))
 
     @staticmethod
-    def for_partition(partition_set, partition):
+    def for_partition(
+        partition_set: "PartitionSetDefinition", partition: "Partition"
+    ) -> "RunsFilter":
         return RunsFilter(tags=DagsterRun.tags_for_partition_set(partition_set, partition))
 
     @staticmethod
-    def for_sensor(sensor):
+    def for_sensor(sensor: "ExternalSensor") -> "RunsFilter":
         return RunsFilter(tags=DagsterRun.tags_for_sensor(sensor))
 
     @staticmethod
-    def for_backfill(backfill_id):
+    def for_backfill(backfill_id: str) -> "RunsFilter":
         return RunsFilter(tags=DagsterRun.tags_for_backfill_id(backfill_id))
 
 
 register_serdes_tuple_fallbacks({"PipelineRunsFilter": RunsFilter})
-# DEPRECATED - keeping around for backcompat reasons (some folks might have imported directly)
-PipelineRunsFilter = RunsFilter
 
 
 class JobBucket(NamedTuple):
@@ -686,7 +687,7 @@ class RunRecord(
         "_RunRecord",
         [
             ("storage_id", int),
-            ("pipeline_run", DagsterRun),
+            ("dagster_run", DagsterRun),
             ("create_timestamp", datetime),
             ("update_timestamp", datetime),
             ("start_time", Optional[float]),
@@ -702,17 +703,17 @@ class RunRecord(
 
     def __new__(
         cls,
-        storage_id,
-        pipeline_run,
-        create_timestamp,
-        update_timestamp,
-        start_time=None,
-        end_time=None,
+        storage_id: int,
+        dagster_run: DagsterRun,
+        create_timestamp: datetime,
+        update_timestamp: datetime,
+        start_time: Optional[float] = None,
+        end_time: Optional[float] = None,
     ):
         return super(RunRecord, cls).__new__(
             cls,
             storage_id=check.int_param(storage_id, "storage_id"),
-            pipeline_run=check.inst_param(pipeline_run, "pipeline_run", DagsterRun),
+            dagster_run=check.inst_param(dagster_run, "dagster_run", DagsterRun),
             create_timestamp=check.inst_param(create_timestamp, "create_timestamp", datetime),
             update_timestamp=check.inst_param(update_timestamp, "update_timestamp", datetime),
             # start_time and end_time fields will be populated once the run has started and ended, respectively, but will be None beforehand.
