@@ -1,5 +1,7 @@
 from abc import ABC, abstractmethod
-from typing import Callable, Iterable, Mapping, Optional, Sequence, Set, Tuple, Union
+from typing import TYPE_CHECKING, Iterable, Mapping, Optional, Sequence, Set, Tuple, Union
+
+from typing_extensions import TypedDict
 
 from dagster._core.events import DagsterEvent
 from dagster._core.execution.backfill import BulkActionStatus, PartitionBackfill
@@ -13,7 +15,17 @@ from dagster._core.storage.pipeline_run import (
     RunsFilter,
     TagBucket,
 )
+from dagster._core.storage.sql import AlembicVersion
 from dagster._daemon.types import DaemonHeartbeat
+from dagster._utils import PrintFn
+
+if TYPE_CHECKING:
+    from dagster._core.host_representation.origin import ExternalPipelineOrigin
+
+
+class RunGroupInfo(TypedDict):
+    count: int
+    runs: Iterable[DagsterRun]
 
 
 class RunStorage(ABC, MayHaveInstanceWeakref):
@@ -40,7 +52,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
         """
 
     @abstractmethod
-    def handle_run_event(self, run_id: str, event: DagsterEvent):
+    def handle_run_event(self, run_id: str, event: DagsterEvent) -> None:
         """Update run storage in accordance to a pipeline run related DagsterEvent.
 
         Args:
@@ -104,7 +116,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
         filters: Optional[RunsFilter] = None,
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
-    ) -> Mapping[str, Mapping[str, Union[Iterable[DagsterRun], int]]]:
+    ) -> Mapping[str, RunGroupInfo]:
         """Return all of the run groups present in the storage that include rows matching the
         given filter.
 
@@ -137,17 +149,6 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
         # return no more run groups than there are runs in an equivalent call to get_runs, and no
         # more than 2x total instances of PipelineRun.
 
-    @abstractmethod
-    def get_run_by_id(self, run_id: str) -> Optional[DagsterRun]:
-        """Get a run by its id.
-
-        Args:
-            run_id (str): The id of the run
-
-        Returns:
-            Optional[PipelineRun]
-        """
-
     @abstractmethod
     def get_run_records(
         self,
@@ -172,15 +173,31 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
         """
 
     @abstractmethod
-    def get_run_tags(self) -> Sequence[Tuple[str, Set[str]]]:
+    def get_run_tags(
+        self,
+        tag_keys: Optional[Sequence[str]] = None,
+        value_prefix: Optional[str] = None,
+        limit: Optional[int] = None,
+    ) -> Sequence[Tuple[str, Set[str]]]:
         """Get a list of tag keys and the values that have been associated with them.
 
+        Args:
+            tag_keys (Optional[Sequence[str]]): tag keys to filter by.
+
         Returns:
             List[Tuple[str, Set[str]]]
         """
 
     @abstractmethod
-    def add_run_tags(self, run_id: str, new_tags: Mapping[str, str]):
+    def get_run_tag_keys(self) -> Sequence[str]:
+        """Get a list of tag keys.
+
+        Returns:
+            List[str]
+        """
+
+    @abstractmethod
+    def add_run_tags(self, run_id: str, new_tags: Mapping[str, str]) -> None:
         """Add additional tags for a pipeline run.
 
         Args:
@@ -203,7 +220,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
         self,
         snapshot: Union[PipelineSnapshot, ExecutionPlanSnapshot],
         snapshot_id: Optional[str] = None,
-    ):
+    ) -> None:
         """Add a snapshot to the storage.
 
         Args:
@@ -312,31 +329,31 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
         """
 
     @abstractmethod
-    def wipe(self):
+    def wipe(self) -> None:
         """Clears the run storage."""
 
     @abstractmethod
-    def delete_run(self, run_id: str):
+    def delete_run(self, run_id: str) -> None:
         """Remove a run from storage."""
 
     @property
-    def supports_bucket_queries(self):
+    def supports_bucket_queries(self) -> bool:
         return True
 
     @abstractmethod
     def get_run_partition_data(self, runs_filter: RunsFilter) -> Sequence[RunPartitionData]:
         """Get run partition data for a given partitioned job."""
 
-    def migrate(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def migrate(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         """Call this method to run any required data migrations."""
 
-    def optimize(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def optimize(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         """Call this method to run any optional data migrations for optimized reads."""
 
-    def dispose(self):
+    def dispose(self) -> None:
         """Explicit lifecycle management."""
 
-    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int):
+    def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int) -> None:
         """Allows for optimizing database connection / use in the context of a long lived dagit process.
         """
 
@@ -348,7 +365,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
     # should be split out once all metadata storages are configured together.
 
     @abstractmethod
-    def add_daemon_heartbeat(self, daemon_heartbeat: DaemonHeartbeat):
+    def add_daemon_heartbeat(self, daemon_heartbeat: DaemonHeartbeat) -> None:
         """Called on a regular interval by the daemon."""
 
     @abstractmethod
@@ -356,7 +373,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
         """Latest heartbeats of all daemon types."""
 
     @abstractmethod
-    def wipe_daemon_heartbeats(self):
+    def wipe_daemon_heartbeats(self) -> None:
         """Wipe all daemon heartbeats."""
 
     # Backfill storage
@@ -381,7 +398,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
     def update_backfill(self, partition_backfill: PartitionBackfill):
         """Update a partition backfill in run storage."""
 
-    def alembic_version(self):
+    def alembic_version(self) -> Optional[AlembicVersion]:
         return None
 
     # Key Value Storage
@@ -389,7 +406,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
     # Stores arbitrary key-value pairs. Currently used for the cursor for the auto-reexecution
     # deamon. Bundled into run storage for convenience.
 
-    def supports_kvs(self):
+    def supports_kvs(self) -> bool:
         return True
 
     @abstractmethod
@@ -399,3 +416,7 @@ class RunStorage(ABC, MayHaveInstanceWeakref):
     @abstractmethod
     def kvs_set(self, pairs: Mapping[str, str]) -> None:
         """Set the value for a given key in the current deployment."""
+
+    @abstractmethod
+    def replace_job_origin(self, run: "DagsterRun", job_origin: "ExternalPipelineOrigin") -> None:
+        ...
