@@ -1,15 +1,19 @@
 import os
 from contextlib import contextmanager
+from typing import TYPE_CHECKING, Iterator, Optional
 from urllib.parse import urljoin, urlparse
 
 import sqlalchemy as db
+from sqlalchemy.engine import Connection
 from sqlalchemy.pool import NullPool
 
 from dagster import (
     StringSource,
     _check as check,
 )
+from dagster._config.config_schema import UserConfigSchema
 from dagster._core.storage.sql import (
+    AlembicVersion,
     check_alembic_revision,
     create_engine,
     get_alembic_config,
@@ -24,6 +28,8 @@ from dagster._utils import mkdir_p
 from ..schema import InstanceInfo, RunsTable, RunStorageSqlMetadata, RunTagsTable
 from ..sql_run_storage import SqlRunStorage
 
+if TYPE_CHECKING:
+    from dagster._core.storage.sqlite_storage import SqliteStorageConfig
 MINIMUM_SQLITE_BUCKET_VERSION = [3, 25, 0]
 
 
@@ -50,26 +56,30 @@ class SqliteRunStorage(SqlRunStorage, ConfigurableClass):
     The ``base_dir`` param tells the run storage where on disk to store the database.
     """
 
-    def __init__(self, conn_string, inst_data=None):
+    def __init__(self, conn_string: str, inst_data: Optional[ConfigurableClassData] = None):
         check.str_param(conn_string, "conn_string")
         self._conn_string = conn_string
         self._inst_data = check.opt_inst_param(inst_data, "inst_data", ConfigurableClassData)
         super().__init__()
 
     @property
-    def inst_data(self):
+    def inst_data(self) -> Optional[ConfigurableClassData]:
         return self._inst_data
 
     @classmethod
-    def config_type(cls):
+    def config_type(cls) -> UserConfigSchema:
         return {"base_dir": StringSource}
 
     @staticmethod
-    def from_config_value(inst_data, config_value):
+    def from_config_value(
+        inst_data: Optional[ConfigurableClassData], config_value: "SqliteStorageConfig"
+    ) -> "SqliteRunStorage":
         return SqliteRunStorage.from_local(inst_data=inst_data, **config_value)
 
     @classmethod
-    def from_local(cls, base_dir, inst_data=None):
+    def from_local(
+        cls, base_dir: str, inst_data: Optional[ConfigurableClassData] = None
+    ) -> "SqliteRunStorage":
         check.str_param(base_dir, "base_dir")
         mkdir_p(base_dir)
         conn_string = create_db_conn_string(base_dir, "runs")
@@ -98,7 +108,7 @@ class SqliteRunStorage(SqlRunStorage, ConfigurableClass):
         return run_storage
 
     @contextmanager
-    def connect(self):
+    def connect(self) -> Iterator[Connection]:
         engine = create_engine(self._conn_string, poolclass=NullPool)
         conn = engine.connect()
         try:
@@ -106,18 +116,18 @@ class SqliteRunStorage(SqlRunStorage, ConfigurableClass):
         finally:
             conn.close()
 
-    def _alembic_upgrade(self, rev="head"):
+    def _alembic_upgrade(self, rev: str = "head") -> None:
         alembic_config = get_alembic_config(__file__)
         with self.connect() as conn:
             run_alembic_upgrade(alembic_config, conn, rev=rev)
 
-    def _alembic_downgrade(self, rev="head"):
+    def _alembic_downgrade(self, rev: str = "head") -> None:
         alembic_config = get_alembic_config(__file__)
         with self.connect() as conn:
             run_alembic_downgrade(alembic_config, conn, rev=rev)
 
     @property
-    def supports_bucket_queries(self):
+    def supports_bucket_queries(self) -> bool:
         parts = get_sqlite_version().split(".")
         try:
             for i in range(min(len(parts), len(MINIMUM_SQLITE_BUCKET_VERSION))):
@@ -131,14 +141,14 @@ class SqliteRunStorage(SqlRunStorage, ConfigurableClass):
 
         return False
 
-    def upgrade(self):
+    def upgrade(self) -> None:
         self._check_for_version_066_migration_and_perform()
         self._alembic_upgrade()
 
     # In version 0.6.6, we changed the layout of the of the sqllite dbs on disk
     # to move from the root of DAGSTER_HOME/runs.db to DAGSTER_HOME/history/runs.bd
     # This function checks for that condition and does the move
-    def _check_for_version_066_migration_and_perform(self):
+    def _check_for_version_066_migration_and_perform(self) -> None:
         old_conn_string = "sqlite://" + urljoin(urlparse(self._conn_string).path, "../runs.db")
         path_to_old_db = urlparse(old_conn_string).path
         # sqlite URLs look like `sqlite:///foo/bar/baz on Unix/Mac` but on Windows they look like
@@ -152,7 +162,7 @@ class SqliteRunStorage(SqlRunStorage, ConfigurableClass):
                 self.add_run(run)
             os.unlink(path_to_old_db)
 
-    def delete_run(self, run_id):
+    def delete_run(self, run_id: str) -> None:
         """Override the default sql delete run implementation until we can get full
         support on cascading deletes.
         """
@@ -163,7 +173,7 @@ class SqliteRunStorage(SqlRunStorage, ConfigurableClass):
             conn.execute(remove_tags)
             conn.execute(remove_run)
 
-    def alembic_version(self):
+    def alembic_version(self) -> AlembicVersion:
         alembic_config = get_alembic_config(__file__)
         with self.connect() as conn:
             return check_alembic_revision(alembic_config, conn)
