@@ -1,10 +1,13 @@
-from typing import Callable, Mapping
+from typing import Callable, Mapping, Optional
 
 import sqlalchemy as db
+import sqlalchemy.exc as db_exc
 from tqdm import tqdm
 
 from dagster._core.scheduler.instigation import InstigatorState
+from dagster._core.storage.schedules.base import ScheduleStorage
 from dagster._serdes import deserialize_as
+from dagster._utils import PrintFn
 
 from ..schedules.schema import InstigatorsTable, JobTable, JobTickTable
 
@@ -19,16 +22,17 @@ OPTIONAL_SCHEDULE_DATA_MIGRATIONS: Mapping[str, Callable] = {
 }
 
 
-def add_selector_id_to_jobs_table(storage, print_fn=None):
+def add_selector_id_to_jobs_table(
+    storage: ScheduleStorage, print_fn: Optional[PrintFn] = None
+) -> None:
     """
     Utility method that calculates the selector_id for each stored instigator state, and writes
     it to the jobs table.
     """
-
     if print_fn:
         print_fn("Querying storage.")
 
-    with storage.connect() as conn:
+    with storage.connect() as conn:  # type: ignore
         rows = conn.execute(
             db.select(
                 [
@@ -40,7 +44,9 @@ def add_selector_id_to_jobs_table(storage, print_fn=None):
             ).order_by(JobTable.c.id.asc())
         ).fetchall()
 
-        for (row_id, state_str, create_timestamp, update_timestamp) in tqdm(rows):
+        rows_progress = tqdm(rows) if print_fn else rows
+
+        for row_id, state_str, create_timestamp, update_timestamp in rows_progress:
             state = deserialize_as(state_str, InstigatorState)
             selector_id = state.selector_id
 
@@ -58,7 +64,7 @@ def add_selector_id_to_jobs_table(storage, print_fn=None):
                         update_timestamp=update_timestamp,
                     )
                 )
-            except db.exc.IntegrityError:
+            except db_exc.IntegrityError:
                 conn.execute(
                     InstigatorsTable.update()
                     .where(InstigatorsTable.c.selector_id == selector_id)
@@ -82,19 +88,22 @@ def add_selector_id_to_jobs_table(storage, print_fn=None):
         print_fn("Complete.")
 
 
-def add_selector_id_to_ticks_table(storage, print_fn=None):
+def add_selector_id_to_ticks_table(
+    storage: ScheduleStorage, print_fn: Optional[PrintFn] = None
+) -> None:
     """
     Utility method that calculates the selector_id for each stored instigator state, and writes
     it to the jobs table.
     """
-
     if print_fn:
         print_fn("Querying storage.")
 
     instigator_states = storage.all_instigator_state()
-    for state in tqdm(instigator_states):
 
-        with storage.connect() as conn:
+    states = tqdm(instigator_states) if print_fn else instigator_states
+
+    for state in states:
+        with storage.connect() as conn:  # type: ignore
             conn.execute(
                 JobTickTable.update()  # pylint: disable=no-value-for-parameter
                 .where(JobTickTable.c.job_origin_id == state.instigator_origin_id)
