@@ -1,10 +1,21 @@
 from abc import abstractmethod
 from collections import defaultdict
 from datetime import datetime
-from typing import Callable, Iterable, Mapping, Optional, Sequence, cast
+from typing import (
+    Any,
+    Callable,
+    ContextManager,
+    Iterable,
+    Mapping,
+    Optional,
+    Sequence,
+    cast,
+)
 
 import pendulum
 import sqlalchemy as db
+import sqlalchemy.exc as db_exc
+from sqlalchemy.engine import Connection
 
 import dagster._check as check
 from dagster._core.definitions.run_request import InstigatorType
@@ -15,8 +26,9 @@ from dagster._core.scheduler.instigation import (
     TickData,
     TickStatus,
 )
+from dagster._core.storage.sql import SqlAlchemyQuery, SqlAlchemyRow
 from dagster._serdes import deserialize_json_to_dagster_namedtuple, serialize_dagster_namedtuple
-from dagster._utils import utc_datetime_from_timestamp
+from dagster._utils import PrintFn, utc_datetime_from_timestamp
 
 from .base import ScheduleStorage
 from .migration import (
@@ -32,10 +44,10 @@ class SqlScheduleStorage(ScheduleStorage):
     """Base class for SQL backed schedule storage."""
 
     @abstractmethod
-    def connect(self):
+    def connect(self) -> ContextManager[Connection]:
         """Context manager yielding a sqlalchemy.engine.Connection."""
 
-    def execute(self, query):
+    def execute(self, query: SqlAlchemyQuery) -> Sequence[SqlAlchemyRow]:
         with self.connect() as conn:
             result_proxy = conn.execute(query)
             res = result_proxy.fetchall()
@@ -43,12 +55,15 @@ class SqlScheduleStorage(ScheduleStorage):
 
         return res
 
-    def _deserialize_rows(self, rows):
+    def _deserialize_rows(self, rows: Sequence[SqlAlchemyRow]) -> Sequence[object]:
         return list(map(lambda r: deserialize_json_to_dagster_namedtuple(r[0]), rows))
 
     def all_instigator_state(
-        self, repository_origin_id=None, repository_selector_id=None, instigator_type=None
-    ):
+        self,
+        repository_origin_id: Optional[str] = None,
+        repository_selector_id: Optional[str] = None,
+        instigator_type: Optional[InstigatorType] = None,
+    ) -> Sequence[InstigatorState]:
         check.opt_inst_param(instigator_type, "instigator_type", InstigatorType)
 
         if self.has_instigators_table() and self.has_built_index(SCHEDULE_JOBS_SELECTOR_ID):
@@ -67,9 +82,9 @@ class SqlScheduleStorage(ScheduleStorage):
                 query = query.where(JobTable.c.job_type == instigator_type.value)
 
         rows = self.execute(query)
-        return self._deserialize_rows(rows)
+        return [cast(InstigatorState, r) for r in self._deserialize_rows(rows)]
 
-    def get_instigator_state(self, origin_id, selector_id):
+    def get_instigator_state(self, origin_id: str, selector_id: str) -> Optional[InstigatorState]:
         check.str_param(origin_id, "origin_id")
         check.str_param(selector_id, "selector_id")
 
@@ -87,9 +102,9 @@ class SqlScheduleStorage(ScheduleStorage):
             )
 
         rows = self.execute(query)
-        return self._deserialize_rows(rows[:1])[0] if len(rows) else None
+        return cast(InstigatorState, self._deserialize_rows(rows[:1])[0]) if len(rows) else None
 
-    def _has_instigator_state_by_selector(self, selector_id):
+    def _has_instigator_state_by_selector(self, selector_id: str) -> bool:
         check.str_param(selector_id, "selector_id")
 
         query = (
@@ -99,9 +114,9 @@ class SqlScheduleStorage(ScheduleStorage):
         )
 
         rows = self.execute(query)
-        return self._deserialize_rows(rows[:1])[0] if len(rows) else None
+        return self._deserialize_rows(rows[:1])[0] if len(rows) else None  # type: ignore
 
-    def _add_or_update_instigators_table(self, conn, state):
+    def _add_or_update_instigators_table(self, conn: Connection, state: InstigatorState) -> None:
         selector_id = state.selector_id
         try:
             conn.execute(
@@ -113,7 +128,7 @@ class SqlScheduleStorage(ScheduleStorage):
                     instigator_body=serialize_dagster_namedtuple(state),
                 )
             )
-        except db.exc.IntegrityError:
+        except db_exc.IntegrityError:
             conn.execute(
                 InstigatorsTable.update()
                 .where(InstigatorsTable.c.selector_id == selector_id)
@@ -125,7 +140,7 @@ class SqlScheduleStorage(ScheduleStorage):
                 )
             )
 
-    def add_instigator_state(self, state) -> InstigatorState:
+    def add_instigator_state(self, state: InstigatorState) -> InstigatorState:
         check.inst_param(state, "state", InstigatorState)
         with self.connect() as conn:
             try:
@@ -138,7 +153,7 @@ class SqlScheduleStorage(ScheduleStorage):
                         job_body=serialize_dagster_namedtuple(state),
                     )
                 )
-            except db.exc.IntegrityError as exc:
+            except db_exc.IntegrityError as exc:
                 raise DagsterInvariantViolationError(
                     f"InstigatorState {state.instigator_origin_id} is already present in storage"
                 ) from exc
@@ -149,7 +164,7 @@ class SqlScheduleStorage(ScheduleStorage):
 
         return state
 
-    def update_instigator_state(self, state) -> InstigatorState:
+    def update_instigator_state(self, state: InstigatorState) -> InstigatorState:
         check.inst_param(state, "state", InstigatorState)
         if not self.get_instigator_state(state.instigator_origin_id, state.selector_id):
             raise DagsterInvariantViolationError(
@@ -177,7 +192,7 @@ class SqlScheduleStorage(ScheduleStorage):
 
         return state
 
-    def delete_instigator_state(self, origin_id, selector_id):
+    def delete_instigator_state(self, origin_id: str, selector_id: str) -> None:
         check.str_param(origin_id, "origin_id")
         check.str_param(selector_id, "selector_id")
 
@@ -201,7 +216,7 @@ class SqlScheduleStorage(ScheduleStorage):
                         )
                     )
 
-    def _jobs_has_selector_state(self, conn, selector_id):
+    def _jobs_has_selector_state(self, conn: Connection, selector_id: str) -> bool:
         query = (
             db.select([db.func.count()])
             .select_from(JobTable)
@@ -210,9 +225,16 @@ class SqlScheduleStorage(ScheduleStorage):
         result = conn.execute(query)
         row = result.fetchone()
         result.close()
-        return row[0] > 0
+        return row[0] > 0  # type: ignore  # (possible none)
 
-    def _add_filter_limit(self, query, before=None, after=None, limit=None, statuses=None):
+    def _add_filter_limit(
+        self,
+        query: SqlAlchemyQuery,
+        before: Optional[float] = None,
+        after: Optional[float] = None,
+        limit: Optional[int] = None,
+        statuses=None,
+    ) -> SqlAlchemyQuery:
         check.opt_float_param(before, "before")
         check.opt_float_param(after, "after")
         check.opt_int_param(limit, "limit")
@@ -229,14 +251,14 @@ class SqlScheduleStorage(ScheduleStorage):
         return query
 
     @property
-    def supports_batch_queries(self):
+    def supports_batch_queries(self) -> bool:
         return self.has_instigators_table() and self.has_built_index(SCHEDULE_TICKS_SELECTOR_ID)
 
-    def has_instigators_table(self):
+    def has_instigators_table(self) -> bool:
         with self.connect() as conn:
             return self._has_instigators_table(conn)
 
-    def _has_instigators_table(self, conn):
+    def _has_instigators_table(self, conn: Connection) -> bool:
         table_names = db.inspect(conn).get_table_names()
         return "instigators" in table_names
 
@@ -291,7 +313,15 @@ class SqlScheduleStorage(ScheduleStorage):
             results[selector_id].append(InstigatorTick(tick_id, tick_data))
         return results
 
-    def get_ticks(self, origin_id, selector_id, before=None, after=None, limit=None, statuses=None):
+    def get_ticks(
+        self,
+        origin_id: str,
+        selector_id: str,
+        before: Optional[float] = None,
+        after: Optional[float] = None,
+        limit: Optional[int] = None,
+        statuses: Optional[Sequence[TickStatus]] = None,
+    ) -> Sequence[InstigatorTick]:
         check.str_param(origin_id, "origin_id")
         check.opt_float_param(before, "before")
         check.opt_float_param(after, "after")
@@ -322,10 +352,10 @@ class SqlScheduleStorage(ScheduleStorage):
 
         rows = self.execute(query)
         return list(
-            map(lambda r: InstigatorTick(r[0], deserialize_json_to_dagster_namedtuple(r[1])), rows)
+            map(lambda r: InstigatorTick(r[0], deserialize_json_to_dagster_namedtuple(r[1])), rows)  # type: ignore
         )
 
-    def create_tick(self, tick_data):
+    def create_tick(self, tick_data: TickData) -> InstigatorTick:
         check.inst_param(tick_data, "tick_data", TickData)
 
         values = {
@@ -346,13 +376,13 @@ class SqlScheduleStorage(ScheduleStorage):
                 result = conn.execute(tick_insert)
                 tick_id = result.inserted_primary_key[0]
                 return InstigatorTick(tick_id, tick_data)
-            except db.exc.IntegrityError as exc:
+            except db_exc.IntegrityError as exc:
                 raise DagsterInvariantViolationError(
                     f"Unable to insert InstigatorTick for job {tick_data.instigator_name} in"
                     " storage"
                 ) from exc
 
-    def update_tick(self, tick):
+    def update_tick(self, tick: InstigatorTick) -> InstigatorTick:
         check.inst_param(tick, "tick", InstigatorTick)
 
         values = {
@@ -373,7 +403,13 @@ class SqlScheduleStorage(ScheduleStorage):
 
         return tick
 
-    def purge_ticks(self, origin_id, selector_id, before, tick_statuses=None):
+    def purge_ticks(
+        self,
+        origin_id: str,
+        selector_id: str,
+        before: float,
+        tick_statuses: Optional[Sequence[TickStatus]] = None,
+    ) -> None:
         check.str_param(origin_id, "origin_id")
         check.float_param(before, "before")
         check.opt_list_param(tick_statuses, "tick_statuses", of_type=TickStatus)
@@ -404,7 +440,7 @@ class SqlScheduleStorage(ScheduleStorage):
         with self.connect() as conn:
             conn.execute(query)
 
-    def wipe(self):
+    def wipe(self) -> None:
         """Clears the schedule storage."""
         with self.connect() as conn:
             # https://stackoverflow.com/a/54386260/324449
@@ -415,7 +451,7 @@ class SqlScheduleStorage(ScheduleStorage):
 
     # MIGRATIONS
 
-    def has_secondary_index_table(self):
+    def has_secondary_index_table(self) -> bool:
         with self.connect() as conn:
             return "secondary_indexes" in db.inspect(conn).get_table_names()
 
@@ -434,7 +470,7 @@ class SqlScheduleStorage(ScheduleStorage):
 
         return len(results) > 0
 
-    def mark_index_built(self, migration_name: str):
+    def mark_index_built(self, migration_name: str) -> None:
         query = (
             SecondaryIndexMigrationTable.insert().values(  # pylint: disable=no-value-for-parameter
                 name=migration_name,
@@ -444,7 +480,7 @@ class SqlScheduleStorage(ScheduleStorage):
         with self.connect() as conn:
             try:
                 conn.execute(query)
-            except db.exc.IntegrityError:
+            except db_exc.IntegrityError:
                 conn.execute(
                     SecondaryIndexMigrationTable.update()  # pylint: disable=no-value-for-parameter
                     .where(SecondaryIndexMigrationTable.c.name == migration_name)
@@ -452,8 +488,11 @@ class SqlScheduleStorage(ScheduleStorage):
                 )
 
     def _execute_data_migrations(
-        self, migrations, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False
-    ):
+        self,
+        migrations: Mapping[str, Callable[..., Any]],
+        print_fn: Optional[Callable] = None,
+        force_rebuild_all: bool = False,
+    ) -> None:
         for migration_name, migration_fn in migrations.items():
             if self.has_built_index(migration_name):
                 if not force_rebuild_all:
@@ -467,12 +506,12 @@ class SqlScheduleStorage(ScheduleStorage):
             if print_fn:
                 print_fn(f"Finished data migration: {migration_name}")
 
-    def migrate(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def migrate(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         self._execute_data_migrations(
             REQUIRED_SCHEDULE_DATA_MIGRATIONS, print_fn, force_rebuild_all
         )
 
-    def optimize(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
+    def optimize(self, print_fn: Optional[PrintFn] = None, force_rebuild_all: bool = False) -> None:
         self._execute_data_migrations(
             OPTIONAL_SCHEDULE_DATA_MIGRATIONS, print_fn, force_rebuild_all
         )
