@@ -1,13 +1,17 @@
 from contextlib import contextmanager
+from typing import Iterator, Optional
 
 from packaging.version import parse
+from sqlalchemy.engine import Connection
 from sqlalchemy.pool import NullPool
 
 from dagster import (
     StringSource,
     _check as check,
 )
+from dagster._config.config_schema import UserConfigSchema
 from dagster._core.storage.sql import (
+    AlembicVersion,
     check_alembic_revision,
     create_engine,
     get_alembic_config,
@@ -27,7 +31,7 @@ MINIMUM_SQLITE_BATCH_VERSION = "3.25.0"
 class SqliteScheduleStorage(SqlScheduleStorage, ConfigurableClass):
     """Local SQLite backed schedule storage."""
 
-    def __init__(self, conn_string, inst_data=None):
+    def __init__(self, conn_string: str, inst_data: Optional[ConfigurableClassData] = None):
         check.str_param(conn_string, "conn_string")
         self._conn_string = conn_string
         self._inst_data = check.opt_inst_param(inst_data, "inst_data", ConfigurableClassData)
@@ -35,19 +39,23 @@ class SqliteScheduleStorage(SqlScheduleStorage, ConfigurableClass):
         super().__init__()
 
     @property
-    def inst_data(self):
+    def inst_data(self) -> Optional[ConfigurableClassData]:
         return self._inst_data
 
     @classmethod
-    def config_type(cls):
+    def config_type(cls) -> UserConfigSchema:
         return {"base_dir": StringSource}
 
     @staticmethod
-    def from_config_value(inst_data, config_value):
+    def from_config_value(
+        inst_data: Optional[ConfigurableClassData], config_value
+    ) -> "SqliteScheduleStorage":
         return SqliteScheduleStorage.from_local(inst_data=inst_data, **config_value)
 
     @classmethod
-    def from_local(cls, base_dir, inst_data=None):
+    def from_local(
+        cls, base_dir: str, inst_data: Optional[ConfigurableClassData] = None
+    ) -> "SqliteScheduleStorage":
         check.str_param(base_dir, "base_dir")
         mkdir_p(base_dir)
         conn_string = create_db_conn_string(base_dir, "schedules")
@@ -71,7 +79,7 @@ class SqliteScheduleStorage(SqlScheduleStorage, ConfigurableClass):
         return schedule_storage
 
     @contextmanager
-    def connect(self):
+    def connect(self) -> Iterator[Connection]:
         engine = create_engine(self._conn_string, poolclass=NullPool)
         conn = engine.connect()
         try:
@@ -80,7 +88,7 @@ class SqliteScheduleStorage(SqlScheduleStorage, ConfigurableClass):
             conn.close()
 
     @property
-    def supports_batch_queries(self):
+    def supports_batch_queries(self) -> bool:
         if not super().supports_batch_queries:
             return False
 
@@ -88,12 +96,12 @@ class SqliteScheduleStorage(SqlScheduleStorage, ConfigurableClass):
             MINIMUM_SQLITE_BATCH_VERSION
         )
 
-    def upgrade(self):
+    def upgrade(self) -> None:
         alembic_config = get_alembic_config(__file__)
         with self.connect() as conn:
             run_alembic_upgrade(alembic_config, conn)
 
-    def alembic_version(self):
+    def alembic_version(self) -> AlembicVersion:
         alembic_config = get_alembic_config(__file__)
         with self.connect() as conn:
             return check_alembic_revision(alembic_config, conn)
