@@ -1,13 +1,16 @@
-# pylint chokes on the perfectly ok import from alembic.migration
 import threading
 from functools import lru_cache
+from typing import Any, Optional, Tuple, Union
 
 import sqlalchemy as db
 from alembic.command import downgrade, stamp, upgrade
 from alembic.config import Config
-from alembic.migration import MigrationContext  # pylint: disable=import-error
+from alembic.runtime.environment import EnvironmentContext
+from alembic.runtime.migration import MigrationContext
 from alembic.script import ScriptDirectory
+from sqlalchemy.engine import Connection
 from sqlalchemy.ext.compiler import compiles
+from typing_extensions import TypeAlias
 
 from dagster._utils import file_relative_path
 from dagster._utils.log import quieten
@@ -17,9 +20,21 @@ create_engine = db.create_engine  # exported
 
 ALEMBIC_SCRIPTS_LOCATION = "dagster:_core/storage/alembic"
 
+# Stand-in for a typed query object, which is only available in sqlalchemy 2+
+SqlAlchemyQuery: TypeAlias = Any
+
+# Stand-in for a typed row object, which is only available in sqlalchemy 2+
+SqlAlchemyRow: TypeAlias = Any
+
+AlembicVersion: TypeAlias = Tuple[Optional[str], Optional[Union[str, Tuple[str, ...]]]]
+
 
 @lru_cache(maxsize=3)  # run, event, and schedule storages
-def get_alembic_config(dunder_file, config_path="alembic/alembic.ini", script_location=None):
+def get_alembic_config(
+    dunder_file: str,
+    config_path: str = "alembic/alembic.ini",
+    script_location: Optional[str] = None,
+) -> Config:
     if not script_location:
         script_location = ALEMBIC_SCRIPTS_LOCATION
 
@@ -28,13 +43,17 @@ def get_alembic_config(dunder_file, config_path="alembic/alembic.ini", script_lo
     return alembic_config
 
 
-def run_alembic_upgrade(alembic_config, conn, run_id=None, rev="head"):
+def run_alembic_upgrade(
+    alembic_config: Config, conn: Connection, run_id: Optional[str] = None, rev: str = "head"
+) -> None:
     alembic_config.attributes["connection"] = conn
     alembic_config.attributes["run_id"] = run_id
     upgrade(alembic_config, rev)
 
 
-def run_alembic_downgrade(alembic_config, conn, rev, run_id=None):
+def run_alembic_downgrade(
+    alembic_config: Config, conn: Connection, rev: str, run_id: Optional[str] = None
+) -> None:
     alembic_config.attributes["connection"] = conn
     alembic_config.attributes["run_id"] = run_id
     downgrade(alembic_config, rev)
@@ -44,13 +63,15 @@ def run_alembic_downgrade(alembic_config, conn, rev, run_id=None):
 _alembic_lock = threading.Lock()
 
 
-def stamp_alembic_rev(alembic_config, conn, rev="head", quiet=True):
+def stamp_alembic_rev(
+    alembic_config: Config, conn: Connection, rev: str = "head", quiet: bool = True
+) -> None:
     with _alembic_lock, quieten(quiet):
         alembic_config.attributes["connection"] = conn
         stamp(alembic_config, rev)
 
 
-def check_alembic_revision(alembic_config, conn):
+def check_alembic_revision(alembic_config: Config, conn: Connection) -> AlembicVersion:
     with _alembic_lock:
         migration_context = MigrationContext.configure(conn)
         db_revision = migration_context.get_current_revision()
@@ -60,7 +81,9 @@ def check_alembic_revision(alembic_config, conn):
     return (db_revision, head_revision)
 
 
-def run_migrations_offline(context, config, target_metadata):
+def run_migrations_offline(
+    context: EnvironmentContext, config: Config, target_metadata: db.MetaData
+) -> None:
     """Run migrations in 'offline' mode.
 
     This configures the context with just a URL
@@ -99,7 +122,9 @@ def run_migrations_offline(context, config, target_metadata):
             raise
 
 
-def run_migrations_online(context, config, target_metadata):
+def run_migrations_online(
+    context: EnvironmentContext, config: Config, target_metadata: db.MetaData
+) -> None:
     """Run migrations in 'online' mode.
 
     In this scenario we need to create an Engine
@@ -141,33 +166,33 @@ MYSQL_FLOAT_PRECISION: int = 32
 
 # datetime issue fix from here: https://stackoverflow.com/questions/29711102/sqlalchemy-mysql-millisecond-or-microsecond-precision/29723278
 @compiles(db.DateTime, "mysql")
-def compile_datetime_and_add_precision_mysql(_element, _compiler, **_kw):
+def compile_datetime_and_add_precision_mysql(_element, _compiler, **_kw) -> str:
     return f"DATETIME({MYSQL_DATE_PRECISION})"
 
 
 class get_current_timestamp(db.sql.expression.FunctionElement):  # pylint: disable=abstract-method
     """Like CURRENT_TIMESTAMP, but has the same semantics on MySQL, Postgres, and Sqlite."""
 
-    type = db.types.DateTime()
+    type = db.types.DateTime()  # type: ignore
 
 
 @compiles(get_current_timestamp, "mysql")
-def compiles_get_current_timestamp_mysql(_element, _compiler, **_kw):
+def compiles_get_current_timestamp_mysql(_element, _compiler, **_kw) -> str:
     return f"CURRENT_TIMESTAMP({MYSQL_DATE_PRECISION})"
 
 
 @compiles(get_current_timestamp)
-def compiles_get_current_timestamp_default(_element, _compiler, **_kw):
+def compiles_get_current_timestamp_default(_element, _compiler, **_kw) -> str:
     return "CURRENT_TIMESTAMP"
 
 
 @compiles(db.types.TIMESTAMP, "mysql")
-def add_precision_to_mysql_timestamps(_element, _compiler, **_kw):
+def add_precision_to_mysql_timestamps(_element, _compiler, **_kw) -> str:
     return f"TIMESTAMP({MYSQL_DATE_PRECISION})"
 
 
 @compiles(db.types.Float, "mysql")
-def add_precision_to_mysql_floats(_element, _compiler, **_kw):
+def add_precision_to_mysql_floats(_element, _compiler, **_kw) -> str:
     """Forces floats to have minimum precision of 32, which converts the underlying type to be a
     double.  This is necessary because the default precision of floats is too low for some types,
     including unix timestamps, resulting in truncated values in MySQL.
@@ -176,7 +201,7 @@ def add_precision_to_mysql_floats(_element, _compiler, **_kw):
 
 
 @compiles(db.types.FLOAT, "mysql")
-def add_precision_to_mysql_FLOAT(_element, _compiler, **_kw):
+def add_precision_to_mysql_FLOAT(_element, _compiler, **_kw) -> str:
     """Forces floats to have minimum precision of 32, which converts the underlying type to be a
     double.  This is necessary because the default precision of floats is too low for some types,
     including unix timestamps, resulting in truncated values in MySQL.
