@@ -1,10 +1,12 @@
 import os
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 
 import yaml
+from typing_extensions import Self, TypedDict
 
 from dagster import _check as check
 from dagster._config import StringSource
+from dagster._config.config_schema import UserConfigSchema
 from dagster._serdes import ConfigurableClass, ConfigurableClassData
 from dagster._utils import mkdir_p
 
@@ -16,16 +18,23 @@ from .runs.sqlite.sqlite_run_storage import SqliteRunStorage
 from .schedules.base import ScheduleStorage
 from .schedules.sqlite.sqlite_schedule_storage import SqliteScheduleStorage
 
+if TYPE_CHECKING:
+    from dagster._core.instance import DagsterInstance
 
-def _runs_directory(base):
+
+class SqliteStorageConfig(TypedDict):
+    base_dir: str
+
+
+def _runs_directory(base: str) -> str:
     return os.path.join(base, "history", "")
 
 
-def _event_logs_directory(base):
+def _event_logs_directory(base: str) -> str:
     return os.path.join(base, "history", "runs", "")
 
 
-def _schedule_directory(base):
+def _schedule_directory(base: str) -> str:
     return os.path.join(base, "schedules")
 
 
@@ -49,7 +58,7 @@ class DagsterSqliteStorage(DagsterStorage, ConfigurableClass):
 
     """
 
-    def __init__(self, base_dir, inst_data=None):
+    def __init__(self, base_dir: str, inst_data: Optional[ConfigurableClassData] = None):
         self.base_dir = check.str_param(base_dir, "base_dir")
         self._run_storage = SqliteRunStorage.from_local(_runs_directory(base_dir))
         self._event_log_storage = SqliteEventLogStorage(_event_logs_directory(base_dir))
@@ -58,29 +67,31 @@ class DagsterSqliteStorage(DagsterStorage, ConfigurableClass):
         super().__init__()
 
     @property
-    def inst_data(self):
+    def inst_data(self) -> Optional[ConfigurableClassData]:
         return self._inst_data
 
     @classmethod
-    def config_type(cls):
+    def config_type(cls) -> UserConfigSchema:
         return {"base_dir": StringSource}
 
     @staticmethod
-    def from_config_value(inst_data, config_value):
+    def from_config_value(
+        inst_data: ConfigurableClassData, config_value: SqliteStorageConfig
+    ) -> "DagsterSqliteStorage":
         return DagsterSqliteStorage.from_local(inst_data=inst_data, **config_value)
 
     @classmethod
-    def from_local(cls, base_dir, inst_data=None):
+    def from_local(cls, base_dir: str, inst_data: Optional[ConfigurableClassData] = None) -> Self:
         check.str_param(base_dir, "base_dir")
         mkdir_p(base_dir)
         return cls(base_dir, inst_data=inst_data)
 
-    def register_instance(self, instance):
-        if not self._run_storage._instance:  # pylint: disable=protected-access
+    def register_instance(self, instance: "DagsterInstance") -> None:
+        if not self._run_storage._instance:
             self._run_storage.register_instance(instance)
-        if not self._event_log_storage._instance:  # pylint: disable=protected-access
+        if not self._event_log_storage._instance:
             self._event_log_storage.register_instance(instance)
-        if not self._schedule_storage._instance:  # pylint: disable=protected-access
+        if not self._schedule_storage._instance:
             self._schedule_storage.register_instance(instance)
 
     @property
@@ -119,7 +130,7 @@ class DagsterSqliteStorage(DagsterStorage, ConfigurableClass):
             yaml.dump({"base_dir": _schedule_directory(self.base_dir)}, default_flow_style=False),
         )
 
-    def dispose(self):
+    def dispose(self) -> None:
         self.event_log_storage.dispose()
         self.run_storage.dispose()
         self.schedule_storage.dispose()
