@@ -75,7 +75,6 @@ def composite_descent(pipeline_def, solids_config, resource_defs):
             SolidConfig objects. It includes an entry for solids at every level of the
             composite tree - i.e. not just leaf solids, but composite solids as well
     """
-
     check.inst_param(pipeline_def, "pipeline_def", PipelineDefinition)
     check.dict_param(solids_config, "solids_config")
     check.dict_param(resource_defs, "resource_defs", key_type=str, value_type=ResourceDefinition)
@@ -116,9 +115,7 @@ def _composite_descent(
 
     This process unrolls recursively as you descend down the tree.
     """
-
-    for solid in parent_stack.current_container.solids:
-
+    for solid in parent_stack.current_container.nodes:
         current_stack = parent_stack.descend(solid)
         current_handle = current_stack.handle
 
@@ -207,12 +204,13 @@ def _apply_top_level_config_mapping(
         # be evaluated against
 
         type_to_evaluate_against = define_solid_dictionary_cls(
-            solids=graph_def.solids,
+            solids=graph_def.nodes,
             ignored_solids=None,
             dependency_structure=graph_def.dependency_structure,
             resource_defs=resource_defs,
             is_using_graph_job_op_apis=is_using_graph_job_op_apis,
             asset_layer=pipeline_def.asset_layer,
+            node_input_source_assets=graph_def.node_input_source_assets,
         )
 
         # process against that new type
@@ -270,13 +268,14 @@ def _get_mapped_solids_dict(
     ignored_solids = graph_def.get_top_level_omitted_nodes() if graph_def.is_subselected else None
 
     type_to_evaluate_against = define_solid_dictionary_cls(
-        solids=graph_def.solids,
+        solids=graph_def.nodes,
         ignored_solids=ignored_solids,
         dependency_structure=graph_def.dependency_structure,
         parent_handle=current_stack.handle,
         resource_defs=resource_defs,
         is_using_graph_job_op_apis=is_using_graph_job_op_apis,
         asset_layer=asset_layer,
+        node_input_source_assets=graph_def.node_input_source_assets,
     )
 
     # process against that new type
@@ -302,9 +301,8 @@ def _get_error_lambda(current_stack):
 
 
 def _get_top_level_error_lambda(pipeline_def):
-    return lambda: (
-        f"The config mapping function on top-level graph {pipeline_def.graph.name} in job "
-        f"{pipeline_def.name} has thrown an unexpected error during its execution."
+    return (
+        lambda: f"The config mapping function on top-level graph {pipeline_def.graph.name} in job {pipeline_def.name} has thrown an unexpected error during its execution."
     )
 
 
