@@ -71,13 +71,6 @@ class OutputsConfig(NamedTuple):
         else:
             return set()
 
-    @property
-    def type_materializer_specs(self) -> Sequence[object]:
-        if isinstance(self.config, list):
-            return self.config
-        else:
-            return []
-
     def get_output_manager_config(self, output_name) -> object:
         if isinstance(self.config, dict):
             return self.config.get(output_name)
@@ -99,7 +92,7 @@ class ResolvedRunConfig(
     NamedTuple(
         "_ResolvedRunConfig",
         [
-            ("solids", Mapping[str, OpConfig]),
+            ("ops", Mapping[str, OpConfig]),
             ("execution", "ExecutionConfig"),
             ("resources", Mapping[str, ResourceConfig]),
             ("loggers", Mapping[str, Mapping[str, object]]),
@@ -111,7 +104,7 @@ class ResolvedRunConfig(
 ):
     def __new__(
         cls,
-        solids: Optional[Mapping[str, OpConfig]] = None,
+        ops: Optional[Mapping[str, OpConfig]] = None,
         execution: Optional["ExecutionConfig"] = None,
         resources: Optional[Mapping[str, ResourceConfig]] = None,
         loggers: Optional[Mapping[str, Mapping[str, object]]] = None,
@@ -130,7 +123,7 @@ class ResolvedRunConfig(
 
         return super(ResolvedRunConfig, cls).__new__(
             cls,
-            solids=check.opt_mapping_param(solids, "solids", key_type=str, value_type=OpConfig),
+            ops=check.opt_mapping_param(ops, "ops", key_type=str, value_type=OpConfig),
             execution=execution,
             resources=resources,
             loggers=check.opt_mapping_param(loggers, "loggers", key_type=str, value_type=Mapping),
@@ -214,9 +207,8 @@ class ResolvedRunConfig(
             pipeline_def, config_value.get(node_key, {}), mode_def.resource_defs
         )
         input_configs = config_value.get("inputs", {})
-
         return ResolvedRunConfig(
-            solids=solid_config_dict,
+            ops=solid_config_dict,
             execution=ExecutionConfig.from_dict(config_mapped_execution_configs),
             loggers=config_mapped_logger_configs,
             original_config_dict=run_config,
@@ -228,15 +220,15 @@ class ResolvedRunConfig(
     def to_dict(self) -> Mapping[str, Mapping[str, object]]:
         env_dict: Dict[str, Mapping[str, object]] = {}
 
-        solid_configs: Dict[str, object] = {}
-        for solid_name, solid_config in self.solids.items():
-            solid_configs[solid_name] = {
-                "config": solid_config.config,
-                "inputs": solid_config.inputs,
-                "outputs": solid_config.outputs.config,
+        op_configs: Dict[str, object] = {}
+        for op_name, op_config in self.ops.items():
+            op_configs[op_name] = {
+                "config": op_config.config,
+                "inputs": op_config.inputs,
+                "outputs": op_config.outputs.config,
             }
 
-        env_dict["solids"] = solid_configs
+        env_dict["ops"] = op_configs
 
         env_dict["execution"] = (
             {self.execution.execution_engine_name: self.execution.execution_engine_config}
