@@ -2,28 +2,24 @@ from __future__ import annotations
 
 import hashlib
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, AbstractSet, Any, Callable, Iterator, Optional, Union, cast
+from typing import TYPE_CHECKING, AbstractSet, Any, Callable, Iterator, Optional, cast
 
 from typing_extensions import TypeAlias
 
 import dagster._check as check
 from dagster._config import ConfigType
 from dagster._core.decorator_utils import get_function_params, validate_expected_params
-from dagster._core.definitions.events import AssetMaterialization, Materialization
 from dagster._core.errors import DagsterInvalidDefinitionError
-from dagster._utils import ensure_gen
 from dagster._utils.backcompat import experimental_arg_warning
 
 from ..definitions.resource_requirement import (
     ResourceRequirement,
     TypeLoaderResourceRequirement,
-    TypeMaterializerResourceRequirement,
 )
 
 if TYPE_CHECKING:
     from dagster._core.execution.context.system import (
         DagsterTypeLoaderContext,
-        DagsterTypeMaterializerContext,
     )
 
 
@@ -69,44 +65,6 @@ class DagsterTypeLoader(ABC):
             )
 
 
-class DagsterTypeMaterializer(ABC):
-    """
-    Dagster type materializers are used to materialize outputs of the dagster type they are attached
-    to.
-
-    The recommended way to define a type loader is with the
-    :py:func:`@dagster_type_materializer <dagster_type_materializer>` decorator.
-    """
-
-    @property
-    @abstractmethod
-    def schema_type(self) -> ConfigType:
-        pass
-
-    @abstractmethod
-    def materialize_runtime_values(
-        self,
-        _context: "DagsterTypeMaterializerContext",
-        _config_value: object,
-        _runtime_value: object,
-    ) -> Iterator[Union[AssetMaterialization, Materialization]]:
-        """
-        How to materialize a runtime value given configuration.
-        """
-
-    def required_resource_keys(self) -> AbstractSet[str]:
-        return frozenset()
-
-    def get_resource_requirements(
-        self, outer_context: Optional[object] = None
-    ) -> Iterator[ResourceRequirement]:
-        type_display_name = cast(str, outer_context)
-        for resource_key in sorted(list(self.required_resource_keys())):
-            yield TypeMaterializerResourceRequirement(
-                key=resource_key, type_display_name=type_display_name
-            )
-
-
 class DagsterTypeLoaderFromDecorator(DagsterTypeLoader):
     def __init__(
         self,
@@ -238,74 +196,7 @@ def dagster_type_loader(
             )
 
         return _create_type_loader_for_decorator(
-            config_type, func, required_resource_keys, loader_version, external_version_fn  # type: ignore  # mypy bug
+            config_type, func, required_resource_keys, loader_version, external_version_fn
         )
 
     return wrapper
-
-
-class DagsterTypeMaterializerForDecorator(DagsterTypeMaterializer):
-    def __init__(self, config_type, func, required_resource_keys):
-        self._config_type = check.inst_param(config_type, "config_type", ConfigType)
-        self._func = check.callable_param(func, "func")
-        self._required_resource_keys = check.opt_set_param(
-            required_resource_keys, "required_resource_keys", of_type=str
-        )
-
-    @property
-    def schema_type(self) -> ConfigType:
-        return self._config_type
-
-    def materialize_runtime_values(
-        self, context: "DagsterTypeMaterializerContext", config_value: object, runtime_value: object
-    ) -> Iterator[Union[Materialization, AssetMaterialization]]:
-        return ensure_gen(self._func(context, config_value, runtime_value))
-
-    def required_resource_keys(self) -> AbstractSet[str]:
-        return frozenset(self._required_resource_keys)
-
-
-def _create_output_materializer_for_decorator(
-    config_type: ConfigType,
-    func: Callable[["DagsterTypeMaterializerContext", object, object], AssetMaterialization],
-    required_resource_keys: Optional[AbstractSet[str]],
-) -> DagsterTypeMaterializerForDecorator:
-    return DagsterTypeMaterializerForDecorator(config_type, func, required_resource_keys)
-
-
-def dagster_type_materializer(
-    config_schema: object, required_resource_keys: Optional[AbstractSet[str]] = None
-) -> Callable[
-    [Callable[["DagsterTypeMaterializerContext", object, object], AssetMaterialization]],
-    DagsterTypeMaterializerForDecorator,
-]:
-    """Create an output materialization hydration config that configurably materializes a runtime
-    value.
-
-    The decorated function should take a :py:class:'dagster.DagsterTypeMaterializerContext`, the parsed config value, and the
-    runtime value. It should materialize the runtime value, and should
-    return an appropriate :py:class:`AssetMaterialization`.
-
-    Args:
-        config_schema (object): The type of the config data expected by the decorated function.
-
-    Examples:
-        .. code-block:: python
-
-            # Takes a list of dicts such as might be read in using csv.DictReader, as well as a config
-            value, and writes
-            @dagster_type_materializer(str)
-            def materialize_df(_context, path, value):
-                with open(path, 'w') as fd:
-                    writer = csv.DictWriter(fd, fieldnames=value[0].keys())
-                    writer.writeheader()
-                    writer.writerows(rowdicts=value)
-
-                return AssetMaterialization.file(path)
-    """
-    from dagster._config import resolve_to_config_type
-
-    config_type = resolve_to_config_type(config_schema)
-    return lambda func: _create_output_materializer_for_decorator(
-        config_type, func, required_resource_keys  # type: ignore
-    )
