@@ -1,8 +1,10 @@
 import dagster._check as check
 from dagster._builtins import Bool, Float, Int, String
 
-from .dagster_type import Any as RuntimeAny
-from .dagster_type import List
+from .dagster_type import (
+    Any as RuntimeAny,
+    List,
+)
 from .python_dict import PythonDict
 from .python_set import PythonSet
 from .python_tuple import PythonTuple
@@ -13,10 +15,10 @@ SUPPORTED_RUNTIME_BUILTINS = {
     float: Float,
     bool: Bool,
     str: String,
-    list: List(RuntimeAny),  # type: ignore
-    tuple: PythonTuple,  # type: ignore
-    set: PythonSet,  # type: ignore
-    dict: PythonDict,  # type: ignore
+    list: List(RuntimeAny),
+    tuple: PythonTuple,
+    set: PythonSet,
+    dict: PythonDict,
 }
 
 
