@@ -5,11 +5,12 @@ import warnings
 from abc import ABC, abstractmethod
 from contextlib import ExitStack
 from itertools import count
-from typing import TYPE_CHECKING, Dict, Mapping, Optional, Sequence, Set, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, Mapping, Optional, Sequence, Set, TypeVar, Union
 
 from typing_extensions import Self
 
 import dagster._check as check
+from dagster._core.definitions.selector import PipelineSelector
 from dagster._core.errors import (
     DagsterRepositoryLocationLoadError,
     DagsterRepositoryLocationNotFoundError,
@@ -20,14 +21,12 @@ from dagster._core.host_representation import (
     ExternalPartitionSet,
     ExternalPipeline,
     GrpcServerRepositoryLocation,
-    PipelineSelector,
     RepositoryHandle,
     RepositoryLocation,
     RepositoryLocationOrigin,
 )
 from dagster._core.host_representation.grpc_server_registry import (
     GrpcServerRegistry,
-    ProcessGrpcServerRegistry,
 )
 from dagster._core.host_representation.grpc_server_state_subscriber import (
     LocationStateChangeEvent,
@@ -61,6 +60,7 @@ if TYPE_CHECKING:
         ExternalPartitionTagsData,
     )
 
+T = TypeVar("T")
 
 DAGIT_GRPC_SERVER_HEARTBEAT_TTL = 45
 
@@ -110,12 +110,12 @@ class BaseWorkspaceRequestContext(IWorkspace):
         pass
 
     @abstractmethod
-    def permissions_for_location(self, location_name: str) -> Mapping[str, PermissionResult]:
+    def permissions_for_location(self, *, location_name: str) -> Mapping[str, PermissionResult]:
         pass
 
     def has_permission_for_location(self, permission: str, location_name: str) -> bool:
         if self.has_repository_location_name(location_name):
-            permissions = self.permissions_for_location(location_name)
+            permissions = self.permissions_for_location(location_name=location_name)
             return permissions[permission].enabled
 
         # if not in workspace, fall back to the global permissions across all code locations
@@ -144,7 +144,7 @@ class BaseWorkspaceRequestContext(IWorkspace):
             return location_entry.repository_location
 
         if location_entry.load_error:
-            error_info = cast(SerializableErrorInfo, location_entry.load_error)
+            error_info = location_entry.load_error
             raise DagsterRepositoryLocationLoadError(
                 f"Failure loading {location_name}: {error_info.to_string()}",
                 load_error_infos=[error_info],
@@ -202,7 +202,7 @@ class BaseWorkspaceRequestContext(IWorkspace):
     def shutdown_repository_location(self, name: str):
         self.process_context.shutdown_repository_location(name)
 
-    def reload_workspace(self) -> Self:  # type: ignore  # fmt: skip
+    def reload_workspace(self) -> Self:
         self.process_context.reload_workspace()
         return self.process_context.create_request_context()
 
@@ -243,7 +243,11 @@ class BaseWorkspaceRequestContext(IWorkspace):
         )
 
     def get_external_partition_config(
-        self, repository_handle: RepositoryHandle, partition_set_name: str, partition_name: str
+        self,
+        repository_handle: RepositoryHandle,
+        partition_set_name: str,
+        partition_name: str,
+        instance: DagsterInstance,
     ) -> Union["ExternalPartitionConfigData", "ExternalPartitionExecutionErrorData"]:
         return self.get_repository_location(
             repository_handle.location_name
@@ -251,10 +255,15 @@ class BaseWorkspaceRequestContext(IWorkspace):
             repository_handle=repository_handle,
             partition_set_name=partition_set_name,
             partition_name=partition_name,
+            instance=instance,
         )
 
     def get_external_partition_tags(
-        self, repository_handle: RepositoryHandle, partition_set_name: str, partition_name: str
+        self,
+        repository_handle: RepositoryHandle,
+        partition_set_name: str,
+        partition_name: str,
+        instance: DagsterInstance,
     ) -> Union["ExternalPartitionTagsData", "ExternalPartitionExecutionErrorData"]:
         return self.get_repository_location(
             repository_handle.location_name
@@ -262,6 +271,7 @@ class BaseWorkspaceRequestContext(IWorkspace):
             repository_handle=repository_handle,
             partition_set_name=partition_set_name,
             partition_name=partition_name,
+            instance=instance,
         )
 
     def get_external_partition_names(
@@ -276,6 +286,7 @@ class BaseWorkspaceRequestContext(IWorkspace):
         repository_handle: RepositoryHandle,
         partition_set_name: str,
         partition_names: Sequence[str],
+        instance: DagsterInstance,
     ) -> Union["ExternalPartitionSetExecutionParamData", "ExternalPartitionExecutionErrorData"]:
         return self.get_repository_location(
             repository_handle.location_name
@@ -283,9 +294,12 @@ class BaseWorkspaceRequestContext(IWorkspace):
             repository_handle=repository_handle,
             partition_set_name=partition_set_name,
             partition_names=partition_names,
+            instance=instance,
         )
 
-    def get_external_notebook_data(self, repository_location_name, notebook_path: str):
+    def get_external_notebook_data(
+        self, repository_location_name: str, notebook_path: str
+    ) -> bytes:
         check.str_param(repository_location_name, "repository_location_name")
         check.str_param(notebook_path, "notebook_path")
         repository_location = self.get_repository_location(repository_location_name)
@@ -317,7 +331,7 @@ class WorkspaceRequestContext(BaseWorkspaceRequestContext):
     def get_workspace_snapshot(self) -> Mapping[str, WorkspaceLocationEntry]:
         return self._workspace_snapshot
 
-    def get_location_entry(self, name) -> Optional[WorkspaceLocationEntry]:
+    def get_location_entry(self, name: str) -> Optional[WorkspaceLocationEntry]:
         return self._workspace_snapshot.get(name)
 
     def get_location_statuses(self) -> Sequence[WorkspaceLocationStatusEntry]:
@@ -342,7 +356,7 @@ class WorkspaceRequestContext(BaseWorkspaceRequestContext):
     def permissions(self) -> Mapping[str, PermissionResult]:
         return get_user_permissions(self._read_only)
 
-    def permissions_for_location(self, location_name: str) -> Mapping[str, PermissionResult]:
+    def permissions_for_location(self, *, location_name: str) -> Mapping[str, PermissionResult]:
         return get_location_scoped_user_permissions(self._read_only)
 
     def has_permission(self, permission: str) -> bool:
@@ -372,12 +386,12 @@ class WorkspaceRequestContext(BaseWorkspaceRequestContext):
 class IWorkspaceProcessContext(ABC):
     """
     Class that stores process-scoped information about a dagit session.
-    In most cases, you will want to create an `BaseWorkspaceRequestContext` to create a request-scoped
+    In most cases, you will want to create a `BaseWorkspaceRequestContext` to create a request-scoped
     object.
     """
 
     @abstractmethod
-    def create_request_context(self, source=None) -> BaseWorkspaceRequestContext:
+    def create_request_context(self, source: Optional[Any] = None) -> BaseWorkspaceRequestContext:
         """
         Create a usable fixed context for the scope of a request.
 
@@ -408,7 +422,7 @@ class IWorkspaceProcessContext(ABC):
     def instance(self) -> DagsterInstance:
         pass
 
-    def __enter__(self):
+    def __enter__(self) -> Self:
         return self
 
     def __exit__(self, exception_type, exception_value, traceback):
@@ -419,9 +433,9 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
     """
     This class is a process-scoped object that:
 
-    1. Maintain an update-to-date dictionary of repository locations
-    1. Create a `WorkspaceRequestContext` to be the workspace for each request
-    2. Run watch thread processes that monitor repository locations
+    1. Maintains an update-to-date dictionary of repository locations
+    2. Creates a `WorkspaceRequestContext` to be the workspace for each request
+    3. Runs watch thread processes that monitor repository locations
 
     To access a RepositoryLocation, you should create a `WorkspaceRequestContext`
     using `create_request_context`.
@@ -433,8 +447,8 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
         workspace_load_target: Optional[WorkspaceLoadTarget],
         version: str = "",
         read_only: bool = False,
-        grpc_server_registry=None,
-        code_server_log_level="INFO",
+        grpc_server_registry: Optional[GrpcServerRegistry] = None,
+        code_server_log_level: str = "INFO",
     ):
         self._stack = ExitStack()
 
@@ -467,7 +481,7 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
             )
         else:
             self._grpc_server_registry = self._stack.enter_context(
-                ProcessGrpcServerRegistry(
+                GrpcServerRegistry(
                     instance=self._instance,
                     reload_interval=0,
                     heartbeat_ttl=DAGIT_GRPC_SERVER_HEARTBEAT_TTL,
@@ -482,7 +496,7 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
         )
 
     @property
-    def workspace_load_target(self):
+    def workspace_load_target(self) -> Optional[WorkspaceLoadTarget]:
         return self._workspace_load_target
 
     @property
@@ -522,18 +536,18 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
             )
 
     @property
-    def instance(self):
+    def instance(self) -> DagsterInstance:
         return self._instance
 
     @property
-    def read_only(self):
+    def read_only(self) -> bool:
         return self._read_only
 
     @property
     def permissions(self) -> Mapping[str, PermissionResult]:
         return get_user_permissions(True)
 
-    def permissions_for_location(self, _location_name: str) -> Mapping[str, PermissionResult]:
+    def permissions_for_location(self, *, location_name: str) -> Mapping[str, PermissionResult]:
         return get_location_scoped_user_permissions(True)
 
     @property
@@ -679,7 +693,7 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
             if entry.repository_location:
                 entry.repository_location.cleanup()
 
-    def create_request_context(self, source=None) -> WorkspaceRequestContext:
+    def create_request_context(self, source: Optional[object] = None) -> WorkspaceRequestContext:
         return WorkspaceRequestContext(
             instance=self._instance,
             workspace_snapshot=self.create_snapshot(),
