@@ -3,11 +3,15 @@ import threading
 import time
 from concurrent.futures import ThreadPoolExecutor, as_completed
 from contextlib import ExitStack
-from typing import Dict, List, Optional
+from typing import Dict, Iterable, List, Optional, Sequence
 
-from dagster import _check as check
+from dagster import (
+    DagsterEvent,
+    DagsterEventType,
+    _check as check,
+)
 from dagster._core.errors import DagsterRepositoryLocationLoadError, DagsterUserCodeUnreachableError
-from dagster._core.events import DagsterEvent, DagsterEventType, EngineEventData
+from dagster._core.events import EngineEventData
 from dagster._core.instance import DagsterInstance
 from dagster._core.launcher import LaunchRunContext
 from dagster._core.run_coordinator.queued_run_coordinator import (
@@ -24,6 +28,7 @@ from dagster._core.storage.tags import PRIORITY_TAG
 from dagster._core.workspace.context import IWorkspaceProcessContext
 from dagster._core.workspace.workspace import IWorkspace
 from dagster._daemon.daemon import IntervalDaemon, TDaemonGenerator
+from dagster._utils import len_iter
 from dagster._utils.error import serializable_error_info_from_exc_info
 from dagster._utils.tags import TagConcurrencyLimitsCounter
 
@@ -190,14 +195,13 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
         in_progress_runs = self._get_in_progress_runs(instance)
 
         max_concurrent_runs_enabled = max_concurrent_runs != -1  # setting to -1 disables the limit
+        max_runs_to_launch = max_concurrent_runs - len_iter(in_progress_runs)
         if max_concurrent_runs_enabled:
-            max_runs_to_launch = max_concurrent_runs - len(in_progress_runs)
-
             # Possibly under 0 if runs were launched without queuing
             if max_runs_to_launch <= 0:
                 self._logger.info(
                     "{} runs are currently in progress. Maximum is {}, won't launch more.".format(
-                        len(in_progress_runs), max_concurrent_runs
+                        len_iter(in_progress_runs), max_concurrent_runs
                     )
                 )
                 return []
@@ -260,10 +264,10 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
         runs = instance.get_runs(filters=queued_runs_filter)[::-1]
         return runs
 
-    def _get_in_progress_runs(self, instance):
+    def _get_in_progress_runs(self, instance: DagsterInstance) -> Iterable[DagsterRun]:
         return instance.get_runs(filters=RunsFilter(statuses=IN_PROGRESS_RUN_STATUSES))
 
-    def _priority_sort(self, runs):
+    def _priority_sort(self, runs: Iterable[DagsterRun]) -> Sequence[DagsterRun]:
         def get_priority(run):
             priority_tag_value = run.tags.get(PRIORITY_TAG, "0")
             try:
@@ -289,7 +293,6 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
         run_queue_config: RunQueueConfig,
         fixed_iteration_time: Optional[float],
     ) -> bool:
-
         # double check that the run is still queued before dequeing
         run = check.not_none(instance.get_run_by_id(run.run_id))
 
@@ -311,7 +314,10 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
 
         if location_name and self._is_location_pausing_dequeues(location_name, now):
             self._logger.info(
-                "Pausing dequeues for runs from code location %s to give its code server time to recover",
+                (
+                    "Pausing dequeues for runs from code location %s to give its code server time"
+                    " to recover"
+                ),
                 location_name,
             )
             return False
@@ -326,9 +332,7 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
         run = check.not_none(instance.get_run_by_id(run.run_id))
 
         try:
-            instance.run_launcher.launch_run(
-                LaunchRunContext(pipeline_run=run, workspace=workspace)
-            )
+            instance.run_launcher.launch_run(LaunchRunContext(dagster_run=run, workspace=workspace))
         except Exception as e:
             error = serializable_error_info_from_exc_info(sys.exc_info())
 
@@ -336,13 +340,13 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
             # Make sure we don't re-enqueue a run if it has already finished or moved into STARTED:
             if run.status not in (DagsterRunStatus.QUEUED, DagsterRunStatus.STARTING):
                 self._logger.info(
-                    f"Run {run.run_id} failed while being dequeued, but has already advanced to {run.status} - moving on. Error: {error.to_string()}"
+                    f"Run {run.run_id} failed while being dequeued, but has already advanced to"
+                    f" {run.status} - moving on. Error: {error.to_string()}"
                 )
                 return False
             elif run_queue_config.max_user_code_failure_retries and isinstance(
                 e, (DagsterUserCodeUnreachableError, DagsterRepositoryLocationLoadError)
             ):
-
                 if location_name:
                     with self._location_timeouts_lock:
                         # Don't try to dequeue runs from this location for another N seconds
@@ -359,7 +363,10 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
                 num_retries_so_far = len(enqueue_event_records) - 1
 
                 if num_retries_so_far >= run_queue_config.max_user_code_failure_retries:
-                    message = f"Run dequeue failed to reach the user code server after {run_queue_config.max_user_code_failure_retries} attempts, failing run"
+                    message = (
+                        "Run dequeue failed to reach the user code server after"
+                        f" {run_queue_config.max_user_code_failure_retries} attempts, failing run"
+                    )
                     message_with_full_error = f"{message}: {error.to_string()}"
                     self._logger.error(message_with_full_error)
                     instance.report_engine_event(
@@ -374,7 +381,10 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
                         run_queue_config.max_user_code_failure_retries - num_retries_so_far
                     )
                     retries_str = "retr" + ("y" if retries_left == 1 else "ies")
-                    message = f"Run dequeue failed to reach the user code server, re-submitting the run into the queue ({retries_left} {retries_str} remaining)"
+                    message = (
+                        "Run dequeue failed to reach the user code server, re-submitting the run"
+                        f" into the queue ({retries_left} {retries_str} remaining)"
+                    )
                     message_with_full_error = f"{message}: {error.to_string()}"
                     self._logger.warning(message_with_full_error)
 
@@ -391,7 +401,10 @@ class QueuedRunCoordinatorDaemon(IntervalDaemon):
                     instance.report_dagster_event(enqueued_event, run_id=run.run_id)
                     return False
             else:
-                message = "Caught an unrecoverable error while dequeuing the run. Marking the run as failed and dropping it from the queue"
+                message = (
+                    "Caught an unrecoverable error while dequeuing the run. Marking the run as"
+                    " failed and dropping it from the queue"
+                )
                 message_with_full_error = f"{message}: {error.to_string()}"
                 self._logger.error(message_with_full_error)
 
