@@ -14,10 +14,10 @@ import pendulum
 import dagster._check as check
 import dagster._seven as seven
 from dagster._core.definitions.run_request import InstigatorType, RunRequest
+from dagster._core.definitions.selector import PipelineSelector
 from dagster._core.definitions.sensor_definition import DefaultSensorStatus, SensorExecutionData
 from dagster._core.definitions.utils import validate_tags
 from dagster._core.errors import DagsterError
-from dagster._core.host_representation import PipelineSelector
 from dagster._core.host_representation.external import ExternalPipeline, ExternalSensor
 from dagster._core.host_representation.external_data import ExternalTargetData
 from dagster._core.host_representation.repository_location import RepositoryLocation
@@ -34,7 +34,7 @@ from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus, Run
 from dagster._core.storage.tags import RUN_KEY_TAG, SENSOR_NAME_TAG
 from dagster._core.telemetry import SENSOR_RUN_CREATED, hash_name, log_action
 from dagster._core.workspace.context import IWorkspaceProcessContext
-from dagster._scheduler.stale import resolve_stale_assets
+from dagster._scheduler.stale import resolve_stale_or_missing_assets
 from dagster._utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
 from dagster._utils.merger import merge_dicts
 
@@ -496,10 +496,7 @@ def _process_tick_generator(
 
     except Exception:
         error_info = serializable_error_info_from_exc_info(sys.exc_info())
-        logger.error(
-            f"Sensor daemon caught an error for sensor {external_sensor.name} :"
-            f" {error_info.to_string()}"
-        )
+        logger.exception(f"Sensor daemon caught an error for sensor {external_sensor.name}")
 
     yield error_info
 
@@ -632,7 +629,7 @@ def _evaluate_sensor(
 
     for run_request in sensor_runtime_data.run_requests:
         if run_request.stale_assets_only:
-            stale_assets = resolve_stale_assets(workspace_process_context, run_request, external_sensor)  # type: ignore
+            stale_assets = resolve_stale_or_missing_assets(workspace_process_context, run_request, external_sensor)  # type: ignore
             # asset selection is empty set after filtering for stale
             if len(stale_assets) == 0:
                 continue
