@@ -11,11 +11,12 @@ from .generate import _should_skip_file
 # Currently we only download from 'master' branch
 DEFAULT_GITHUB_URL = "https://codeload.github.com/dagster-io/dagster/tar.gz/master"
 # Examples aren't that can't be downloaded from the dagster project CLI
-EXAMPLES_TO_IGNORE = ["docs_snippets"]
+EXAMPLES_TO_IGNORE = ["docs_snippets", "experimental"]
 # Hardcoded list of available examples. The list is tested against the examples folder in this mono
 # repo to make sure it's up-to-date.
 AVAILABLE_EXAMPLES = [
     "assets_dbt_python",
+    "assets_dynamic_partitions",
     "assets_modern_data_stack",
     "assets_pandas_pyspark",
     "assets_pandas_type_metadata",
@@ -36,6 +37,7 @@ AVAILABLE_EXAMPLES = [
     "with_great_expectations",
     "with_pyspark",
     "with_pyspark_emr",
+    "with_wandb",
 ]
 
 
