@@ -54,7 +54,7 @@ from .types import ExecuteExternalPipelineArgs
 
 
 class RunInSubprocessComplete:
-    """Sentinel passed over multiprocessing Queue when subprocess is complete"""
+    """Sentinel passed over multiprocessing Queue when subprocess is complete."""
 
 
 class StartRunInSubprocessSuccessful:
@@ -139,8 +139,10 @@ def core_execute_run(
         raise
     except Exception:
         yield instance.report_engine_event(
-            "An exception was thrown during execution that is likely a framework error, "
-            "rather than an error in user code.",
+            (
+                "An exception was thrown during execution that is likely a framework error, "
+                "rather than an error in user code."
+            ),
             pipeline_run,
             EngineEventData.engine_error(serializable_error_info_from_exc_info(sys.exc_info())),
         )
@@ -155,7 +157,6 @@ def _run_in_subprocess(
     subprocess_status_handler,
     run_event_handler,
 ):
-
     start_termination_thread(termination_event)
     try:
         execute_run_args = deserialize_as(serialized_execute_run_args, ExecuteExternalPipelineArgs)
@@ -170,7 +171,8 @@ def _run_in_subprocess(
 
             if not pipeline_run:
                 raise DagsterRunNotFoundError(
-                    "gRPC server could not load run {run_id} in order to execute it. Make sure that the gRPC server has access to your run storage.".format(
+                    "gRPC server could not load run {run_id} in order to execute it. Make sure that"
+                    " the gRPC server has access to your run storage.".format(
                         run_id=execute_run_args.pipeline_run_id
                     ),
                     invalid_run_id=execute_run_args.pipeline_run_id,
@@ -263,14 +265,14 @@ def get_external_schedule_execution(
     repo_def: RepositoryDefinition,
     instance_ref: Optional[InstanceRef],
     schedule_name: str,
-    scheduled_execution_timestamp: float,
-    scheduled_execution_timezone: str,
+    scheduled_execution_timestamp: Optional[float],
+    scheduled_execution_timezone: Optional[str],
 ):
     schedule_def = repo_def.get_schedule_def(schedule_name)
     scheduled_execution_time = (
         pendulum.from_timestamp(
             scheduled_execution_timestamp,
-            tz=scheduled_execution_timezone,
+            tz=check.not_none(scheduled_execution_timezone),
         )
         if scheduled_execution_timestamp
         else None
@@ -282,8 +284,9 @@ def get_external_schedule_execution(
         try:
             with user_code_error_boundary(
                 ScheduleExecutionError,
-                lambda: "Error occurred during the execution function for schedule "
-                "{schedule_name}".format(schedule_name=schedule_def.name),
+                lambda: "Error occurred during the execution function for schedule {schedule_name}".format(
+                    schedule_name=schedule_def.name
+                ),
             ):
                 return schedule_def.evaluate_tick(schedule_context)
         except Exception:
@@ -318,8 +321,9 @@ def get_external_sensor_execution(
         try:
             with user_code_error_boundary(
                 SensorExecutionError,
-                lambda: "Error occurred during the execution of evaluation_fn for sensor "
-                "{sensor_name}".format(sensor_name=sensor_def.name),
+                lambda: "Error occurred during the execution of evaluation_fn for sensor {sensor_name}".format(
+                    sensor_name=sensor_def.name
+                ),
             ):
                 return sensor_def.evaluate_tick(sensor_context)
         except Exception:
@@ -332,15 +336,14 @@ def get_partition_config(
     repo_def: RepositoryDefinition,
     partition_set_name: str,
     partition_name: str,
+    instance: Optional[DagsterInstance] = None,
 ):
-
     partition_set_def = repo_def.get_partition_set_def(partition_set_name)
-    partition = partition_set_def.get_partition(partition_name)
+    partition = partition_set_def.get_partition(partition_name, instance)
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: "Error occurred during the evaluation of the `run_config_for_partition` "
-            "function for partition set {partition_set_name}".format(
+            lambda: "Error occurred during the evaluation of the `run_config_for_partition` function for partition set {partition_set_name}".format(
                 partition_set_name=partition_set_def.name
             ),
         ):
@@ -367,8 +370,7 @@ def get_partition_names(
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: f"Error occurred during the execution of the partition generation function for "
-            f"{_get_target_for_partition_execution_error(partition_set_def)}",
+            lambda: f"Error occurred during the execution of the partition generation function for {_get_target_for_partition_execution_error(partition_set_def)}",
         ):
             return ExternalPartitionNamesData(
                 partition_names=partition_set_def.get_partition_names()
@@ -383,14 +385,15 @@ def get_partition_tags(
     repo_def: RepositoryDefinition,
     partition_set_name: str,
     partition_name: str,
+    instance: Optional[DagsterInstance] = None,
 ):
     partition_set_def = repo_def.get_partition_set_def(partition_set_name)
-    partition = partition_set_def.get_partition(partition_name)
+
+    partition = partition_set_def.get_partition(partition_name, dynamic_partitions_store=instance)
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: "Error occurred during the evaluation of the `tags_for_partition` function for "
-            f"{_get_target_for_partition_execution_error(partition_set_def)}",
+            lambda: f"Error occurred during the evaluation of the `tags_for_partition` function for {_get_target_for_partition_execution_error(partition_set_def)}",
         ):
             tags = partition_set_def.tags_for_partition(partition)
             return ExternalPartitionTagsData(name=partition.name, tags=tags)
@@ -434,15 +437,15 @@ def get_partition_set_execution_param_data(
     repo_definition: RepositoryDefinition,
     partition_set_name: str,
     partition_names: Sequence[str],
+    instance: Optional[DagsterInstance] = None,
 ) -> Union[ExternalPartitionSetExecutionParamData, ExternalPartitionExecutionErrorData]:
     partition_set_def = repo_definition.get_partition_set_def(partition_set_name)
     try:
         with user_code_error_boundary(
             PartitionExecutionError,
-            lambda: "Error occurred during the partition generation for "
-            f"{_get_target_for_partition_execution_error(partition_set_def)}",
+            lambda: f"Error occurred during the partition generation for {_get_target_for_partition_execution_error(partition_set_def)}",
         ):
-            all_partitions = partition_set_def.get_partitions()
+            all_partitions = partition_set_def.get_partitions(dynamic_partitions_store=instance)
         partitions = [
             partition for partition in all_partitions if partition.name in partition_names
         ]
@@ -451,9 +454,8 @@ def get_partition_set_execution_param_data(
         for partition in partitions:
 
             def _error_message_fn(partition_name):
-                return lambda: (
-                    "Error occurred during the partition config and tag generation for "
-                    f"'{partition_name}' in {_get_target_for_partition_execution_error(partition_set_def)}"
+                return (
+                    lambda: f"Error occurred during the partition config and tag generation for '{partition_name}' in {_get_target_for_partition_execution_error(partition_set_def)}"
                 )
 
             with user_code_error_boundary(
@@ -483,7 +485,8 @@ def get_notebook_data(notebook_path):
 
     if not notebook_path.endswith(".ipynb"):
         raise Exception(
-            "unexpected file extension for notebooks. Please provide a path that ends with '.ipynb'."
+            "unexpected file extension for notebooks. Please provide a path that ends with"
+            " '.ipynb'."
         )
 
     with open(os.path.abspath(notebook_path), "rb") as f:
