@@ -9,6 +9,7 @@ import threading
 import time
 import uuid
 from concurrent.futures import ThreadPoolExecutor
+from contextlib import nullcontext
 from multiprocessing.synchronize import Event as MPEvent
 from subprocess import Popen
 from threading import Event as ThreadingEventType
@@ -31,6 +32,7 @@ from dagster._core.host_representation.external_data import (
 )
 from dagster._core.host_representation.origin import ExternalRepositoryOrigin
 from dagster._core.instance import DagsterInstance, InstanceRef
+from dagster._core.libraries import DagsterLibraryRegistry
 from dagster._core.origin import DEFAULT_DAGSTER_ENTRY_POINT, get_python_environment_entry_point
 from dagster._core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster._core.workspace.autodiscovery import LoadableTarget
@@ -236,7 +238,7 @@ class DagsterApiServer(DagsterApiServicer):
         self._serializable_load_error = None
 
         self._entry_point = (
-            frozenlist(check.sequence_param(entry_point, "entry_point", of_type=str))  # type: ignore
+            frozenlist(check.sequence_param(entry_point, "entry_point", of_type=str))
             if entry_point is not None
             else DEFAULT_DAGSTER_ENTRY_POINT
         )
@@ -244,6 +246,15 @@ class DagsterApiServer(DagsterApiServicer):
         self._container_image = check.opt_str_param(container_image, "container_image")
         self._container_context = check.opt_dict_param(container_context, "container_context")
 
+        # When will this be set in a gRPC server?
+        #  - When running `dagster dev` (or `dagit`) in the gRPC server subprocesses that are spun up
+        #  - When running code in Dagster Cloud on 1.1 or later
+        # When will it not be set?
+        #  - When running your own grpc server with `dagster api grpc`
+        #  - When using an integration that spins up gRPC servers (for example, the Dagster Helm
+        #    chart or the deploy_docker example)
+        self._instance_ref = check.opt_inst_param(instance_ref, "instance_ref", InstanceRef)
+
         try:
             if inject_env_vars_from_instance:
                 # If arguments indicate it wants to load env vars, use the passed-in instance
@@ -352,23 +363,23 @@ class DagsterApiServer(DagsterApiServicer):
             )
         return loaded_repos.definitions_by_name[external_repo_origin.repository_name]
 
-    def Ping(self, request, _context) -> api_pb2.PingReply:  # type: ignore  # fmt: skip
+    def Ping(self, request, _context) -> api_pb2.PingReply:  # type: ignore
         echo = request.echo
-        return api_pb2.PingReply(echo=echo)
+        return api_pb2.PingReply(echo=echo)  # type: ignore
 
-    def StreamingPing(self, request, _context) -> Iterator[api_pb2.StreamingPingEvent]:  # type: ignore  # fmt: skip
+    def StreamingPing(self, request, _context) -> Iterator[api_pb2.StreamingPingEvent]:  # type: ignore
         sequence_length = request.sequence_length
         echo = request.echo
         for sequence_number in range(sequence_length):
-            yield api_pb2.StreamingPingEvent(sequence_number=sequence_number, echo=echo)
+            yield api_pb2.StreamingPingEvent(sequence_number=sequence_number, echo=echo)  # type: ignore
 
-    def Heartbeat(self, request, _context) -> api_pb2.PingReply:  # type: ignore  # fmt: skip
+    def Heartbeat(self, request, _context) -> api_pb2.PingReply:  # type: ignore
         self.__last_heartbeat_time = time.time()
         echo = request.echo
-        return api_pb2.PingReply(echo=echo)
+        return api_pb2.PingReply(echo=echo)  # type: ignore
 
-    def GetServerId(self, _request, _context) -> api_pb2.GetServerIdReply:  # type: ignore  # fmt: skip
-        return api_pb2.GetServerIdReply(server_id=self._server_id)
+    def GetServerId(self, _request, _context) -> api_pb2.GetServerIdReply:  # type:ignore
+        return api_pb2.GetServerIdReply(server_id=self._server_id)  # type: ignore
 
     def ExecutionPlanSnapshot(self, request, _context):
         execution_plan_args = deserialize_as(
@@ -389,11 +400,9 @@ class DagsterApiServer(DagsterApiServicer):
             )
         )
 
-    def ListRepositories(
-        self, request, _context
-    ) -> api_pb2.ListRepositoriesReply:  # type: ignore  # fmt: skip
+    def ListRepositories(self, request, _context) -> api_pb2.ListRepositoriesReply:  # type: ignore
         if self._serializable_load_error:
-            return api_pb2.ListRepositoriesReply(
+            return api_pb2.ListRepositoriesReply(  # type: ignore
                 serialized_list_repositories_response_or_error=serialize_dagster_namedtuple(
                     self._serializable_load_error
                 )
@@ -408,20 +417,19 @@ class DagsterApiServer(DagsterApiServicer):
             entry_point=self._entry_point,
             container_image=self._container_image,
             container_context=self._container_context,
+            dagster_library_versions=DagsterLibraryRegistry.get(),
         )
 
-        return api_pb2.ListRepositoriesReply(
+        return api_pb2.ListRepositoriesReply(  # type: ignore
             serialized_list_repositories_response_or_error=serialize_dagster_namedtuple(response)
         )
 
-    def ExternalPartitionNames(
-        self, request, _context
-    ) -> api_pb2.ExternalPartitionNamesReply:  # type: ignore  # fmt: skip
+    def ExternalPartitionNames(self, request, _context) -> api_pb2.ExternalPartitionNamesReply:  # type: ignore
         partition_names_args = deserialize_as(
             request.serialized_partition_names_args,
             PartitionNamesArgs,
         )
-        return api_pb2.ExternalPartitionNamesReply(
+        return api_pb2.ExternalPartitionNamesReply(  # type: ignore
             serialized_external_partition_names_or_external_partition_execution_error=serialize_dagster_namedtuple(
                 get_partition_names(
                     self._get_repo_for_origin(partition_names_args.repository_origin),
@@ -430,12 +438,10 @@ class DagsterApiServer(DagsterApiServicer):
             )
         )
 
-    def ExternalNotebookData(
-        self, request, _context
-    ) -> api_pb2.ExternalNotebookDataReply:  # type: ignore  # fmt: skip
+    def ExternalNotebookData(self, request, _context) -> api_pb2.ExternalNotebookDataReply:  # type: ignore
         notebook_path = request.notebook_path
         check.str_param(notebook_path, "notebook_path")
-        return api_pb2.ExternalNotebookDataReply(content=get_notebook_data(notebook_path))
+        return api_pb2.ExternalNotebookDataReply(content=get_notebook_data(notebook_path))  # type: ignore
 
     def ExternalPartitionSetExecutionParams(self, request, _context):
         args = deserialize_as(
@@ -443,53 +449,69 @@ class DagsterApiServer(DagsterApiServicer):
             PartitionSetExecutionParamArgs,
         )
 
-        serialized_data = serialize_dagster_namedtuple(
-            get_partition_set_execution_param_data(
-                self._get_repo_for_origin(args.repository_origin),
-                partition_set_name=args.partition_set_name,
-                partition_names=args.partition_names,
+        instance_ref = args.instance_ref if args.instance_ref else self._instance_ref
+
+        with DagsterInstance.from_ref(instance_ref) if instance_ref else nullcontext() as instance:
+            serialized_data = serialize_dagster_namedtuple(
+                get_partition_set_execution_param_data(
+                    self._get_repo_for_origin(args.repository_origin),
+                    partition_set_name=args.partition_set_name,
+                    partition_names=args.partition_names,
+                    instance=instance,
+                )
             )
-        )
 
         yield from self._split_serialized_data_into_chunk_events(serialized_data)
 
     def ExternalPartitionConfig(self, request, _context):
         args = deserialize_as(request.serialized_partition_args, PartitionArgs)
 
-        return api_pb2.ExternalPartitionConfigReply(
-            serialized_external_partition_config_or_external_partition_execution_error=serialize_dagster_namedtuple(
+        instance_ref = args.instance_ref if args.instance_ref else self._instance_ref
+
+        with DagsterInstance.from_ref(instance_ref) if instance_ref else nullcontext() as instance:
+            serialized_data = serialize_dagster_namedtuple(
                 get_partition_config(
                     self._get_repo_for_origin(args.repository_origin),
                     args.partition_set_name,
                     args.partition_name,
+                    instance=instance,
                 )
             )
+
+        return api_pb2.ExternalPartitionConfigReply(
+            serialized_external_partition_config_or_external_partition_execution_error=serialized_data
         )
 
-    def ExternalPartitionTags(
-        self, request, _context
-    ) -> api_pb2.ExternalPartitionTagsReply:  # type: ignore  # fmt: skip
+    def ExternalPartitionTags(self, request, _context) -> api_pb2.ExternalPartitionTagsReply:  # type: ignore
         partition_args = deserialize_as(request.serialized_partition_args, PartitionArgs)
 
-        return api_pb2.ExternalPartitionTagsReply(
-            serialized_external_partition_tags_or_external_partition_execution_error=serialize_dagster_namedtuple(
+        instance_ref = (
+            partition_args.instance_ref if partition_args.instance_ref else self._instance_ref
+        )
+
+        with DagsterInstance.from_ref(instance_ref) if instance_ref else nullcontext() as instance:
+            serialized_data = serialize_dagster_namedtuple(
                 get_partition_tags(
                     self._get_repo_for_origin(partition_args.repository_origin),
                     partition_args.partition_set_name,
                     partition_args.partition_name,
+                    instance=instance,
                 )
             )
+
+        return api_pb2.ExternalPartitionTagsReply(  # type: ignore
+            serialized_external_partition_tags_or_external_partition_execution_error=serialized_data
         )
 
     def ExternalPipelineSubsetSnapshot(
         self, request: Any, _context
-    ) -> api_pb2.ExternalPipelineSubsetSnapshotReply:  # type: ignore  # fmt: skip
+    ) -> api_pb2.ExternalPipelineSubsetSnapshotReply:  # type: ignore
         pipeline_subset_snapshot_args = deserialize_as(
             request.serialized_pipeline_subset_snapshot_args,
             PipelineSubsetSnapshotArgs,
         )
 
-        return api_pb2.ExternalPipelineSubsetSnapshotReply(
+        return api_pb2.ExternalPipelineSubsetSnapshotReply(  # type: ignore
             serialized_external_pipeline_subset_result=serialize_dagster_namedtuple(
                 get_external_pipeline_subset_result(
                     self._get_repo_for_origin(
@@ -526,9 +548,7 @@ class DagsterApiServer(DagsterApiServicer):
             serialized_external_repository_data=serialized_external_repository_data,
         )
 
-    def ExternalJob(
-        self, request, _context
-    ) -> api_pb2.ExternalJobReply:  # type: ignore  # fmt: skip
+    def ExternalJob(self, request, _context) -> api_pb2.ExternalJobReply:  # type: ignore
         try:
             repository_origin = deserialize_as(
                 request.serialized_repository_origin,
@@ -537,9 +557,9 @@ class DagsterApiServer(DagsterApiServicer):
 
             job_def = self._get_repo_for_origin(repository_origin).get_pipeline(request.job_name)
             ser_job_data = serialize_dagster_namedtuple(external_pipeline_data_from_def(job_def))
-            return api_pb2.ExternalJobReply(serialized_job_data=ser_job_data)
+            return api_pb2.ExternalJobReply(serialized_job_data=ser_job_data)  # type: ignore
         except Exception:
-            return api_pb2.ExternalJobReply(
+            return api_pb2.ExternalJobReply(  # type: ignore
                 serialized_error=serialize_dagster_namedtuple(
                     serializable_error_info_from_exc_info(sys.exc_info())
                 )
@@ -616,16 +636,16 @@ class DagsterApiServer(DagsterApiServicer):
 
         yield from self._split_serialized_data_into_chunk_events(serialized_sensor_data)
 
-    def ShutdownServer(self, request, _context) -> api_pb2.ShutdownServerReply:  # type: ignore  # fmt: skip
+    def ShutdownServer(self, request, _context) -> api_pb2.ShutdownServerReply:  # type: ignore
         try:
             self._shutdown_once_executions_finish_event.set()
-            return api_pb2.ShutdownServerReply(
+            return api_pb2.ShutdownServerReply(  # type: ignore
                 serialized_shutdown_server_result=serialize_dagster_namedtuple(
                     ShutdownServerResult(success=True, serializable_error_info=None)
                 )
             )
         except:
-            return api_pb2.ShutdownServerReply(
+            return api_pb2.ShutdownServerReply(  # type: ignore
                 serialized_shutdown_server_result=serialize_dagster_namedtuple(
                     ShutdownServerResult(
                         success=False,
@@ -664,7 +684,7 @@ class DagsterApiServer(DagsterApiServicer):
             )
         )
 
-    def CanCancelExecution(self, request, _context) -> api_pb2.CanCancelExecutionReply:  # type: ignore  # fmt: skip
+    def CanCancelExecution(self, request, _context) -> api_pb2.CanCancelExecutionReply:  # type: ignore
         can_cancel_execution_request = deserialize_as(
             request.serialized_can_cancel_execution_request,
             CanCancelExecutionRequest,
@@ -675,15 +695,15 @@ class DagsterApiServer(DagsterApiServicer):
                 run_id in self._executions and not self._termination_events[run_id].is_set()
             )
 
-        return api_pb2.CanCancelExecutionReply(
+        return api_pb2.CanCancelExecutionReply(  # type: ignore
             serialized_can_cancel_execution_result=serialize_dagster_namedtuple(
                 CanCancelExecutionResult(can_cancel=can_cancel)
             )
         )
 
-    def StartRun(self, request, _context) -> api_pb2.StartRunReply:  # type: ignore  # fmt: skip
+    def StartRun(self, request, _context) -> api_pb2.StartRunReply:  # type: ignore
         if self._shutdown_once_executions_finish_event.is_set():
-            return api_pb2.StartRunReply(
+            return api_pb2.StartRunReply(  # type: ignore
                 serialized_start_run_result=serialize_dagster_namedtuple(
                     StartRunResult(
                         success=False,
@@ -709,7 +729,7 @@ class DagsterApiServer(DagsterApiServicer):
             )
 
         except:
-            return api_pb2.StartRunReply(
+            return api_pb2.StartRunReply(  # type: ignore
                 serialized_start_run_result=serialize_dagster_namedtuple(
                     StartRunResult(
                         success=False,
@@ -787,7 +807,7 @@ class DagsterApiServer(DagsterApiServicer):
             with self._execution_lock:
                 self._clear_run(run_id)
 
-        return api_pb2.StartRunReply(
+        return api_pb2.StartRunReply(  # type: ignore
             serialized_start_run_result=serialize_dagster_namedtuple(
                 StartRunResult(
                     success=success,
@@ -806,9 +826,9 @@ class DagsterApiServer(DagsterApiServicer):
             )
         )
 
-    def GetCurrentRuns(self, request, context) -> api_pb2.GetCurrentRunsReply:  # type: ignore  # fmt: skip
+    def GetCurrentRuns(self, request, context) -> api_pb2.GetCurrentRunsReply:  # type: ignore
         with self._execution_lock:
-            return api_pb2.GetCurrentRunsReply(
+            return api_pb2.GetCurrentRunsReply(  # type: ignore
                 serialized_current_runs=serialize_dagster_namedtuple(
                     GetCurrentRunsResult(
                         current_runs=list(self._executions.keys()), serializable_error_info=None
@@ -1182,7 +1202,6 @@ class GrpcServerProcess:
     ):
         self.port = None
         self.socket = None
-        self.server_process = None
 
         self.loadable_target_origin = check.opt_inst_param(
             loadable_target_origin, "loadable_target_origin", LoadableTargetOrigin
@@ -1204,7 +1223,7 @@ class GrpcServerProcess:
         )
 
         if seven.IS_WINDOWS or force_port:
-            self.server_process, self.port = _open_server_process_on_dynamic_port(
+            server_process, self.port = _open_server_process_on_dynamic_port(
                 instance_ref=instance_ref,
                 location_name=location_name,
                 max_retries=max_retries,
@@ -1221,7 +1240,7 @@ class GrpcServerProcess:
         else:
             self.socket = safe_tempfile_path_unmanaged()
 
-            self.server_process = open_server_process(
+            server_process = open_server_process(
                 instance_ref=instance_ref,
                 location_name=location_name,
                 port=None,
@@ -1237,8 +1256,10 @@ class GrpcServerProcess:
                 env=env,
             )
 
-        if self.server_process is None:
+        if server_process is None:
             raise CouldNotStartServerProcess(port=self.port, socket=self.socket)
+        else:
+            self.server_process = server_process
 
     @property
     def pid(self):
