@@ -249,7 +249,6 @@ class ExecuteStepArgs(
         Get the command args to run this step. If skip_serialized_namedtuple is True, then get_command_env should
         be used to pass the args to Click using an env var.
         """
-
         return (
             _get_entry_point(self.pipeline_origin)
             + ["api", "execute_step"]
@@ -293,17 +292,19 @@ class ListRepositoriesResponse(
             ("entry_point", Optional[Sequence[str]]),
             ("container_image", Optional[str]),
             ("container_context", Optional[Mapping[str, Any]]),
+            ("dagster_library_versions", Optional[Mapping[str, str]]),
         ],
     )
 ):
     def __new__(
         cls,
-        repository_symbols,
-        executable_path=None,
-        repository_code_pointer_dict=None,
-        entry_point=None,
-        container_image=None,
-        container_context=None,
+        repository_symbols: Sequence[LoadableRepositorySymbol],
+        executable_path: Optional[str] = None,
+        repository_code_pointer_dict: Optional[Mapping[str, CodePointer]] = None,
+        entry_point: Optional[Sequence[str]] = None,
+        container_image: Optional[str] = None,
+        container_context: Optional[Mapping] = None,
+        dagster_library_versions: Optional[Mapping[str, str]] = None,
     ):
         return super(ListRepositoriesResponse, cls).__new__(
             cls,
@@ -311,7 +312,7 @@ class ListRepositoriesResponse(
                 repository_symbols, "repository_symbols", of_type=LoadableRepositorySymbol
             ),
             executable_path=check.opt_str_param(executable_path, "executable_path"),
-            repository_code_pointer_dict=check.opt_dict_param(
+            repository_code_pointer_dict=check.opt_mapping_param(
                 repository_code_pointer_dict,
                 "repository_code_pointer_dict",
                 key_type=str,
@@ -319,15 +320,18 @@ class ListRepositoriesResponse(
             ),
             entry_point=(
                 frozenlist(check.sequence_param(entry_point, "entry_point", of_type=str))
-                if entry_point != None
+                if entry_point is not None
                 else None
             ),
             container_image=check.opt_str_param(container_image, "container_image"),
             container_context=(
                 check.dict_param(container_context, "container_context")
-                if container_context != None
+                if container_context is not None
                 else None
             ),
+            dagster_library_versions=check.opt_nullable_mapping_param(
+                dagster_library_versions, "dagster_library_versions"
+            ),
         )
 
 
@@ -369,6 +373,7 @@ class PartitionArgs(
             ("repository_origin", ExternalRepositoryOrigin),
             ("partition_set_name", str),
             ("partition_name", str),
+            ("instance_ref", Optional[InstanceRef]),
         ],
     )
 ):
@@ -377,6 +382,7 @@ class PartitionArgs(
         repository_origin: ExternalRepositoryOrigin,
         partition_set_name: str,
         partition_name: str,
+        instance_ref: Optional[InstanceRef] = None,
     ):
         return super(PartitionArgs, cls).__new__(
             cls,
@@ -387,6 +393,7 @@ class PartitionArgs(
             ),
             partition_set_name=check.str_param(partition_set_name, "partition_set_name"),
             partition_name=check.str_param(partition_name, "partition_name"),
+            instance_ref=check.opt_inst_param(instance_ref, "instance_ref", InstanceRef),
         )
 
 
@@ -415,6 +422,7 @@ class PartitionSetExecutionParamArgs(
             ("repository_origin", ExternalRepositoryOrigin),
             ("partition_set_name", str),
             ("partition_names", Sequence[str]),
+            ("instance_ref", Optional[InstanceRef]),
         ],
     )
 ):
@@ -423,6 +431,7 @@ class PartitionSetExecutionParamArgs(
         repository_origin: ExternalRepositoryOrigin,
         partition_set_name: str,
         partition_names: Sequence[str],
+        instance_ref: Optional[InstanceRef] = None,
     ):
         return super(PartitionSetExecutionParamArgs, cls).__new__(
             cls,
@@ -431,6 +440,7 @@ class PartitionSetExecutionParamArgs(
             ),
             partition_set_name=check.str_param(partition_set_name, "partition_set_name"),
             partition_names=check.sequence_param(partition_names, "partition_names", of_type=str),
+            instance_ref=check.opt_inst_param(instance_ref, "instance_ref", InstanceRef),
         )
 
 
