@@ -1,6 +1,5 @@
 from dagster._core.definitions import (
     AssetGroup as AssetGroup,
-    DagsterRunMetadataValue as DagsterPipelineRunMetadataValue,  # noqa: F401
     DynamicOutputDefinition as DynamicOutputDefinition,
     InputDefinition as InputDefinition,
     Materialization as Materialization,
@@ -14,11 +13,9 @@ from dagster._core.definitions import (
     daily_schedule as daily_schedule,
     default_executors as default_executors,
     hourly_schedule as hourly_schedule,
-    lambda_solid as lambda_solid,
     monthly_schedule as monthly_schedule,
     pipeline as pipeline,
     schedule_from_partitions as schedule_from_partitions,
-    solid as solid,
     weekly_schedule as weekly_schedule,
 )
 from dagster._core.execution.api import (
@@ -27,7 +24,6 @@ from dagster._core.execution.api import (
     reexecute_pipeline as reexecute_pipeline,
 )
 from dagster._core.execution.context.compute import OpExecutionContext as OpExecutionContext
-from dagster._core.execution.context.invocation import build_solid_context as build_solid_context
 from dagster._core.execution.results import (
     CompositeSolidExecutionResult as CompositeSolidExecutionResult,
     OpExecutionResult as OpExecutionResult,
