@@ -1,27 +1,25 @@
 import importlib
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Any, Dict, Mapping, NamedTuple, Type
+from typing import Any, Dict, Mapping, NamedTuple, Type
 
 import dagster._check as check
+from dagster._config.config_schema import UserConfigSchema
 from dagster._utils import convert_dagster_submodule_name
 from dagster._utils.yaml_utils import load_run_config_yaml
 
 from .serdes import DefaultNamedTupleSerializer, WhitelistMap, whitelist_for_serdes
 
-if TYPE_CHECKING:
-    from dagster._config.config_type import ConfigType
 
-
-class ConfigurableClassDataSerializer(DefaultNamedTupleSerializer):
+class ConfigurableClassDataSerializer(DefaultNamedTupleSerializer["ConfigurableClassData"]):
     @classmethod
     def value_to_storage_dict(
         cls,
-        value: NamedTuple,
+        value: "ConfigurableClassData",
         whitelist_map: WhitelistMap,
         descent_path: str,
     ) -> Dict[str, Any]:
         dct = super().value_to_storage_dict(value, whitelist_map, descent_path)
-        dct["module_name"] = convert_dagster_submodule_name(value.module_name, "public")  # type: ignore
+        dct["module_name"] = convert_dagster_submodule_name(value.module_name, "public")
         return dct
 
 
@@ -141,7 +139,7 @@ class ConfigurableClass(ABC):
 
     @classmethod
     @abstractmethod
-    def config_type(cls) -> "ConfigType":
+    def config_type(cls) -> "UserConfigSchema":
         """dagster.ConfigType: The config type against which to validate a config yaml fragment
         serialized in an instance of ``ConfigurableClassData``.
         """
@@ -149,7 +147,7 @@ class ConfigurableClass(ABC):
 
     @staticmethod
     @abstractmethod
-    def from_config_value(inst_data: Any, config_value: Mapping[str, object]) -> object:
+    def from_config_value(inst_data: Any, config_value: Any) -> object:
         """New up an instance of the ConfigurableClass from a validated config value.
 
         Called by ConfigurableClassData.rehydrate.
@@ -175,7 +173,7 @@ class ConfigurableClass(ABC):
         )
 
 
-def class_from_code_pointer(module_name: str, class_name: str) -> Type[Any]:
+def class_from_code_pointer(module_name: str, class_name: str) -> Type[object]:
     try:
         module = importlib.import_module(module_name)
     except ModuleNotFoundError:
