@@ -22,32 +22,66 @@ from typing import (
     Any,
     Callable,
     Dict,
+    FrozenSet,
+    Generic,
     List,
     Mapping,
     NamedTuple,
     Optional,
+    Sequence,
     Set,
     Tuple,
     Type,
-    TypeVar,
     Union,
     cast,
     overload,
 )
 
+from typing_extensions import Final, TypeAlias, TypeVar
+
 import dagster._check as check
 import dagster._seven as seven
 
 from .errors import DeserializationError, SerdesUsageError, SerializationError
 
+###################################################################################################
+# Types
+###################################################################################################
+
+JsonSerializableValue: TypeAlias = Union[
+    Sequence["JsonSerializableValue"],
+    Mapping[str, "JsonSerializableValue"],
+    str,
+    int,
+    float,
+    bool,
+    None,
+]
+
+PackableValue: TypeAlias = Union[
+    Sequence["PackableValue"],
+    Mapping[str, "PackableValue"],
+    str,
+    int,
+    float,
+    bool,
+    None,
+    # Tuple["PackableValue", ...],
+    NamedTuple,
+    Set["PackableValue"],
+    FrozenSet["PackableValue"],
+    Enum,
+]
+
+
 ###################################################################################################
 # Whitelisting
 ###################################################################################################
 
-TupleEntry = Tuple[
+TupleEntry: TypeAlias = Tuple[
     Optional[Type[NamedTuple]], Type["NamedTupleSerializer"], Mapping[str, Parameter]
 ]
-EnumEntry = Tuple[Type[Enum], Type["EnumSerializer"]]
+EnumEntry: TypeAlias = Tuple[Type[Enum], Type["EnumSerializer"]]
 
 
 class WhitelistMap(NamedTuple):
@@ -70,9 +104,12 @@ class WhitelistMap(NamedTuple):
             nt: The namedtuple class to register.
                 Can be None to gracefull load previously serialized objects as None.
             serializer: The class to use when serializing and deserializing
-            args_for_class: the inspect.signature paramaters for __new__
         """
-        self.tuples[name] = (nt, serializer or DefaultNamedTupleSerializer, args_for_class)
+        self.tuples[name] = (
+            nt,
+            serializer or DefaultNamedTupleSerializer,
+            args_for_class,
+        )
 
     def has_tuple_entry(self, name: str) -> bool:
         return name in self.tuples
@@ -85,7 +122,7 @@ class WhitelistMap(NamedTuple):
         name: str,
         enum: Type[Enum],
         serializer: Optional[Type["EnumSerializer"]],
-    ):
+    ) -> None:
         self.enums[name] = (enum, serializer or DefaultEnumSerializer)
 
     def has_enum_entry(self, name: str) -> bool:
@@ -94,7 +131,7 @@ class WhitelistMap(NamedTuple):
     def get_enum_entry(self, name: str) -> EnumEntry:
         return self.enums[name]
 
-    def register_serialized_name(self, name: str, serialized_name: str):
+    def register_serialized_name(self, name: str, serialized_name: str) -> None:
         self.serialized_names[name] = serialized_name
 
     def has_serialized_name(self, name: str) -> bool:
@@ -113,13 +150,15 @@ class WhitelistMap(NamedTuple):
         return self.deserialized_names[name]
 
     @staticmethod
-    def create():
+    def create() -> "WhitelistMap":
         return WhitelistMap(tuples={}, enums={}, serialized_names={}, deserialized_names={})
 
 
-_WHITELIST_MAP = WhitelistMap.create()
+_WHITELIST_MAP: Final[WhitelistMap] = WhitelistMap.create()
 
-T_Type = TypeVar("T_Type", bound=Type[Any])
+T = TypeVar("T")
+U = TypeVar("U")
+T_Type = TypeVar("T_Type", bound=Type[object])
 
 
 @overload
@@ -145,7 +184,7 @@ def whitelist_for_serdes(
 ) -> Union[T_Type, Callable[[T_Type], T_Type]]:
     """
     Decorator to whitelist a NamedTuple or enum to be serializable. If a `storage_name` is provided
-    for a NamedTuple, then serialized instances of the NamedTuple will be stored with under the
+    for a NamedTuple, then serialized instances of the NamedTuple will be stored under the
     `storage_name` instead of the class name. This is primarily useful for maintaining backwards
     compatibility. If a serialized object undergoes a name change, then setting `storage_name` to
     the old name will (a) allow the object to be deserialized by versions of Dagster prior to the
@@ -165,7 +204,6 @@ def whitelist_for_serdes(
         return _whitelist_for_serdes(whitelist_map=_WHITELIST_MAP)(__cls)
     else:  # decorator passed params
         check.opt_class_param(serializer, "serializer", superclass=Serializer)
-        serializer = cast(Type[Serializer], serializer)
         return _whitelist_for_serdes(
             whitelist_map=_WHITELIST_MAP, serializer=serializer, storage_name=storage_name
         )
@@ -184,11 +222,10 @@ def _whitelist_for_serdes(
         elif issubclass(klass, tuple) and (
             serializer is None or issubclass(serializer, NamedTupleSerializer)
         ):
-            sig_params = signature(klass.__new__).parameters
-            _check_serdes_tuple_class_invariants(klass, sig_params)
-            whitelist_map.register_tuple(
-                klass.__name__, cast(Type[NamedTuple], klass), serializer, sig_params
-            )
+            nt_klass = cast(Type[NamedTuple], klass)
+            sig_params = signature(nt_klass.__new__).parameters
+            _check_serdes_tuple_class_invariants(nt_klass, sig_params)
+            whitelist_map.register_tuple(nt_klass.__name__, nt_klass, serializer, sig_params)
             if storage_name:
                 whitelist_map.register_serialized_name(klass.__name__, storage_name)
                 whitelist_map.register_deserialized_name(storage_name, klass.__name__)
@@ -230,17 +267,20 @@ class DefaultEnumSerializer(EnumSerializer):
         return str(value)
 
 
-class NamedTupleSerializer(Serializer):
+T_NamedTuple = TypeVar("T_NamedTuple", bound=NamedTuple, default=NamedTuple)
+
+
+class NamedTupleSerializer(Serializer, Generic[T_NamedTuple]):
     @classmethod
     @abstractmethod
     def value_from_storage_dict(
         cls,
         storage_dict: Dict[str, Any],
-        klass: Type[Any],
+        klass: Type[T_NamedTuple],
         args_for_class: Mapping[str, Parameter],
         whitelist_map: WhitelistMap,
         descent_path: str,
-    ) -> NamedTuple:
+    ) -> T_NamedTuple:
         """
         Load the target value from the object tree output of json parsing.
 
@@ -257,10 +297,10 @@ class NamedTupleSerializer(Serializer):
     @abstractmethod
     def value_to_storage_dict(
         cls,
-        value: NamedTuple,
+        value: T_NamedTuple,
         whitelist_map: WhitelistMap,
         descent_path: str,
-    ) -> Mapping[str, Any]:
+    ) -> Dict[str, JsonSerializableValue]:
         """
         Transform the object in to a form that can be json serialized.
 
@@ -275,7 +315,7 @@ class NamedTupleSerializer(Serializer):
 EMPTY_VALUES_TO_SKIP: Tuple[None, List[Any], Dict[Any, Any], Set[Any]] = (None, [], {}, set())
 
 
-class DefaultNamedTupleSerializer(NamedTupleSerializer):
+class DefaultNamedTupleSerializer(NamedTupleSerializer[T_NamedTuple]):
     @classmethod
     def skip_when_empty(cls) -> Set[str]:
         # Override this method to leave out certain fields from the serialized namedtuple
@@ -287,11 +327,11 @@ class DefaultNamedTupleSerializer(NamedTupleSerializer):
     def value_from_storage_dict(
         cls,
         storage_dict: Dict[str, Any],
-        klass: Type[Any],
+        klass: Type[T_NamedTuple],
         args_for_class: Mapping[str, Parameter],
         whitelist_map: WhitelistMap,
         descent_path: str,
-    ) -> NamedTuple:
+    ) -> T_NamedTuple:
         # Naively implements backwards compatibility by filtering arguments that aren't present in
         # the constructor. If a property is present in the serialized object, but doesn't exist in
         # the version of the class loaded into memory, that property will be completely ignored.
@@ -306,20 +346,24 @@ class DefaultNamedTupleSerializer(NamedTupleSerializer):
     def value_from_unpacked(
         cls,
         unpacked_dict: Mapping[str, Any],
-        klass: Type[Any],
-    ):
-        return klass(**unpacked_dict)
+        klass: Type[T_NamedTuple],
+    ) -> T_NamedTuple:
+        # False positive type error here due to an eccentricity of `NamedTuple`-- calling `NamedTuple`
+        # directly acts as a class factory, which is not true for `NamedTuple` subclasses (which act
+        # like normal constructors). Because we have no subclass info here, the type checker thinks
+        # we are invoking the class factory and complains about arguments.
+        return cast(T_NamedTuple, klass(**unpacked_dict))  # type: ignore
 
     @classmethod
     def value_to_storage_dict(
         cls,
-        value: NamedTuple,
+        value: T_NamedTuple,
         whitelist_map: WhitelistMap,
         descent_path: str,
-    ) -> Dict[str, Any]:
+    ) -> Dict[str, JsonSerializableValue]:
         skip_when_empty_fields = cls.skip_when_empty()
 
-        base_dict = {}
+        base_dict: Dict[str, JsonSerializableValue] = {}
         for key, inner_value in value._asdict().items():
             if key in skip_when_empty_fields and inner_value in EMPTY_VALUES_TO_SKIP:
                 continue
@@ -340,26 +384,26 @@ class DefaultNamedTupleSerializer(NamedTupleSerializer):
 ###################################################################################################
 
 
-def serialize_dagster_namedtuple(nt: tuple, **json_kwargs) -> str:
+def serialize_dagster_namedtuple(nt: NamedTuple, **json_kwargs: object) -> str:
     """Serialize a whitelisted named tuple to a json encoded string."""
     check.tuple_param(nt, "nt")
     return _serialize_dagster_namedtuple(nt, whitelist_map=_WHITELIST_MAP, **json_kwargs)
 
 
 def _serialize_dagster_namedtuple(
-    nt: Tuple[Any, ...], whitelist_map: WhitelistMap, **json_kwargs
+    nt: NamedTuple, whitelist_map: WhitelistMap, **json_kwargs: object
 ) -> str:
     return seven.json.dumps(pack_inner_value(nt, whitelist_map, _root(nt)), **json_kwargs)
 
 
-def serialize_value(val: Any, whitelist_map: WhitelistMap = _WHITELIST_MAP) -> str:
+def serialize_value(val: PackableValue, whitelist_map: WhitelistMap = _WHITELIST_MAP) -> str:
     """Serialize a value to a json encoded string."""
     return seven.json.dumps(
         pack_inner_value(val, whitelist_map=whitelist_map, descent_path=_root(val))
     )
 
 
-def pack_value(val: Any) -> Any:
+def pack_value(val: PackableValue) -> JsonSerializableValue:
     """
     Transform a value in to a json serializable form.
 
@@ -372,13 +416,16 @@ def pack_value(val: Any) -> Any:
     return pack_inner_value(val, whitelist_map=_WHITELIST_MAP, descent_path=_root(val))
 
 
-def pack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str) -> Any:
+def pack_inner_value(
+    val: PackableValue, whitelist_map: WhitelistMap, descent_path: str
+) -> JsonSerializableValue:
     if isinstance(val, list):
         return [
             pack_inner_value(item, whitelist_map, f"{descent_path}[{idx}]")
             for idx, item in enumerate(val)
         ]
     if isinstance(val, tuple):
+        val = cast(NamedTuple, val)
         klass_name = val.__class__.__name__
         if not whitelist_map.has_tuple_entry(klass_name):
             raise SerializationError(
@@ -387,7 +434,6 @@ def pack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str) -
                     f" {val}.{_path_msg(descent_path)}"
                 ),
             )
-        val = cast(NamedTuple, val)
         _, serializer, _ = whitelist_map.get_tuple_entry(klass_name)
         return serializer.value_to_storage_dict(val, whitelist_map, descent_path)
     if isinstance(val, Enum):
@@ -423,7 +469,8 @@ def pack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str) -
             for key, value in val.items()
         }
 
-    return val
+    # list/dict checks above don't fully cover Sequence/Mapping
+    return val  # type: ignore
 
 
 ###################################################################################################
@@ -433,7 +480,7 @@ def pack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str) -
 
 def deserialize_json_to_dagster_namedtuple(
     json_str: str,
-) -> tuple:
+) -> NamedTuple:
     """Deserialize a json encoded string in to a whitelisted named tuple."""
     with warnings.catch_warnings():
         warnings.simplefilter("ignore", DeprecationWarning)
@@ -448,11 +495,7 @@ def deserialize_json_to_dagster_namedtuple(
             f" {type(dagster_namedtuple)}."
         )
 
-    return dagster_namedtuple
-
-
-T = TypeVar("T")
-U = TypeVar("U")
+    return dagster_namedtuple  # type: ignore  # (tuple check is not NamedTuple check)
 
 
 @overload
@@ -478,12 +521,12 @@ def opt_deserialize_as(json_str: Optional[str], cls: Type[T]) -> Optional[T]:
     return deserialize_as(json_str, cls) if json_str else None
 
 
-def _deserialize_json(json_str: str, whitelist_map: WhitelistMap):
+def _deserialize_json(json_str: str, whitelist_map: WhitelistMap) -> PackableValue:
     value = seven.json.loads(json_str)
     return unpack_inner_value(value, whitelist_map=whitelist_map, descent_path=_root(value))
 
 
-def deserialize_value(val: str, whitelist_map: WhitelistMap = _WHITELIST_MAP) -> Any:
+def deserialize_value(val: str, whitelist_map: WhitelistMap = _WHITELIST_MAP) -> PackableValue:
     """Deserialize a json encoded string in to its original value."""
     return unpack_inner_value(
         seven.json.loads(check.str_param(val, "val")),
@@ -492,7 +535,7 @@ def deserialize_value(val: str, whitelist_map: WhitelistMap = _WHITELIST_MAP) ->
     )
 
 
-def unpack_value(val: Any) -> Any:
+def unpack_value(val: JsonSerializableValue) -> PackableValue:
     """Convert a packed value in to its original form."""
     return unpack_inner_value(
         val,
@@ -501,7 +544,9 @@ def unpack_value(val: Any) -> Any:
     )
 
 
-def unpack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str) -> Any:
+def unpack_inner_value(
+    val: JsonSerializableValue, whitelist_map: WhitelistMap, descent_path: str
+) -> PackableValue:
     if isinstance(val, list):
         return [
             unpack_inner_value(item, whitelist_map, f"{descent_path}[{idx}]")
@@ -536,7 +581,8 @@ def unpack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str)
             val, klass, args_for_class, whitelist_map, descent_path
         )
     if isinstance(val, dict) and val.get("__enum__"):
-        name, member = val["__enum__"].split(".")
+        enum = cast(str, val["__enum__"])
+        name, member = enum.split(".")
         if not whitelist_map.has_enum_entry(name):
             raise DeserializationError(
                 f"Attempted to deserialize enum {name} which was not in the whitelist.\n"
@@ -547,12 +593,12 @@ def unpack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str)
         return enum_serializer.value_from_storage_str(member, enum_class)
     if isinstance(val, dict) and val.get("__set__") is not None:
         set_path = descent_path + "{}"
-        return set([unpack_inner_value(item, whitelist_map, set_path) for item in val["__set__"]])
+        items = cast(List[JsonSerializableValue], val["__set__"])
+        return set([unpack_inner_value(item, whitelist_map, set_path) for item in items])
     if isinstance(val, dict) and val.get("__frozenset__") is not None:
         frz_set_path = descent_path + "{}"
-        return frozenset(
-            [unpack_inner_value(item, whitelist_map, frz_set_path) for item in val["__frozenset__"]]
-        )
+        items = cast(List[JsonSerializableValue], val["__frozenset__"])
+        return frozenset([unpack_inner_value(item, whitelist_map, frz_set_path) for item in items])
     if isinstance(val, dict):
         return {
             key: unpack_inner_value(value, whitelist_map, f"{descent_path}.{key}")
@@ -568,7 +614,7 @@ def unpack_inner_value(val: Any, whitelist_map: WhitelistMap, descent_path: str)
 
 
 def register_serdes_tuple_fallbacks(
-    fallback_map: Mapping[str, Optional[Type]],
+    fallback_map: Mapping[str, Optional[Type[NamedTuple]]],
     whitelist_map: WhitelistMap = _WHITELIST_MAP,
 ) -> None:
     """
@@ -591,7 +637,7 @@ def register_serdes_tuple_fallbacks(
 
 
 def register_serdes_enum_fallbacks(
-    fallback_map: Mapping[str, Optional[Type[Enum]]],
+    fallback_map: Mapping[str, Type[Enum]],
     whitelist_map: WhitelistMap = _WHITELIST_MAP,
 ) -> None:
     """
@@ -614,16 +660,16 @@ def register_serdes_enum_fallbacks(
 ###################################################################################################
 
 
-def _get_dunder_new_params(sig_params):
+def _get_dunder_new_params(sig_params: Any):
     return list(sig_params.values())
 
 
-def _check_serdes_tuple_class_invariants(klass, sig_params):
+def _check_serdes_tuple_class_invariants(klass: Type[NamedTuple], sig_params: Any):
     dunder_new_params = _get_dunder_new_params(sig_params)
 
     cls_param = dunder_new_params[0]
 
-    def _with_header(msg):
+    def _with_header(msg: str) -> str:
         return f"For namedtuple {klass.__name__}: {msg}"
 
     if cls_param.name not in {"cls", "_cls"}:
@@ -681,9 +727,11 @@ def _root(val: Any) -> str:
     return f"<root:{val.__class__.__name__}>"
 
 
-def replace_storage_keys(storage_dict: Dict[str, Any], key_mapping: Mapping[str, str]):
+def replace_storage_keys(
+    storage_dict: Dict[str, Any], key_mapping: Mapping[str, str]
+) -> Dict[str, Any]:
     """Returns a version of the storage dict that replaces all the keys."""
-    result = {}
+    result: Dict[str, Any] = {}
     for key, value in storage_dict.items():
         if key not in key_mapping:
             result[key] = value
