@@ -1,52 +1,31 @@
 import os
 import shutil
 import tempfile
-import uuid
 from collections import defaultdict
 from contextlib import contextmanager
-from typing import (
-    TYPE_CHECKING,
-    AbstractSet,
-    Any,
-    Dict,
-    Generator,
-    Mapping,
-    Optional,
-    Union,
-    overload,
-)
+from typing import TYPE_CHECKING, AbstractSet, Any, Dict, Mapping, Optional, Union, cast, overload
 
 # top-level include is dangerous in terms of incurring circular deps
 from dagster import (
     DagsterInvariantViolationError,
     DependencyDefinition,
-    Failure,
     NodeInvocation,
-    RepositoryDefinition,
-    TypeCheck,
+    _check as check,
 )
-from dagster import _check as check
 from dagster._core.definitions import (
     GraphDefinition,
-    GraphIn,
-    GraphOut,
     InputMapping,
     ModeDefinition,
     OpDefinition,
     OutputMapping,
     PipelineDefinition,
-    ResourceDefinition,
-    lambda_solid,
+    op,
 )
 from dagster._core.definitions.logger_definition import LoggerDefinition
 from dagster._core.definitions.node_definition import NodeDefinition
 from dagster._core.definitions.pipeline_base import InMemoryPipeline
 from dagster._core.definitions.resource_definition import ScopedResourcesBuilder
-from dagster._core.execution.api import (
-    create_execution_plan,
-    execute_pipeline,
-    scoped_pipeline_context,
-)
+from dagster._core.execution.api import create_execution_plan, execute_pipeline
 from dagster._core.execution.context.system import PlanExecutionContext
 from dagster._core.execution.context_creation_pipeline import (
     create_context_creation_data,
@@ -58,25 +37,19 @@ from dagster._core.execution.context_creation_pipeline import (
 from dagster._core.execution.execute_in_process_result import ExecuteInProcessResult
 from dagster._core.instance import DagsterInstance
 from dagster._core.scheduler import Scheduler
-from dagster._core.scheduler.scheduler import DagsterScheduleDoesNotExist, DagsterSchedulerError
-from dagster._core.snap import snapshot_from_execution_plan
-from dagster._core.storage.file_manager import LocalFileManager
 from dagster._core.storage.pipeline_run import DagsterRun
-from dagster._core.types.dagster_type import DagsterType, resolve_dagster_type
 from dagster._core.utility_solids import define_stub_solid
-from dagster._core.utils import make_new_run_id
 from dagster._serdes import ConfigurableClass
 
-# pylint: disable=unused-import
+# re-export
 from ..temp_file import (
-    get_temp_dir,
-    get_temp_file_handle,
-    get_temp_file_handle_with_data,
-    get_temp_file_name,
-    get_temp_file_name_with_data,
-    get_temp_file_names,
+    get_temp_dir as get_temp_dir,
+    get_temp_file_handle as get_temp_file_handle,
+    get_temp_file_handle_with_data as get_temp_file_handle_with_data,
+    get_temp_file_name as get_temp_file_name,
+    get_temp_file_name_with_data as get_temp_file_name_with_data,
+    get_temp_file_names as get_temp_file_names,
 )
-from ..typing_api import is_typing_type
 
 if TYPE_CHECKING:
     from dagster._core.execution.results import CompositeSolidExecutionResult, OpExecutionResult
@@ -153,7 +126,7 @@ def build_pipeline_with_input_stubs(
                 input_value,
             )
             stub_solid_defs.append(stub_solid_def)
-            deps[_dep_key_of(solid)][input_name] = DependencyDefinition(stub_solid_def.name)  # type: ignore
+            deps[_dep_key_of(solid)][input_name] = DependencyDefinition(stub_solid_def.name)
 
     return PipelineDefinition(
         name=pipeline_def.name + "_stubbed",
@@ -275,7 +248,8 @@ def wrap_op_in_graph_and_execute(
     do_output_mapping: bool = True,
 ) -> ExecuteInProcessResult:
     """Run a dagster op in an actual execution.
-    For internal use."""
+    For internal use.
+    """
     return wrap_op_in_graph(
         op_def, tags, do_input_mapping=do_input_mapping, do_output_mapping=do_output_mapping
     ).execute_in_process(
@@ -296,7 +270,6 @@ def execute_solid_within_pipeline(
     tags: Optional[Dict[str, str]] = None,
     instance: Optional[DagsterInstance] = None,
 ) -> Union["CompositeSolidExecutionResult", "OpExecutionResult"]:
-
     """Execute a single solid within an existing pipeline.
 
     Intended to support tests. Input values may be passed directly.
@@ -322,7 +295,6 @@ def execute_solid_within_pipeline(
         Union[CompositeSolidExecutionResult, SolidExecutionResult]: The result of executing the
         solid.
     """
-
     return execute_solids_within_pipeline(
         pipeline_def,
         solid_names={solid_name},
@@ -396,7 +368,7 @@ def execute_solid(
     solid_defs = [solid_def]
 
     def create_value_solid(input_name, input_value):
-        @lambda_solid(name=input_name)
+        @op(name=input_name)
         def input_solid():
             return input_value
 
@@ -452,8 +424,11 @@ class FilesystemTestScheduler(Scheduler, ConfigurableClass):
         return {"base_dir": str}
 
     @staticmethod
-    def from_config_value(inst_data: object, config_value):
-        return FilesystemTestScheduler(artifacts_dir=config_value["base_dir"], inst_data=inst_data)
+    def from_config_value(
+        inst_data: object, config_value: Mapping[str, object]
+    ) -> "FilesystemTestScheduler":
+        artifacts_dir = cast(str, config_value["base_dir"])
+        return FilesystemTestScheduler(artifacts_dir=artifacts_dir, inst_data=inst_data)
 
     def debug_info(self) -> str:
         return ""
